<!--
# Autogenerated from Broadworks XML Schemas
# Do not edit as changes will be overwritten.
# Generated on 2022-03-12T10:21:34.210723
-->
# Responses


## `AuthenticationResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
`AuthenticationRequest()`/Response is 1st stage of the 2 stage OCI login process.


**Attributes:**

|Name               |Type|Description       |
|-------------------|----|------------------|
|user_id            |str |userId            |
|nonce              |str |nonce             |
|password_algorithm |str |passwordAlgorithm |
</div>


## `AuthenticationVerifyResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `AuthenticationVerifyRequest()`

Replaced By: `AuthenticationVerifyResponse14sp8()`

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|user_domain           |str  |userDomain                     |
|last_name             |str  |lastName *Optional*            |
|first_name            |str  |firstName *Optional*           |
</div>


## `AuthenticationVerifyResponse14sp8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `AuthenticationVerifyRequest14sp8()` If a phoneNumber is returned, it will
be the primay DN of the user

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|last_name             |str  |lastName *Optional*            |
|first_name            |str  |firstName *Optional*           |
|user_id               |str  |userId                         |
|phone_number          |str  |phoneNumber *Optional*         |
</div>


## `AuthenticationVerifyResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `AuthenticationVerifyRequest21sp1()` If a phoneNumber is returned, it will
be the primay DN of the user The parameter tokenRevocationTime is represented in the
number of milliseconds since January 1, 1970, 00:00:00 GMT, and it is set to the more
current time between the system level token revocation time and user level token
revocation time.

Replaced by `AuthenticationVerifyResponse22V2()`.

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|last_name             |str  |lastName *Optional*            |
|first_name            |str  |firstName *Optional*           |
|user_id               |str  |userId                         |
|phone_number          |str  |phoneNumber *Optional*         |
|token_revocation_time |int  |tokenRevocationTime *Optional* |
</div>


## `AuthenticationVerifyResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `AuthenticationVerifyRequest22()` If a phoneNumber is returned, it will be
the primary DN of the user Replaced by `AuthenticationVerifyResponse22V2()`.


**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|last_name             |str  |lastName *Optional*            |
|first_name            |str  |firstName *Optional*           |
|user_id               |str  |userId                         |
|phone_number          |str  |phoneNumber *Optional*         |
|reseller_id           |str  |resellerId *Optional*          |
</div>


## `AuthenticationVerifyResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `AuthenticationVerifyRequest22V2()` The following data elements are only
returned in AS data mode: tokenRevocationTime If a phoneNumber is returned, it will be
the primary DN of the user.

The parameter tokenRevocationTime is represented in the number of milliseconds since
January 1, 1970, 00:00:00 GMT, and it is set to the more current time between the
system level token revocation time and user level token revocation time.  Replaced by
`AuthenticationVerifyResponse22V3()`

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|last_name             |str  |lastName *Optional*            |
|first_name            |str  |firstName *Optional*           |
|user_id               |str  |userId                         |
|phone_number          |str  |phoneNumber *Optional*         |
|reseller_id           |str  |resellerId *Optional*          |
|token_revocation_time |int  |tokenRevocationTime *Optional* |
</div>


## `AuthenticationVerifyResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `AuthenticationVerifyRequest22V3()` The following data elements are only
returned in AS data mode: resellerId If a phoneNumber is returned, it will be the
primary DN of the user.

The parameter tokenRevocationTime is represented in the number of milliseconds since
January 1, 1970, 00:00:00 GMT, and it is set to the more current time between the
system level token revocation time and user level token revocation time.  Replaced by
`AuthenticationVerifyResponse22V4()`.

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|last_name             |str  |lastName *Optional*            |
|first_name            |str  |firstName *Optional*           |
|user_id               |str  |userId                         |
|phone_number          |str  |phoneNumber *Optional*         |
|reseller_id           |str  |resellerId *Optional*          |
|token_revocation_time |int  |tokenRevocationTime *Optional* |
</div>


## `AuthenticationVerifyResponse22V4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `AuthenticationVerifyRequest22V4()` The following data elements are only
returned in AS data mode: resellerId If a phoneNumber is returned, it will be the
primary DN of the user.

The parameter tokenRevocationTime is represented in the number of milliseconds since
January 1, 1970, 00:00:00 GMT, and it is set to the more current time between the
system level token revocation time and user level token revocation time.

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|last_name             |str  |lastName *Optional*            |
|first_name            |str  |firstName *Optional*           |
|user_id               |str  |userId                         |
|phone_number          |str  |phoneNumber *Optional*         |
|reseller_id           |str  |resellerId *Optional*          |
|token_revocation_time |int  |tokenRevocationTime *Optional* |
</div>


## `DeviceManagementFileAuthLocationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Return the address and credentials of the File Repository hosting the requested access
device file.

Also return the file name and path on the File Repository.  This is a response to
`DeviceManagementFileAuthLocationGetRequest()`.

**Attributes:**

|Name                                   |Type |Description                                   |
|---------------------------------------|-----|----------------------------------------------|
|file_repository_user_name              |str  |fileRepositoryUserName                        |
|file_repository_password               |str  |fileRepositoryPassword                        |
|net_address                            |str  |netAddress                                    |
|remote_file_format                     |str  |remoteFileFormat                              |
|port_number                            |int  |portNumber *Optional*                         |
|root_directory                         |str  |rootDirectory *Optional*                      |
|cpe_file_directory                     |str  |cpeFileDirectory *Optional*                   |
|secure                                 |bool |secure *Optional*                             |
|mac_in_non_request_uri                 |bool |macInNonRequestURI *Optional*                 |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional*           |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication *Optional*        |
|mac_based_file_authentication          |bool |macBasedFileAuthentication *Optional*         |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication *Optional* |
|completion_notification                |bool |completionNotification *Optional*             |
|file_category                          |str  |fileCategory *Optional*                       |
</div>


## `DeviceManagementFileAuthLocationGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Return the address and credentials of the File Repository hosting the requested access
device file.

Also return the file name and path on the File Repository.  This is a response to
`DeviceManagementFileAuthLocationGetRequest17()`. Replaced by:
`DeviceManagementFileAuthLocationGetRequest18()`

**Attributes:**

|Name                                   |Type |Description                                   |
|---------------------------------------|-----|----------------------------------------------|
|file_repository_user_name              |str  |fileRepositoryUserName                        |
|file_repository_password               |str  |fileRepositoryPassword                        |
|net_address                            |str  |netAddress                                    |
|remote_file_format                     |str  |remoteFileFormat                              |
|port_number                            |int  |portNumber *Optional*                         |
|root_directory                         |str  |rootDirectory *Optional*                      |
|cpe_file_directory                     |str  |cpeFileDirectory *Optional*                   |
|secure                                 |bool |secure *Optional*                             |
|mac_in_non_request_uri                 |bool |macInNonRequestURI *Optional*                 |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional*           |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication *Optional*        |
|mac_based_file_authentication          |bool |macBasedFileAuthentication *Optional*         |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication *Optional* |
|completion_notification                |bool |completionNotification *Optional*             |
|file_category                          |str  |fileCategory *Optional*                       |
</div>


## `DeviceManagementFileAuthLocationGetResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Return the address and credentials of the File Repository hosting the requested access
device file.

Also return the file name and path on the File Repository.  This is a response to
`DeviceManagementFileAuthLocationGetRequest18()`. Replaced by:
`DeviceManagementFileAuthLocationGetResponse21()`.

**Attributes:**

|Name                                   |Type |Description                                   |
|---------------------------------------|-----|----------------------------------------------|
|file_repository_user_name              |str  |fileRepositoryUserName                        |
|file_repository_password               |str  |fileRepositoryPassword                        |
|net_address                            |str  |netAddress                                    |
|remote_file_format                     |str  |remoteFileFormat                              |
|port_number                            |int  |portNumber *Optional*                         |
|root_directory                         |str  |rootDirectory *Optional*                      |
|cpe_file_directory                     |str  |cpeFileDirectory *Optional*                   |
|secure                                 |bool |secure *Optional*                             |
|mac_in_non_request_uri                 |bool |macInNonRequestURI *Optional*                 |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional*           |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication *Optional*        |
|mac_based_file_authentication          |bool |macBasedFileAuthentication *Optional*         |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication *Optional* |
|completion_notification                |bool |completionNotification *Optional*             |
|file_category                          |str  |fileCategory *Optional*                       |
|enable_caching                         |bool |enableCaching *Optional*                      |
</div>


## `DeviceManagementFileAuthLocationGetResponse20sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
This is a response to `DeviceManagementFileAuthLocationGetRequest20sp1()`.

Return the address and credentials of the File Repository hosting the requested access
device file.  Also return the file name and path on the File Repository.  Replaced by:
`DeviceManagementFileAuthLocationGetResponse21sp1()`.

**Attributes:**

|Name                                   |Type |Description                                   |
|---------------------------------------|-----|----------------------------------------------|
|file_repository_user_name              |str  |fileRepositoryUserName                        |
|file_repository_password               |str  |fileRepositoryPassword                        |
|net_address                            |str  |netAddress                                    |
|remote_file_format                     |str  |remoteFileFormat                              |
|port_number                            |int  |portNumber *Optional*                         |
|root_directory                         |str  |rootDirectory *Optional*                      |
|cpe_file_directory                     |str  |cpeFileDirectory *Optional*                   |
|secure                                 |bool |secure *Optional*                             |
|mac_in_non_request_uri                 |bool |macInNonRequestURI *Optional*                 |
|mac_in_cert                            |bool |macInCert *Optional*                          |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional*           |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication *Optional*        |
|mac_based_file_authentication          |bool |macBasedFileAuthentication *Optional*         |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication *Optional* |
|completion_notification                |bool |completionNotification *Optional*             |
|file_category                          |str  |fileCategory *Optional*                       |
|enable_caching                         |bool |enableCaching *Optional*                      |
</div>


## `DeviceManagementFileAuthLocationGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
This is a response to `DeviceManagementFileAuthLocationGetRequest21()`.

Return the address and credentials of the File Repository hosting the requested access
device file.  Also return the file name and path on the File Repository.  Also returns
the status of the file authentication.  Replaced by:
`DeviceManagementFileAuthLocationGetResponse21sp1()`.

**Attributes:**

|Name                                   |Type |Description                                   |
|---------------------------------------|-----|----------------------------------------------|
|status                                 |str  |status *Optional*                             |
|file_repository_user_name              |str  |fileRepositoryUserName                        |
|file_repository_password               |str  |fileRepositoryPassword                        |
|net_address                            |str  |netAddress                                    |
|remote_file_format                     |str  |remoteFileFormat                              |
|port_number                            |int  |portNumber *Optional*                         |
|root_directory                         |str  |rootDirectory *Optional*                      |
|cpe_file_directory                     |str  |cpeFileDirectory *Optional*                   |
|secure                                 |bool |secure *Optional*                             |
|mac_in_non_request_uri                 |bool |macInNonRequestURI *Optional*                 |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional*           |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication *Optional*        |
|mac_based_file_authentication          |bool |macBasedFileAuthentication *Optional*         |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication *Optional* |
|completion_notification                |bool |completionNotification *Optional*             |
|file_category                          |str  |fileCategory *Optional*                       |
|enable_caching                         |bool |enableCaching *Optional*                      |
|notify_file_upload                     |bool |notifyFileUpload *Optional*                   |
</div>


## `DeviceManagementFileAuthLocationGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
This is a response to `DeviceManagementFileAuthLocationGetRequest21sp1()`.

Return the address and credentials of the File Repository hosting the requested access
device file.  Also return the file name and path on the File Repository.  Also returns
the status of the file authentication.

**Attributes:**

|Name                                   |Type |Description                                   |
|---------------------------------------|-----|----------------------------------------------|
|status                                 |str  |status *Optional*                             |
|file_repository_user_name              |str  |fileRepositoryUserName                        |
|file_repository_password               |str  |fileRepositoryPassword                        |
|net_address                            |str  |netAddress                                    |
|remote_file_format                     |str  |remoteFileFormat                              |
|port_number                            |int  |portNumber *Optional*                         |
|root_directory                         |str  |rootDirectory *Optional*                      |
|cpe_file_directory                     |str  |cpeFileDirectory *Optional*                   |
|secure                                 |bool |secure *Optional*                             |
|mac_in_non_request_uri                 |bool |macInNonRequestURI *Optional*                 |
|mac_in_cert                            |bool |macInCert *Optional*                          |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional*           |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication *Optional*        |
|mac_based_file_authentication          |bool |macBasedFileAuthentication *Optional*         |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication *Optional* |
|completion_notification                |bool |completionNotification *Optional*             |
|file_category                          |str  |fileCategory *Optional*                       |
|enable_caching                         |bool |enableCaching *Optional*                      |
|notify_file_upload                     |bool |notifyFileUpload *Optional*                   |
</div>


## `DeviceManagementFileAuthLocationGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
This is a response to `DeviceManagementFileAuthLocationGetRequest22()`.

Return the address and credentials of the File Repository hosting the requested access
device file.  Also return the file name and path on the File Repository.  Also returns
the status of the file authentication.

**Attributes:**

|Name                                   |Type |Description                                   |
|---------------------------------------|-----|----------------------------------------------|
|status                                 |str  |status *Optional*                             |
|file_repository_user_name              |str  |fileRepositoryUserName                        |
|file_repository_password               |str  |fileRepositoryPassword                        |
|net_address                            |str  |netAddress                                    |
|remote_file_format                     |str  |remoteFileFormat                              |
|port_number                            |int  |portNumber *Optional*                         |
|root_directory                         |str  |rootDirectory *Optional*                      |
|cpe_file_directory                     |str  |cpeFileDirectory *Optional*                   |
|secure                                 |bool |secure *Optional*                             |
|mac_in_non_request_uri                 |bool |macInNonRequestURI *Optional*                 |
|mac_in_cert                            |bool |macInCert *Optional*                          |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional*           |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication *Optional*        |
|mac_based_file_authentication          |bool |macBasedFileAuthentication *Optional*         |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication *Optional* |
|completion_notification                |bool |completionNotification *Optional*             |
|file_category                          |str  |fileCategory *Optional*                       |
|enable_caching                         |bool |enableCaching *Optional*                      |
|notify_file_upload                     |bool |notifyFileUpload *Optional*                   |
</div>


## `DeviceManagementFileAuthLocationGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
This is a response to `DeviceManagementFileAuthLocationGetRequest22V2()`.

Return the address and credentials of the File Repository hosting the requested access
device file.  Also return the file name and path on the File Repository.  Also returns
the status of the file authentication.

**Attributes:**

|Name                                   |Type |Description                                   |
|---------------------------------------|-----|----------------------------------------------|
|status                                 |str  |status *Optional*                             |
|file_repository_user_name              |str  |fileRepositoryUserName                        |
|file_repository_password               |str  |fileRepositoryPassword                        |
|net_address                            |str  |netAddress                                    |
|remote_file_format                     |str  |remoteFileFormat                              |
|port_number                            |int  |portNumber *Optional*                         |
|root_directory                         |str  |rootDirectory *Optional*                      |
|cpe_file_directory                     |str  |cpeFileDirectory *Optional*                   |
|secure                                 |bool |secure *Optional*                             |
|mac_in_non_request_uri                 |bool |macInNonRequestURI *Optional*                 |
|mac_in_cert                            |bool |macInCert *Optional*                          |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional*           |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication *Optional*        |
|mac_based_file_authentication          |bool |macBasedFileAuthentication *Optional*         |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication *Optional* |
|completion_notification                |bool |completionNotification *Optional*             |
|file_category                          |str  |fileCategory *Optional*                       |
|enable_caching                         |bool |enableCaching *Optional*                      |
|notify_file_upload                     |bool |notifyFileUpload *Optional*                   |
</div>


## `DeviceManagementFileAuthLocationGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
This is a response to `DeviceManagementFileAuthLocationGetRequest22V3()`.

Return the address and credentials of the File Repository hosting the requested access
device file.  Also return the file name and path on the File Repository.  Also returns
the status of the file authentication.

**Attributes:**

|Name                                   |Type |Description                                   |
|---------------------------------------|-----|----------------------------------------------|
|status                                 |str  |status *Optional*                             |
|file_repository_user_name              |str  |fileRepositoryUserName                        |
|file_repository_password               |str  |fileRepositoryPassword                        |
|net_address                            |str  |netAddress                                    |
|remote_file_format                     |str  |remoteFileFormat                              |
|port_number                            |int  |portNumber *Optional*                         |
|root_directory                         |str  |rootDirectory *Optional*                      |
|cpe_file_directory                     |str  |cpeFileDirectory *Optional*                   |
|secure                                 |bool |secure *Optional*                             |
|mac_in_non_request_uri                 |bool |macInNonRequestURI *Optional*                 |
|mac_in_cert                            |bool |macInCert *Optional*                          |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional*           |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication *Optional*        |
|mac_based_file_authentication          |bool |macBasedFileAuthentication *Optional*         |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication *Optional* |
|completion_notification                |bool |completionNotification *Optional*             |
|file_category                          |str  |fileCategory *Optional*                       |
|enable_caching                         |bool |enableCaching *Optional*                      |
|notify_file_upload                     |bool |notifyFileUpload *Optional*                   |
</div>


## `EnterpriseBroadWorksMobileManagerGetDomainListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseBroadWorksMobileManagerGetDomainListRequest()`.

Contains the list of domains.

**Attributes:**

|Name        |Type      |Description           |
|------------|----------|----------------------|
|domain_name |List[str] |domainName *Optional* |
</div>


## `EnterpriseBroadWorksMobileManagerGetHomeZoneListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseBroadWorksMobileManagerGetHomeZoneListRequest()`.

Contains a table with column headings: "Home Zone Id", "Domain Name", "Mobile Country
Code", "Mobile Network Code", "Local Area Code" and "Cell Identity".

**Attributes:**

|Name             |Type                 |Description                                                   |
|-----------------|---------------------|--------------------------------------------------------------|
|home_zones_table |List(homeZonesTable) |homeZonesTable - *Table* array of homeZonesTable named tuples |
</div>


## `EnterpriseBroadWorksMobileManagerGetHomeZoneResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseBroadWorksMobileManagerGetHomeZoneRequest()`

**Attributes:**

|Name                  |Type|Description        |
|----------------------|----|-------------------|
|home_zone_domain_name |str |homeZoneDomainName |
|mobile_country_code   |str |mobileCountryCode  |
|mobile_network_code   |str |mobileNetworkCode  |
|location_area_code    |str |locationAreaCode   |
|cell_identity         |str |cellIdentity       |
</div>


## `EnterpriseBroadWorksMobileManagerGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseBroadWorksMobileManagerGetRequest()`

**Attributes:**

|Name                            |Type |Description                   |
|--------------------------------|-----|------------------------------|
|mobile_manager_id               |str  |mobileManagerId               |
|name                            |str  |name                          |
|is_active                       |bool |isActive                      |
|local_to_carrier                |bool |localToCarrier                |
|deactivation_reason             |str  |deactivationReason *Optional* |
|max_tx_per_second_enabled       |bool |maxTxPerSecondEnabled         |
|max_tx_per_second               |int  |maxTxPerSecond *Optional*     |
|tldn_enabled                    |bool |tldnEnabled                   |
|generic_number_enabled          |bool |genericNumberEnabled          |
|mobile_state_check_enabled      |bool |mobileStateCheckEnabled       |
|location_based_services_enabled |bool |locationBasedServicesEnabled  |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentListRequest()`.

The response contains a table with columns: "Mobile Number", "User Id", "Last Name",
"First Name","Phone Number","Extension", "Group Id", "Department" and "Mobile
Network". The "Mobile Number" column contains a single DN. The "User Id", "Last Name"
and "First Name" columns contains the corresponding attributes of the user possessing
the DN(s). The "Phone Number" column contains a single DN. The "Group Id" column
contains the Group Id of the user.  The "Department" column contains the department of
the user if it is part of a department.  The "Mobile Network" column contains the
Mobile Network the number belongs to.

**Attributes:**

|Name                                                 |Type                                                  |Description                                                                                                                     |
|-----------------------------------------------------|------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------|
|mobile_subscriber_directory_numbers_assignment_table |List(mobileSubscriberDirectoryNumbersAssignmentTable) |mobileSubscriberDirectoryNumbersAssignmentTable - *Table* array of mobileSubscriberDirectoryNumbersAssignmentTable named tuples |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentPagedSortedListRequest()`.

The response contains a table with columns: "Mobile Number", "User Id", "Last Name",
"First Name", "Phone Number", "Extension", "Group Id", "Department", "Department
Type", "Parent Department", "Parent Department Type", "Mobile Network", "Country
Code", "National Prefix", "Available", "Mobile Country Code", "Mobile National
Prefix". The "Mobile Number" column contains a single DN. The "User Id", "Last Name"
and "First Name" columns contains the corresponding attributes of the user possessing
the DN(s). The "Phone Number" column contains a single DN. The "Group Id" column
contains the Group Id of the user.  The "Group Name" column contains the Group Name of
the user.  The "Department" column contains the department of the user if it is part
of a department.  The "Parent Department" column contains the parent department of the
user if it is part of a department.  The "Department Type" and "Parent Department
Type" columns will contain the values "Enterprise" or "Group". The "Mobile Network"
column contains the Mobile Network the number belongs to.  The "Country Code" column
indicates the dialing prefix for the phone number.  The "National Prefix" column
indicates the digit sequence to be dialed before the telephone number.  The
"Available" column indicates if the Mobile Number is available.  The "Mobile Country
Code" column indicates the dialing prefix for the mobile number.  The "Mobile National
Prefix" column indicates the digit sequence to be dialed before the mobile number.
Replaced by:
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentPagedSortedListResponse22()`

**Attributes:**

|Name                                                 |Type                                                  |Description                                                                                                                     |
|-----------------------------------------------------|------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------|
|mobile_subscriber_directory_numbers_assignment_table |List(mobileSubscriberDirectoryNumbersAssignmentTable) |mobileSubscriberDirectoryNumbersAssignmentTable - *Table* array of mobileSubscriberDirectoryNumbersAssignmentTable named tuples |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentPagedSortedListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentPagedSortedListRequest22()`.

The response contains the number of entries that would be returned if the response was
not page size restricted.  Contains a table with columns: "Mobile Number", "User Id",
"Last Name", "First Name", "Phone Number", "Extension", "Group Id", "Department",
"Department Type", "Parent Department", "Parent Department Type", "Mobile Network",
"Country Code", "National Prefix", "Available", "Mobile Country Code", "Mobile
National Prefix". The "Mobile Number" column contains a single DN. The "User Id",
"Last Name" and "First Name" columns contains the corresponding attributes of the user
possessing the DN(s). The "Phone Number" column contains a single DN. The "Group Id"
column contains the Group Id of the user.  The "Group Name" column contains the Group
Name of the user.  The "Department" column contains the department of the user if it
is part of a department.  The "Parent Department" column contains the parent
department of the user if it is part of a department.  The "Department Type" and
"Parent Department Type" columns will contain the values "Enterprise" or "Group". The
"Mobile Network" column contains the Mobile Network the number belongs to.  The
"Country Code" column indicates the dialing prefix for the phone number.  The
"National Prefix" column indicates the digit sequence to be dialed before the
telephone number.  The "Available" column indicates if the Mobile Number is available.
The "Mobile Country Code" column indicates the dialing prefix for the mobile number.
The "Mobile National Prefix" column indicates the digit sequence to be dialed before
the mobile number.

**Attributes:**

|Name                                                 |Type                                                  |Description                                                                                                                     |
|-----------------------------------------------------|------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------|
|total_number_of_rows                                 |int                                                   |totalNumberOfRows *Optional*                                                                                                    |
|mobile_subscriber_directory_numbers_assignment_table |List(mobileSubscriberDirectoryNumbersAssignmentTable) |mobileSubscriberDirectoryNumbersAssignmentTable - *Table* array of mobileSubscriberDirectoryNumbersAssignmentTable named tuples |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListRequest()`.

Contains a list of available Mobile Subscriber Directory Numbers not yet assigned to
any user.

**Attributes:**

|Name                                         |Type      |Description                                         |
|---------------------------------------------|----------|----------------------------------------------------|
|available_mobile_subscriber_directory_number |List[str] |availableMobileSubscriberDirectoryNumber *Optional* |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListRequest22()`.

The response contains a table with columns: "Phone Number", "E164 Phone Number". The
"Phone Number" column contains Mobile Subscriber DNs not yet assigned to any user.
The "E164 Phone Number" column contains Mobile Subscriber DNs not yet assigned to any
user in E.164 format.

**Attributes:**

|Name                                               |Type                                                |Description                                                                                                                 |
|---------------------------------------------------|----------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------|
|available_mobile_subscriber_directory_number_table |List(availableMobileSubscriberDirectoryNumberTable) |availableMobileSubscriberDirectoryNumberTable - *Table* array of availableMobileSubscriberDirectoryNumberTable named tuples |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailablePagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailablePagedSortedListRequest()`.

The response contains a table with columns: "Mobile Number", "Mobile Network", "Mobile
Country Code", "Mobile National Prefix". The "Mobile Number" column contains a single
DN. The "Mobile Network" column contains the Mobile Network the number belongs to.
The "Mobile Country Code" column indicates the dialing prefix for the mobile number.
The "Mobile National Prefix" column indicates the digit sequence to be dialed before
the mobile number.  Replaced by:
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailablePagedSortedListResponse22()`

**Attributes:**

|Name                                               |Type                                                |Description                                                                                                                 |
|---------------------------------------------------|----------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------|
|available_mobile_subscriber_directory_number_table |List(availableMobileSubscriberDirectoryNumberTable) |availableMobileSubscriberDirectoryNumberTable - *Table* array of availableMobileSubscriberDirectoryNumberTable named tuples |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailablePagedSortedListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailablePagedSortedListRequest22()`.

The response contains the number of entries that would be returned if the response was
not page size restricted.  Contains a table with columns: "Mobile Number", "Mobile
Network", "Mobile Country Code", "Mobile National Prefix". The "Mobile Number" column
contains a single DN. The "Mobile Network" column contains the Mobile Network the
number belongs to.  The "Mobile Country Code" column indicates the dialing prefix for
the mobile number.  The "Mobile National Prefix" column indicates the digit sequence
to be dialed before the mobile number.

**Attributes:**

|Name                                               |Type                                                |Description                                                                                                                 |
|---------------------------------------------------|----------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------|
|total_number_of_rows                               |int                                                 |totalNumberOfRows *Optional*                                                                                                |
|available_mobile_subscriber_directory_number_table |List(availableMobileSubscriberDirectoryNumberTable) |availableMobileSubscriberDirectoryNumberTable - *Table* array of availableMobileSubscriberDirectoryNumberTable named tuples |
</div>


## `EnterpriseCallCenterAgentThresholdDefaultProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallCenterAgentThresholdDefaultProfileGetRequest()`.

The agent table contains the agents assigned to the profile and has column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name",
"Phone Number", "Extension", "Department", "Email Address";

**Attributes:**

|Name                                                  |Type             |Description                                                      |
|------------------------------------------------------|-----------------|-----------------------------------------------------------------|
|profile_name                                          |str              |profileName                                                      |
|profile_description                                   |str              |profileDescription *Optional*                                    |
|threshold_current_call_state_idle_time_yellow         |int              |thresholdCurrentCallStateIdleTimeYellow *Optional*               |
|threshold_current_call_state_idle_time_red            |int              |thresholdCurrentCallStateIdleTimeRed *Optional*                  |
|threshold_current_call_state_on_call_time_yellow      |int              |thresholdCurrentCallStateOnCallTimeYellow *Optional*             |
|threshold_current_call_state_on_call_time_red         |int              |thresholdCurrentCallStateOnCallTimeRed *Optional*                |
|threshold_current_agent_state_unavailable_time_yellow |int              |thresholdCurrentAgentStateUnavailableTimeYellow *Optional*       |
|threshold_current_agent_state_unavailable_time_red    |int              |thresholdCurrentAgentStateUnavailableTimeRed *Optional*          |
|threshold_average_busy_in_time_yellow                 |int              |thresholdAverageBusyInTimeYellow *Optional*                      |
|threshold_average_busy_in_time_red                    |int              |thresholdAverageBusyInTimeRed *Optional*                         |
|threshold_average_busy_out_time_yellow                |int              |thresholdAverageBusyOutTimeYellow *Optional*                     |
|threshold_average_busy_out_time_red                   |int              |thresholdAverageBusyOutTimeRed *Optional*                        |
|threshold_average_wrap_up_time_yellow                 |int              |thresholdAverageWrapUpTimeYellow *Optional*                      |
|threshold_average_wrap_up_time_red                    |int              |thresholdAverageWrapUpTimeRed *Optional*                         |
|enable_notification_email                             |bool             |enableNotificationEmail                                          |
|notification_email_address                            |List[str]        |notificationEmailAddress *Optional*                              |
|agent_table                                           |List(agentTable) |agentTable - *Table* array of agentTable named tuples *Optional* |
</div>


## `EnterpriseCallCenterAgentThresholdProfileGetAvailableAgentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`EnterpriseCallCenterAgentThresholdProfileGetAvailableAgentListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address", "Agent Threshold Profile";

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|agent_table |List(agentTable) |agentTable - *Table* array of agentTable named tuples |
</div>


## `EnterpriseCallCenterAgentThresholdProfileGetAvailableAgentPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`EnterpriseCallCenterAgentThresholdProfileGetAvailableAgentPagedSortedListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address", "Agent Threshold Profile";

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|agent_table |List(agentTable) |agentTable - *Table* array of agentTable named tuples |
</div>


## `EnterpriseCallCenterAgentThresholdProfileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallCenterAgentThresholdProfileGetListRequest()`.

Contains a table with all the Call Center Agent Threshold Profiles in the Enterprise.
The column headings are: "Default", "Name", "Description".

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|profiles_table |List(profilesTable) |profilesTable - *Table* array of profilesTable named tuples |
</div>


## `EnterpriseCallCenterAgentThresholdProfileGetPagedSortedResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallCenterAgentThresholdProfileGetPagedSortedRequest()`.

The agentTable contains the agents assigned to the profile and has the column
headings: "User Id", "Group Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name", "Phone Number", "Extension", "Department", "Email Address";

**Attributes:**

|Name                                                  |Type             |Description                                                |
|------------------------------------------------------|-----------------|-----------------------------------------------------------|
|profile_description                                   |str              |profileDescription *Optional*                              |
|threshold_current_call_state_idle_time_yellow         |int              |thresholdCurrentCallStateIdleTimeYellow *Optional*         |
|threshold_current_call_state_idle_time_red            |int              |thresholdCurrentCallStateIdleTimeRed *Optional*            |
|threshold_current_call_state_on_call_time_yellow      |int              |thresholdCurrentCallStateOnCallTimeYellow *Optional*       |
|threshold_current_call_state_on_call_time_red         |int              |thresholdCurrentCallStateOnCallTimeRed *Optional*          |
|threshold_current_agent_state_unavailable_time_yellow |int              |thresholdCurrentAgentStateUnavailableTimeYellow *Optional* |
|threshold_current_agent_state_unavailable_time_red    |int              |thresholdCurrentAgentStateUnavailableTimeRed *Optional*    |
|threshold_average_busy_in_time_yellow                 |int              |thresholdAverageBusyInTimeYellow *Optional*                |
|threshold_average_busy_in_time_red                    |int              |thresholdAverageBusyInTimeRed *Optional*                   |
|threshold_average_busy_out_time_yellow                |int              |thresholdAverageBusyOutTimeYellow *Optional*               |
|threshold_average_busy_out_time_red                   |int              |thresholdAverageBusyOutTimeRed *Optional*                  |
|threshold_average_wrap_up_time_yellow                 |int              |thresholdAverageWrapUpTimeYellow *Optional*                |
|threshold_average_wrap_up_time_red                    |int              |thresholdAverageWrapUpTimeRed *Optional*                   |
|enable_notification_email                             |bool             |enableNotificationEmail                                    |
|notification_email_address                            |List[str]        |notificationEmailAddress *Optional*                        |
|agent_table                                           |List(agentTable) |agentTable - *Table* array of agentTable named tuples      |
</div>


## `EnterpriseCallCenterAgentThresholdProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallCenterAgentThresholdProfileGetRequest()`.

The agentTable contains the agents assigned to the profile and has the column
headings: "User Id", "Group Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name", "Phone Number", "Extension", "Department", "Email Address";

**Attributes:**

|Name                                                  |Type             |Description                                                |
|------------------------------------------------------|-----------------|-----------------------------------------------------------|
|profile_description                                   |str              |profileDescription *Optional*                              |
|threshold_current_call_state_idle_time_yellow         |int              |thresholdCurrentCallStateIdleTimeYellow *Optional*         |
|threshold_current_call_state_idle_time_red            |int              |thresholdCurrentCallStateIdleTimeRed *Optional*            |
|threshold_current_call_state_on_call_time_yellow      |int              |thresholdCurrentCallStateOnCallTimeYellow *Optional*       |
|threshold_current_call_state_on_call_time_red         |int              |thresholdCurrentCallStateOnCallTimeRed *Optional*          |
|threshold_current_agent_state_unavailable_time_yellow |int              |thresholdCurrentAgentStateUnavailableTimeYellow *Optional* |
|threshold_current_agent_state_unavailable_time_red    |int              |thresholdCurrentAgentStateUnavailableTimeRed *Optional*    |
|threshold_average_busy_in_time_yellow                 |int              |thresholdAverageBusyInTimeYellow *Optional*                |
|threshold_average_busy_in_time_red                    |int              |thresholdAverageBusyInTimeRed *Optional*                   |
|threshold_average_busy_out_time_yellow                |int              |thresholdAverageBusyOutTimeYellow *Optional*               |
|threshold_average_busy_out_time_red                   |int              |thresholdAverageBusyOutTimeRed *Optional*                  |
|threshold_average_wrap_up_time_yellow                 |int              |thresholdAverageWrapUpTimeYellow *Optional*                |
|threshold_average_wrap_up_time_red                    |int              |thresholdAverageWrapUpTimeRed *Optional*                   |
|enable_notification_email                             |bool             |enableNotificationEmail                                    |
|notification_email_address                            |List[str]        |notificationEmailAddress *Optional*                        |
|agent_table                                           |List(agentTable) |agentTable - *Table* array of agentTable named tuples      |
</div>


## `EnterpriseCallCenterAgentUnavailableCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallCenterAgentUnavailableCodeGetListRequest()`.

Contains a table with column headings: "Is Active", "Code", "Description".

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|unavailable_codes_table |List(unavailableCodesTable) |unavailableCodesTable - *Table* array of unavailableCodesTable named tuples |
</div>


## `EnterpriseCallCenterAgentUnavailableCodeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallCenterAgentUnavailableCodeGetRequest()`

**Attributes:**

|Name        |Type |Description            |
|------------|-----|-----------------------|
|is_active   |bool |isActive               |
|description |str  |description *Optional* |
</div>


## `EnterpriseCallCenterAgentUnavailableCodeSettingsGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterAgentUnavailableCodeSettingsGetRequest()`.

Replaced by `EnterpriseCallCenterAgentUnavailableCodeSettingsGetResponse17sp4()`.

**Attributes:**

|Name                                                  |Type |Description                                                |
|------------------------------------------------------|-----|-----------------------------------------------------------|
|enable_agent_unavailable_codes                        |bool |enableAgentUnavailableCodes                                |
|default_agent_unavailable_code_on_dnd                 |str  |defaultAgentUnavailableCodeOnDND *Optional*                |
|default_agent_unavailable_code_on_personal_calls      |str  |defaultAgentUnavailableCodeOnPersonalCalls *Optional*      |
|default_agent_unavailable_code_on_consecutive_bounces |str  |defaultAgentUnavailableCodeOnConsecutiveBounces *Optional* |
|force_use_of_agent_unavailable_codes                  |bool |forceUseOfAgentUnavailableCodes                            |
|default_agent_unavailable_code                        |str  |defaultAgentUnavailableCode *Optional*                     |
</div>


## `EnterpriseCallCenterAgentUnavailableCodeSettingsGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterAgentUnavailableCodeSettingsGetRequest17sp4()`.


**Attributes:**

|Name                                                  |Type |Description                                                |
|------------------------------------------------------|-----|-----------------------------------------------------------|
|enable_agent_unavailable_codes                        |bool |enableAgentUnavailableCodes                                |
|default_agent_unavailable_code_on_dnd                 |str  |defaultAgentUnavailableCodeOnDND *Optional*                |
|default_agent_unavailable_code_on_personal_calls      |str  |defaultAgentUnavailableCodeOnPersonalCalls *Optional*      |
|default_agent_unavailable_code_on_consecutive_bounces |str  |defaultAgentUnavailableCodeOnConsecutiveBounces *Optional* |
|default_agent_unavailable_code_on_not_reachable       |str  |defaultAgentUnavailableCodeOnNotReachable *Optional*       |
|force_use_of_agent_unavailable_codes                  |bool |forceUseOfAgentUnavailableCodes                            |
|default_agent_unavailable_code                        |str  |defaultAgentUnavailableCode *Optional*                     |
</div>


## `EnterpriseCallCenterCallDispositionCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallCenterCallDispositionCodeGetListRequest()`.

Contains a table with column headings: "Is Active", "Code", "Description".

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|disposition_codes_table |List(dispositionCodesTable) |dispositionCodesTable - *Table* array of dispositionCodesTable named tuples |
</div>


## `EnterpriseCallCenterCallDispositionCodeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallCenterCallDispositionCodeGetRequest()`

**Attributes:**

|Name        |Type |Description            |
|------------|-----|-----------------------|
|is_active   |bool |isActive               |
|description |str  |description *Optional* |
</div>


## `EnterpriseCallCenterCallDispositionCodeGetUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallCenterCallDispositionCodeGetUsageListRequest()`.

The Type column contains either "Call Center" or "Route Point". Contains a table with
column headings: "Group Id", "Id", "Name" and "Type".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|call_center_table |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `EnterpriseCallCenterCurrentAndPastAgentGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallCenterCurrentAndPastAgentGetListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name                     |Type                        |Description                                                                 |
|-------------------------|----------------------------|----------------------------------------------------------------------------|
|agent_user_table         |List(agentUserTable)        |agentUserTable - *Table* array of agentUserTable named tuples               |
|deleted_agent_user_table |List(deletedAgentUserTable) |deletedAgentUserTable - *Table* array of deletedAgentUserTable named tuples |
</div>


## `EnterpriseCallCenterCurrentAndPastCallCenterGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallCenterCurrentAndPastCallCenterGetListRequest()`.


**Attributes:**

|Name                    |Type      |Description                     |
|------------------------|----------|--------------------------------|
|service_user_id         |List[str] |serviceUserId *Optional*        |
|deleted_service_user_id |List[str] |deletedServiceUserId *Optional* |
</div>


## `EnterpriseCallCenterCurrentAndPastDNISGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallCenterCurrentAndPastDNISGetListRequest()`.


**Attributes:**

|Name         |Type      |Description            |
|-------------|----------|-----------------------|
|name         |List[str] |name *Optional*        |
|deleted_name |List[str] |deletedName *Optional* |
</div>


## `EnterpriseCallCenterEnhancedReportingBrandingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallCenterEnhancedReportingBrandingGetRequest()`.


**Attributes:**

|Name                      |Type|Description                        |
|--------------------------|----|-----------------------------------|
|branding_choice           |str |brandingChoice                     |
|branding_file_description |str |brandingFileDescription *Optional* |
</div>


## `EnterpriseCallCenterEnhancedReportingGetAvailableReportTemplateListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`EnterpriseCallCenterEnhancedReportingGetAvailableReportTemplateListRequest()`.

Contains a table with column headings: "Name", "Description" and "Level", "Is Agent
Required", "Is Call Center Required", "Is Call Center Dnis Required", "Is Real Time
Report", "Is Sampling Period Required", "Call Completion Threshold Parameter", "Short
Duration Threshold Parameter", "Service Level Threshold Parameter", "Service Level
Inclusions Parameter", "Service Level Objective Threshold Parameter", "Abandoned Call
Threshold Parameter", "Service Level Threshold Parameter Number", "Abandoned Call
Threshold Parameter Number" and "Scope". The possible values for "Level" are "System"
and "Enterprise". The possible values for "Is Agent Required", "Is Call Center
Required", "Is Call Center Dnis Required", "Is Real Time Report" and "Is Sampling
Period Required" are "true" and "false". The possible values for "Call Completion
Threshold Parameter", "Short Duration Threshold Parameter", "Service Level Threshold
Parameter", "Service Level Inclusions Parameter", "Service Level Objective Threshold
Parameter" and "Abandoned Call Threshold Parameter" are "Required", "Hidden" and "Does
Not Apply". The possible values for "Scope" are "Supervisor Only" and "Supervisor and
Agent".

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|report_template_table |List(reportTemplateTable) |reportTemplateTable - *Table* array of reportTemplateTable named tuples |
</div>


## `EnterpriseCallCenterEnhancedReportingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterEnhancedReportingGetRequest()`.

Replaced by `EnterpriseCallCenterEnhancedReportingGetResponse19()`

**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|reporting_server     |str |reportingServer    |
|web_statistic_source |str |webStatisticSource |
</div>


## `EnterpriseCallCenterEnhancedReportingGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterEnhancedReportingGetRequest19()`.


**Attributes:**

|Name             |Type|Description     |
|-----------------|----|----------------|
|reporting_server |str |reportingServer |
</div>


## `EnterpriseCallCenterEnhancedReportingReportTemplateGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterEnhancedReportingReportTemplateGetListRequest()`.

Contains a table with column headings: "Name", "Description", "Type" and "Enabled".

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|report_template_table |List(reportTemplateTable) |reportTemplateTable - *Table* array of reportTemplateTable named tuples |
</div>


## `EnterpriseCallCenterEnhancedReportingReportTemplateGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterEnhancedReportingReportTemplateGetRequest()`.


**Attributes:**

|Name                                    |Type      |Description                                    |
|----------------------------------------|----------|-----------------------------------------------|
|description                             |str       |description *Optional*                         |
|data_template                           |str       |dataTemplate                                   |
|filter_number                           |int       |filterNumber *Optional*                        |
|xslt_template_description               |str       |xsltTemplateDescription                        |
|scope                                   |str       |scope                                          |
|is_enabled                              |bool      |isEnabled                                      |
|is_realtime_report                      |bool      |isRealtimeReport *Optional*                    |
|call_completion_threshold_param         |str       |callCompletionThresholdParam *Optional*        |
|short_duration_threshold_param          |str       |shortDurationThresholdParam *Optional*         |
|service_level_threshold_param           |str       |serviceLevelThresholdParam *Optional*          |
|service_level_inclusions_param          |str       |serviceLevelInclusionsParam *Optional*         |
|service_level_objective_threshold_param |str       |serviceLevelObjectiveThresholdParam *Optional* |
|abandoned_call_threshold_param          |str       |abandonedCallThresholdParam *Optional*         |
|service_level_threshold_param_number    |int       |serviceLevelThresholdParamNumber *Optional*    |
|abandoned_call_threshold_param_number   |int       |abandonedCallThresholdParamNumber *Optional*   |
|filter_value                            |List[str] |filterValue *Optional*                         |
</div>


## `EnterpriseCallCenterEnhancedReportingScheduledReportGetActiveListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`EnterpriseCallCenterEnhancedReportingScheduledReportGetActiveListRequest()`.

Contains a table with column headings : "Schedule Name", "Description", "Created By",
"Is Supervisor Report", "Report Template Name", "Report Template Level" and
"Recurring". The "Created By" can be either "Administrator" or user id if created by
supervisor.  The possible values for "Recurring" are "None", "Daily", "Weekly",
"Monthly" and "Yearly". The possible values for "Report Level" are "System" and
"Enterprise".

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|scheduled_report_table |List(scheduledReportTable) |scheduledReportTable - *Table* array of scheduledReportTable named tuples |
</div>


## `EnterpriseCallCenterEnhancedReportingScheduledReportGetCompletedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`EnterpriseCallCenterEnhancedReportingScheduledReportGetCompletedListRequest()`
Contains a table with column headings : "Schedule Name", "Description", "Created By",
"Is Supervisor Report", "Report Template Name", "Report Template Level" and
"Recurring".

The "Created By" can be either "Administrator" or user id if created by supervisor.
The possible values for "Recurring" are "None", "Daily", "Weekly", "Monthly" and
"Yearly". The possible values for "Report Level" are "System" and "Enterprise".

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|scheduled_report_table |List(scheduledReportTable) |scheduledReportTable - *Table* array of scheduledReportTable named tuples |
</div>


## `EnterpriseCallCenterEnhancedReportingScheduledReportGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterEnhancedReportingScheduledReportGetListRequest()`.

Contains a table with column headings : "Schedule Name", "Description", "Created By",
"Is Supervisor Report", "Status", "Report Template Name", "Report Template Level" and
"Recurring". The "Created By" can be either "Administrator" or user id if created by
supervisor.  The possible values for "Status" are "Active", and "Completed". The
possible values for "Recurring" are "None", "Daily", "Weekly", "Monthly" and "Yearly".
The possible values for "Report Level" are "System" and "Enterprise".

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|scheduled_report_table |List(scheduledReportTable) |scheduledReportTable - *Table* array of scheduledReportTable named tuples |
</div>


## `EnterpriseCallCenterEnhancedReportingScheduledReportGetReportTemplateUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`EnterpriseCallCenterEnhancedReportingScheduledReportGetReportTemplateUsageListRequest()`.

Contains a table with column headings: "Schedule Name", "Created By", "Created By
Supervisor", and "Is Active". The "Created By" can be either "Administrator" or user
id if created by supervisor.

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|schedule_report_table |List(scheduleReportTable) |scheduleReportTable - *Table* array of scheduleReportTable named tuples |
</div>


## `EnterpriseCallCenterGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterGetRequest()`.

Replaced by `EnterpriseCallCenterGetResponse17sp4()`.

**Attributes:**

|Name                                                        |Type |Description                                                     |
|------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_system_default_guard_timer                              |bool |useSystemDefaultGuardTimer                                      |
|enable_guard_timer                                          |bool |enableGuardTimer                                                |
|guard_timer_seconds                                         |int  |guardTimerSeconds                                               |
|use_system_default_unavailable_settings                     |bool |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
</div>


## `EnterpriseCallCenterGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterGetRequest17sp4()`.

The following elements are only used in AS data mode and not returned in XS data mode:
useSystemDefaultUnavailableSettings forceAgentUnavailableOnDNDActivation
forceAgentUnavailableOnPersonalCalls forceAgentUnavailableOnBouncedCallLimit
numberConsecutiveBouncedCallsToForceAgentUnavailable
forceAgentUnavailableOnNotReachable Replaced by: `EnterpriseCallCenterGetResponse23()`
in AS data mode

**Attributes:**

|Name                                                        |Type |Description                                                     |
|------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_system_default_guard_timer                              |bool |useSystemDefaultGuardTimer                                      |
|enable_guard_timer                                          |bool |enableGuardTimer                                                |
|guard_timer_seconds                                         |int  |guardTimerSeconds                                               |
|use_system_default_unavailable_settings                     |bool |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|force_agent_unavailable_on_not_reachable                    |bool |forceAgentUnavailableOnNotReachable *Optional*                  |
</div>


## `EnterpriseCallCenterGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterGetRequest23()`.

The following elements are only used in AS data mode and not returned in XS data mode:
useSystemDefaultUnavailableSettings forceAgentUnavailableOnDNDActivation
forceAgentUnavailableOnPersonalCalls forceAgentUnavailableOnBouncedCallLimit
numberConsecutiveBouncedCallsToForceAgentUnavailable
forceAgentUnavailableOnNotReachable wrapUpDestination

**Attributes:**

|Name                                                        |Type |Description                                                     |
|------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_system_default_guard_timer                              |bool |useSystemDefaultGuardTimer                                      |
|enable_guard_timer                                          |bool |enableGuardTimer                                                |
|guard_timer_seconds                                         |int  |guardTimerSeconds                                               |
|use_system_default_unavailable_settings                     |bool |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|force_agent_unavailable_on_not_reachable                    |bool |forceAgentUnavailableOnNotReachable *Optional*                  |
|wrap_up_destination                                         |str  |wrapUpDestination *Optional*                                    |
</div>


## `EnterpriseCallCenterGetRoutingPolicyResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterGetRoutingPolicyRequest()`.

Contains a table with column headings: "Service User Id", "Name" and "Priority".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|routing_policy    |str                   |routingPolicy                                                   |
|call_center_table |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `EnterpriseCallCenterMonitoringGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterMonitoringGetRequest()`.


**Attributes:**

|Name                       |Type |Description              |
|---------------------------|-----|-------------------------|
|enable_supervisor_coaching |bool |enableSupervisorCoaching |
</div>


## `EnterpriseCallCenterMonitoringGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterMonitoringGetRequest23()`.


**Attributes:**

|Name                                                |Type |Description                                               |
|----------------------------------------------------|-----|----------------------------------------------------------|
|enable_supervisor_coaching                          |bool |enableSupervisorCoaching                                  |
|bypass_enforcement_of_supervisor_agent_relationship |bool |bypassEnforcementOfSupervisorAgentRelationship *Optional* |
</div>


## `EnterpriseCallRecordingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCallRecordingGetRequest()`.

The response contains the enterprise's Call Recording attributes.

**Attributes:**

|Name                   |Type |Description                     |
|-----------------------|-----|--------------------------------|
|use_cloud_pbx          |bool |useCloudPBX                     |
|use_enterprise_setting |bool |useEnterpriseSetting *Optional* |
|fqdn                   |str  |FQDN *Optional*                 |
</div>


## `EnterpriseCommunicationBarringAuthorizationCodeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EntepriseCommunicationBarringAuthorizationCodeGetRequest()`.


**Attributes:**

|Name                     |Type|Description                      |
|-------------------------|----|---------------------------------|
|description              |str |description *Optional*           |
|network_class_of_service |str |networkClassOfService *Optional* |
</div>


## `EnterpriseEnterpriseTrunkGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseEnterpriseTrunkGetAvailableUserListRequest()`.

The column headings for the enterpriseTrunkUserTable are: "User Id", "Last Name",
"First Name", "Hiragana Last Name", "Hiragana First Name", "Phone Number",
"Extension", "Department", "Email Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `EnterpriseEnterpriseTrunkGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseEnterpriseTrunkGetListRequest()`.

Contains a table of enterprise trunks defined in the enterprise The column headings
are: "Enterprise Trunk Name", "Routing Type"

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|enterprise_trunk_table |List(enterpriseTrunkTable) |enterpriseTrunkTable - *Table* array of enterpriseTrunkTable named tuples |
</div>


## `EnterpriseEnterpriseTrunkGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseEnterpriseTrunkGetRequest()`.

Replaced by: `EnterpriseEnterpriseTrunkGetResponse21()`.

**Attributes:**

|Name                             |Type                        |Description                              |
|---------------------------------|----------------------------|-----------------------------------------|
|maximum_reroute_attempts         |int                         |maximumRerouteAttempts                   |
|route_exhaustion_action          |str                         |routeExhaustionAction                    |
|route_exhaustion_forward_address |str                         |routeExhaustionForwardAddress *Optional* |
|ordered_routing                  |OCI.orderedRouting          |orderedRouting *Optional*                |
|priority_weighted_routing        |OCI.priorityWeightedRouting |priorityWeightedRouting *Optional*       |
</div>


## `EnterpriseEnterpriseTrunkGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseEnterpriseTrunkGetRequest21()`.


**Attributes:**

|Name                                 |Type                        |Description                                 |
|-------------------------------------|----------------------------|--------------------------------------------|
|maximum_reroute_attempts             |int                         |maximumRerouteAttempts                      |
|route_exhaustion_action              |str                         |routeExhaustionAction                       |
|route_exhaustion_forward_address     |str                         |routeExhaustionForwardAddress *Optional*    |
|ordered_routing                      |OCI.orderedRouting          |orderedRouting *Optional*                   |
|priority_weighted_routing            |OCI.priorityWeightedRouting |priorityWeightedRouting *Optional*          |
|enable_capacity_management           |bool                        |enableCapacityManagement                    |
|max_active_calls                     |int                         |maxActiveCalls *Optional*                   |
|capacity_exceeded_trap_initial_calls |int                         |capacityExceededTrapInitialCalls *Optional* |
|capacity_exceeded_trap_offset_calls  |int                         |capacityExceededTrapOffsetCalls *Optional*  |
</div>


## `EnterpriseEnterpriseTrunkGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseEnterpriseTrunkGetRequest22()`.


**Attributes:**

|Name                                  |Type                        |Description                                  |
|--------------------------------------|----------------------------|---------------------------------------------|
|maximum_reroute_attempts              |int                         |maximumRerouteAttempts                       |
|route_exhaustion_action               |str                         |routeExhaustionAction                        |
|route_exhaustion_forward_address      |str                         |routeExhaustionForwardAddress *Optional*     |
|ordered_routing                       |OCI.orderedRouting          |orderedRouting *Optional*                    |
|priority_weighted_routing             |OCI.priorityWeightedRouting |priorityWeightedRouting *Optional*           |
|enable_capacity_management            |bool                        |enableCapacityManagement                     |
|max_active_calls                      |int                         |maxActiveCalls *Optional*                    |
|capacity_exceeded_trap_initial_calls  |int                         |capacityExceededTrapInitialCalls *Optional*  |
|capacity_exceeded_trap_offset_calls   |int                         |capacityExceededTrapOffsetCalls *Optional*   |
|maximum_active_incoming_calls_allowed |int                         |maximumActiveIncomingCallsAllowed *Optional* |
|maximum_active_outgoing_calls_allowed |int                         |maximumActiveOutgoingCallsAllowed *Optional* |
|minimum_active_calls_reserved         |int                         |minimumActiveCallsReserved *Optional*        |
</div>


## `EnterpriseEnterpriseTrunkGetUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseEnterpriseTrunkGetUserListRequest()`.

The column headings for the enterpriseTrunkUserTable are: "Group Id", "User Id", "Last
Name", "First Name", "Phone Number", "Alternate Trunk Identity", "Hiragana Last Name",
"Hiragana First Name", "Extension", "Department", "Email Address" and "Route List
Assigned".

**Attributes:**

|Name                        |Type                           |Description                                                                       |
|----------------------------|-------------------------------|----------------------------------------------------------------------------------|
|enterprise_trunk_user_table |List(enterpriseTrunkUserTable) |enterpriseTrunkUserTable - *Table* array of enterpriseTrunkUserTable named tuples |
</div>


## `EnterpriseLocalGatewayGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseLocalGatewayGetPagedSortedListRequest()`.

Contains a table with column headings "Name", "Device Name", "Device Level", "Group
Id", "Group Name" and "Group External Id". The "Device Level" column contains one of
the AccessDeviceLevel enumerated constants.  The following columns are only populated
in AS data mode "Group External Id"

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|local_gateway_table |List(localGatewayTable) |localGatewayTable - *Table* array of localGatewayTable named tuples |
</div>


## `EnterpriseLocalGatewayGetUsageResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseLocalGatewayGetUsageRequest()`.

Returns the group ID and group name where the local gateway belongs to, a boolean
value to indicate if the local gateway is used in the enterprise call processing
policy.  It also returns an OCITable containing the groups using the given local
gateway.  Column headings are: "Group Id", "Group Name" and "Group External Id". The
following columns are only populated in AS data mode "Group External Id"

**Attributes:**

|Name               |Type             |Description                                           |
|-------------------|-----------------|------------------------------------------------------|
|gateway_group_id   |str              |gatewayGroupId                                        |
|gateway_group_name |str              |gatewayGroupName *Optional*                           |
|used_by_enterprise |bool             |usedByEnterprise                                      |
|group_table        |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
</div>


## `EnterprisePhoneDirectoryGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterprisePhoneDirectoryGetListRequest()`.

Contains a table with a row for each phone number and column headings : "Name",
"Number", "Extension", "Mobile", "Email Address", "Department", "Hiragana Name",
"Group Id", "Yahoo Id". If extended directory information is requested, the following
columns are also included: "First Name", "Last Name", "User Id", "Pager", "Title",
"Time Zone", "Location", "Address Line 1", "Address Line 2", "City", "State", "Zip",
"Country". Replace by: `EnterprisePhoneDirectoryGetListResponse17()`

**Attributes:**

|Name            |Type                 |Description                                                   |
|----------------|---------------------|--------------------------------------------------------------|
|directory_table |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `EnterprisePhoneDirectoryGetListResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterprisePhoneDirectoryGetListRequest17()`.

Contains a table with a row for each phone number and column headings : "Name",
"Number", "Extension", "Mobile", "Email Address", "Department", "Hiragana Name",
"Group Id", "Yahoo Id", "Is Virtual On-Net User". If extended directory information is
requested, the following columns are also included: "First Name", "Last Name", "User
Id", "Pager", "Title", "Time Zone", "Location", "Address Line 1", "Address Line 2",
"City", "State", "Zip", "Country". Replaced by:
`EnterprisePhoneDirectoryGetListResponse18()`

**Attributes:**

|Name            |Type                 |Description                                                   |
|----------------|---------------------|--------------------------------------------------------------|
|directory_table |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `EnterprisePhoneDirectoryGetListResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterprisePhoneDirectoryGetListRequest17sp3()`.

Contains a table with a row for each phone number and column headings : "Name",
"Number", "Extension", "Mobile", "Email Address", "Department", "Hiragana Name",
"Group Id", "Yahoo Id", "IMP Id", "Is Virtual On-Net User". If extended directory
information is requested, the following columns are also included: "First Name", "Last
Name", "User Id", "Pager", "Title", "Time Zone", "Location", "Address Line 1",
"Address Line 2", "City", "State", "Zip", "Country". Replaced by:
`EnterprisePhoneDirectoryGetListResponse18()`

**Attributes:**

|Name            |Type                 |Description                                                   |
|----------------|---------------------|--------------------------------------------------------------|
|directory_table |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `EnterprisePhoneDirectoryGetListResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterprisePhoneDirectoryGetListRequest18()`.

Contains a table with a row for each phone number and column headings : "Name",
"Number", "Extension", "Mobile", "Email Address", "Department", "Hiragana Name",
"Group Id", "Yahoo Id", "User Id", "IMP Id", "Is Virtual On-Net User". If extended
directory information is requested, the following columns are also included: "First
Name", "Last Name", "Pager", "Title", "Time Zone", "Location", "Address Line 1",
"Address Line 2", "City", "State", "Zip", "Country", "Service Name". The Service Name
represents the localized service name for service instances.  The localized values are
taken from the BroadworksLabel.properties file.  Service Name is currently supporting:
AutoAttendant, AutoAttendantStandard, AutoAttendantVideo, CallCenter,
CallCenterStandard, CallCenterPremium HuntGroup, InstantGroupCall,
VoiceMessagingGroup, RoutePoint, BroadWorksAnywhere, GroupPaging, FindmeFollowme,
VoiceXML, FlexibleSeatingGuest, CollaborateAudio, MeetMeConferencing.  For a Regular
User or a Virtual On Network Enterprise Extensions, the Service Name is empty.  The
following columns are returned in AS data mode only: "Service Name"

Replaced By: `EnterprisePhoneDirectoryGetPagedSortedListResponse()`

**Attributes:**

|Name            |Type                 |Description                                                   |
|----------------|---------------------|--------------------------------------------------------------|
|directory_table |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `EnterprisePhoneDirectoryGetPagedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterprisePhoneDirectoryGetPagedListRequest()`.

Contains a table with a row for each phone number and column headings : "Name",
"Number", "Extension", "Mobile", "Email Address", "Department", "Hiragana Name",
"Group Id", "Yahoo Id", "User Id", "IMP Id", "Is Virtual On-Net User". If extended
directory information is requested, the following columns are also included: "First
Name", "Last Name", "Pager", "Title", "Time Zone", "Location", "Address Line 1",
"Address Line 2", "City", "State", "Zip", "Country", "Service Name". The Service Name
represents the localized service name for service instances.  The localized values are
taken from the BroadworksLabel.properties file.  Service Name is currently supporting:
AutoAttendant, AutoAttendantStandard, AutoAttendantVideo, CallCenter,
CallCenterStandard, CallCenterPremium HuntGroup, InstantGroupCall,
VoiceMessagingGroup, RoutePoint, BroadWorksAnywhere, GroupPaging, FindmeFollowme,
VoiceXML, FlexibleSeatingGuest, CollaborateAudio, MeetMeConferencing.  For a Regular
User or a Virtual On Network Enterprise Extensions, the Service Name is empty.  The
following columns are returned in AS data mode only: "Service Name"

Replaced By: `EnterprisePhoneDirectoryGetPagedSortedListResponse()`

**Attributes:**

|Name                 |Type                 |Description                                                   |
|---------------------|---------------------|--------------------------------------------------------------|
|total_number_of_rows |int                  |totalNumberOfRows                                             |
|directory_table      |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `EnterprisePhoneDirectoryGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterprisePhoneDirectoryGetPagedSortedListRequest()`.

Contains a table with a row for each phone number and column headings : "Name",
"Number", "Extension", "Mobile", "Email Address", "Department", "Hiragana Name",
"Group Id", "Yahoo Id", "User Id", "IMP Id", "Is Virtual On-Net User". If extended
directory information is requested, the following columns are also included: "First
Name", "Last Name", "Pager", "Title", "Time Zone", "Location", "Address Line 1",
"Address Line 2", "City", "State", "Zip", "Country", "Service Name". The Service Name
represents the localized service name for service instances.  The localized values are
taken from the BroadworksLabel.properties file.  Service Name is currently supporting:
AutoAttendant, AutoAttendantStandard, AutoAttendantVideo, CallCenter,
CallCenterStandard, CallCenterPremium HuntGroup, InstantGroupCall,
VoiceMessagingGroup, RoutePoint, BroadWorksAnywhere, GroupPaging, FindmeFollowme,
VoiceXML, FlexibleSeatingGuest, CollaborateAudio, MeetMeConferencing.  For a Regular
User or a Virtual On Network Enterprise Extensions, the Service Name is empty.  The
following columns are populated in AS data mode only: "IMP Id"

**Attributes:**

|Name                 |Type                 |Description                                                   |
|---------------------|---------------------|--------------------------------------------------------------|
|total_number_of_rows |int                  |totalNumberOfRows                                             |
|directory_table      |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `EnterprisePreAlertingAnnouncementGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Get the Enterprise level pre-alerting service settings.

The response is either a `EnterprisePreAlertingAnnouncementGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                        |Type|Description                          |
|----------------------------|----|-------------------------------------|
|announcement_interruption   |str |announcementInterruption             |
|interruption_digit_sequence |str |interruptionDigitSequence *Optional* |
|audio_selection             |str |audioSelection                       |
|audio_file_description      |str |audioFileDescription *Optional*      |
|audio_media_type            |str |audioMediaType *Optional*            |
|audio_file_url              |str |audioFileUrl *Optional*              |
|video_selection             |str |videoSelection                       |
|video_file_description      |str |videoFileDescription *Optional*      |
|video_media_type            |str |videoMediaType *Optional*            |
|video_file_url              |str |videoFileUrl *Optional*              |
</div>


## `EnterpriseRouteListEnterpriseTrunkNumberPrefixGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseRouteListEnterpriseTrunkNumberPrefixGetAvailableListRequest()`.

Contains a list of number prefixes that are assigned to an enterprise and still
available for assignment to users within the enterprise.  The column headings are
"Number Prefix" ","Is Active", “Extension Range Start” and “Extension Range End”.

**Attributes:**

|Name                          |Type                             |Description                                                                           |
|------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|available_number_prefix_table |List(availableNumberPrefixTable) |availableNumberPrefixTable - *Table* array of availableNumberPrefixTable named tuples |
</div>


## `EnterpriseRouteListEnterpriseTrunkNumberPrefixGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseRouteListEnterpriseTrunkNumberPrefixGetSummaryListRequest()`.

The response contains a table with columns: "Number Prefix", "Group Id", "User Id",
"Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name", "Phone
Number", "Extension", "Department", "Email Address", "Enterprise Trunk"","Is Active",
“Extension Range Start” and “Extension Range End”. The "User Id", "Last Name", "First
Name", "Hiragana Last Name", "Hiragana First Name", "Phone Number", "Extension",
"Department" and "Email Address" columns contains the corresponding attributes of the
user possessing the number range.  The "Enterprise Trunk" column contains the
enterprise trunk the user possessing the number range belongs to.  The "Is Active"
column indicates if the number range has been activated.  The “Extension Range Start”
column indicates the start for an extension range.  The “Extension Range End” column
indicates the end for an extension range.

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|prefix_summary_table |List(prefixSummaryTable) |prefixSummaryTable - *Table* array of prefixSummaryTable named tuples |
</div>


## `EnterpriseRouteListEnterpriseTrunkNumberRangeGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseRouteListEnterpriseTrunkNumberRangeGetAvailableListRequest()`.

Contains a list of number ranges that are assigned to an enterprise and still
available for assignment to users within the enterprise.  The column headings are
"Number Range Start", "Number Range End" ,"Is Active" and “Extension Length”..

**Attributes:**

|Name                         |Type                            |Description                                                                         |
|-----------------------------|--------------------------------|------------------------------------------------------------------------------------|
|available_number_range_table |List(availableNumberRangeTable) |availableNumberRangeTable - *Table* array of availableNumberRangeTable named tuples |
</div>


## `EnterpriseRouteListEnterpriseTrunkNumberRangeGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseRouteListEnterpriseTrunkNumberRangeGetSummaryListRequest()`.

The response contains a table with columns: "Number Range Start", "Number Range End",
"Group Id", "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Phone Number", "Extension", "Department", "Email Address", "Enterprise
Trunk", "Is Active" and "Extension Length". The "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department"
and "Email Address" columns contains the corresponding attributes of the user
possessing the number range.  The "Enterprise Trunk" column contains the enterprise
trunk the user possessing the number range belongs to.  The "Is Active" column
indicates if the number range has been activated.  The “Extension Length” column
indicates the length of the extension for the enterpris trunk number range.

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|number_range_summary_table |List(numberRangeSummaryTable) |numberRangeSummaryTable - *Table* array of numberRangeSummaryTable named tuples |
</div>


## `EnterpriseSecurityClassificationCustomizationGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseSecurityClassificationCustomizationGetAvailableListRequest()`.

Returns the available group security classifications.  Contains a table with column
headings: "SystemSecurityClassification", "CustomizedSecurityClassification"

**Attributes:**

|Name                               |Type                                  |Description                                                                                     |
|-----------------------------------|--------------------------------------|------------------------------------------------------------------------------------------------|
|security_classification_name_table |List(securityClassificationNameTable) |securityClassificationNameTable - *Table* array of securityClassificationNameTable named tuples |
</div>


## `EnterpriseSessionAdmissionControlGroupGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseSessionAdmissionControlGroupGetListRequest()`.

Contains a table of session admission control group configured in the enterprise.  The
column headings are: "Name", "Is Default", "Maximum Sessions", "Maximum Originating
Sessions", "Maximum Terminating Sessions"..

**Attributes:**

|Name                                  |Type                                    |Description                                                                                         |
|--------------------------------------|----------------------------------------|----------------------------------------------------------------------------------------------------|
|session_admission_control_group_table |List(sessionAdmissionControlGroupTable) |sessionAdmissionControlGroupTable - *Table* array of sessionAdmissionControlGroupTable named tuples |
</div>


## `EnterpriseUserCallForwardingSettingsGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseUserCallForwardingSettingsGetListRequest()`.

Contains a table with column headings: "Group Id", "User Id", "Last Name", "First
Name", "Hiragana Last Name", and "Hiragana First Name", "Phone Number", "Extension",
"Department", "In Trunk Group", "Email Address", "Is Active", "Forwarding Address".
"Is Active" is "true" or "false". The "Forwarding Address" is the Call Forwarding
service's forwarding address.  If the service is Call Forwarding Selective, the
default forwarding address is returned.  "Phone Number" field is presented in the E164
format.

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|user_call_forwarding_table |List(userCallForwardingTable) |userCallForwardingTable - *Table* array of userCallForwardingTable named tuples |
</div>


## `EnterpriseUserCallWaitingSettingsGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseUserCallWaitingSettingsGetListRequest()`.

Contains a table with column headings: "Group Id", "User Id", "Last Name", "First
Name", "Hiragana Last Name", and "Hiragana First Name", "Phone Number", "Extension",
"Department", "In Trunk Group", "Email Address", "Is Active". "Is Active" is "true" or
"false". "Phone Number" is presented in the E164 format.

**Attributes:**

|Name                    |Type                       |Description                                                               |
|------------------------|---------------------------|--------------------------------------------------------------------------|
|user_call_waiting_table |List(userCallWaitingTable) |userCallWaitingTable - *Table* array of userCallWaitingTable named tuples |
</div>


## `EnterpriseUserCallingPlanSettingsGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseUserCallingPlanSettingsGetListRequest()`.

Contains a table with column headings: "Group Id", "User Id", "Last Name", "First
Name", "Hiragana Last Name", and "Hiragana First Name", "Phone Number", "Extension",
"Department", "In Trunk Group", "Email Address", "Use Custom Settings". "Use Custom
Settings" is "true" or "false". "Phone Number" is presented in the E164 format.

**Attributes:**

|Name                    |Type                       |Description                                                               |
|------------------------|---------------------------|--------------------------------------------------------------------------|
|user_calling_plan_table |List(userCallingPlanTable) |userCallingPlanTable - *Table* array of userCallingPlanTable named tuples |
</div>


## `EnterpriseUserHotelingGuestSettingsGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseUserHotelingGuestSettingsGetListRequest()`.

Contains a table with column headings: "Group Id", "User Id", "Last Name", "First
Name", "Hiragana Last Name", and "Hiragana First Name", "Phone Number", "Extension",
"Department", "In Trunk Group", "Email Address", "Is Active". "Is Active" is "true" or
"false". "Phone Number" is presented in the E164 format.

**Attributes:**

|Name                      |Type                         |Description                                                                   |
|--------------------------|-----------------------------|------------------------------------------------------------------------------|
|user_hoteling_guest_table |List(userHotelingGuestTable) |userHotelingGuestTable - *Table* array of userHotelingGuestTable named tuples |
</div>


## `EnterpriseVirtualOnNetEnterpriseExtensionsGetUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseVirtualOnNetEnterpriseExtensionsGetUserListRequest()`.

Contains a table with column headings : "Group Id", "Last Name", "First Name", "Phone
Number", "Extension", "Virtual On-Net Call Type" in a row for each user.

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `EnterpriseVoiceVPNGetPolicyListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseVoiceVPNGetListResponse()`.

Returns a 4 column table with column headings: "Location Code", "Min Extension
Length", "Max Extension Length", "Location Selection".

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|location_list |List(locationList) |locationList - *Table* array of locationList named tuples |
</div>


## `EnterpriseVoiceVPNGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseVoiceVPNGetRequest()`.

Replaced By: `EnterpriseVoiceVPNGetResponse14sp3()`

**Attributes:**

|Name              |Type |Description      |
|------------------|-----|-----------------|
|is_active         |bool |isActive         |
|default_selection |str  |defaultSelection |
|e164_selection    |str  |e164Selection    |
</div>


## `EnterpriseVoiceVPNGetResponse14sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseVoiceVPNGetRequest14sp3()`.


**Attributes:**

|Name              |Type |Description      |
|------------------|-----|-----------------|
|is_active         |bool |isActive         |
|default_selection |str  |defaultSelection |
|e164_selection    |str  |e164Selection    |
|use_phone_context |bool |usePhoneContext  |
</div>


## `ExternalAuthenticationCreateLoginTokenResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ExternalAuthenticationCreateLoginTokenRequest()`.


**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|login_token |str |loginToken |
</div>


## `GroupAccessDeviceAvailablePortGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceAvailablePortGetListRequest()`.

Contains a list of available ports in a device using static mode.  The list is empty
in case the device is using dynamic mode.

**Attributes:**

|Name        |Type      |Description           |
|------------|----------|----------------------|
|port_number |List[int] |portNumber *Optional* |
</div>


## `GroupAccessDeviceCustomTagGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceCustomTagGetListRequest()`.

Contains a table of custom configuration tags managed by the Device Management System
on a per-device profile basis.  In AS data mode, the column headings are: "Tag Name",
"Tag Value", "Actual Tag Value". In XS data mode, the column headings are: "Tag Name",
"Tag Value", "Actual Tag Value" if request is invoked by an admin without system
privileges.  "Tag Name", "Tag Value", "Is Encrypted", "Actual Tag Value" if request is
invoked by an admin with system privileges.

**Attributes:**

|Name                     |Type                        |Description                                                                 |
|-------------------------|----------------------------|----------------------------------------------------------------------------|
|device_custom_tags_table |List(deviceCustomTagsTable) |deviceCustomTagsTable - *Table* array of deviceCustomTagsTable named tuples |
</div>


## `GroupAccessDeviceDeviceActivationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceDeviceActivationGetRequest()`.

The response contains the activation code (if available), the expiry time (if
available) and the activation state.  The expiryTime is represented as a timestamp,
i.e.  the number of milliseconds since January 1, 1970, 00:00:00 GMT.

**Attributes:**

|Name             |Type|Description               |
|-----------------|----|--------------------------|
|activation_code  |str |activationCode *Optional* |
|expiry_time      |int |expiryTime *Optional*     |
|activation_state |str |activationState           |
</div>


## `GroupAccessDeviceFileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceFileGetListRequest()`.

Contains a table of device files managed by the Device Management System on a per-
device profile basis.  The column headings are: "File Type", "File Format", "Is
Authenticated".

Replaced By: `GroupAccessDeviceFileGetListResponse14sp8()`

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|device_files_table |List(deviceFilesTable) |deviceFilesTable - *Table* array of deviceFilesTable named tuples |
</div>


## `GroupAccessDeviceFileGetListResponse14sp8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceFileGetListRequest14sp8()`.

Contains a table of device files managed by the Device Management System on a per-
device profile basis.  The column headings are: "File Format", "Is Authenticated",
"Access URL", "Repository URL", "Template URL", "Extended Capture URL", "Is File
Linked". The following column is only populated in AS data mode for leaf devices.  "Is
File Linked"

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|device_files_table |List(deviceFilesTable) |deviceFilesTable - *Table* array of deviceFilesTable named tuples |
</div>


## `GroupAccessDeviceFileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceFileGetRequest()`.

Replaced By: `GroupAccessDeviceFileGetResponse14sp8()`

**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|file_source             |str |fileSource                       |
|configuration_file_name |str |configurationFileName *Optional* |
</div>


## `GroupAccessDeviceFileGetResponse14sp8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceFileGetRequest14sp8()`.

Replaced by: `GroupAccessDeviceFileGetResponse16sp1()`

**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|file_source             |str |fileSource                       |
|configuration_file_name |str |configurationFileName *Optional* |
</div>


## `GroupAccessDeviceFileGetResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceFileGetRequest16sp1()`.

Replaced by: `GroupAccessDeviceFileGetResponse20()`

**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|file_source             |str |fileSource                       |
|configuration_file_name |str |configurationFileName *Optional* |
|access_url              |str |accessUrl                        |
|repository_url          |str |repositoryUrl *Optional*         |
|template_url            |str |templateUrl *Optional*           |
</div>


## `GroupAccessDeviceFileGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceFileGetRequest20()`.


**Attributes:**

|Name                     |Type |Description                       |
|-------------------------|-----|----------------------------------|
|file_source              |str  |fileSource                        |
|configuration_file_name  |str  |configurationFileName *Optional*  |
|access_url               |str  |accessUrl                         |
|repository_url           |str  |repositoryUrl *Optional*          |
|template_url             |str  |templateUrl *Optional*            |
|extended_capture_enabled |bool |extendedCaptureEnabled *Optional* |
|extended_capture_url     |str  |extendedCaptureURL *Optional*     |
</div>


## `GroupAccessDeviceGetAvailableCustomTagListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetAvailableCustomTagListRequest()`.

Contains a table of all available custom tags managed by the Device Management System
on a per-device profile basis.  In AS data mode, the column headings are: "Tag Name",
"Tag Value", "Tag Level", "Tag Set Name", "Region Name". In XS data mode: the column
headings are: "Tag Name", "Tag Value", "Tag Level", "Tag Set Name", "Is Encrypted" if
request is invoked by a System administrator or by an administrator with higher
priviledges, otherwise the column headings are: "Tag Name", "Tag Value", "Tag Level",
"Tag Source", "Tag Set Name". "Tag Level" can take the value: "System Default",
"System", "Service Provider", "Group" or "Device Profile".

**Attributes:**

|Name                               |Type                                 |Description                                                                                   |
|-----------------------------------|-------------------------------------|----------------------------------------------------------------------------------------------|
|device_available_custom_tags_table |List(deviceAvailableCustomTagsTable) |deviceAvailableCustomTagsTable - *Table* array of deviceAvailableCustomTagsTable named tuples |
</div>


## `GroupAccessDeviceGetAvailableDetailListResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetAvailableDetailListRequest14()`.


**Attributes:**

|Name                    |Type                            |Description                      |
|------------------------|--------------------------------|---------------------------------|
|available_access_device |List[OCI.availableAccessDevice] |availableAccessDevice *Optional* |
</div>


## `GroupAccessDeviceGetAvailableDetailListResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetAvailableDetailListRequest19()`.


**Attributes:**

|Name                    |Type                            |Description                      |
|------------------------|--------------------------------|---------------------------------|
|available_access_device |List[OCI.availableAccessDevice] |availableAccessDevice *Optional* |
</div>


## `GroupAccessDeviceGetEnhancedConfigurationTypeListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetEnhancedConfigurationTypeListRequest()`.


**Attributes:**

|Name        |Type      |Description           |
|------------|----------|----------------------|
|device_type |List[str] |deviceType *Optional* |
</div>


## `GroupAccessDeviceGetEnhancedConfigurationTypeResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetEnhancedConfigurationTypeRequest14()`.


**Attributes:**

|Name                            |Type |Description                      |
|--------------------------------|-----|---------------------------------|
|supports_enhanced_configuration |bool |supportsEnhancedConfiguration    |
|supports_reset                  |bool |supportsReset                    |
|configuration_type              |str  |configurationType *Optional*     |
|configuration_file_name         |str  |configurationFileName *Optional* |
</div>


## `GroupAccessDeviceGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetListRequest()`.

Contains a table of devices configured in the group.  The column headings are: "Device
Name", "Device Type", "Available Ports", "Net Address", "MAC Address", "Status",
"Version", and "Access Device External Id". The following columns are only populated
in AS data mode: "Access Device External Id"

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|access_device_table |List(accessDeviceTable) |accessDeviceTable - *Table* array of accessDeviceTable named tuples |
</div>


## `GroupAccessDeviceGetNativeTagsWithLogicListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetNativeTagsWithLogicListRequest()`.

Contains a table of all native tags with logic managed by the Device Management System
on a per-device profile basis.  The column headings are: "Tag Name", "Tag Value".

**Attributes:**

|Name                                |Type                                 |Description                                                                                   |
|------------------------------------|-------------------------------------|----------------------------------------------------------------------------------------------|
|device_native_tags_with_logic_table |List(deviceNativeTagsWithLogicTable) |deviceNativeTagsWithLogicTable - *Table* array of deviceNativeTagsWithLogicTable named tuples |
</div>


## `GroupAccessDeviceGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetPagedSortedListRequest()`.

Contains a table of devices configured in the group.  The column headings are: "Device
Name", "Device Type", "Available Ports", "Net Address", "MAC Address", "Status",
"Version", and "Support Visual Device Management API". When CloudPBX is not licensed,
the column "Support Visual Device Management API" values are not returned.  Replaced
by `GroupAccessDeviceGetPagedSortedListResponse22()`.

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|access_device_table |List(accessDeviceTable) |accessDeviceTable - *Table* array of accessDeviceTable named tuples |
</div>


## `GroupAccessDeviceGetPagedSortedListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetPagedSortedListRequest22()`.

Contains a table of devices configured in the group.  The column headings are: "Device
Name", "Device Type", "Available Ports", "Net Address", "MAC Address", "Status",
"Version", and "Support Visual Device Management API". When CloudPBX is not licensed,
the column "Support Visual Device Management API" values are not returned.

**Attributes:**

|Name                 |Type                    |Description                                                         |
|---------------------|------------------------|--------------------------------------------------------------------|
|total_number_of_rows |int                     |totalNumberOfRows *Optional*                                        |
|access_device_table  |List(accessDeviceTable) |accessDeviceTable - *Table* array of accessDeviceTable named tuples |
</div>


## `GroupAccessDeviceGetUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetUserListRequest()`.

The column headings for the deviceUserTable are: "Line/Port", "Last Name", "First
Name", "Phone Number", "User Id", "User Type", "Endpoint Type", "Order", "Primary
Line/Port", "Extension", "Department", "Email Address", "Private Identity". In IMS
mode, the table will contain a row for each TEL-URI in the Phone Number column.  In
Standalone mode, rows for the alternate numbers are not included.  The User Type
column contains one of the enumerated UserType values.  The Endpoint Type column
contains one of the enumerated EndpointType values.  The Private Identity column is
empty is AS mode.  Replaced by: `GroupAccessDeviceGetUserListResponse21sp1()` in AS
data mode.

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|device_user_table |List(deviceUserTable) |deviceUserTable - *Table* array of deviceUserTable named tuples |
</div>


## `GroupAccessDeviceGetUserListResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetUserListRequest21sp1()`.

The column headings for the deviceUserTable are: "Line/Port", "Last Name", "First
Name", "Phone Number", "User Id", "User Type", "Endpoint Type", "Order", "Primary
Line/Port", "Extension", "Department", "Email Address", "Private Identity". In IMS
mode, the table will contain a row for each TEL-URI in the Phone Number column.  In
Standalone mode, rows for the alternate numbers are not included.  The User Type
column contains one of the enumerated UserType values.  The Endpoint Type column
contains one of the enumerated EndpointType21sp1 values.  The value Mobility in
Endpoint Type column is only applicable in AS data mode.  The Private Identity column
is empty is AS mode.

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|device_user_table |List(deviceUserTable) |deviceUserTable - *Table* array of deviceUserTable named tuples |
</div>


## `GroupAccessDeviceTagSetGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceTagSetGetRequest()`.

The response includes a tag set name defined in the access device.

**Attributes:**

|Name         |Type|Description           |
|-------------|----|----------------------|
|tag_set_name |str |tagSetName *Optional* |
</div>


## `GroupAccountAuthorizationCodesGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupAccountAuthorizationCodesGetAvailableUserListRequest()`.

The column headings are: "User Id", "Last Name", "First Name", "Hiragana Last Name"
and "Hiragana First Name", "Phone Number", "Extension", "Department", "Email Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupAccountAuthorizationCodesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccountAuthorizationCodesGetRequest()`.

The tables has the following column headings: "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name", "Phone Number", "Extension",
"Department", "Email Address".

**Attributes:**

|Name                            |Type                          |Description                                                                     |
|--------------------------------|------------------------------|--------------------------------------------------------------------------------|
|type                            |str                           |type                                                                            |
|number_of_digits                |int                           |numberOfDigits                                                                  |
|allow_local_and_toll_free_calls |bool                          |allowLocalAndTollFreeCalls                                                      |
|mandatory_usage_user_table      |List(mandatoryUsageUserTable) |mandatoryUsageUserTable - *Table* array of mandatoryUsageUserTable named tuples |
|optional_usage_user_table       |List(optionalUsageUserTable)  |optionalUsageUserTable - *Table* array of optionalUsageUserTable named tuples   |
</div>


## `GroupAdminAlternateIdGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdminAlternateIdGetListRequest()`.

Contains a table of the main admin user id and the alternate admin user ids, the
column headings are: "User Id", "Description", "Alternate". The possible values for
"Alternate" are "true" and "false". The "Description" is only present for alternate
admin user Ids.

**Attributes:**

|Name                |Type                   |Description                                                       |
|--------------------|-----------------------|------------------------------------------------------------------|
|admin_user_id_table |List(adminUserIdTable) |adminUserIdTable - *Table* array of adminUserIdTable named tuples |
</div>


## `GroupAdminGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdminGetListRequest()`.

Contains a 7 column table with column headings "Administrator ID", "Last Name", "First
Name", "Department", "Language", "Locale" and "Encoding". The following columns are
only returned in AS data mode: "Locale" and "Encoding"

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|group_admin_table |List(groupAdminTable) |groupAdminTable - *Table* array of groupAdminTable named tuples |
</div>


## `GroupAdminGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdminGetPagedSortedListRequest()`.

Contains a 8 column table with column headings "Administrator ID", "Last Name", "First
Name", "Administrator Type", "Department", "Language", "Locale" and "Encoding". The
following columns are only returned in AS data mode: "Locale" and "Encoding".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|group_admin_table |List(groupAdminTable) |groupAdminTable - *Table* array of groupAdminTable named tuples |
</div>


## `GroupAdminGetPolicyResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdminGetPolicyRequest()`.

Contains the policy settings for the group administrator.

**Attributes:**

|Name                             |Type|Description                   |
|---------------------------------|----|------------------------------|
|profile_access                   |str |profileAccess                 |
|user_access                      |str |userAccess                    |
|admin_access                     |str |adminAccess                   |
|department_access                |str |departmentAccess              |
|access_device_access             |str |accessDeviceAccess            |
|enhanced_service_instance_access |str |enhancedServiceInstanceAccess |
|feature_access_code_access       |str |featureAccessCodeAccess       |
|phone_number_extension_access    |str |phoneNumberExtensionAccess    |
|service_access                   |str |serviceAccess                 |
</div>


## `GroupAdminGetPolicyResponse14sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdminGetPolicyRequest14sp1()`.

Contains the policy settings for the group administrator.

**Attributes:**

|Name                             |Type|Description                   |
|---------------------------------|----|------------------------------|
|profile_access                   |str |profileAccess                 |
|user_access                      |str |userAccess                    |
|admin_access                     |str |adminAccess                   |
|department_access                |str |departmentAccess              |
|access_device_access             |str |accessDeviceAccess            |
|enhanced_service_instance_access |str |enhancedServiceInstanceAccess |
|feature_access_code_access       |str |featureAccessCodeAccess       |
|phone_number_extension_access    |str |phoneNumberExtensionAccess    |
|service_access                   |str |serviceAccess                 |
|trunk_group_access               |str |trunkGroupAccess              |
</div>


## `GroupAdminGetPolicyResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdminGetPolicyRequest16sp1()`.

Contains the policy settings for the group administrator.  Replaced by:
`GroupAdminGetPolicyRequest17()`

**Attributes:**

|Name                             |Type|Description                   |
|---------------------------------|----|------------------------------|
|profile_access                   |str |profileAccess                 |
|user_access                      |str |userAccess                    |
|admin_access                     |str |adminAccess                   |
|department_access                |str |departmentAccess              |
|access_device_access             |str |accessDeviceAccess            |
|enhanced_service_instance_access |str |enhancedServiceInstanceAccess |
|feature_access_code_access       |str |featureAccessCodeAccess       |
|phone_number_extension_access    |str |phoneNumberExtensionAccess    |
|service_access                   |str |serviceAccess                 |
|trunk_group_access               |str |trunkGroupAccess              |
|session_admission_control_access |str |sessionAdmissionControlAccess |
</div>


## `GroupAdminGetPolicyResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdminGetPolicyRequest16sp2()`.

Contains the policy settings for the group administrator.

**Attributes:**

|Name                             |Type|Description                   |
|---------------------------------|----|------------------------------|
|profile_access                   |str |profileAccess                 |
|user_access                      |str |userAccess                    |
|admin_access                     |str |adminAccess                   |
|department_access                |str |departmentAccess              |
|access_device_access             |str |accessDeviceAccess            |
|enhanced_service_instance_access |str |enhancedServiceInstanceAccess |
|feature_access_code_access       |str |featureAccessCodeAccess       |
|phone_number_extension_access    |str |phoneNumberExtensionAccess    |
|calling_line_id_number_access    |str |callingLineIdNumberAccess     |
|service_access                   |str |serviceAccess                 |
|trunk_group_access               |str |trunkGroupAccess              |
|session_admission_control_access |str |sessionAdmissionControlAccess |
|dialable_caller_id_access        |str |dialableCallerIDAccess        |
</div>


## `GroupAdminGetPolicyResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdminGetPolicyRequest17()`.

Contains the policy settings for the group administrator.

**Attributes:**

|Name                             |Type|Description                   |
|---------------------------------|----|------------------------------|
|profile_access                   |str |profileAccess                 |
|user_access                      |str |userAccess                    |
|admin_access                     |str |adminAccess                   |
|department_access                |str |departmentAccess              |
|access_device_access             |str |accessDeviceAccess            |
|enhanced_service_instance_access |str |enhancedServiceInstanceAccess |
|feature_access_code_access       |str |featureAccessCodeAccess       |
|phone_number_extension_access    |str |phoneNumberExtensionAccess    |
|calling_line_id_number_access    |str |callingLineIdNumberAccess     |
|service_access                   |str |serviceAccess                 |
|trunk_group_access               |str |trunkGroupAccess              |
|session_admission_control_access |str |sessionAdmissionControlAccess |
|office_zone_access               |str |officeZoneAccess              |
</div>


## `GroupAdminGetPolicyResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdminGetPolicyRequest17sp3()`.

Contains the policy settings for the group administrator.  The following elements are
only used in AS data mode: dialableCallerIDAccess

**Attributes:**

|Name                             |Type|Description                   |
|---------------------------------|----|------------------------------|
|profile_access                   |str |profileAccess                 |
|user_access                      |str |userAccess                    |
|admin_access                     |str |adminAccess                   |
|department_access                |str |departmentAccess              |
|access_device_access             |str |accessDeviceAccess            |
|enhanced_service_instance_access |str |enhancedServiceInstanceAccess |
|feature_access_code_access       |str |featureAccessCodeAccess       |
|phone_number_extension_access    |str |phoneNumberExtensionAccess    |
|calling_line_id_number_access    |str |callingLineIdNumberAccess     |
|service_access                   |str |serviceAccess                 |
|trunk_group_access               |str |trunkGroupAccess              |
|session_admission_control_access |str |sessionAdmissionControlAccess |
|office_zone_access               |str |officeZoneAccess              |
|dialable_caller_id_access        |str |dialableCallerIDAccess        |
</div>


## `GroupAdminGetPolicyResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdminGetPolicyRequest18()`.

Contains the policy settings for the group administrator.  The following elements are
only used in AS data mode: dialableCallerIDAccess

**Attributes:**

|Name                             |Type|Description                   |
|---------------------------------|----|------------------------------|
|profile_access                   |str |profileAccess                 |
|user_access                      |str |userAccess                    |
|admin_access                     |str |adminAccess                   |
|department_access                |str |departmentAccess              |
|access_device_access             |str |accessDeviceAccess            |
|enhanced_service_instance_access |str |enhancedServiceInstanceAccess |
|feature_access_code_access       |str |featureAccessCodeAccess       |
|phone_number_extension_access    |str |phoneNumberExtensionAccess    |
|calling_line_id_number_access    |str |callingLineIdNumberAccess     |
|service_access                   |str |serviceAccess                 |
|trunk_group_access               |str |trunkGroupAccess              |
|session_admission_control_access |str |sessionAdmissionControlAccess |
|office_zone_access               |str |officeZoneAccess              |
|number_activation_access         |str |numberActivationAccess        |
|dialable_caller_id_access        |str |dialableCallerIDAccess        |
</div>


## `GroupAdminGetPolicyResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdminGetPolicyRequest19sp1()`.

Contains the policy settings for the group administrator.  The following elements are
only used in AS data mode: dialableCallerIDAccess The following elements are only used
in AS data mode and not returned in XS data mode communicationBarringUserProfileAccess
(This element will not be returned in the response for Service Provider group
administrators)

**Attributes:**

|Name                                      |Type|Description                                      |
|------------------------------------------|----|-------------------------------------------------|
|profile_access                            |str |profileAccess                                    |
|user_access                               |str |userAccess                                       |
|admin_access                              |str |adminAccess                                      |
|department_access                         |str |departmentAccess                                 |
|access_device_access                      |str |accessDeviceAccess                               |
|enhanced_service_instance_access          |str |enhancedServiceInstanceAccess                    |
|feature_access_code_access                |str |featureAccessCodeAccess                          |
|phone_number_extension_access             |str |phoneNumberExtensionAccess                       |
|calling_line_id_number_access             |str |callingLineIdNumberAccess                        |
|service_access                            |str |serviceAccess                                    |
|trunk_group_access                        |str |trunkGroupAccess                                 |
|session_admission_control_access          |str |sessionAdmissionControlAccess                    |
|office_zone_access                        |str |officeZoneAccess                                 |
|number_activation_access                  |str |numberActivationAccess                           |
|dialable_caller_id_access                 |str |dialableCallerIDAccess                           |
|communication_barring_user_profile_access |str |communicationBarringUserProfileAccess *Optional* |
</div>


## `GroupAdminGetPolicyResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdminGetPolicyRequest20()`.

Contains the policy settings for the group administrator.  The following elements are
only used in AS data mode: dialableCallerIDAccess verifyTranslationAndroutingAccess,
value "None" is returned in XS data mode The following elements are only used in AS
data mode and not returned in XS data mode: communicationBarringUserProfileAccess
(This element is only returned for groups in an enterprise)

**Attributes:**

|Name                                      |Type|Description                                      |
|------------------------------------------|----|-------------------------------------------------|
|profile_access                            |str |profileAccess                                    |
|user_access                               |str |userAccess                                       |
|admin_access                              |str |adminAccess                                      |
|department_access                         |str |departmentAccess                                 |
|access_device_access                      |str |accessDeviceAccess                               |
|enhanced_service_instance_access          |str |enhancedServiceInstanceAccess                    |
|feature_access_code_access                |str |featureAccessCodeAccess                          |
|phone_number_extension_access             |str |phoneNumberExtensionAccess                       |
|calling_line_id_number_access             |str |callingLineIdNumberAccess                        |
|service_access                            |str |serviceAccess                                    |
|trunk_group_access                        |str |trunkGroupAccess                                 |
|session_admission_control_access          |str |sessionAdmissionControlAccess                    |
|office_zone_access                        |str |officeZoneAccess                                 |
|number_activation_access                  |str |numberActivationAccess                           |
|dialable_caller_id_access                 |str |dialableCallerIDAccess                           |
|verify_translation_and_routing_access     |str |verifyTranslationAndRoutingAccess                |
|communication_barring_user_profile_access |str |communicationBarringUserProfileAccess *Optional* |
</div>


## `GroupAdminGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupAdminGetRequest()`.

The response contains the group administrators profile information.  Replaced by
`GroupAdminGetResponse21sp1()`

**Attributes:**

|Name                |Type|Description          |
|--------------------|----|---------------------|
|service_provider_id |str |serviceProviderId    |
|group_id            |str |groupId              |
|first_name          |str |firstName *Optional* |
|last_name           |str |lastName *Optional*  |
|language            |str |language             |
</div>


## `GroupAdminGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupAdminGetRequest21sp1()`.

The response contains the group administrators profile information.  Replaced by:
`GroupAdminGetResponse22()`.

**Attributes:**

|Name                |Type|Description          |
|--------------------|----|---------------------|
|service_provider_id |str |serviceProviderId    |
|group_id            |str |groupId              |
|first_name          |str |firstName *Optional* |
|last_name           |str |lastName *Optional*  |
|language            |str |language             |
|locale              |str |locale               |
|encoding            |str |encoding             |
</div>


## `GroupAdminGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupAdminGetRequest22()`.

The response contains the group administrators profile information.

**Attributes:**

|Name                |Type|Description          |
|--------------------|----|---------------------|
|service_provider_id |str |serviceProviderId    |
|group_id            |str |groupId              |
|first_name          |str |firstName *Optional* |
|last_name           |str |lastName *Optional*  |
|language            |str |language             |
|locale              |str |locale               |
|encoding            |str |encoding             |
</div>


## `GroupAdministratorPasswordRulesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdministratorPasswordRulesGetRequest()`.


**Attributes:**

|Name                                        |Type |Description                                       |
|--------------------------------------------|-----|--------------------------------------------------|
|use_external_authentication                 |bool |useExternalAuthentication *Optional*              |
|allow_web_add_external_authentication_users |bool |allowWebAddExternalAuthenticationUsers *Optional* |
|disallow_user_id                            |bool |disallowUserId *Optional*                         |
|disallow_old_password                       |bool |disallowOldPassword *Optional*                    |
|disallow_reversed_old_password              |bool |disallowReversedOldPassword *Optional*            |
|restrict_min_digits                         |bool |restrictMinDigits *Optional*                      |
|min_digits                                  |int  |minDigits *Optional*                              |
|restrict_min_upper_case_letters             |bool |restrictMinUpperCaseLetters *Optional*            |
|min_upper_case_letters                      |int  |minUpperCaseLetters *Optional*                    |
|restrict_min_lower_case_letters             |bool |restrictMinLowerCaseLetters *Optional*            |
|min_lower_case_letters                      |int  |minLowerCaseLetters *Optional*                    |
|restrict_min_non_alphanumeric_characters    |bool |restrictMinNonAlphanumericCharacters *Optional*   |
|min_non_alphanumeric_characters             |int  |minNonAlphanumericCharacters *Optional*           |
|min_length                                  |int  |minLength *Optional*                              |
|max_failed_login_attempts                   |int  |maxFailedLoginAttempts *Optional*                 |
|password_expires_days                       |int  |passwordExpiresDays *Optional*                    |
|send_login_disabled_notify_email            |bool |sendLoginDisabledNotifyEmail *Optional*           |
|login_disabled_notify_email_address         |str  |loginDisabledNotifyEmailAddress *Optional*        |
|disallow_previous_passwords                 |bool |disallowPreviousPasswords *Optional*              |
|number_of_previous_passwords                |int  |numberOfPreviousPasswords *Optional*              |
</div>


## `GroupAdviceOfChargeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAdviceOfChargeGetRequest()`.

Contains a list of Advice of Charge group parameters.

**Attributes:**

|Name                               |Type |Description                     |
|-----------------------------------|-----|--------------------------------|
|use_group_level_ao_c_settings      |bool |useGroupLevelAoCSettings        |
|delay_between_notification_seconds |int  |delayBetweenNotificationSeconds |
</div>


## `GroupAnnouncementFileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAnnouncementFileGetListRequest()`.

When requested, the response contains a table with columns: "Name", "Media Type",
"File Size", "Announcement File External Id". The "Name" column contains the name of
the announcement file.  The "Media Type" column contains the media type of the
announcement File with the possible values: WMA - Windows Media Audio file WAV - A WAV
file 3GP - A 3GP file MOV - A MOV file using a H.263 or H.264 codec.  The "File Size"
column contains the file size (KB) of the announcement file.  The "Announcement File
External Id" column contains the External ID of the announcement file.

The response also contains the current total file size (KB) for the group across all
media types and the maximum total file size (MB) allowed for the group.  The following
columns are populated in AS data mode only: "Announcement File External Id"

**Attributes:**

|Name               |Type                    |Description                                                                    |
|-------------------|------------------------|-------------------------------------------------------------------------------|
|announcement_table |List(announcementTable) |announcementTable - *Table* array of announcementTable named tuples *Optional* |
|total_file_size    |int                     |totalFileSize                                                                  |
|max_file_size      |int                     |maxFileSize                                                                    |
</div>


## `GroupAnnouncementFileGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAnnouncementFileGetPagedSortedListRequest()`.

The response contains a table with columns: "Name", "Media Type", "File Size", and
"Announcement File External Id". The "Name" column contains the name of the
announcement file.  The "Media Type" column contains the media type of the
announcement File with the possible values: WMA - Windows Media Audio file WAV - A WAV
file 3GP - A 3GP file MOV - A MOV file using a H.263 or H.264 codec.  The "File Size"
column contains the file size (KB) of the announcement file.  The following columns
are populated in AS data mode only: "Announcement File External Id"

**Attributes:**

|Name               |Type                    |Description                                                                    |
|-------------------|------------------------|-------------------------------------------------------------------------------|
|announcement_table |List(announcementTable) |announcementTable - *Table* array of announcementTable named tuples *Optional* |
</div>


## `GroupAnnouncementFileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAnnouncementFileGetRequest()`.

The response contains the file size, uploaded timestamp, description and usage for an
announcement file in the user announcement repository.  The usage table has columns
"Service Name", and "Instance Name". The Service Name values correspond to string
values of the GroupService and UserService data types.  With the exception of the
string "Voice Portal" which is returned when the announcement is being used by Voice
Portal Personalized Name.  Replaced by: `GroupAnnouncementFileGetResponse22()`.

**Attributes:**

|Name          |Type             |Description                                           |
|--------------|-----------------|------------------------------------------------------|
|description   |str              |description                                           |
|filesize      |int              |filesize                                              |
|last_uploaded |str              |lastUploaded                                          |
|usage_table   |List(usageTable) |usageTable - *Table* array of usageTable named tuples |
</div>


## `GroupAnnouncementRepositoryGetSettingsResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAnnouncementFileGetSettingsRequest()`.

The response contains the current total file size (KB) for the group across all media
types and the maximum total file size (MB) allowed for the group.  It also indicates
the maximum file size for individual audio and video files.

**Attributes:**

|Name                |Type|Description      |
|--------------------|----|-----------------|
|total_file_size     |int |totalFileSize    |
|max_audio_file_size |int |maxAudioFileSize |
|max_video_file_size |int |maxVideoFileSize |
|max_file_size       |int |maxFileSize      |
</div>


## `GroupApplicationServerSetGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupApplicationServerSetGetRequest()`.

The response contains the group's Application Server set information.

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|application_server_set_name |str |applicationServerSetName *Optional* |
</div>


## `GroupAutoAttendantGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupAutoAttendantGetInstanceListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Video", "Phone
Number", "Extension", "Department", "Is Active", "Type". The column values for "Video"
and "Is Active" can either be true, or false.  The column values for "Type" can either
be Basic or Standard.  In XS Mode the value for the "Type" column will always be
populated with Basic.

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|auto_attendant_table |List(autoAttendantTable) |autoAttendantTable - *Table* array of autoAttendantTable named tuples |
</div>


## `GroupAutoAttendantGetInstancePagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupAutoAttendantGetInstancePagedSortedListRequest()`.

The response contains a table with columns: "Service User Id", "Name", "Phone Number",
"Is Phone Number Activated", "Country Code", "National Prefix", "Extension",
"Department", "Department Type", "Parent Department", "Parent Department Type", "Is
Active", "Type". The column values for "Is Active" can either be true, or false.  The
column values for "Type" can either be Basic or Standard.  The "Department Type" and
"Parent Department Type" columns will contain the values "Enterprise" or "Group". In
XS Mode the value for the "Type" column will always be populated with Basic.

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|auto_attendant_table |List(autoAttendantTable) |autoAttendantTable - *Table* array of autoAttendantTable named tuples |
</div>


## `GroupAutoAttendantSubmenuGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupAutoAttendantSubmenuGetListRequest()`.

Contains a table with column headings: "Submenu Id" "Is Used". The column values for
"Is Used" can either be true, or false.

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|submenu_table |List(submenuTable) |submenuTable - *Table* array of submenuTable named tuples |
</div>


## `GroupAutoAttendantSubmenuGetUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupAutoAttendantSubmenuGetUsageListRequest()`.

Contains a table with column headings: "Type" and "Submenu ID". The "Type" Column will
contain one of the following: Business Hours Menu, After Hours Menu, Holiday Menu or
Submenu.  The "Submenu ID" Column will be left blank when the "Type" Column contains
one of the base menu types (Business Hours Menu, After Hours Menu or Holiday Menu),
and will contain the Submenu ID when the "Type" Column contains type Submenu.

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|submenu_table |List(submenuTable) |submenuTable - *Table* array of submenuTable named tuples |
</div>


## `GroupBroadWorksAnywhereGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupBroadWorksAnywhereGetInstanceListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Phone Number",
"Extension", "Department", "Is Active". The column value for "Is Active" can either be
true, or false.

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|broad_works_anywhere_table |List(broadWorksAnywhereTable) |broadWorksAnywhereTable - *Table* array of broadWorksAnywhereTable named tuples |
</div>


## `GroupBroadWorksMobileManagerGetDomainListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupBroadWorksMobileManagerGetDomainListRequest()`.

Contains the list of domains.

**Attributes:**

|Name        |Type      |Description           |
|------------|----------|----------------------|
|domain_name |List[str] |domainName *Optional* |
</div>


## `GroupBroadWorksMobileManagerGetHomeZoneListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupBroadWorksMobileManagerGetHomeZoneListRequest()`.

Contains a table with column headings: "Home Zone Id", "Domain Name", "Mobile Country
Code", "Mobile Network Code", "Local Area Code" and "Cell Identity".

**Attributes:**

|Name             |Type                 |Description                                                   |
|-----------------|---------------------|--------------------------------------------------------------|
|home_zones_table |List(homeZonesTable) |homeZonesTable - *Table* array of homeZonesTable named tuples |
</div>


## `GroupBroadWorksMobileManagerGetHomeZoneResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupBroadWorksMobileManagerGetHomeZoneRequest()`

**Attributes:**

|Name                  |Type|Description        |
|----------------------|----|-------------------|
|home_zone_domain_name |str |homeZoneDomainName |
|mobile_country_code   |str |mobileCountryCode  |
|mobile_network_code   |str |mobileNetworkCode  |
|location_area_code    |str |locationAreaCode   |
|cell_identity         |str |cellIdentity       |
</div>


## `GroupBroadWorksMobileManagerGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupBroadWorksMobileManagerGetRequest()`

**Attributes:**

|Name                            |Type |Description                   |
|--------------------------------|-----|------------------------------|
|mobile_manager_id               |str  |mobileManagerId               |
|name                            |str  |name                          |
|is_active                       |bool |isActive                      |
|local_to_carrier                |bool |localToCarrier                |
|deactivation_reason             |str  |deactivationReason *Optional* |
|max_tx_per_second_enabled       |bool |maxTxPerSecondEnabled         |
|max_tx_per_second               |int  |maxTxPerSecond *Optional*     |
|tldn_enabled                    |bool |tldnEnabled                   |
|generic_number_enabled          |bool |genericNumberEnabled          |
|mobile_state_check_enabled      |bool |mobileStateCheckEnabled       |
|location_based_services_enabled |bool |locationBasedServicesEnabled  |
</div>


## `GroupBroadWorksMobilityGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `GroupBroadWorksMobilityGetRequest()`.


**Attributes:**

|Name                         |Type |Description               |
|-----------------------------|-----|--------------------------|
|use_setting_level            |str  |useSettingLevel           |
|enable_location_services     |bool |enableLocationServices    |
|enable_msrn_lookup           |bool |enableMSRNLookup          |
|enable_mobile_state_checking |bool |enableMobileStateChecking |
|deny_call_originations       |bool |denyCallOriginations      |
|deny_call_terminations       |bool |denyCallTerminations      |
</div>


## `GroupBroadWorksMobilityGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `GroupBroadWorksMobilityGetRequest19sp1()`.

Replaced by: `GroupBroadWorksMobilityGetResponse22()` in AS data mode

**Attributes:**

|Name                            |Type |Description                   |
|--------------------------------|-----|------------------------------|
|use_setting_level               |str  |useSettingLevel               |
|enable_location_services        |bool |enableLocationServices        |
|enable_msrn_lookup              |bool |enableMSRNLookup              |
|enable_mobile_state_checking    |bool |enableMobileStateChecking     |
|deny_call_originations          |bool |denyCallOriginations          |
|deny_call_terminations          |bool |denyCallTerminations          |
|enable_announcement_suppression |bool |enableAnnouncementSuppression |
</div>


## `GroupBroadWorksMobilityGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `GroupBroadWorksMobilityGetRequest21sp1()`.

Replaced by `GroupBroadWorksMobilityGetResponse22V2()`.

**Attributes:**

|Name                                           |Type |Description                               |
|-----------------------------------------------|-----|------------------------------------------|
|use_setting_level                              |str  |useSettingLevel                           |
|enable_location_services                       |bool |enableLocationServices                    |
|enable_msrn_lookup                             |bool |enableMSRNLookup                          |
|enable_mobile_state_checking                   |bool |enableMobileStateChecking                 |
|deny_call_originations                         |bool |denyCallOriginations                      |
|deny_call_terminations                         |bool |denyCallTerminations                      |
|enable_announcement_suppression                |bool |enableAnnouncementSuppression             |
|enable_internal_clid_delivery_access_locations |bool |enableInternalCLIDDeliveryAccessLocations |
</div>


## `GroupBroadWorksMobilityGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `GroupBroadWorksMobilityGetRequest22()`.

Replaced by `GroupBroadWorksMobilityGetResponse22V2()`.

**Attributes:**

|Name                            |Type |Description                   |
|--------------------------------|-----|------------------------------|
|use_setting_level               |str  |useSettingLevel               |
|enable_location_services        |bool |enableLocationServices        |
|enable_msrn_lookup              |bool |enableMSRNLookup              |
|enable_mobile_state_checking    |bool |enableMobileStateChecking     |
|deny_call_originations          |bool |denyCallOriginations          |
|deny_call_terminations          |bool |denyCallTerminations          |
|enable_announcement_suppression |bool |enableAnnouncementSuppression |
|enable_internal_clid_delivery   |bool |enableInternalCLIDDelivery    |
</div>


## `GroupBroadWorksMobilityGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `GroupBroadWorksMobilityGetRequest22V2()`.

Replaced by `GroupBroadWorksMobilityGetResponse22V3()`.

**Attributes:**

|Name                                           |Type |Description                               |
|-----------------------------------------------|-----|------------------------------------------|
|use_setting_level                              |str  |useSettingLevel                           |
|enable_location_services                       |bool |enableLocationServices                    |
|enable_msrn_lookup                             |bool |enableMSRNLookup                          |
|enable_mobile_state_checking                   |bool |enableMobileStateChecking                 |
|deny_call_originations                         |bool |denyCallOriginations                      |
|deny_call_terminations                         |bool |denyCallTerminations                      |
|enable_announcement_suppression                |bool |enableAnnouncementSuppression             |
|enable_internal_clid_delivery                  |bool |enableInternalCLIDDelivery                |
|enable_internal_clid_delivery_access_locations |bool |enableInternalCLIDDeliveryAccessLocations |
|enable_enhanced_unreachable_state_checking     |bool |enableEnhancedUnreachableStateChecking    |
|enable_network_call_barring_status_check       |bool |enableNetworkCallBarringStatusCheck       |
</div>


## `GroupBroadWorksMobilityGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `GroupBroadWorksMobilityGetRequest22V3()`.

Replaced by `GroupBroadWorksMobilityGetResponse22V4()`.

**Attributes:**

|Name                                           |Type |Description                               |
|-----------------------------------------------|-----|------------------------------------------|
|use_setting_level                              |str  |useSettingLevel                           |
|enable_location_services                       |bool |enableLocationServices                    |
|enable_msrn_lookup                             |bool |enableMSRNLookup                          |
|enable_mobile_state_checking                   |bool |enableMobileStateChecking                 |
|deny_call_originations                         |bool |denyCallOriginations                      |
|deny_call_terminations                         |bool |denyCallTerminations                      |
|enable_announcement_suppression                |bool |enableAnnouncementSuppression             |
|enable_internal_clid_delivery                  |bool |enableInternalCLIDDelivery                |
|enable_internal_clid_delivery_access_locations |bool |enableInternalCLIDDeliveryAccessLocations |
|enable_enhanced_unreachable_state_checking     |bool |enableEnhancedUnreachableStateChecking    |
|enable_network_call_barring_status_check       |bool |enableNetworkCallBarringStatusCheck       |
|network_translation_index                      |str  |networkTranslationIndex *Optional*        |
</div>


## `GroupBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`GroupBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentListRequest()`.

The response contains a table with columns: "Mobile Number", "User Id", "Last Name",
"First Name","Phone Number", "Extension", "Department",. The "Mobile Number" column
contains a single DN. The "User Id", "Last Name" and "First Name" columns contains the
corresponding attributes of the user possessing the DN(s). The "Phone Number" column
contains a single DN. The "Department" column contains the department of the user if
it is part of a department.

**Attributes:**

|Name                                     |Type                                       |Description                                                                                               |
|-----------------------------------------|-------------------------------------------|----------------------------------------------------------------------------------------------------------|
|mobile_subscriber_directory_number_table |List(mobileSubscriberDirectoryNumberTable) |mobileSubscriberDirectoryNumberTable - *Table* array of mobileSubscriberDirectoryNumberTable named tuples |
</div>


## `GroupBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`GroupBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListRequest()`.

Contains a list of available Mobile Subscriber Directory Numbers not yet assigned to
any user.

**Attributes:**

|Name                               |Type      |Description                                |
|-----------------------------------|----------|-------------------------------------------|
|mobile_subscriber_directory_number |List[str] |mobileSubscriberDirectoryNumber *Optional* |
</div>


## `GroupCallCapacityManagementGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCapacityManagementGetAvailableUserListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallCapacityManagementGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCapacityManagementGetInstanceListRequest()`.

Contains a table with column headings: "Name", "Is Default", "Maximum Calls", "Maximum
Incoming Calls", "Maximum Outgoing Calls".

**Attributes:**

|Name                      |Type                         |Description                                                                   |
|--------------------------|-----------------------------|------------------------------------------------------------------------------|
|call_capacity_group_table |List(callCapacityGroupTable) |callCapacityGroupTable - *Table* array of callCapacityGroupTable named tuples |
</div>


## `GroupCallCapacityManagementGetInstanceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCapacityManagementGetInstanceRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name                              |Type            |Description                                         |
|----------------------------------|----------------|----------------------------------------------------|
|name                              |str             |name                                                |
|max_active_calls_allowed          |int             |maxActiveCallsAllowed                               |
|max_incoming_active_calls_allowed |int             |maxIncomingActiveCallsAllowed *Optional*            |
|max_outgoing_active_calls_allowed |int             |maxOutgoingActiveCallsAllowed *Optional*            |
|default_group_for_new_users       |bool            |defaultGroupForNewUsers                             |
|user_table                        |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallCenterAgentThresholdDefaultProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterAgentThresholdDefaultProfileGetRequest()`.

The agent table contains the agents assigned to the profile and has column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name",
"Phone Number", "Extension", "Department", "Email Address";

**Attributes:**

|Name                                                  |Type             |Description                                                      |
|------------------------------------------------------|-----------------|-----------------------------------------------------------------|
|profile_name                                          |str              |profileName                                                      |
|profile_description                                   |str              |profileDescription *Optional*                                    |
|threshold_current_call_state_idle_time_yellow         |int              |thresholdCurrentCallStateIdleTimeYellow *Optional*               |
|threshold_current_call_state_idle_time_red            |int              |thresholdCurrentCallStateIdleTimeRed *Optional*                  |
|threshold_current_call_state_on_call_time_yellow      |int              |thresholdCurrentCallStateOnCallTimeYellow *Optional*             |
|threshold_current_call_state_on_call_time_red         |int              |thresholdCurrentCallStateOnCallTimeRed *Optional*                |
|threshold_current_agent_state_unavailable_time_yellow |int              |thresholdCurrentAgentStateUnavailableTimeYellow *Optional*       |
|threshold_current_agent_state_unavailable_time_red    |int              |thresholdCurrentAgentStateUnavailableTimeRed *Optional*          |
|threshold_average_busy_in_time_yellow                 |int              |thresholdAverageBusyInTimeYellow *Optional*                      |
|threshold_average_busy_in_time_red                    |int              |thresholdAverageBusyInTimeRed *Optional*                         |
|threshold_average_busy_out_time_yellow                |int              |thresholdAverageBusyOutTimeYellow *Optional*                     |
|threshold_average_busy_out_time_red                   |int              |thresholdAverageBusyOutTimeRed *Optional*                        |
|threshold_average_wrap_up_time_yellow                 |int              |thresholdAverageWrapUpTimeYellow *Optional*                      |
|threshold_average_wrap_up_time_red                    |int              |thresholdAverageWrapUpTimeRed *Optional*                         |
|enable_notification_email                             |bool             |enableNotificationEmail                                          |
|notification_email_address                            |List[str]        |notificationEmailAddress *Optional*                              |
|agent_table                                           |List(agentTable) |agentTable - *Table* array of agentTable named tuples *Optional* |
</div>


## `GroupCallCenterAgentThresholdProfileGetAvailableAgentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterAgentThresholdProfileGetAvailableAgentListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address", "Agent Threshold Profile";

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|agent_table |List(agentTable) |agentTable - *Table* array of agentTable named tuples |
</div>


## `GroupCallCenterAgentThresholdProfileGetAvailableAgentPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`GroupCallCenterAgentThresholdProfileGetAvailableAgentPagedSortedListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address", "Agent Threshold Profile";

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|agent_table |List(agentTable) |agentTable - *Table* array of agentTable named tuples |
</div>


## `GroupCallCenterAgentThresholdProfileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterAgentThresholdProfileGetListRequest()`.

Contains a table with all the Call Center Agent Threshold Profiles in the Group.  The
column headings are: "Default", "Name", "Description".

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|profiles_table |List(profilesTable) |profilesTable - *Table* array of profilesTable named tuples |
</div>


## `GroupCallCenterAgentThresholdProfileGetPagedSortedResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterAgentThresholdProfileGetPagedSortedRequest()`.

The agentTable contains the agents assigned to the profile and has the column
headings: "User Id", "Group Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name", "Phone Number", "Extension", "Department", "Email Address";

**Attributes:**

|Name                                                  |Type             |Description                                                |
|------------------------------------------------------|-----------------|-----------------------------------------------------------|
|profile_description                                   |str              |profileDescription *Optional*                              |
|threshold_current_call_state_idle_time_yellow         |int              |thresholdCurrentCallStateIdleTimeYellow *Optional*         |
|threshold_current_call_state_idle_time_red            |int              |thresholdCurrentCallStateIdleTimeRed *Optional*            |
|threshold_current_call_state_on_call_time_yellow      |int              |thresholdCurrentCallStateOnCallTimeYellow *Optional*       |
|threshold_current_call_state_on_call_time_red         |int              |thresholdCurrentCallStateOnCallTimeRed *Optional*          |
|threshold_current_agent_state_unavailable_time_yellow |int              |thresholdCurrentAgentStateUnavailableTimeYellow *Optional* |
|threshold_current_agent_state_unavailable_time_red    |int              |thresholdCurrentAgentStateUnavailableTimeRed *Optional*    |
|threshold_average_busy_in_time_yellow                 |int              |thresholdAverageBusyInTimeYellow *Optional*                |
|threshold_average_busy_in_time_red                    |int              |thresholdAverageBusyInTimeRed *Optional*                   |
|threshold_average_busy_out_time_yellow                |int              |thresholdAverageBusyOutTimeYellow *Optional*               |
|threshold_average_busy_out_time_red                   |int              |thresholdAverageBusyOutTimeRed *Optional*                  |
|threshold_average_wrap_up_time_yellow                 |int              |thresholdAverageWrapUpTimeYellow *Optional*                |
|threshold_average_wrap_up_time_red                    |int              |thresholdAverageWrapUpTimeRed *Optional*                   |
|enable_notification_email                             |bool             |enableNotificationEmail                                    |
|notification_email_address                            |List[str]        |notificationEmailAddress *Optional*                        |
|agent_table                                           |List(agentTable) |agentTable - *Table* array of agentTable named tuples      |
</div>


## `GroupCallCenterAgentThresholdProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterAgentThresholdProfileGetRequest()`.

The agentTable contains the agents assigned to the profile and has the column
headings: "User Id", "Group Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name", "Phone Number", "Extension", "Department", "Email Address";

**Attributes:**

|Name                                                  |Type             |Description                                                |
|------------------------------------------------------|-----------------|-----------------------------------------------------------|
|profile_description                                   |str              |profileDescription *Optional*                              |
|threshold_current_call_state_idle_time_yellow         |int              |thresholdCurrentCallStateIdleTimeYellow *Optional*         |
|threshold_current_call_state_idle_time_red            |int              |thresholdCurrentCallStateIdleTimeRed *Optional*            |
|threshold_current_call_state_on_call_time_yellow      |int              |thresholdCurrentCallStateOnCallTimeYellow *Optional*       |
|threshold_current_call_state_on_call_time_red         |int              |thresholdCurrentCallStateOnCallTimeRed *Optional*          |
|threshold_current_agent_state_unavailable_time_yellow |int              |thresholdCurrentAgentStateUnavailableTimeYellow *Optional* |
|threshold_current_agent_state_unavailable_time_red    |int              |thresholdCurrentAgentStateUnavailableTimeRed *Optional*    |
|threshold_average_busy_in_time_yellow                 |int              |thresholdAverageBusyInTimeYellow *Optional*                |
|threshold_average_busy_in_time_red                    |int              |thresholdAverageBusyInTimeRed *Optional*                   |
|threshold_average_busy_out_time_yellow                |int              |thresholdAverageBusyOutTimeYellow *Optional*               |
|threshold_average_busy_out_time_red                   |int              |thresholdAverageBusyOutTimeRed *Optional*                  |
|threshold_average_wrap_up_time_yellow                 |int              |thresholdAverageWrapUpTimeYellow *Optional*                |
|threshold_average_wrap_up_time_red                    |int              |thresholdAverageWrapUpTimeRed *Optional*                   |
|enable_notification_email                             |bool             |enableNotificationEmail                                    |
|notification_email_address                            |List[str]        |notificationEmailAddress *Optional*                        |
|agent_table                                           |List(agentTable) |agentTable - *Table* array of agentTable named tuples      |
</div>


## `GroupCallCenterAgentUnavailableCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterAgentUnavailableCodeGetListRequest()`.

Contains a table with column headings: "Is Active", "Code", "Description".

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|unavailable_codes_table |List(unavailableCodesTable) |unavailableCodesTable - *Table* array of unavailableCodesTable named tuples |
</div>


## `GroupCallCenterAgentUnavailableCodeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterAgentUnavailableCodeGetRequest()`

**Attributes:**

|Name        |Type |Description            |
|------------|-----|-----------------------|
|is_active   |bool |isActive               |
|description |str  |description *Optional* |
</div>


## `GroupCallCenterAgentUnavailableCodeSettingsGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterAgentUnavailableCodeSettingsGetRequest()`.

Replaced by `GroupCallCenterAgentUnavailableCodeSettingsGetResponse17sp4()`.

**Attributes:**

|Name                                                  |Type |Description                                                |
|------------------------------------------------------|-----|-----------------------------------------------------------|
|enable_agent_unavailable_codes                        |bool |enableAgentUnavailableCodes                                |
|default_agent_unavailable_code_on_dnd                 |str  |defaultAgentUnavailableCodeOnDND *Optional*                |
|default_agent_unavailable_code_on_personal_calls      |str  |defaultAgentUnavailableCodeOnPersonalCalls *Optional*      |
|default_agent_unavailable_code_on_consecutive_bounces |str  |defaultAgentUnavailableCodeOnConsecutiveBounces *Optional* |
|force_use_of_agent_unavailable_codes                  |bool |forceUseOfAgentUnavailableCodes                            |
|default_agent_unavailable_code                        |str  |defaultAgentUnavailableCode *Optional*                     |
</div>


## `GroupCallCenterAgentUnavailableCodeSettingsGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterAgentUnavailableCodeSettingsGetRequest17sp4()`.


**Attributes:**

|Name                                                  |Type |Description                                                |
|------------------------------------------------------|-----|-----------------------------------------------------------|
|enable_agent_unavailable_codes                        |bool |enableAgentUnavailableCodes                                |
|default_agent_unavailable_code_on_dnd                 |str  |defaultAgentUnavailableCodeOnDND *Optional*                |
|default_agent_unavailable_code_on_personal_calls      |str  |defaultAgentUnavailableCodeOnPersonalCalls *Optional*      |
|default_agent_unavailable_code_on_consecutive_bounces |str  |defaultAgentUnavailableCodeOnConsecutiveBounces *Optional* |
|default_agent_unavailable_code_on_not_reachable       |str  |defaultAgentUnavailableCodeOnNotReachable *Optional*       |
|force_use_of_agent_unavailable_codes                  |bool |forceUseOfAgentUnavailableCodes                            |
|default_agent_unavailable_code                        |str  |defaultAgentUnavailableCode *Optional*                     |
</div>


## `GroupCallCenterBouncedCallGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterBouncedCallGetRequest()`.


**Attributes:**

|Name                                 |Type |Description                     |
|-------------------------------------|-----|--------------------------------|
|is_active                            |bool |isActive                        |
|number_of_rings_before_bouncing_call |int  |numberOfRingsBeforeBouncingCall |
|enable_transfer                      |bool |enableTransfer *Optional*       |
|transfer_phone_number                |str  |transferPhoneNumber *Optional*  |
|bounce_call_when_agent_unavailable   |bool |bounceCallWhenAgentUnavailable  |
</div>


## `GroupCallCenterBouncedCallGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterBouncedCallGetRequest17()`.

The following elements are only used in AS data mode and not returned in XS data mode:
enableTransfer transferPhoneNumber bounceCallWhenAgentUnavailable
alertCallCenterCallOnHold alertCallCenterCallOnHoldSeconds bounceCallCenterCallOnHold
bounceCallCenterCallOnHoldSeconds

**Attributes:**

|Name                                    |Type |Description                                  |
|----------------------------------------|-----|---------------------------------------------|
|is_active                               |bool |isActive                                     |
|number_of_rings_before_bouncing_call    |int  |numberOfRingsBeforeBouncingCall              |
|enable_transfer                         |bool |enableTransfer *Optional*                    |
|transfer_phone_number                   |str  |transferPhoneNumber *Optional*               |
|bounce_call_when_agent_unavailable      |bool |bounceCallWhenAgentUnavailable *Optional*    |
|alert_call_center_call_on_hold          |bool |alertCallCenterCallOnHold *Optional*         |
|alert_call_center_call_on_hold_seconds  |int  |alertCallCenterCallOnHoldSeconds *Optional*  |
|bounce_call_center_call_on_hold         |bool |bounceCallCenterCallOnHold *Optional*        |
|bounce_call_center_call_on_hold_seconds |int  |bounceCallCenterCallOnHoldSeconds *Optional* |
</div>


## `GroupCallCenterCallDispositionCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterCallDispositionCodeGetListRequest()`.

Contains a table with column headings: "Is Active", "Code", "Description".

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|disposition_codes_table |List(dispositionCodesTable) |dispositionCodesTable - *Table* array of dispositionCodesTable named tuples |
</div>


## `GroupCallCenterCallDispositionCodeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterCallDispositionCodeGetRequest()`

**Attributes:**

|Name        |Type |Description            |
|------------|-----|-----------------------|
|is_active   |bool |isActive               |
|description |str  |description *Optional* |
</div>


## `GroupCallCenterCallDispositionCodeGetUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterCallDispositionCodeGetUsageListRequest()`.

The Type column contains either "Call Center" or "Route Point". Contains a table with
column headings: "Id", "Name" and "Type".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|call_center_table |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `GroupCallCenterComfortMessageBypassGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterComfortMessageBypassGetRequest()`.


**Attributes:**

|Name                                          |Type |Description                              |
|----------------------------------------------|-----|-----------------------------------------|
|is_active                                     |bool |isActive                                 |
|call_waiting_age_threshold_seconds            |int  |callWaitingAgeThresholdSeconds           |
|play_announcement_after_ringing               |bool |playAnnouncementAfterRinging             |
|ring_time_before_playing_announcement_seconds |int  |ringTimeBeforePlayingAnnouncementSeconds |
|audio_message_selection                       |str  |audioMessageSelection                    |
|audio_file_url                                |str  |audioFileUrl *Optional*                  |
|audio_file_description                        |str  |audioFileDescription *Optional*          |
|audio_media_type                              |str  |audioMediaType *Optional*                |
|video_message_selection                       |str  |videoMessageSelection                    |
|video_file_url                                |str  |videoFileUrl *Optional*                  |
|video_file_description                        |str  |videoFileDescription *Optional*          |
|video_media_type                              |str  |videoMediaType *Optional*                |
</div>


## `GroupCallCenterCurrentAndPastAgentGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterCurrentAndPastAgentGetListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name                     |Type                        |Description                                                                 |
|-------------------------|----------------------------|----------------------------------------------------------------------------|
|agent_user_table         |List(agentUserTable)        |agentUserTable - *Table* array of agentUserTable named tuples               |
|deleted_agent_user_table |List(deletedAgentUserTable) |deletedAgentUserTable - *Table* array of deletedAgentUserTable named tuples |
</div>


## `GroupCallCenterCurrentAndPastCallCenterGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterCurrentAndPastCallCenterGetListRequest()`.


**Attributes:**

|Name                    |Type      |Description                     |
|------------------------|----------|--------------------------------|
|service_user_id         |List[str] |serviceUserId *Optional*        |
|deleted_service_user_id |List[str] |deletedServiceUserId *Optional* |
</div>


## `GroupCallCenterCurrentAndPastDNISGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterCurrentAndPastDNISGetListRequest()`.


**Attributes:**

|Name         |Type      |Description            |
|-------------|----------|-----------------------|
|name         |List[str] |name *Optional*        |
|deleted_name |List[str] |deletedName *Optional* |
</div>


## `GroupCallCenterDistinctiveRingingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterDistinctiveRingingGetRequest()`.

The following element is only used in AS data mode and not returned in XS data mode:
distinctiveRingingForceDeliveryRingPattern

**Attributes:**

|Name                                             |Type |Description                                           |
|-------------------------------------------------|-----|------------------------------------------------------|
|distinctive_ringing_call_center_calls            |bool |distinctiveRingingCallCenterCalls                     |
|distinctive_ringing_ring_pattern_for_call_center |str  |distinctiveRingingRingPatternForCallCenter            |
|distinctive_ringing_force_delivery_ring_pattern  |str  |distinctiveRingingForceDeliveryRingPattern *Optional* |
</div>


## `GroupCallCenterEnhancedGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterEnhancedGetRequest()`.


**Attributes:**

|Name                        |Type |Description              |
|----------------------------|-----|-------------------------|
|override_agent_wrap_up_time |bool |overrideAgentWrapUpTime  |
|wrap_up_seconds             |int  |wrapUpSeconds *Optional* |
</div>


## `GroupCallCenterEnhancedReportingBrandingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterEnhancedReportingBrandingGetRequest()`.


**Attributes:**

|Name                      |Type|Description                        |
|--------------------------|----|-----------------------------------|
|branding_choice           |str |brandingChoice                     |
|branding_file_description |str |brandingFileDescription *Optional* |
</div>


## `GroupCallCenterEnhancedReportingGetAvailableReportTemplateListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterEnhancedReportingGetAvailableReportTemplateListRequest()`.

Contains a table with column headings: "Name", "Description" and "Level", "Is Agent
Required", "Is Call Center Required", "Is Call Center Dnis Required","Is Real Time
Report", "Is Sampling Period Required", "Call Completion Threshold Parameter", "Short
Duration Threshold Parameter", "Service Level Threshold Parameter", "Service Level
Inclusions Parameter", "Service Level Objective Threshold Parameter", "Abandoned Call
Threshold Parameter", "Service Level Threshold Parameter Number", and "Abandoned Call
Threshold Parameter Number". The possible values for "Level" are "System" and "Group".
The possible values for "Is Agent Required", "Is Call Center Required", "Is Call
Center Dnis Required", "Is Real Time Report" and "Is Sampling Period Required" are
"true" and "false". The possible values for "Call Completion Threshold Parameter",
"Short Duration Threshold Parameter", "Service Level Threshold Parameter", "Service
Level Inclusions Parameter","Service Level Objective Threshold Parameter" and
"Abandoned Call Threshold Parameter" are "Required", "Hidden" and "Does Not Apply".

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|report_template_table |List(reportTemplateTable) |reportTemplateTable - *Table* array of reportTemplateTable named tuples |
</div>


## `GroupCallCenterEnhancedReportingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterEnhancedReportingGetRequest()`.

Replaced by `GroupCallCenterEnhancedReportingGetResponse19()`

**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|reporting_server     |str |reportingServer    |
|web_statistic_source |str |webStatisticSource |
</div>


## `GroupCallCenterEnhancedReportingGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterEnhancedReportingGetRequest19()`.


**Attributes:**

|Name             |Type|Description     |
|-----------------|----|----------------|
|reporting_server |str |reportingServer |
</div>


## `GroupCallCenterEnhancedReportingReportTemplateGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterEnhancedReportingReportTemplateGetListRequest()`.

Contains a table with column headings: "Name", "Description", "Type" and "Enabled"

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|report_template_table |List(reportTemplateTable) |reportTemplateTable - *Table* array of reportTemplateTable named tuples |
</div>


## `GroupCallCenterEnhancedReportingReportTemplateGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterEnhancedReportingReportTemplateGetRequest()`.


**Attributes:**

|Name                                    |Type      |Description                                    |
|----------------------------------------|----------|-----------------------------------------------|
|description                             |str       |description *Optional*                         |
|data_template                           |str       |dataTemplate                                   |
|filter_number                           |int       |filterNumber *Optional*                        |
|xslt_template_description               |str       |xsltTemplateDescription                        |
|scope                                   |str       |scope                                          |
|is_enabled                              |bool      |isEnabled                                      |
|is_realtime_report                      |bool      |isRealtimeReport *Optional*                    |
|call_completion_threshold_param         |str       |callCompletionThresholdParam *Optional*        |
|short_duration_threshold_param          |str       |shortDurationThresholdParam *Optional*         |
|service_level_threshold_param           |str       |serviceLevelThresholdParam *Optional*          |
|service_level_inclusions_param          |str       |serviceLevelInclusionsParam *Optional*         |
|service_level_objective_threshold_param |str       |serviceLevelObjectiveThresholdParam *Optional* |
|abandoned_call_threshold_param          |str       |abandonedCallThresholdParam *Optional*         |
|service_level_threshold_param_number    |int       |serviceLevelThresholdParamNumber *Optional*    |
|abandoned_call_threshold_param_number   |int       |abandonedCallThresholdParamNumber *Optional*   |
|filter_value                            |List[str] |filterValue *Optional*                         |
</div>


## `GroupCallCenterEnhancedReportingScheduledReportGetActiveListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterEnhancedReportingScheduledReportGetActiveListRequest()`
Contains a table with column headings : "Schedule Name", "Description", "Created By",
"Is Supervisor Report", "Report Template Name", "Report Template Level" and
"Recurring".

The "Created By" can be either "Administrator" or user id if created by supervisor.
The possible values for "Recurring" are "None", "Daily", "Weekly", "Monthly" and
"Yearly". The possible values for "Report Template Level" are "System" and "Group".

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|scheduled_report_table |List(scheduledReportTable) |scheduledReportTable - *Table* array of scheduledReportTable named tuples |
</div>


## `GroupCallCenterEnhancedReportingScheduledReportGetCompletedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterEnhancedReportingScheduledReportGetCompletedListRequest()`
Contains a table with column headings : "Schedule Name", "Description", "Created By",
"Is Supervisor Report", "Report Template Name", "Report Template Level" and
"Recurring".

The "Created By" can be either "Administrator" or user id if created by supervisor.
The possible values for "Recurring" are "None", "Daily", "Weekly", "Monthly" and
"Yearly". The possible values for "Report Template Level" are "System" and "Group".

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|scheduled_report_table |List(scheduledReportTable) |scheduledReportTable - *Table* array of scheduledReportTable named tuples |
</div>


## `GroupCallCenterEnhancedReportingScheduledReportGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterEnhancedReportingScheduledReportGetListRequest()`.

Contains a table with column headings : "Schedule Name", "Description", "Created By",
"Is Supervisor Report", "Status", "Report Template Name", "Report Template Level" and
"Recurring". The "Created By" can be either "Administrator" or user id if created by
supervisor.  The possible values for "Status" are "Active", and "Completed". The
possible values for "Recurring" are "None", "Daily", "Weekly", "Monthly" and "Yearly".
The possible values for "Report Template Level" are "System" and "Group".

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|scheduled_report_table |List(scheduledReportTable) |scheduledReportTable - *Table* array of scheduledReportTable named tuples |
</div>


## `GroupCallCenterEnhancedReportingScheduledReportGetReportTemplateUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`GroupCallCenterEnhancedReportingScheduledReportGetReportTemplateUsageListRequest()`.

Contains a table with column headings: "Schedule Name", "Created By", "Created By
Supervisor", and "Is Active". The "Created By" can be either "Administrator" or user
id if created by supervisor.

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|schedule_report_table |List(scheduleReportTable) |scheduleReportTable - *Table* array of scheduleReportTable named tuples |
</div>


## `GroupCallCenterForcedForwardingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterForcedForwardingGetRequest()`.


**Attributes:**

|Name                                |Type |Description                      |
|------------------------------------|-----|---------------------------------|
|is_active                           |bool |isActive                         |
|forward_to_phone_number             |str  |forwardToPhoneNumber *Optional*  |
|allow_enable_via_fac                |bool |allowEnableViaFAC                |
|play_announcement_before_forwarding |bool |playAnnouncementBeforeForwarding |
|audio_message_selection             |str  |audioMessageSelection            |
|audio_file_url                      |str  |audioFileUrl *Optional*          |
|audio_file_description              |str  |audioFileDescription *Optional*  |
|audio_media_type                    |str  |audioMediaType *Optional*        |
|video_message_selection             |str  |videoMessageSelection            |
|video_file_url                      |str  |videoFileUrl *Optional*          |
|video_file_description              |str  |videoFileDescription *Optional*  |
|video_media_type                    |str  |videoMediaType *Optional*        |
</div>


## `GroupCallCenterGetAgentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAgentListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Weight", "Phone Number", "Extension",
"Department", "Email Address", "Skill Level". The following column is only returned in
AS data mode: "Skill Level"

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|agent_table |List(agentTable) |agentTable - *Table* array of agentTable named tuples |
</div>


## `GroupCallCenterGetAgentPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAgentPagedSortedListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Weight", "Phone Number", "Extension",
"Department", "Email Address", "Skill Level".

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|agent_table |List(agentTable) |agentTable - *Table* array of agentTable named tuples |
</div>


## `GroupCallCenterGetAnnouncementResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAnnouncementRequest()`.


**Attributes:**

|Name                                            |Type|Description                                           |
|------------------------------------------------|----|------------------------------------------------------|
|entrance_message_selection                      |str |entranceMessageSelection                              |
|entrance_message_audio_file_description         |str |entranceMessageAudioFileDescription *Optional*        |
|entrance_message_video_file_description         |str |entranceMessageVideoFileDescription *Optional*        |
|periodic_comfort_message_selection              |str |periodicComfortMessageSelection                       |
|periodic_comfort_message_audio_file_description |str |periodicComfortMessageAudioFileDescription *Optional* |
|periodic_comfort_message_video_file_description |str |periodicComfortMessageVideoFileDescription *Optional* |
|on_hold_message_selection                       |str |onHoldMessageSelection                                |
|on_hold_message_audio_file_description          |str |onHoldMessageAudioFileDescription *Optional*          |
|on_hold_message_video_file_description          |str |onHoldMessageVideoFileDescription *Optional*          |
</div>


## `GroupCallCenterGetAvailableAgentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAvailableAgentListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallCenterGetAvailableAgentPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAvailableAgentPagedSortedListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallCenterGetAvailableSupervisorListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAvailableSupervisorListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallCenterGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAvailableUserListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallCenterGetDNISAgentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetDNISAgentListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|agent_table |List(agentTable) |agentTable - *Table* array of agentTable named tuples |
</div>


## `GroupCallCenterGetDNISListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetDNISListResponse()`.

Contains a table with column headings: "Name", "Phone Number", "Extension",
"Priority", "Is Primary DNIS".

**Attributes:**

|Name                                    |Type            |Description                                         |
|----------------------------------------|----------------|----------------------------------------------------|
|display_dnis_number                     |bool            |displayDNISNumber                                   |
|display_dnis_name                       |bool            |displayDNISName                                     |
|promote_calls_from_priority1to0         |bool            |promoteCallsFromPriority1to0                        |
|promote_calls_from_priority2to1         |bool            |promoteCallsFromPriority2to1                        |
|promote_calls_from_priority3to2         |bool            |promoteCallsFromPriority3to2                        |
|promote_calls_from_priority1to0_seconds |int             |promoteCallsFromPriority1to0Seconds                 |
|promote_calls_from_priority2to1_seconds |int             |promoteCallsFromPriority2to1Seconds                 |
|promote_calls_from_priority3to2_seconds |int             |promoteCallsFromPriority3to2Seconds                 |
|dnis_table                              |List(dnisTable) |dnisTable - *Table* array of dnisTable named tuples |
</div>


## `GroupCallCenterGetDNISResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetDNISResponse()`.


**Attributes:**

|Name                                  |Type |Description                         |
|--------------------------------------|-----|------------------------------------|
|dnis_phone_number                     |str  |dnisPhoneNumber *Optional*          |
|extension                             |str  |extension *Optional*                |
|use_custom_clid_settings              |bool |useCustomCLIDSettings               |
|calling_line_id_phone_number          |str  |callingLineIdPhoneNumber *Optional* |
|calling_line_id_last_name             |str  |callingLineIdLastName *Optional*    |
|calling_line_id_first_name            |str  |callingLineIdFirstName *Optional*   |
|use_custom_dnis_announcement_settings |bool |useCustomDnisAnnouncementSettings   |
|priority                              |str  |priority                            |
|allow_outgoing_acd_call               |bool |allowOutgoingACDCall                |
</div>


## `GroupCallCenterGetDistinctiveRingingResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetDistinctiveRingingRequest()`.


**Attributes:**

|Name                                             |Type |Description                                           |
|-------------------------------------------------|-----|------------------------------------------------------|
|distinctive_ringing_call_center_calls            |bool |distinctiveRingingCallCenterCalls                     |
|distinctive_ringing_ring_pattern_for_call_center |str  |distinctiveRingingRingPatternForCallCenter            |
|distinctive_ringing_force_delivery_ring_pattern  |str  |distinctiveRingingForceDeliveryRingPattern *Optional* |
</div>


## `GroupCallCenterGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetInstanceListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Video", "Phone
Number", "Extension", "Department", "Is Active", "Policy", "Type". The column values
for "Video" and "Is Active" can either be true, or false.  The column values for
"Type" can be "Basic", "Standard" or "Premium" in AS data mode and "Basic" in XS data
mode.  NOTE: prior to release 14, the policy column did not match the HuntPolicy
enumerated type.

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|call_center_table |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `GroupCallCenterGetInstancePagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetInstancePagedSortedListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Video", "Phone
Number", "Extension", "Department", "Is Active", "Policy", "Type". The column values
for "Video" and "Is Active" can either be true, or false.  The column values for
"Type" can be "Basic", "Standard" or "Premium". NOTE: prior to release 14, the policy
column did not match the HuntPolicy enumerated type.

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|call_center_table |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `GroupCallCenterGetInstanceQueueStatusResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains Call Center queue status and a table with column headings: "User Id", "First
Name", "Last Name", "Phone Number", "Extension", "Department", "Email Address".


**Attributes:**

|Name                       |Type                         |Description                                                                   |
|---------------------------|-----------------------------|------------------------------------------------------------------------------|
|number_of_calls_queued_now |int                          |numberOfCallsQueuedNow                                                        |
|agents_currently_staffed   |List(agentsCurrentlyStaffed) |agentsCurrentlyStaffed - *Table* array of agentsCurrentlyStaffed named tuples |
</div>


## `GroupCallCenterGetInstanceStatisticsReportingResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains Call Center statistics reporting settings.


**Attributes:**

|Name                      |Type |Description                       |
|--------------------------|-----|----------------------------------|
|generate_daily_report     |bool |generateDailyReport               |
|collection_period_minutes |int  |collectionPeriodMinutes           |
|reporting_email_address1  |str  |reportingEmailAddress1 *Optional* |
|reporting_email_address2  |str  |reportingEmailAddress2 *Optional* |
</div>


## `GroupCallCenterGetInstanceStatisticsReportingResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains Call Center statistics reporting settings.


**Attributes:**

|Name                      |Type |Description                       |
|--------------------------|-----|----------------------------------|
|generate_daily_report     |bool |generateDailyReport               |
|collection_period_minutes |int  |collectionPeriodMinutes           |
|reporting_email_address1  |str  |reportingEmailAddress1 *Optional* |
|reporting_email_address2  |str  |reportingEmailAddress2 *Optional* |
|statistics_source         |str  |statisticsSource                  |
</div>


## `GroupCallCenterGetInstanceStatisticsReportingResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetInstanceStatisticsReportingRequest17sp1()`.

Contains Call Center statistics reporting settings.

**Attributes:**

|Name                      |Type |Description                       |
|--------------------------|-----|----------------------------------|
|generate_daily_report     |bool |generateDailyReport               |
|collection_period_minutes |int  |collectionPeriodMinutes           |
|reporting_email_address1  |str  |reportingEmailAddress1 *Optional* |
|reporting_email_address2  |str  |reportingEmailAddress2 *Optional* |
|statistics_source         |str  |statisticsSource                  |
</div>


## `GroupCallCenterGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetRequest()`.

Replaced by `GroupCallCenterGetResponse17sp4()`.

**Attributes:**

|Name                                                        |Type |Description                                                     |
|------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_system_default_guard_timer                              |bool |useSystemDefaultGuardTimer                                      |
|enable_guard_timer                                          |bool |enableGuardTimer                                                |
|guard_timer_seconds                                         |int  |guardTimerSeconds                                               |
|use_system_default_unavailable_settings                     |bool |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
</div>


## `GroupCallCenterGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetRequest17sp4()`.

The following elements are only used in AS data mode and not returned in XS data mode:
useSystemDefaultUnavailableSettings forceAgentUnavailableOnDNDActivation
forceAgentUnavailableOnPersonalCalls forceAgentUnavailableOnBouncedCallLimit
numberConsecutiveBouncedCallsToForceAgentUnavailable
forceAgentUnavailableOnNotReachable Replaced by: `GroupCallCenterGetResponse23()`

**Attributes:**

|Name                                                        |Type |Description                                                     |
|------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_system_default_guard_timer                              |bool |useSystemDefaultGuardTimer                                      |
|enable_guard_timer                                          |bool |enableGuardTimer                                                |
|guard_timer_seconds                                         |int  |guardTimerSeconds                                               |
|use_system_default_unavailable_settings                     |bool |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|force_agent_unavailable_on_not_reachable                    |bool |forceAgentUnavailableOnNotReachable *Optional*                  |
</div>


## `GroupCallCenterGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetRequest23()`.

The following elements are only used in AS data mode and not returned in XS data mode:
useSystemDefaultUnavailableSettings forceAgentUnavailableOnDNDActivation
forceAgentUnavailableOnPersonalCalls forceAgentUnavailableOnBouncedCallLimit
numberConsecutiveBouncedCallsToForceAgentUnavailable
forceAgentUnavailableOnNotReachable wrapUpDestination

**Attributes:**

|Name                                                        |Type |Description                                                     |
|------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_system_default_guard_timer                              |bool |useSystemDefaultGuardTimer                                      |
|enable_guard_timer                                          |bool |enableGuardTimer                                                |
|guard_timer_seconds                                         |int  |guardTimerSeconds                                               |
|use_system_default_unavailable_settings                     |bool |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|force_agent_unavailable_on_not_reachable                    |bool |forceAgentUnavailableOnNotReachable *Optional*                  |
|wrap_up_destination                                         |str  |wrapUpDestination *Optional*                                    |
</div>


## `GroupCallCenterGetRoutingPolicyResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetRoutingPolicyRequest()`.

Contains a table with column headings: "Service User Id", "Name" and "Priority".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|routing_policy    |str                   |routingPolicy                                                   |
|call_center_table |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `GroupCallCenterGetSupervisorListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetSupervisorListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name". Element "reportingServerURL"" will always be blank.

Replaced By: `GroupCallCenterSupervisorReportingGetResponse()`

**Attributes:**

|Name                 |Type                  |Description                                                     |
|---------------------|----------------------|----------------------------------------------------------------|
|reporting_server_url |str                   |reportingServerURL *Optional*                                   |
|supervisor_table     |List(supervisorTable) |supervisorTable - *Table* array of supervisorTable named tuples |
</div>


## `GroupCallCenterGetSupervisorListResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetSupervisorListRequest16()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name             |Type                  |Description                                                     |
|-----------------|----------------------|----------------------------------------------------------------|
|supervisor_table |List(supervisorTable) |supervisorTable - *Table* array of supervisorTable named tuples |
</div>


## `GroupCallCenterGetUnlicensedAgentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetUnlicensedAgentListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Group Id", "Extension",
"Department", "Email Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallCenterHolidayServiceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterHolidayServiceGetRequest()`.


**Attributes:**

|Name                            |Type |Description                     |
|--------------------------------|-----|--------------------------------|
|action                          |str  |action                          |
|holiday_schedule                |str  |holidaySchedule *Optional*      |
|transfer_phone_number           |str  |transferPhoneNumber *Optional*  |
|play_announcement_before_action |bool |playAnnouncementBeforeAction    |
|audio_message_selection         |str  |audioMessageSelection           |
|audio_file_url                  |str  |audioFileUrl *Optional*         |
|audio_file_description          |str  |audioFileDescription *Optional* |
|audio_media_type                |str  |audioMediaType *Optional*       |
|video_message_selection         |str  |videoMessageSelection           |
|video_file_url                  |str  |videoFileUrl *Optional*         |
|video_file_description          |str  |videoFileDescription *Optional* |
|video_media_type                |str  |videoMediaType *Optional*       |
</div>


## `GroupCallCenterMonitoringGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterMonitoringGetRequest()`.


**Attributes:**

|Name                       |Type |Description              |
|---------------------------|-----|-------------------------|
|enable_supervisor_coaching |bool |enableSupervisorCoaching |
</div>


## `GroupCallCenterNightServiceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterNightServiceGetRequest()`.


**Attributes:**

|Name                            |Type |Description                           |
|--------------------------------|-----|--------------------------------------|
|action                          |str  |action                                |
|business_hours                  |str  |businessHours *Optional*              |
|force_night_service             |bool |forceNightService                     |
|allow_manual_override_via_fac   |bool |allowManualOverrideViaFAC             |
|transfer_phone_number           |str  |transferPhoneNumber *Optional*        |
|play_announcement_before_action |bool |playAnnouncementBeforeAction          |
|audio_message_selection         |str  |audioMessageSelection                 |
|audio_file_url                  |str  |audioFileUrl *Optional*               |
|audio_file_description          |str  |audioFileDescription *Optional*       |
|audio_media_type                |str  |audioMediaType *Optional*             |
|video_message_selection         |str  |videoMessageSelection                 |
|video_file_url                  |str  |videoFileUrl *Optional*               |
|video_file_description          |str  |videoFileDescription *Optional*       |
|video_media_type                |str  |videoMediaType *Optional*             |
|manual_announcement_mode        |str  |manualAnnouncementMode                |
|manual_audio_message_selection  |str  |manualAudioMessageSelection           |
|manual_audio_file_url           |str  |manualAudioFileUrl *Optional*         |
|manual_audio_file_description   |str  |manualAudioFileDescription *Optional* |
|manual_audio_media_type         |str  |manualAudioMediaType *Optional*       |
|manual_video_message_selection  |str  |manualVideoMessageSelection           |
|manual_video_file_url           |str  |manualVideoFileUrl *Optional*         |
|manual_video_file_description   |str  |manualVideoFileDescription *Optional* |
|manual_video_media_type         |str  |manualVideoMediaType *Optional*       |
</div>


## `GroupCallCenterOverflowGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterOverflowGetRequest()`.


**Attributes:**

|Name                                         |Type |Description                              |
|---------------------------------------------|-----|-----------------------------------------|
|action                                       |str  |action                                   |
|transfer_phone_number                        |str  |transferPhoneNumber *Optional*           |
|overflow_after_timeout                       |bool |overflowAfterTimeout                     |
|timeout_seconds                              |int  |timeoutSeconds                           |
|play_announcement_before_overflow_processing |bool |playAnnouncementBeforeOverflowProcessing |
|audio_message_selection                      |str  |audioMessageSelection                    |
|audio_file_url                               |str  |audioFileUrl *Optional*                  |
|audio_file_description                       |str  |audioFileDescription *Optional*          |
|audio_media_type                             |str  |audioMediaType *Optional*                |
|video_message_selection                      |str  |videoMessageSelection *Optional*         |
|video_file_url                               |str  |videoFileUrl *Optional*                  |
|video_file_description                       |str  |videoFileDescription *Optional*          |
|video_media_type                             |str  |videoMediaType *Optional*                |
</div>


## `GroupCallCenterQueueCallDispositionCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterQueueCallDispositionCodeGetListRequest()`.

Contains a table with column headings: "Is Active", "Code", "Description" and "Level".
Level column can be any of the values in the data type CallDispositionCodeLevel.

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|disposition_codes_table |List(dispositionCodesTable) |dispositionCodesTable - *Table* array of dispositionCodesTable named tuples |
</div>


## `GroupCallCenterQueueCallDispositionCodeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterQueueCallDispositionCodeGetRequest()`

**Attributes:**

|Name        |Type |Description            |
|------------|-----|-----------------------|
|is_active   |bool |isActive               |
|description |str  |description *Optional* |
</div>


## `GroupCallCenterQueueStatusNotificationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterQueueStatusNotificationGetRequest()`.

The response contains the call center status configuration information.

**Attributes:**

|Name                             |Type |Description                   |
|---------------------------------|-----|------------------------------|
|enable_queue_status_notification |bool |enableQueueStatusNotification |
|enable_queue_depth_threshold     |bool |enableQueueDepthThreshold     |
|enable_waiting_time_threshold    |bool |enableWaitingTimeThreshold    |
|number_of_calls_threshold        |int  |numberOfCallsThreshold        |
|waiting_time_of_calls_threshold  |int  |waitingTimeOfCallsThreshold   |
</div>


## `GroupCallCenterQueueThresholdsGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterQueueThresholdsGetRequest()`.


**Attributes:**

|Name                                          |Type      |Description                                         |
|----------------------------------------------|----------|----------------------------------------------------|
|is_active                                     |bool      |isActive                                            |
|threshold_current_calls_in_queue_yellow       |int       |thresholdCurrentCallsInQueueYellow *Optional*       |
|threshold_current_calls_in_queue_red          |int       |thresholdCurrentCallsInQueueRed *Optional*          |
|threshold_current_longest_waiting_call_yellow |int       |thresholdCurrentLongestWaitingCallYellow *Optional* |
|threshold_current_longest_waiting_call_red    |int       |thresholdCurrentLongestWaitingCallRed *Optional*    |
|threshold_average_estimated_wait_time_yellow  |int       |thresholdAverageEstimatedWaitTimeYellow *Optional*  |
|threshold_average_estimated_wait_time_red     |int       |thresholdAverageEstimatedWaitTimeRed *Optional*     |
|threshold_average_handling_time_yellow        |int       |thresholdAverageHandlingTimeYellow *Optional*       |
|threshold_average_handling_time_red           |int       |thresholdAverageHandlingTimeRed *Optional*          |
|threshold_average_speed_of_answer_yellow      |int       |thresholdAverageSpeedOfAnswerYellow *Optional*      |
|threshold_average_speed_of_answer_red         |int       |thresholdAverageSpeedOfAnswerRed *Optional*         |
|enable_notification_email                     |bool      |enableNotificationEmail                             |
|notification_email_address                    |List[str] |notificationEmailAddress *Optional*                 |
</div>


## `GroupCallCenterStrandedCallGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterStrandedCallGetRequest()`.


**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|action                  |str |action                           |
|transfer_phone_number   |str |transferPhoneNumber *Optional*   |
|audio_message_selection |str |audioMessageSelection *Optional* |
|audio_file_url          |str |audioFileUrl *Optional*          |
|audio_file_description  |str |audioFileDescription *Optional*  |
|audio_media_type        |str |audioMediaType *Optional*        |
|video_message_selection |str |videoMessageSelection *Optional* |
|video_file_url          |str |videoFileUrl *Optional*          |
|video_file_description  |str |videoFileDescription *Optional*  |
|video_media_type        |str |videoMediaType *Optional*        |
</div>


## `GroupCallCenterSupervisorReportingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterSupervisorReportingGetRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name".

**Attributes:**

|Name                  |Type                  |Description                                                     |
|----------------------|----------------------|----------------------------------------------------------------|
|reporting_server_name |str                   |reportingServerName *Optional*                                  |
|supervisor_table      |List(supervisorTable) |supervisorTable - *Table* array of supervisorTable named tuples |
</div>


## `GroupCallParkGetAvailableAlternateRecallUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallParkGetAvailableAlternateRecallUserListResponse()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name".

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|available_hunt_group_table |List(availableHuntGroupTable) |availableHuntGroupTable - *Table* array of availableHuntGroupTable named tuples |
</div>


## `GroupCallParkGetAvailableAlternateRecallUserPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`GroupCallParkGetAvailableAlternateRecallUserPagedSortedListResponse()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", “Phone Number”, “Extension”, “Department”, “Email
Address”. The Email Address will never be populated, since Hunt Groups don't have
Email Addresses.

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|available_hunt_group_table |List(availableHuntGroupTable) |availableHuntGroupTable - *Table* array of availableHuntGroupTable named tuples |
</div>


## `GroupCallParkGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallParkGetAvailableUserListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallParkGetAvailableUserPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallParkGetAvailableUserPagedSortedListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallParkGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallParkGetInstanceListRequest()`.


**Attributes:**

|Name |Type      |Description     |
|-----|----------|----------------|
|name |List[str] |name *Optional* |
</div>


## `GroupCallParkGetInstancePagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallParkGetInstancePagedSortedListRequest()`.


**Attributes:**

|Name |Type      |Description     |
|-----|----------|----------------|
|name |List[str] |name *Optional* |
</div>


## `GroupCallParkGetInstancePagedSortedResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallParkGetInstancePagedSortedRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address". The users are in the table are in the order they will try to be parked on.

**Attributes:**

|Name                     |Type            |Description                                         |
|-------------------------|----------------|----------------------------------------------------|
|recall_alternate_user_id |str             |recallAlternateUserId *Optional*                    |
|recall_to                |str             |recallTo                                            |
|user_table               |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallParkGetInstanceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallParkGetInstanceRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name". The users are in the table are in the order they
will try to be parked on.

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallParkGetInstanceResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallParkGetInstanceRequest16sp2()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address". The users are in the table are in the order they will try to be parked on.

**Attributes:**

|Name                     |Type            |Description                                         |
|-------------------------|----------------|----------------------------------------------------|
|recall_alternate_user_id |str             |recallAlternateUserId *Optional*                    |
|recall_to                |str             |recallTo                                            |
|user_table               |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallParkGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallParkGetRequest()`.

Contains the settings that apply to the whole group for Call Park.

**Attributes:**

|Name                            |Type |Description                   |
|--------------------------------|-----|------------------------------|
|recall_timer_seconds            |int  |recallTimerSeconds            |
|display_timer_seconds           |int  |displayTimerSeconds           |
|enable_destination_announcement |bool |enableDestinationAnnouncement |
</div>


## `GroupCallParkGetResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallParkGetRequest16sp2()`.

Contains the settings that apply to the whole group for Call Park.

**Attributes:**

|Name                                |Type |Description                      |
|------------------------------------|-----|---------------------------------|
|recall_timer_seconds                |int  |recallTimerSeconds               |
|display_timer_seconds               |int  |displayTimerSeconds              |
|enable_destination_announcement     |bool |enableDestinationAnnouncement    |
|recall_alternate_user_id            |str  |recallAlternateUserId *Optional* |
|recall_ring_pattern                 |str  |recallRingPattern                |
|recall_to                           |str  |recallTo                         |
|alternate_user_recall_timer_seconds |int  |alternateUserRecallTimerSeconds  |
</div>


## `GroupCallPickupGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallPickupGetAvailableUserListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallPickupGetAvailableUserPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallPickupGetAvailableUserPagedSortedListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallPickupGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallPickupGetInstanceListRequest()`.


**Attributes:**

|Name |Type      |Description     |
|-----|----------|----------------|
|name |List[str] |name *Optional* |
</div>


## `GroupCallPickupGetInstancePagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallPickupGetInstancePagedSortedListRequest()`.


**Attributes:**

|Name |Type      |Description     |
|-----|----------|----------------|
|name |List[str] |name *Optional* |
</div>


## `GroupCallPickupGetInstancePagedSortedResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallPickupGetInstancePagedSortedRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallPickupGetInstanceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallPickupGetInstanceRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCallProcessingGetPolicyResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest14()`.


**Attributes:**

|Name                                            |Type |Description                                |
|------------------------------------------------|-----|-------------------------------------------|
|use_group_setting                               |bool |useGroupSetting                            |
|use_max_simultaneous_calls                      |bool |useMaxSimultaneousCalls                    |
|max_simultaneous_calls                          |int  |maxSimultaneousCalls                       |
|use_max_simultaneous_video_calls                |bool |useMaxSimultaneousVideoCalls               |
|max_simultaneous_video_calls                    |int  |maxSimultaneousVideoCalls                  |
|use_max_call_time_for_answered_calls            |bool |useMaxCallTimeForAnsweredCalls             |
|max_call_time_for_answered_calls_minutes        |int  |maxCallTimeForAnsweredCallsMinutes         |
|use_max_call_time_for_unanswered_calls          |bool |useMaxCallTimeForUnansweredCalls           |
|max_call_time_for_unanswered_calls_minutes      |int  |maxCallTimeForUnansweredCallsMinutes       |
|media_policy_selection                          |str  |mediaPolicySelection                       |
|supported_media_set_name                        |str  |supportedMediaSetName *Optional*           |
|network_usage_selection                         |str  |networkUsageSelection                      |
|enforce_group_calling_line_identity_restriction |bool |enforceGroupCallingLineIdentityRestriction |
</div>


## `GroupCallProcessingGetPolicyResponse14sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest14sp1()`.


**Attributes:**

|Name                                             |Type |Description                                |
|-------------------------------------------------|-----|-------------------------------------------|
|use_group_setting                                |bool |useGroupSetting                            |
|use_max_simultaneous_calls                       |bool |useMaxSimultaneousCalls                    |
|max_simultaneous_calls                           |int  |maxSimultaneousCalls                       |
|use_max_simultaneous_video_calls                 |bool |useMaxSimultaneousVideoCalls               |
|max_simultaneous_video_calls                     |int  |maxSimultaneousVideoCalls                  |
|use_max_call_time_for_answered_calls             |bool |useMaxCallTimeForAnsweredCalls             |
|max_call_time_for_answered_calls_minutes         |int  |maxCallTimeForAnsweredCallsMinutes         |
|use_max_call_time_for_unanswered_calls           |bool |useMaxCallTimeForUnansweredCalls           |
|max_call_time_for_unanswered_calls_minutes       |int  |maxCallTimeForUnansweredCallsMinutes       |
|media_policy_selection                           |str  |mediaPolicySelection                       |
|supported_media_set_name                         |str  |supportedMediaSetName *Optional*           |
|network_usage_selection                          |str  |networkUsageSelection                      |
|enforce_group_calling_line_identity_restriction  |bool |enforceGroupCallingLineIdentityRestriction |
|use_max_concurrent_redirected_calls              |bool |useMaxConcurrentRedirectedCalls            |
|max_concurrent_redirected_calls                  |int  |maxConcurrentRedirectedCalls               |
|use_max_find_me_follow_me_depth                  |bool |useMaxFindMeFollowMeDepth                  |
|max_find_me_follow_me_depth                      |int  |maxFindMeFollowMeDepth                     |
|max_redirection_depth                            |int  |maxRedirectionDepth                        |
|use_max_concurrent_find_me_follow_me_invocations |bool |useMaxConcurrentFindMeFollowMeInvocations  |
|max_concurrent_find_me_follow_me_invocations     |int  |maxConcurrentFindMeFollowMeInvocations     |
</div>


## `GroupCallProcessingGetPolicyResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest14sp4()`.

Replaced By : `GroupCallProcessingGetPolicyResponse15()`

**Attributes:**

|Name                                                                  |Type |Description                                                  |
|----------------------------------------------------------------------|-----|-------------------------------------------------------------|
|use_group_setting                                                     |bool |useGroupSetting                                              |
|use_max_simultaneous_calls                                            |bool |useMaxSimultaneousCalls                                      |
|max_simultaneous_calls                                                |int  |maxSimultaneousCalls                                         |
|use_max_simultaneous_video_calls                                      |bool |useMaxSimultaneousVideoCalls                                 |
|max_simultaneous_video_calls                                          |int  |maxSimultaneousVideoCalls                                    |
|use_max_call_time_for_answered_calls                                  |bool |useMaxCallTimeForAnsweredCalls                               |
|max_call_time_for_answered_calls_minutes                              |int  |maxCallTimeForAnsweredCallsMinutes                           |
|use_max_call_time_for_unanswered_calls                                |bool |useMaxCallTimeForUnansweredCalls                             |
|max_call_time_for_unanswered_calls_minutes                            |int  |maxCallTimeForUnansweredCallsMinutes                         |
|media_policy_selection                                                |str  |mediaPolicySelection                                         |
|supported_media_set_name                                              |str  |supportedMediaSetName *Optional*                             |
|network_usage_selection                                               |str  |networkUsageSelection                                        |
|enforce_group_calling_line_identity_restriction                       |bool |enforceGroupCallingLineIdentityRestriction                   |
|allow_enterprise_group_call_typing_for_private_dialing_plan           |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan          |
|allow_enterprise_group_call_typing_for_public_dialing_plan            |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan           |
|override_clid_restriction_for_external_calls_via_private_dialing_plan |bool |overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan |
|enable_enterprise_extension_dialing                                   |bool |enableEnterpriseExtensionDialing                             |
|use_max_concurrent_redirected_calls                                   |bool |useMaxConcurrentRedirectedCalls                              |
|max_concurrent_redirected_calls                                       |int  |maxConcurrentRedirectedCalls                                 |
|use_max_find_me_follow_me_depth                                       |bool |useMaxFindMeFollowMeDepth                                    |
|max_find_me_follow_me_depth                                           |int  |maxFindMeFollowMeDepth                                       |
|max_redirection_depth                                                 |int  |maxRedirectionDepth                                          |
|use_max_concurrent_find_me_follow_me_invocations                      |bool |useMaxConcurrentFindMeFollowMeInvocations                    |
|max_concurrent_find_me_follow_me_invocations                          |int  |maxConcurrentFindMeFollowMeInvocations                       |
</div>


## `GroupCallProcessingGetPolicyResponse14sp7`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest14sp7()`.


**Attributes:**

|Name                                                                  |Type |Description                                                  |
|----------------------------------------------------------------------|-----|-------------------------------------------------------------|
|use_group_clid_setting                                                |bool |useGroupCLIDSetting                                          |
|use_group_media_setting                                               |bool |useGroupMediaSetting                                         |
|use_group_call_limits_setting                                         |bool |useGroupCallLimitsSetting                                    |
|use_group_translation_routing_setting                                 |bool |useGroupTranslationRoutingSetting                            |
|use_max_simultaneous_calls                                            |bool |useMaxSimultaneousCalls                                      |
|max_simultaneous_calls                                                |int  |maxSimultaneousCalls                                         |
|use_max_simultaneous_video_calls                                      |bool |useMaxSimultaneousVideoCalls                                 |
|max_simultaneous_video_calls                                          |int  |maxSimultaneousVideoCalls                                    |
|use_max_call_time_for_answered_calls                                  |bool |useMaxCallTimeForAnsweredCalls                               |
|max_call_time_for_answered_calls_minutes                              |int  |maxCallTimeForAnsweredCallsMinutes                           |
|use_max_call_time_for_unanswered_calls                                |bool |useMaxCallTimeForUnansweredCalls                             |
|max_call_time_for_unanswered_calls_minutes                            |int  |maxCallTimeForUnansweredCallsMinutes                         |
|media_policy_selection                                                |str  |mediaPolicySelection                                         |
|supported_media_set_name                                              |str  |supportedMediaSetName *Optional*                             |
|network_usage_selection                                               |str  |networkUsageSelection                                        |
|enforce_group_calling_line_identity_restriction                       |bool |enforceGroupCallingLineIdentityRestriction                   |
|allow_enterprise_group_call_typing_for_private_dialing_plan           |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan          |
|allow_enterprise_group_call_typing_for_public_dialing_plan            |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan           |
|override_clid_restriction_for_external_calls_via_private_dialing_plan |bool |overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan |
|enable_enterprise_extension_dialing                                   |bool |enableEnterpriseExtensionDialing                             |
|use_max_concurrent_redirected_calls                                   |bool |useMaxConcurrentRedirectedCalls                              |
|max_concurrent_redirected_calls                                       |int  |maxConcurrentRedirectedCalls                                 |
|use_max_find_me_follow_me_depth                                       |bool |useMaxFindMeFollowMeDepth                                    |
|max_find_me_follow_me_depth                                           |int  |maxFindMeFollowMeDepth                                       |
|max_redirection_depth                                                 |int  |maxRedirectionDepth                                          |
|use_max_concurrent_find_me_follow_me_invocations                      |bool |useMaxConcurrentFindMeFollowMeInvocations                    |
|max_concurrent_find_me_follow_me_invocations                          |int  |maxConcurrentFindMeFollowMeInvocations                       |
|clid_policy                                                           |str  |clidPolicy                                                   |
|emergency_clid_policy                                                 |str  |emergencyClidPolicy                                          |
|allow_alternate_numbers_for_redirecting_identity                      |bool |allowAlternateNumbersForRedirectingIdentity                  |
|use_group_name                                                        |bool |useGroupName                                                 |
</div>


## `GroupCallProcessingGetPolicyResponse15`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest15()`.


**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_group_setting                                           |bool |useGroupSetting                                     |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
</div>


## `GroupCallProcessingGetPolicyResponse15sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest15sp2()`.


**Attributes:**

|Name                                                        |Type |Description                                              |
|------------------------------------------------------------|-----|---------------------------------------------------------|
|use_group_clid_setting                                      |bool |useGroupCLIDSetting                                      |
|use_group_media_setting                                     |bool |useGroupMediaSetting                                     |
|use_group_call_limits_setting                               |bool |useGroupCallLimitsSetting                                |
|use_group_translation_routing_setting                       |bool |useGroupTranslationRoutingSetting                        |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                                  |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                     |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                             |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                                |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                           |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                       |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                         |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                     |
|media_policy_selection                                      |str  |mediaPolicySelection                                     |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                         |
|network_usage_selection                                     |str  |networkUsageSelection                                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction               |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan      |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan       |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional* |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*       |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                         |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                          |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                             |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                                |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                                   |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                      |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations                |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations                   |
|clid_policy                                                 |str  |clidPolicy                                               |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                      |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity              |
|use_group_name                                              |bool |useGroupName                                             |
</div>


## `GroupCallProcessingGetPolicyResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest16()`.


**Attributes:**

|Name                                                        |Type |Description                                              |
|------------------------------------------------------------|-----|---------------------------------------------------------|
|use_group_clid_setting                                      |bool |useGroupCLIDSetting                                      |
|use_group_media_setting                                     |bool |useGroupMediaSetting                                     |
|use_group_call_limits_setting                               |bool |useGroupCallLimitsSetting                                |
|use_group_translation_routing_setting                       |bool |useGroupTranslationRoutingSetting                        |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                                  |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                     |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                             |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                                |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                           |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                       |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                         |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                     |
|media_policy_selection                                      |str  |mediaPolicySelection                                     |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                         |
|network_usage_selection                                     |str  |networkUsageSelection                                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction               |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan      |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan       |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional* |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*       |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                         |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                          |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                             |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                                |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                                   |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                      |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations                |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations                   |
|clid_policy                                                 |str  |clidPolicy                                               |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                      |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity              |
|use_group_name                                              |bool |useGroupName                                             |
</div>


## `GroupCallProcessingGetPolicyResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest16sp2()`.


**Attributes:**

|Name                                                        |Type |Description                                              |
|------------------------------------------------------------|-----|---------------------------------------------------------|
|use_group_clid_setting                                      |bool |useGroupCLIDSetting                                      |
|use_group_media_setting                                     |bool |useGroupMediaSetting                                     |
|use_group_call_limits_setting                               |bool |useGroupCallLimitsSetting                                |
|use_group_translation_routing_setting                       |bool |useGroupTranslationRoutingSetting                        |
|use_group_dclid_setting                                     |bool |useGroupDCLIDSetting                                     |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                                  |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                     |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                             |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                                |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                           |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                       |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                         |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                     |
|media_policy_selection                                      |str  |mediaPolicySelection                                     |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                         |
|network_usage_selection                                     |str  |networkUsageSelection                                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction               |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan      |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan       |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional* |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*       |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                         |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                          |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                             |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                                |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                                   |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                      |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations                |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations                   |
|clid_policy                                                 |str  |clidPolicy                                               |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                      |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity              |
|use_group_name                                              |bool |useGroupName                                             |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                                   |
</div>


## `GroupCallProcessingGetPolicyResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest17()`.


**Attributes:**

|Name                                                        |Type |Description                                              |
|------------------------------------------------------------|-----|---------------------------------------------------------|
|use_group_clid_setting                                      |bool |useGroupCLIDSetting                                      |
|use_group_media_setting                                     |bool |useGroupMediaSetting                                     |
|use_group_call_limits_setting                               |bool |useGroupCallLimitsSetting                                |
|use_group_translation_routing_setting                       |bool |useGroupTranslationRoutingSetting                        |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                                  |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                     |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                             |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                                |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                           |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                       |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                         |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                     |
|media_policy_selection                                      |str  |mediaPolicySelection                                     |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                         |
|network_usage_selection                                     |str  |networkUsageSelection                                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction               |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan      |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan       |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional* |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*       |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                         |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                          |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                             |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                                |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                                   |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                      |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations                |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations                   |
|clid_policy                                                 |str  |clidPolicy                                               |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                      |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity              |
|use_group_name                                              |bool |useGroupName                                             |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                         |
</div>


## `GroupCallProcessingGetPolicyResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest17sp3()`.

The following elements are only used in AS data mode: useGroupDCLIDSetting
enableDialableCallerID Replaced by `GroupCallProcessingGetPolicyResponse17sp4()`

**Attributes:**

|Name                                                        |Type |Description                                              |
|------------------------------------------------------------|-----|---------------------------------------------------------|
|use_group_clid_setting                                      |bool |useGroupCLIDSetting                                      |
|use_group_media_setting                                     |bool |useGroupMediaSetting                                     |
|use_group_call_limits_setting                               |bool |useGroupCallLimitsSetting                                |
|use_group_translation_routing_setting                       |bool |useGroupTranslationRoutingSetting                        |
|use_group_dclid_setting                                     |bool |useGroupDCLIDSetting                                     |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                                  |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                     |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                             |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                                |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                           |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                       |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                         |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                     |
|media_policy_selection                                      |str  |mediaPolicySelection                                     |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                         |
|network_usage_selection                                     |str  |networkUsageSelection                                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction               |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan      |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan       |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional* |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*       |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                         |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                          |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                             |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                                |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                                   |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                      |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations                |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations                   |
|clid_policy                                                 |str  |clidPolicy                                               |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                      |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity              |
|use_group_name                                              |bool |useGroupName                                             |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                         |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                                   |
</div>


## `GroupCallProcessingGetPolicyResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest17sp4()`.

The following elements are only used in AS data mode: useGroupDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity Replaced by
`GroupCallProcessingGetPolicyResponse18()`

**Attributes:**

|Name                                                        |Type |Description                                              |
|------------------------------------------------------------|-----|---------------------------------------------------------|
|use_group_clid_setting                                      |bool |useGroupCLIDSetting                                      |
|use_group_media_setting                                     |bool |useGroupMediaSetting                                     |
|use_group_call_limits_setting                               |bool |useGroupCallLimitsSetting                                |
|use_group_translation_routing_setting                       |bool |useGroupTranslationRoutingSetting                        |
|use_group_dclid_setting                                     |bool |useGroupDCLIDSetting                                     |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                                  |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                     |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                             |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                                |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                           |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                       |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                         |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                     |
|media_policy_selection                                      |str  |mediaPolicySelection                                     |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                         |
|network_usage_selection                                     |str  |networkUsageSelection                                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction               |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan      |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan       |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional* |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*       |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                         |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                          |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                             |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                                |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                                   |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                      |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations                |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations                   |
|clid_policy                                                 |str  |clidPolicy                                               |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                      |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity              |
|use_group_name                                              |bool |useGroupName                                             |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                         |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                                   |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity              |
</div>


## `GroupCallProcessingGetPolicyResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest18()`.

The following elements are only used in AS data mode: useGroupDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
allowDepartmentCLIDNameOverride

**Attributes:**

|Name                                                        |Type |Description                                              |
|------------------------------------------------------------|-----|---------------------------------------------------------|
|use_group_clid_setting                                      |bool |useGroupCLIDSetting                                      |
|use_group_media_setting                                     |bool |useGroupMediaSetting                                     |
|use_group_call_limits_setting                               |bool |useGroupCallLimitsSetting                                |
|use_group_translation_routing_setting                       |bool |useGroupTranslationRoutingSetting                        |
|use_group_dclid_setting                                     |bool |useGroupDCLIDSetting                                     |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                                  |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                     |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                             |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                                |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                           |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                       |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                         |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                     |
|media_policy_selection                                      |str  |mediaPolicySelection                                     |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                         |
|network_usage_selection                                     |str  |networkUsageSelection                                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction               |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan      |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan       |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional* |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*       |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                         |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                          |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                             |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                                |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                                   |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                      |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations                |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations                   |
|clid_policy                                                 |str  |clidPolicy                                               |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                      |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity              |
|use_group_name                                              |bool |useGroupName                                             |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                         |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                                   |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity              |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                          |
</div>


## `GroupCallProcessingGetPolicyResponse18sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest18sp1()`.

The following elements are only used in AS data mode : useGroupDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
allowDepartmentCLIDNameOverride enterpriseCallsCLIDPolicy, value "Use Location Code
plus Extension" is returned in XS data mode.  groupCallsCLIDPolicy, value "Use
Extension" is returned in XS data mode.  Replaced by:
`GroupCallProcessingGetPolicyResponse19sp1()`

**Attributes:**

|Name                                                        |Type |Description                                              |
|------------------------------------------------------------|-----|---------------------------------------------------------|
|use_group_clid_setting                                      |bool |useGroupCLIDSetting                                      |
|use_group_media_setting                                     |bool |useGroupMediaSetting                                     |
|use_group_call_limits_setting                               |bool |useGroupCallLimitsSetting                                |
|use_group_translation_routing_setting                       |bool |useGroupTranslationRoutingSetting                        |
|use_group_dclid_setting                                     |bool |useGroupDCLIDSetting                                     |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                                  |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                     |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                             |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                                |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                           |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                       |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                         |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                     |
|media_policy_selection                                      |str  |mediaPolicySelection                                     |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                         |
|network_usage_selection                                     |str  |networkUsageSelection                                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction               |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan      |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan       |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional* |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*       |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                         |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                          |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                             |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                                |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                                   |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                      |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations                |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations                   |
|clid_policy                                                 |str  |clidPolicy                                               |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                      |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity              |
|use_group_name                                              |bool |useGroupName                                             |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                         |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                                   |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity              |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                          |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                                |
|group_calls_clid_policy                                     |str  |groupCallsCLIDPolicy                                     |
</div>


## `GroupCallProcessingGetPolicyResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest19sp1()`.

The following elements are only used in AS data mode : useGroupDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
allowDepartmentCLIDNameOverride enterpriseCallsCLIDPolicy, value "Use Location Code
plus Extension" is returned in XS data mode.  groupCallsCLIDPolicy, value "Use
Extension" is returned in XS data mode.  Replaced by:
`GroupCallProcessingGetPolicyResponse21sp1()`

**Attributes:**

|Name                                                        |Type |Description                                              |
|------------------------------------------------------------|-----|---------------------------------------------------------|
|use_group_clid_setting                                      |bool |useGroupCLIDSetting                                      |
|use_group_media_setting                                     |bool |useGroupMediaSetting                                     |
|use_group_call_limits_setting                               |bool |useGroupCallLimitsSetting                                |
|use_group_translation_routing_setting                       |bool |useGroupTranslationRoutingSetting                        |
|use_group_dclid_setting                                     |bool |useGroupDCLIDSetting                                     |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                                  |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                     |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                             |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                                |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                           |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                       |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                         |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                     |
|media_policy_selection                                      |str  |mediaPolicySelection                                     |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                         |
|network_usage_selection                                     |str  |networkUsageSelection                                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction               |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan      |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan       |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional* |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*       |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                         |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                          |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                             |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                                |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                                   |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                      |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations                |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations                   |
|clid_policy                                                 |str  |clidPolicy                                               |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                      |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity              |
|use_group_name                                              |bool |useGroupName                                             |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                         |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                                   |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity              |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                          |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                                |
|group_calls_clid_policy                                     |str  |groupCallsCLIDPolicy                                     |
</div>


## `GroupCallProcessingGetPolicyResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest21sp1()`.

The following elements are only used in AS data mode : useGroupDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
allowDepartmentCLIDNameOverride enterpriseCallsCLIDPolicy, value "Use Location Code
plus Extension" is returned in XS data mode.  groupCallsCLIDPolicy, value "Use
Extension" is returned in XS data mode.  useGroupPhoneListLookupSetting, value "false"
is returned in XS data mode.  enablePhoneListLookup, value "false" is returned in XS
data mode.  Replaced by: `GroupCallProcessingGetPolicyResponse21sp2()`

**Attributes:**

|Name                                                        |Type |Description                                              |
|------------------------------------------------------------|-----|---------------------------------------------------------|
|use_group_clid_setting                                      |bool |useGroupCLIDSetting                                      |
|use_group_media_setting                                     |bool |useGroupMediaSetting                                     |
|use_group_call_limits_setting                               |bool |useGroupCallLimitsSetting                                |
|use_group_translation_routing_setting                       |bool |useGroupTranslationRoutingSetting                        |
|use_group_dclid_setting                                     |bool |useGroupDCLIDSetting                                     |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                                  |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                     |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                             |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                                |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                           |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                       |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                         |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                     |
|media_policy_selection                                      |str  |mediaPolicySelection                                     |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                         |
|network_usage_selection                                     |str  |networkUsageSelection                                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction               |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan      |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan       |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional* |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*       |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                         |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                          |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                             |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                                |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                                   |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                      |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations                |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations                   |
|clid_policy                                                 |str  |clidPolicy                                               |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                      |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity              |
|use_group_name                                              |bool |useGroupName                                             |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                         |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                                   |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity              |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                          |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                                |
|group_calls_clid_policy                                     |str  |groupCallsCLIDPolicy                                     |
|use_group_phone_list_lookup_setting                         |bool |useGroupPhoneListLookupSetting                           |
|enable_phone_list_lookup                                    |bool |enablePhoneListLookup                                    |
</div>


## `GroupCallProcessingGetPolicyResponse21sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest21sp2()`.

The following elements are only used in AS data mode: useGroupDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
allowDepartmentCLIDNameOverride enterpriseCallsCLIDPolicy, value "Use Location Code
plus Extension" is returned in XS data mode.  groupCallsCLIDPolicy, value "Use
Extension" is returned in XS data mode.  useGroupPhoneListLookupSetting, value "false"
is returned in XS data mode.  enablePhoneListLookup, value "false" is returned in XS
data mode.  The following elements are only used in XS data mode and not returned in
AS data mode: routeOverrideDomain routeOverridePrefix Replaced by:
`GroupCallProcessingGetPolicyResponse22()` in AS data mode

**Attributes:**

|Name                                                        |Type |Description                                              |
|------------------------------------------------------------|-----|---------------------------------------------------------|
|use_group_clid_setting                                      |bool |useGroupCLIDSetting                                      |
|use_group_media_setting                                     |bool |useGroupMediaSetting                                     |
|use_group_call_limits_setting                               |bool |useGroupCallLimitsSetting                                |
|use_group_translation_routing_setting                       |bool |useGroupTranslationRoutingSetting                        |
|use_group_dclid_setting                                     |bool |useGroupDCLIDSetting                                     |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                                  |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                     |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                             |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                                |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                           |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                       |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                         |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                     |
|media_policy_selection                                      |str  |mediaPolicySelection                                     |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                         |
|network_usage_selection                                     |str  |networkUsageSelection                                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction               |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan      |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan       |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional* |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*       |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                         |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                          |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                             |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                                |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                                   |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                      |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations                |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations                   |
|clid_policy                                                 |str  |clidPolicy                                               |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                      |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity              |
|use_group_name                                              |bool |useGroupName                                             |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                         |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                                   |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity              |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                          |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                                |
|group_calls_clid_policy                                     |str  |groupCallsCLIDPolicy                                     |
|use_group_phone_list_lookup_setting                         |bool |useGroupPhoneListLookupSetting                           |
|enable_phone_list_lookup                                    |bool |enablePhoneListLookup                                    |
|route_override_domain                                       |str  |routeOverrideDomain *Optional*                           |
|route_override_prefix                                       |str  |routeOverridePrefix *Optional*                           |
</div>


## `GroupCallProcessingGetPolicyResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest22()`.

The following elements are only used in AS data mode: useGroupDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
allowDepartmentCLIDNameOverride enterpriseCallsCLIDPolicy, value "Use Location Code
plus Extension" is returned in XS data mode.  groupCallsCLIDPolicy, value "Use
Extension" is returned in XS data mode.  useGroupPhoneListLookupSetting, value "false"
is returned in XS data mode.  enablePhoneListLookup, value "false" is returned in XS
data mode.  useMaxConcurrentTerminatingAlertingRequests, value "false" is returned in
XS data mode.  maxConcurrentTerminatingAlertingRequests, value "10" is returned in XS
data mode.  includeRedirectionsInMaximumNumberOfConcurrentCalls, value "false" is
returned in XS data mode.  useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable,
value "false" is returned in XS data mode.
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable, value "false" is
returned in XS data mode.  The following elements are only used in XS data mode and
not returned in AS data mode: routeOverrideDomain routeOverridePrefix Replaced by:
`GroupCallProcessingGetPolicyRequest22V2()` in AS data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_group_clid_setting                                                    |bool |useGroupCLIDSetting                                             |
|use_group_media_setting                                                   |bool |useGroupMediaSetting                                            |
|use_group_call_limits_setting                                             |bool |useGroupCallLimitsSetting                                       |
|use_group_translation_routing_setting                                     |bool |useGroupTranslationRoutingSetting                               |
|use_group_dclid_setting                                                   |bool |useGroupDCLIDSetting                                            |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*        |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*              |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|group_calls_clid_policy                                                   |str  |groupCallsCLIDPolicy                                            |
|use_group_phone_list_lookup_setting                                       |bool |useGroupPhoneListLookupSetting                                  |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                  |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                  |
</div>


## `GroupCallProcessingGetPolicyResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest22V2()`.

The following elements are only used in AS data mode: useGroupDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
allowDepartmentCLIDNameOverride enterpriseCallsCLIDPolicy, value "Use Location Code
plus Extension" is returned in XS data mode.  groupCallsCLIDPolicy, value "Use
Extension" is returned in XS data mode.  useGroupPhoneListLookupSetting, value "false"
is returned in XS data mode.  enablePhoneListLookup, value "false" is returned in XS
data mode.  useMaxConcurrentTerminatingAlertingRequests, value "false" is returned in
XS data mode.  maxConcurrentTerminatingAlertingRequests, value "10" is returned in XS
data mode.  includeRedirectionsInMaximumNumberOfConcurrentCalls, value "false" is
returned in XS data mode.  useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable,
value "false" is returned in XS data mode.
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable, value "false" is
returned in XS data mode.  allowMobileDNForRedirectingIdentity,value "false" is
returned in XS data mode.  The following elements are only used in XS data mode and
not returned in AS data mode: routeOverrideDomain routeOverridePrefix Replaced by:
`GroupCallProcessingGetPolicyResponse22V3()` in AS data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_group_clid_setting                                                    |bool |useGroupCLIDSetting                                             |
|use_group_media_setting                                                   |bool |useGroupMediaSetting                                            |
|use_group_call_limits_setting                                             |bool |useGroupCallLimitsSetting                                       |
|use_group_translation_routing_setting                                     |bool |useGroupTranslationRoutingSetting                               |
|use_group_dclid_setting                                                   |bool |useGroupDCLIDSetting                                            |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*        |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*              |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|group_calls_clid_policy                                                   |str  |groupCallsCLIDPolicy                                            |
|use_group_phone_list_lookup_setting                                       |bool |useGroupPhoneListLookupSetting                                  |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                  |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                  |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity                             |
</div>


## `GroupCallProcessingGetPolicyResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallProcessingGetPolicyRequest22V3()`.

The following elements are not returned for a group within a service provider:
enableGatewayRoutePolicy networkCallsGatewayRouteIdentity
networkURLCallsGatewayRouteIdentity emergencyCallsGatewayRouteIdentity
repairCallsGatewayRouteIdentity callTypingErrorsGatewayRouteIdentity The following
elements are only used in AS data mode: useGroupDCLIDSetting enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity allowDepartmentCLIDNameOverride
enterpriseCallsCLIDPolicy, value "Use Location Code plus Extension" is returned in XS
data mode.  groupCallsCLIDPolicy, value "Use Extension" is returned in XS data mode.
useGroupPhoneListLookupSetting, value "false" is returned in XS data mode.
enablePhoneListLookup, value "false" is returned in XS data mode.
useMaxConcurrentTerminatingAlertingRequests, value "false" is returned in XS data
mode.  maxConcurrentTerminatingAlertingRequests, value "10" is returned in XS data
mode.  includeRedirectionsInMaximumNumberOfConcurrentCalls, value "false" is returned
in XS data mode.  useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable, value
"false" is returned in XS data mode.
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable, value "false" is
returned in XS data mode.  allowMobileDNForRedirectingIdentity,value "false" is
returned in XS data mode.  The following elements are only used in AS data mode and
not returned in XS data mode: enableGatewayRoutePolicy
networkCallsGatewayRouteIdentity networkURLCallsGatewayRouteIdentity
emergencyCallsGatewayRouteIdentity repairCallsGatewayRouteIdentity
callTypingErrorsGatewayRouteIdentity The following elements are only used in XS data
mode and not returned in AS data mode: routeOverrideDomain routeOverridePrefix

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_group_clid_setting                                                    |bool |useGroupCLIDSetting                                             |
|use_group_media_setting                                                   |bool |useGroupMediaSetting                                            |
|use_group_call_limits_setting                                             |bool |useGroupCallLimitsSetting                                       |
|use_group_translation_routing_setting                                     |bool |useGroupTranslationRoutingSetting                               |
|use_group_dclid_setting                                                   |bool |useGroupDCLIDSetting                                            |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*        |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*              |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|group_calls_clid_policy                                                   |str  |groupCallsCLIDPolicy                                            |
|use_group_phone_list_lookup_setting                                       |bool |useGroupPhoneListLookupSetting                                  |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                  |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                  |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity                             |
|enable_gateway_route_policy                                               |bool |enableGatewayRoutePolicy *Optional*                             |
|network_calls_gateway_route_identity                                      |str  |networkCallsGatewayRouteIdentity *Optional*                     |
|network_url_calls_gateway_route_identity                                  |str  |networkURLCallsGatewayRouteIdentity *Optional*                  |
|emergency_calls_gateway_route_identity                                    |str  |emergencyCallsGatewayRouteIdentity *Optional*                   |
|repair_calls_gateway_route_identity                                       |str  |repairCallsGatewayRouteIdentity *Optional*                      |
|call_typing_errors_gateway_route_identity                                 |str  |callTypingErrorsGatewayRouteIdentity *Optional*                 |
</div>


## `GroupCallRecordingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallRecordingGetRequest()`.

The response contains the group's Call Recording platform information.

**Attributes:**

|Name |Type|Description     |
|-----|----|----------------|
|name |str |name *Optional* |
</div>


## `GroupCallingLineIdGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallingLineIdGetRequest()`.

The response contains the group's calling line id settings.

**Attributes:**

|Name                         |Type |Description                         |
|-----------------------------|-----|------------------------------------|
|use_group_number             |bool |useGroupNumber                      |
|use_group_name               |bool |useGroupName                        |
|calling_line_id_phone_number |str  |callingLineIdPhoneNumber *Optional* |
|calling_line_id_name         |str  |callingLineIdName *Optional*        |
</div>


## `GroupCallingPlanGetDigitPatternListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallingPlanGetDigitPatternListRequest()`.

Contains a table with column headings: "Name", "Digit Pattern".

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|digit_pattern_table |List(digitPatternTable) |digitPatternTable - *Table* array of digitPatternTable named tuples |
</div>


## `GroupCollaborateBridgeGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCollaborateBridgeGetAvailableUserListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", and "Hiragana First Name", "Phone Number", "Extension", "Department",
"Department Type", "Parent Department", "Parent Department Type", "Email Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCollaborateBridgeGetAvailableUserPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCollaborateBridgeGetAvailableUserPagedSortedListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Is Phone Number Activated",
"Country Code","National Prefix", "Extension", "Department", "Department Type",
"Parent Department", "Parent Department Type", "Email Address", "IMP Id", "Mobile
Number", "Group Id", "Group Name".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCollaborateBridgeGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCollaborateBridgeGetInstanceListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Phone Number",
"Extension", "Department", "Participants", and "Is Default". The column values for "Is
default" can either be true, or false.

**Attributes:**

|Name                     |Type                         |Description                                                                   |
|-------------------------|-----------------------------|------------------------------------------------------------------------------|
|collaborate_bridge_table |List(collaborateBridgeTable) |collaborateBridgeTable - *Table* array of collaborateBridgeTable named tuples |
</div>


## `GroupCollaborateBridgeGetInstancePagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCollaborateBridgeGetInstancePagedSortedListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Phone Number", "Is
Phone Number Activated", "Country Code","National Prefix", "Extension", "Department",
"Department Type", "Parent Department", "Parent Department Type", "Participants", "Is
Default", "Max Room Participants", "Is Support Outdial". The column values for "Is
default", "Is Support Outdial" can either be true, or false.

**Attributes:**

|Name                     |Type                         |Description                                                                   |
|-------------------------|-----------------------------|------------------------------------------------------------------------------|
|collaborate_bridge_table |List(collaborateBridgeTable) |collaborateBridgeTable - *Table* array of collaborateBridgeTable named tuples |
</div>


## `GroupCommunicationBarringAuthorizationCodeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCommunicationBarringAuthorizationCodeGetRequest()`.


**Attributes:**

|Name                     |Type|Description                      |
|-------------------------|----|---------------------------------|
|description              |str |description *Optional*           |
|network_class_of_service |str |networkClassOfService *Optional* |
</div>


## `GroupCommunicationBarringGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCommunicationBarringGetRequest()`.


**Attributes:**

|Name                                 |Type |Description                      |
|-------------------------------------|-----|---------------------------------|
|use_default_service_provider_profile |bool |useDefaultServiceProviderProfile |
|profile                              |str  |profile *Optional*               |
</div>


## `GroupCommunicationBarringProfileGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCommunicationBarringProfileGetAssignedListRequest()`.

The response contains a simple list of all communication barring profiles assigned to
the group.

**Attributes:**

|Name         |Type      |Description            |
|-------------|----------|-----------------------|
|profile_name |List[str] |profileName *Optional* |
</div>


## `GroupCustomContactDirectoryGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCustomContactDirectoryGetAvailableUserListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name". Replace by:
`GroupCustomContactDirectoryGetAvailableUserListResponse17()`

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCustomContactDirectoryGetAvailableUserListResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCustomContactDirectoryGetAvailableUserListRequest17()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Virtual On-Net Phone Number", "Group Id", "Is
Virtual On-Net User", "Phone Number", "Extension", "Department", "Email Address". If
the entry represents a Virtual On-Net user then "User Id" is blank, the "Virtual On-
Net Phone Number" contains the phone Number of the Virtual On-Net user, the "Group Id"
contains the Virtual On-Net user's group and the "Is Virtual On-Net User" contains
true.  If the entry represents a BroadWorks user then the "User Id" contains his
BroadWorks userId, the "Virtual On-Net Phone Number" and "Group Id" fields are blank
and the "Is Virtual On-Net User" contains false.

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCustomContactDirectoryGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCustomContactDirectoryGetListRequest()`.

The response contains all the group's custom contact directory names.

**Attributes:**

|Name |Type      |Description     |
|-----|----------|----------------|
|name |List[str] |name *Optional* |
</div>


## `GroupCustomContactDirectoryGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCustomContactDirectoryGetRequest()`.

The response contains all the group's custom contact directory names.  Contains a
table with column headings: "User Id", "Last Name", "First Name", "Hiragana Last
Name", "Hiragana First Name". Replace by: `GroupCustomContactDirectoryGetResponse17()`

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCustomContactDirectoryGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCustomContactDirectoryGetRequest17()`.

The response contains all the contacts in the group's given custom contact directory.
Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Virtual On-Net Phone Number", "Group Id", "Is
Virtual On-Net User", "Department", "Phone Number", "Extension", "Mobile", "Email
Address", "Yahoo Id", "Title", "IMP Id", "Receptionist Note". If the entry represents
a Virtual On-Net user then "User Id" is blank, the "Virtual On-Net Phone Number"
contains the phone Number of the Virtual On-Net user, the "Group Id" contains the
Virtual On-Net user's group and the "Is Virtual On-Net User" contains true.  If the
entry represents a BroadWorks user then the "User Id" contains his BroadWorks userId,
the "Virtual On-Net Phone Number" and "Group Id" fields are field is blank and the "Is
Virtual On-Net User" contains false.  The Receptionist Note column is only populated
in AS Mode, if the user sending the request is the owner of the Receptionist Note and
a Note exists.

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupCustomRingbackGroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCustomRingbackGroupGetRequest()`.

Replaced By: `GroupCustomRingbackGroupGetResponse16()`

**Attributes:**

|Name                   |Type |Description                     |
|-----------------------|-----|--------------------------------|
|is_active              |bool |isActive                        |
|audio_selection        |str  |audioSelection                  |
|audio_file_description |str  |audioFileDescription *Optional* |
|audio_file_url         |str  |audioFileUrl *Optional*         |
|video_selection        |str  |videoSelection                  |
|video_file_description |str  |videoFileDescription *Optional* |
|video_file_url         |str  |videoFileUrl *Optional*         |
</div>


## `GroupCustomRingbackGroupGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCustomRingbackGroupGetRequest16()`.

Replaced by: `GroupCustomRingbackGroupGetResponse20()` in AS data mode

**Attributes:**

|Name                   |Type |Description                     |
|-----------------------|-----|--------------------------------|
|is_active              |bool |isActive                        |
|audio_selection        |str  |audioSelection                  |
|audio_file_description |str  |audioFileDescription *Optional* |
|audio_media_type       |str  |audioMediaType *Optional*       |
|audio_file_url         |str  |audioFileUrl *Optional*         |
|video_selection        |str  |videoSelection                  |
|video_file_description |str  |videoFileDescription *Optional* |
|video_media_type       |str  |videoMediaType *Optional*       |
|video_file_url         |str  |videoFileUrl *Optional*         |
</div>


## `GroupDepartmentAdminGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDepartmentAdminGetListRequest()`.

Contains a 5 column table with column headings "Administrator ID", "Last Name", "First
Name", "Department", "Language".

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|department_admin_table |List(departmentAdminTable) |departmentAdminTable - *Table* array of departmentAdminTable named tuples |
</div>


## `GroupDepartmentGetListResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDepartmentGetListRequest18()`.

Contains a table of department attributes.  The column headings are: "Is Enterprise
Department", "Department Name", "Full Path Name", "Calling Line Id Name", and "Calling
Line Id Phone Number"

**Attributes:**

|Name             |Type                  |Description                                                     |
|-----------------|----------------------|----------------------------------------------------------------|
|department_table |List(departmentTable) |departmentTable - *Table* array of departmentTable named tuples |
</div>


## `GroupDeviceActivationPolicyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDeviceActivationPolicyGetRequest()`.


**Attributes:**

|Name                                  |Type |Description                      |
|--------------------------------------|-----|---------------------------------|
|use_group_settings                    |bool |useGroupSettings                 |
|allow_activation_code_request_by_user |bool |allowActivationCodeRequestByUser |
|send_activation_code_in_email         |bool |sendActivationCodeInEmail        |
</div>


## `GroupDeviceManagementEventGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDeviceManagementEventGetListRequest()`.

Contains a table with column headings: "Event Id", "Status", "Action", "Level",
"Type", "Additional Info", "Is Local", "Completion %", "Pushed/ Same Hash/ Not
Pushed", "Login Id", "Start Time", "Process Time". "Event Id" is a unique identifer
for the event.  "Status" can be: Pending, Queued, In Progress, Process On Other Host,
Stale, Completed, Canceled.  "Action" can be: Delete, Download, Rebuild, Reset,
Upload.  "Level" can be: Device, Device Type, Device Type Group, Group, User.  "Type"
can be: Automatic, Manual.  "Additional Info" includes the affected device type,
device or group.  It depends on the level of the event: Device Profile: "Device Name"
"Service Provider Id" "Group Id" Device Type: "Device Type Name" Device Type Group:
"Service Provider Id" "Group Id" "Device Type Name" Group: "Service Provider Id"
"Group Id" User: "User Id" "Is Local" is set to "yes" if the event is processed on the
server who received the request, "no" otherwise meaning that the event is processed on
another server.  "Completion %" provides an estimate of the completion of the event.
A percentage is given, the current number of completed expanded event, and the total
number of expanded event.  "Pushed/ Same Hash/ Not Pushed" gives the total number of
files that were pushed, not pushed because of same hash, and not pushed when
processing the event.  "LoginId" is the user or admin id who triggered the event.
"Start Time" is the date when the event was started.  The display shows the month,
days, hours, and minutes (MM-dd hh:mm). "Process Time" is the time taken to process
the event in hours, minutes, seconds, and milliseconds (hhhh:mm:ss.SSS). Each row
represents an event sorted by priority of processing.  The first row in the table is
an event that has an associated expanded event currently being processed or next in
line to be processed.

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|event_table |List(eventTable) |eventTable - *Table* array of eventTable named tuples |
</div>


## `GroupDeviceManagementEventGetListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDeviceManagementEventGetListRequest22()`.

Contains a table with column headings: "Event Id", "Status", "Action", "Level",
"Type", "Additional Info", "Is Local", "Completion %", "Pushed/ Same Hash/ Not
Pushed", "Login Id", "Start Time", "Process Time", "Rx Time", "Total Time", "Request",
"Priority". "Event Id" is a unique identifer for the event.  "Status" can be: Pending,
Queued, In Progress, Process On Other Host, Stale, Completed, Canceled.  "Action" can
be: Delete, Download, Rebuild, Reset, Upload.  "Level" can be: Device, Device Type,
Device Type Group, Group, User.  "Type" can be: Automatic, Manual.  "Additional Info"
includes the affected device type, device or group.  It depends on the level of the
event: Device Profile: "Device Name" "Service Provider Id" "Group Id" Device Type:
"Device Type Name" Device Type Service Provider: "Service Provider Id" "Device Type
Name" Service Provider: "Service Provider Id" Device Type Group: "Service Provider Id"
"Group Id" "Device Type Name" Group: "Service Provider Id" "Group Id" User: "User Id"
"Is Local" is set to "yes" if the event is processed on the server who received the
request, "no" otherwise meaning that the event is processed on another server.
"Completion %" provides an estimate of the completion of the event.  A percentage is
given, the current number of completed expanded event, and the total number of
expanded event.  "Pushed/ Same Hash/ Not Pushed" gives the total number of files that
were pushed, not pushed because of same hash, and not pushed when processing the
event.  "LoginId" is the user or admin id who triggered the event.  "Start Time" is
the date when the event's processing started.  The display shows the month, day,
hours, minutes, and seconds (MM-dd hh:mm:ss). "Process Time" is the time taken to
process the event in hours, minutes, seconds, and milliseconds (hhhh:mm:ss.SSS). "Rx
Time" is the date when the event was received via OCI-P and stored in the system.  The
display shows the month, day, hours, minutes, and seconds (MM-dd hh:mm:ss). "Total
Time" is the total time the event was in the system, from the moment it was received
and stored until its processing ended, in hours, minutes, seconds, and milliseconds
(hhhh:mm:ss.SSS). "Request" is the name of the OCI-P request that triggered the event.
"Priority" is the priority of the event.

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|event_table |List(eventTable) |eventTable - *Table* array of eventTable named tuples |
</div>


## `GroupDeviceManagementGetAccessDeviceCountForDeviceTypeGroupResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDeviceManagementGetAccessDeviceCountForDeviceTypeGroupRequest()`.


**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|access_device_count |int |accessDeviceCount |
</div>


## `GroupDeviceTypeCustomTagGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDeviceTypeCustomTagGetListRequest()`.

Contains a table of custom configuration tags managed by the Device Management System
on a per-device type basis for a group.  In As data mode, the column headings are:
"Tag Name", "Tag Value", "Actual Tag Value". In XS data mode, the column headings are:
"Tag Name", "Tag Value", "Actual Tag Value" if request is invoked by an admin without
system privileges.  "Tag Name", "Tag Value", "Is Encrypted", "Actual Tag Value" if
request is invoked by an admin with system privileges.

**Attributes:**

|Name                                |Type                                 |Description                                                                                   |
|------------------------------------|-------------------------------------|----------------------------------------------------------------------------------------------|
|group_device_type_custom_tags_table |List(groupDeviceTypeCustomTagsTable) |groupDeviceTypeCustomTagsTable - *Table* array of groupDeviceTypeCustomTagsTable named tuples |
</div>


## `GroupDeviceTypeFileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDeviceTypeFileGetListRequest()`.

Contains a table of device type files managed by the Device Management System, on a
per-group basis.  The column headings are: "File Type", "File Format", "Is
Authenticated".

Replaced By: `GroupDeviceTypeFileGetListResponse14sp8()`

**Attributes:**

|Name                          |Type                            |Description                                                                         |
|------------------------------|--------------------------------|------------------------------------------------------------------------------------|
|group_device_type_files_table |List(groupDeviceTypeFilesTable) |groupDeviceTypeFilesTable - *Table* array of groupDeviceTypeFilesTable named tuples |
</div>


## `GroupDeviceTypeFileGetListResponse14sp8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDeviceTypeFileGetListRequest14sp8()`.

Contains a table of device type files managed by the Device Management System, on a
per-group basis.  The column headings are: "File Format", "Is Authenticated", "Access
URL", "Repository URL", "Template URL". Replaced by:
`GroupDeviceTypeFileGetListResponse21()`

**Attributes:**

|Name                          |Type                            |Description                                                                         |
|------------------------------|--------------------------------|------------------------------------------------------------------------------------|
|group_device_type_files_table |List(groupDeviceTypeFilesTable) |groupDeviceTypeFilesTable - *Table* array of groupDeviceTypeFilesTable named tuples |
</div>


## `GroupDeviceTypeFileGetListResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDeviceTypeFileGetListRequest21()`.

Contains a table of device type files managed by the Device Management System, on a
per-group basis.  The column headings are: "File Format", "Is Authenticated", "Access
URL", "Repository URL", "Template URL".

**Attributes:**

|Name                                 |Type                            |Description                                                                         |
|-------------------------------------|--------------------------------|------------------------------------------------------------------------------------|
|group_device_type_files_table        |List(groupDeviceTypeFilesTable) |groupDeviceTypeFilesTable - *Table* array of groupDeviceTypeFilesTable named tuples |
|group_has_customizable_dynamic_files |bool                            |groupHasCustomizableDynamicFiles                                                    |
</div>


## `GroupDeviceTypeFileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDeviceTypeFileGetRequest()`.

Replaced By: `GroupDeviceTypeFileGetResponse14sp8()`

**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|file_source             |str |fileSource *Optional*            |
|configuration_file_name |str |configurationFileName *Optional* |
</div>


## `GroupDeviceTypeFileGetResponse14sp8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDeviceTypeFileGetRequest14sp8()`.

Replaced by: `GroupDeviceTypeFileGetResponse16sp1()`

**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|file_source             |str |fileSource *Optional*            |
|configuration_file_name |str |configurationFileName *Optional* |
</div>


## `GroupDeviceTypeFileGetResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDeviceTypeFileGetRequest16sp1()`.


**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|file_source             |str |fileSource *Optional*            |
|configuration_file_name |str |configurationFileName *Optional* |
|access_url              |str |accessUrl                        |
|repository_url          |str |repositoryUrl *Optional*         |
|template_url            |str |templateUrl *Optional*           |
</div>


## `GroupDeviceTypeTagSetGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDeviceTypeTagSetGetRequest()`.


**Attributes:**

|Name         |Type|Description           |
|-------------|----|----------------------|
|tag_set_name |str |tagSetName *Optional* |
</div>


## `GroupDialPlanPolicyGetAccessCodeListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDialPlanPolicyGetAccessCodeListRequest()` Contains a table with
column headings: "Access Code", "Enable Secondary Dial Tone", "Description"

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|access_code_table |List(accessCodeTable) |accessCodeTable - *Table* array of accessCodeTable named tuples |
</div>


## `GroupDialPlanPolicyGetAccessCodeResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDialPlanPolicyGetAccessCodeRequest()`

**Attributes:**

|Name                                              |Type |Description                                 |
|--------------------------------------------------|-----|--------------------------------------------|
|include_code_for_network_translations_and_routing |bool |includeCodeForNetworkTranslationsAndRouting |
|include_code_for_screening_services               |bool |includeCodeForScreeningServices             |
|enable_secondary_dial_tone                        |bool |enableSecondaryDialTone                     |
|description                                       |str  |description *Optional*                      |
</div>


## `GroupDialPlanPolicyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDialPlanPolicyGetRequest()` Replaced by:
`GroupDialPlanPolicyGetResponse17()`

**Attributes:**

|Name                                  |Type |Description                      |
|--------------------------------------|-----|---------------------------------|
|use_setting                           |str  |useSetting                       |
|requires_access_code_for_public_calls |bool |requiresAccessCodeForPublicCalls |
|allow_e164_public_calls               |bool |allowE164PublicCalls             |
|public_digit_map                      |str  |publicDigitMap *Optional*        |
|private_digit_map                     |str  |privateDigitMap *Optional*       |
</div>


## `GroupDialPlanPolicyGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDialPlanPolicyGetRequest17()`

**Attributes:**

|Name                                            |Type |Description                               |
|------------------------------------------------|-----|------------------------------------------|
|use_setting                                     |str  |useSetting                                |
|requires_access_code_for_public_calls           |bool |requiresAccessCodeForPublicCalls          |
|allow_e164_public_calls                         |bool |allowE164PublicCalls                      |
|prefer_e164_number_format_for_callback_services |bool |preferE164NumberFormatForCallbackServices |
|public_digit_map                                |str  |publicDigitMap *Optional*                 |
|private_digit_map                               |str  |privateDigitMap *Optional*                |
</div>


## `GroupDialPlanPolicyGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDialPlanPolicyGetRequest22()` The following elements are only used
in AS data mode: overrideResolvedDeviceDigitMap The following elements are only used
in AS data mode and not returned in XS data mode: deviceDigitMap

**Attributes:**

|Name                                            |Type |Description                               |
|------------------------------------------------|-----|------------------------------------------|
|use_setting                                     |str  |useSetting                                |
|requires_access_code_for_public_calls           |bool |requiresAccessCodeForPublicCalls          |
|allow_e164_public_calls                         |bool |allowE164PublicCalls                      |
|prefer_e164_number_format_for_callback_services |bool |preferE164NumberFormatForCallbackServices |
|public_digit_map                                |str  |publicDigitMap *Optional*                 |
|private_digit_map                               |str  |privateDigitMap *Optional*                |
|override_resolved_device_digit_map              |bool |overrideResolvedDeviceDigitMap            |
|device_digit_map                                |str  |deviceDigitMap *Optional*                 |
</div>


## `GroupDialableCallerIDCriteriaGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDialableCallerIDCriteriaGetRequest()`.

The response contains the Dialable Caller ID Criteria information.

**Attributes:**

|Name                           |Type      |Description                            |
|-------------------------------|----------|---------------------------------------|
|description                    |str       |description *Optional*                 |
|prefix_digits                  |str       |prefixDigits *Optional*                |
|match_call_type                |List[str] |matchCallType *Optional*               |
|match_alternate_call_indicator |List[str] |matchAlternateCallIndicator *Optional* |
|match_local_category           |bool      |matchLocalCategory                     |
|match_national_category        |bool      |matchNationalCategory                  |
|match_interlata_category       |bool      |matchInterlataCategory                 |
|match_intralata_category       |bool      |matchIntralataCategory                 |
|match_international_category   |bool      |matchInternationalCategory             |
|match_private_category         |bool      |matchPrivateCategory                   |
|match_emergency_category       |bool      |matchEmergencyCategory                 |
|match_other_category           |bool      |matchOtherCategory                     |
</div>


## `GroupDialableCallerIDGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDialableCallerIDGetRequest()`.

The criteria table's column headings are "Active", "Name", "Description", "Prefix
Digits", "Priority".

**Attributes:**

|Name                        |Type                |Description                                                 |
|----------------------------|--------------------|------------------------------------------------------------|
|use_group_criteria          |bool                |useGroupCriteria                                            |
|ns_screening_failure_policy |str                 |nsScreeningFailurePolicy                                    |
|criteria_table              |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `GroupDigitCollectionGetResponse13mp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDigitCollectionGetRequest13mp4()`.


**Attributes:**

|Name              |Type|Description                |
|------------------|----|---------------------------|
|use_setting       |str |useSetting                 |
|access_code       |str |accessCode *Optional*      |
|public_digit_map  |str |publicDigitMap *Optional*  |
|private_digit_map |str |privateDigitMap *Optional* |
</div>


## `GroupDirectoryNumberHuntingGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDirectoryNumberHuntingGetAvailableUserListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupDirectoryNumberHuntingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDirectoryNumberHuntingGetRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address". Replaced by: `GroupDirectoryNumberHuntingGetResponse17sp1()`

**Attributes:**

|Name             |Type                 |Description                                                   |
|-----------------|---------------------|--------------------------------------------------------------|
|agent_user_table |List(agentUserTable) |agentUserTable - *Table* array of agentUserTable named tuples |
</div>


## `GroupDirectoryNumberHuntingGetResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDirectoryNumberHuntingGetRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name                                                     |Type                 |Description                                                   |
|---------------------------------------------------------|---------------------|--------------------------------------------------------------|
|agent_user_table                                         |List(agentUserTable) |agentUserTable - *Table* array of agentUserTable named tuples |
|use_terminate_call_to_agent_first                        |bool                 |useTerminateCallToAgentFirst                                  |
|use_original_agent_services_for_busy_and_no_answer_calls |bool                 |useOriginalAgentServicesForBusyAndNoAnswerCalls               |
</div>


## `GroupDnGetActivationListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDnGetActivationListRequest()`.

The response contains a table with columns: "Phone Numbers", and "Activated". ". Phone
Numbers are only returned if assigned to a user.  The "Phone Numbers" column contains
either a single DN or a range of DNs.  The "Activated" column indicates if the phone
number(s) are activated or not.

**Attributes:**

|Name     |Type          |Description                                     |
|---------|--------------|------------------------------------------------|
|dn_table |List(dnTable) |dnTable - *Table* array of dnTable named tuples |
</div>


## `GroupDnGetAssignmentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDnGetAssignmentListRequest()`.

The response contains a table with columns: "Phone Numbers", "Assigned To",
"Department", "Activated". The "Phone Numbers" column contains either a single DN or a
range of DNs.  The "Assigned To" column contains the user name or service instance
name possessing the DN(s). The "Department" column contains the department of the DN,
not the department of the user or service instance.  The "Activated" column indicates
if the DN or DN range has been activated.  Only has a value if the DN(s) is assigned
to a user.  Replaced by: `GroupDnGetAssignmentListResponse18()`

**Attributes:**

|Name     |Type          |Description                                     |
|---------|--------------|------------------------------------------------|
|dn_table |List(dnTable) |dnTable - *Table* array of dnTable named tuples |
</div>


## `GroupDnGetAssignmentListResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDnGetAssignmentListRequest18()`.

The response contains a table with columns: "Phone Numbers", "Department",
"Activated", "User Id", "Last Name", "First Name", "Extension", "Email Address", "User
Type", "Country Code", "National Prefix". The "Phone Numbers" column contains either a
single DN or a range of DNs.  The "User Id", "Last Name" and "First Name" columns
contains the corresponding attributes of the user possessing the DN(s). For a service
instance, "Last Name" contains the service instance name and "First Name" column
contains the corresponding enumerated UserType value.  The "Department" column
contains the department of the DN, not the department of the user or service instance.
The "Activated" column indicates if the DN or DN range has been activated.  The "User
Type" column contains the corresponding enumerated UserType value.  The "Country Code"
column indicates the dialing prefix for the phone number.  The "National Prefix"
column indicates the digit sequence to be dialed before the telephone number.  NOTE:
the same phone number can show up in the list twice if the phone number is being used
as the group calling line Id.

**Attributes:**

|Name     |Type          |Description                                     |
|---------|--------------|------------------------------------------------|
|dn_table |List(dnTable) |dnTable - *Table* array of dnTable named tuples |
</div>


## `GroupDnGetAssignmentPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDnGetAssignmentPagedSortedListRequest()`.

The response contains a table with columns: "Phone Numbers", "Department", "Department
Type", "Parent Department", "Parent Department Type", "Activated", "Available", "User
Id", "Last Name", "First Name", "Extension", "Email Address", "User Type", "Country
Code", "National Prefix". The "Phone Numbers" column contains either a single DN or a
range of DNs.  The "User Id", "Last Name" and "First Name" columns contains the
corresponding attributes of the user possessing the DN(s). For a service instance,
"Last Name" contains the service instance name and "First Name" column contains the
corresponding enumerated UserType value.  The "Department" column contains the
department of the DN, not the department of the user or service instance.  The
"Department Type" and "Parent Department Type" columns will contain the values
"Enterprise" or "Group". The "Activated" column indicates if the DN or DN range has
been activated.  Only has a value if the DN(s) is assigned to a user.  The "User Type"
column contains the corresponding enumerated UserType value.  The "Country Code"
column indicates the dialing prefix for the phone number.  The "National Prefix"
column indicates the digit sequence to be dialed before the telephone number.  NOTE:
the same phone number can show up in the list twice if the phone number is being used
as the group calling line Id.

**Attributes:**

|Name     |Type          |Description                                     |
|---------|--------------|------------------------------------------------|
|dn_table |List(dnTable) |dnTable - *Table* array of dnTable named tuples |
</div>


## `GroupDnGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDnGetAvailableListRequest()`.

The response contains the list of DNs that are assigned to a group and still available
for assignment to users or service instances within the group.

**Attributes:**

|Name         |Type      |Description            |
|-------------|----------|-----------------------|
|phone_number |List[str] |phoneNumber *Optional* |
</div>


## `GroupDnGetAvailableRangesListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDnGetAvailableRangesListRequest()`.

The response contains the list of group DNs that are not assigned to user, service
instances or IMRN pool.  The Dns are returned in a list of DNs or DN ranges and
formated in E164 format for display.

**Attributes:**

|Name         |Type      |Description            |
|-------------|----------|-----------------------|
|phone_number |List[str] |phoneNumber *Optional* |
</div>


## `GroupDnGetDetailedAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDnGetDetailedAvailableListRequest()`.

The response contains a table with columns: "Phone Number", "Department". The "Phone
Numbers" column contains a single DN. The "Department" column contains the department
of the DN if the DN is part of the department.  The "Activated" column indicates if
the DN has been activated.  Only has a value if the DN(s) is assigned to a user or if
"Group Enable Activation Mode" is enabled.

**Attributes:**

|Name     |Type          |Description                                     |
|---------|--------------|------------------------------------------------|
|dn_table |List(dnTable) |dnTable - *Table* array of dnTable named tuples |
</div>


## `GroupDnGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDnGetListRequest()`.

The response contains the list of DNs assigned to the group.

**Attributes:**

|Name         |Type      |Description            |
|-------------|----------|-----------------------|
|phone_number |List[str] |phoneNumber *Optional* |
</div>


## `GroupDnGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDnGetSummaryListRequest()`.

The response contains a table with columns: "Phone Numbers", "Assigned". The "Phone
Numbers" column contains either a single DN or a range of DNs.  The "Assigned" column
contains a boolean flag indicating if the DN(s) are currently assigned to a user or
service instance.  The "Activated" column indicates if the DN or DN range has been
activated.  Only has a value if the DN(s) is assigned to a user or if either “User
Enable Activation mode “ or "Group and User Enable Activation Mode" is enabled.

**Attributes:**

|Name     |Type          |Description                                     |
|---------|--------------|------------------------------------------------|
|dn_table |List(dnTable) |dnTable - *Table* array of dnTable named tuples |
</div>


## `GroupDomainGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains a simple list of all group domain names.


**Attributes:**

|Name                 |Type      |Description        |
|---------------------|----------|-------------------|
|group_default_domain |str       |groupDefaultDomain |
|domain               |List[str] |domain *Optional*  |
</div>


## `GroupDomainGetAssignedUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDomainGetAssignedUserListRequest()`.

The table columns are: "User Id", "Last Name", "First Name", "Department", "Phone
Number", "Email Address", "Service Provider Id", "Group Id", "Hiragana Last Name" and
"Hiragana First Name", "Extension".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupEmergencyCallNotificationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupEmergencyCallNotificationGetRequest()`.


**Attributes:**

|Name                                   |Type |Description                                |
|---------------------------------------|-----|-------------------------------------------|
|send_emergency_call_notification_email |bool |sendEmergencyCallNotificationEmail         |
|emergency_call_notify_email_address    |str  |emergencyCallNotifyEmailAddress *Optional* |
</div>


## `GroupEmergencyZonesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupEmergencyZonesGetRequest()`.


**Attributes:**

|Name                                |Type |Description                                |
|------------------------------------|-----|-------------------------------------------|
|is_active                           |bool |isActive                                   |
|emergency_zones_prohibition         |str  |emergencyZonesProhibition                  |
|send_emergency_call_notify_email    |bool |sendEmergencyCallNotifyEmail               |
|emergency_call_notify_email_address |str  |emergencyCallNotifyEmailAddress *Optional* |
</div>


## `GroupEndpointGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupEndpointGetListRequest()`.

The column headings for the endpointTable are: "Line/Port", "Last Name", "First Name",
"User Id", "User Type", "Phone Number", "Extension", "Device Type", "Device Name",
"Net Address", "MAC Address", "Department", "Email Address". Possible values for User
Type are "User", "CCBasic", "CCStandard", "CCPremium", "RP", "MOH", "MOHVideo".

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|endpoint_table |List(endpointTable) |endpointTable - *Table* array of endpointTable named tuples |
</div>


## `GroupEnhancedCallLogsSchemaInstanceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupEnhancedCallLogsSchemaInstanceGetRequest()`.


**Attributes:**

|Name |Type|Description     |
|-----|----|----------------|
|name |str |name *Optional* |
</div>


## `GroupEnterpriseTrunkGetAvailableTrunkGroupListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupEnterpriseTrunkGetAvailableTrunkGroupListRequest()`.


**Attributes:**

|Name             |Type      |Description               |
|-----------------|----------|--------------------------|
|trunk_group_name |List[str] |trunkGroupName *Optional* |
</div>


## `GroupEnterpriseTrunkGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupEnterpriseTrunkGetAvailableUserListRequest()`.

The column headings for the enterpriseTrunkUserTable are: "User Id", "Last Name",
"First Name", "Hiragana Last Name", "Hiragana First Name", "Phone Number",
"Extension", "Department", "Email Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupEnterpriseTrunkGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupEnterpriseTrunkGetListRequest()`.

Contains a table of enterprise trunks defined in the enterprise The column headings
are: "Enterprise Trunk Name", "Routing Type"

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|enterprise_trunk_table |List(enterpriseTrunkTable) |enterpriseTrunkTable - *Table* array of enterpriseTrunkTable named tuples |
</div>


## `GroupEnterpriseTrunkGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupEnterpriseTrunkGetRequest()`.

Replaced by: `GroupEnterpriseTrunkGetResponse21()`.

**Attributes:**

|Name                             |Type                        |Description                              |
|---------------------------------|----------------------------|-----------------------------------------|
|maximum_reroute_attempts         |int                         |maximumRerouteAttempts                   |
|route_exhaustion_action          |str                         |routeExhaustionAction                    |
|route_exhaustion_forward_address |str                         |routeExhaustionForwardAddress *Optional* |
|ordered_routing                  |OCI.orderedRouting          |orderedRouting *Optional*                |
|priority_weighted_routing        |OCI.priorityWeightedRouting |priorityWeightedRouting *Optional*       |
</div>


## `GroupEnterpriseTrunkGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupEnterpriseTrunkGetRequest21()`.


**Attributes:**

|Name                                 |Type                        |Description                                 |
|-------------------------------------|----------------------------|--------------------------------------------|
|maximum_reroute_attempts             |int                         |maximumRerouteAttempts                      |
|route_exhaustion_action              |str                         |routeExhaustionAction                       |
|route_exhaustion_forward_address     |str                         |routeExhaustionForwardAddress *Optional*    |
|ordered_routing                      |OCI.orderedRouting          |orderedRouting *Optional*                   |
|priority_weighted_routing            |OCI.priorityWeightedRouting |priorityWeightedRouting *Optional*          |
|enable_capacity_management           |bool                        |enableCapacityManagement                    |
|max_active_calls                     |int                         |maxActiveCalls *Optional*                   |
|capacity_exceeded_trap_initial_calls |int                         |capacityExceededTrapInitialCalls *Optional* |
|capacity_exceeded_trap_offset_calls  |int                         |capacityExceededTrapOffsetCalls *Optional*  |
</div>


## `GroupEnterpriseTrunkGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupEnterpriseTrunkGetRequest22()`.


**Attributes:**

|Name                                  |Type                        |Description                                  |
|--------------------------------------|----------------------------|---------------------------------------------|
|maximum_reroute_attempts              |int                         |maximumRerouteAttempts                       |
|route_exhaustion_action               |str                         |routeExhaustionAction                        |
|route_exhaustion_forward_address      |str                         |routeExhaustionForwardAddress *Optional*     |
|ordered_routing                       |OCI.orderedRouting          |orderedRouting *Optional*                    |
|priority_weighted_routing             |OCI.priorityWeightedRouting |priorityWeightedRouting *Optional*           |
|enable_capacity_management            |bool                        |enableCapacityManagement                     |
|max_active_calls                      |int                         |maxActiveCalls *Optional*                    |
|capacity_exceeded_trap_initial_calls  |int                         |capacityExceededTrapInitialCalls *Optional*  |
|capacity_exceeded_trap_offset_calls   |int                         |capacityExceededTrapOffsetCalls *Optional*   |
|maximum_active_incoming_calls_allowed |int                         |maximumActiveIncomingCallsAllowed *Optional* |
|maximum_active_outgoing_calls_allowed |int                         |maximumActiveOutgoingCallsAllowed *Optional* |
|minimum_active_calls_reserved         |int                         |minimumActiveCallsReserved *Optional*        |
</div>


## `GroupEnterpriseTrunkGetUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupEnterpriseTrunkGetUserListRequest()`.

The column headings for the enterpriseTrunkUserTable are: "User Id", "Last Name",
"First Name", "Phone Number", "Alternate Trunk Identity", "Hiragana Last Name",
"Hiragana First Name", "Extension", "Department", "Email Address" and "Route List
Assigned".

**Attributes:**

|Name                        |Type                           |Description                                                                       |
|----------------------------|-------------------------------|----------------------------------------------------------------------------------|
|enterprise_trunk_user_table |List(enterpriseTrunkUserTable) |enterpriseTrunkUserTable - *Table* array of enterpriseTrunkUserTable named tuples |
</div>


## `GroupExchangeIntegrationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupExchangeIntegrationGetRequest()`.


**Attributes:**

|Name                        |Type |Description                 |
|----------------------------|-----|----------------------------|
|enable_exchange_integration |bool |enableExchangeIntegration   |
|exchange_url                |str  |exchangeURL *Optional*      |
|exchange_user_name          |str  |exchangeUserName *Optional* |
</div>


## `GroupExtensionLengthGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupExtensionLengthGetRequest()`.


**Attributes:**

|Name             |Type|Description     |
|-----------------|----|----------------|
|extension_length |int |extensionLength |
</div>


## `GroupExtensionLengthGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupExtensionLengthGetRequest17()`.

Replaced by: `GroupExtensionLengthGetResponse22()` in AS data mode

**Attributes:**

|Name                     |Type|Description            |
|-------------------------|----|-----------------------|
|min_extension_length     |int |minExtensionLength     |
|max_extension_length     |int |maxExtensionLength     |
|default_extension_length |int |defaultExtensionLength |
</div>


## `GroupExtensionLengthGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupExtensionLengthGetRequest22()`.

The following elements are only used in AS data mode and not returned in XS data mode:
useExterpriseExtensionLengthSetting

**Attributes:**

|Name                                    |Type |Description                                    |
|----------------------------------------|-----|-----------------------------------------------|
|min_extension_length                    |int  |minExtensionLength                             |
|max_extension_length                    |int  |maxExtensionLength                             |
|default_extension_length                |int  |defaultExtensionLength                         |
|use_enterprise_extension_length_setting |bool |useEnterpriseExtensionLengthSetting *Optional* |
</div>


## `GroupFileRepositoryDeviceUserGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupFileRepositoryDeviceUserGetListRequest()`.

Contains a table with column headings : "User Name","Allow Delete","Allow Get","Allow
Put" in a row for each file repository service provider user.

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|file_repository_user_table |List(fileRepositoryUserTable) |fileRepositoryUserTable - *Table* array of fileRepositoryUserTable named tuples |
</div>


## `GroupFindMeFollowMeAlertingGroupGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupFindMeFollowMeAlertingGroupGetAvailableUserListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupFindMeFollowMeGetAlertingGroupListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupFindMeFollowMeGetAlertingGroupListRequest()`.

Contains a table with column headings: "Name", "Priority".

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|alerting_group_table |List(alertingGroupTable) |alertingGroupTable - *Table* array of alertingGroupTable named tuples |
</div>


## `GroupFindMeFollowMeGetAlertingGroupResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupFindMeFollowMeGetAlertingGroupRequest()`.

Contains the alerting group information.  The user table’s column headings are: "User
Id", "Last Name", "First Name", "Hiragana Last Name" and "Hiragana First Name", "Phone
Number", "Extension", "Department", "Email Address". The criteria table's column
headings are: "Is Active", "Criteria Name", "Time Schedule", "Calls From",
"Blacklisted", "Holiday Schedule"", "Calls To Type", "Calls To Number" and "Calls To
Extension". The possible values for the "Calls To Type" column are the following or a
combination of them separated by comma: - Primary - Alternate X (where x is a number
between 1 and 10) The possible values for the "Calls To Number" column are the
following or a combination of them separated by comma: - The value of the phone number
for the corresponding Calls To Type, when the number is available.  i.e.  Alternate 1
may have extension, but no number.  - When no number is available a blank space is
provided instead.  The possible values for the "Calls To Extension" column are the
following or a combination of them separated by comma: - The value of the extension
for the corresponding Calls To Type, when the extension is available.  i.e.  Primary
may have number, but no extension.  - When no extension is available a blank space is
provided instead.

**Attributes:**

|Name                         |Type                |Description                                                 |
|-----------------------------|--------------------|------------------------------------------------------------|
|alerting_group_description   |str                 |alertingGroupDescription *Optional*                         |
|use_diversion_inhibitor      |bool                |useDiversionInhibitor                                       |
|answer_confirmation_required |bool                |answerConfirmationRequired                                  |
|number_of_rings              |int                 |numberOfRings                                               |
|phone_number                 |List[str]           |phoneNumber *Optional*                                      |
|user_table                   |List(userTable)     |userTable - *Table* array of userTable named tuples         |
|criteria_table               |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `GroupFindMeFollowMeGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupFindMeFollowMeGetInstanceListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Phone Number",
"Extension", "Department", "Is Active". The column value for "Is Active" can either be
true, or false.

**Attributes:**

|Name                    |Type                      |Description                                                             |
|------------------------|--------------------------|------------------------------------------------------------------------|
|find_me_follow_me_table |List(findMeFollowMeTable) |findMeFollowMeTable - *Table* array of findMeFollowMeTable named tuples |
</div>


## `GroupFlexibleSeatingAccessDeviceGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupFlexibleSeatingAccessDeviceGetListRequest()`

**Attributes:**

|Name                    |Type                            |Description                      |
|------------------------|--------------------------------|---------------------------------|
|available_access_device |List[OCI.availableAccessDevice] |availableAccessDevice *Optional* |
</div>


## `GroupFlexibleSeatingHostGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupFlexibleSeatingHostGetInstanceListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Phone Number",
"Extension", "Department", "Is Active". The column value for "Is Active" can either be
true, or false.

**Attributes:**

|Name                        |Type                           |Description                                                                       |
|----------------------------|-------------------------------|----------------------------------------------------------------------------------|
|flexible_seating_host_table |List(flexibleSeatingHostTable) |flexibleSeatingHostTable - *Table* array of flexibleSeatingHostTable named tuples |
</div>


## `GroupFlexibleSeatingHostGuestAssociationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupFlexibleSeatingHostGuestAssociationGetRequest()`.


**Attributes:**

|Name                        |Type |Description                         |
|----------------------------|-----|------------------------------------|
|enforce_association_limit   |bool |enforceAssociationLimit             |
|association_limit_hours     |int  |associationLimitHours               |
|access_level                |str  |accessLevel                         |
|guest_last_name             |str  |guestLastName *Optional*            |
|guest_first_name            |str  |guestFirstName *Optional*           |
|guest_phone_number          |str  |guestPhoneNumber *Optional*         |
|guest_extension             |str  |guestExtension *Optional*           |
|guest_location_dialing_code |str  |guestLocationDialingCode *Optional* |
|guest_association_date_time |str  |guestAssociationDateTime *Optional* |
</div>


## `GroupFlexibleSeatingHostRoutingPoliciesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupFlexibleSeatingHostRoutingPoliciesGetRequest()`.


**Attributes:**

|Name                        |Type |Description             |
|----------------------------|-----|------------------------|
|allow_emergency_calls       |bool |allowEmergencyCalls     |
|allow_calls_to_voice_portal |bool |allowCallsToVoicePortal |
</div>


## `GroupGetDefaultResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupGetDefaultRequest()`.

All values are default values for a group's profile.

**Attributes:**

|Name                   |Type|Description         |
|-----------------------|----|--------------------|
|default_domain         |str |defaultDomain       |
|user_limit             |int |userLimit           |
|time_zone              |str |timeZone            |
|time_zone_display_name |str |timeZoneDisplayName |
</div>


## `GroupGetListInServiceProviderPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupGetListInServiceProviderPagedSortedListRequest()`.

Contains a table with column headings: "Group Id", "Group Name", "User Limit" and
"Group External Id" and a row for each group.  The following columns are only
populated in AS data mode: "Group External Id".

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|group_table |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
</div>


## `GroupGetListInServiceProviderResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupGetListInServiceProviderRequest()`.

Contains a 3 column table with column headings: "Group Id", "Group Name", "User Limit"
and a row for each group.

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|group_table |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
</div>


## `GroupGetListInSystemResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupGetListInSystemRequest()`.

Contains a table with column headings: "Group Id", "Group Name", "User Limit",
"Organization Id", "Organization Type", "Reseller Id" and a row for each group.  The
"Organization Id" column is populated with either a service provider Id or an
enterprise Id.  The "Organization Type" column is populated with one of the enumerated
strings defined in the OrganizationType OCI data type.  Please see
OCISchemaDataTypes.xsd for details on OrganizationType.  The following columns are
only returned in AS data mode: Reseller Id

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|group_table |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
</div>


## `GroupGetUserServiceAssignedUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Return a table containing the list of users assigned the user service or service pack.

The table contains columns: "User Id", "Last Name", "First Name", "Department", "Phone
Number", "Email Address", "Hiragana Last Name"; "Hiragana First Name", "Extension".
This is a response to the `GroupGetUserServiceAssignedUserListRequest()`.

**Attributes:**

|Name            |Type                |Description                                                 |
|----------------|--------------------|------------------------------------------------------------|
|user_list_table |List(userListTable) |userListTable - *Table* array of userListTable named tuples |
</div>


## `GroupGroupPagingGetAvailableOriginatorListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupGroupPagingGetAvailableOriginatorListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name" and "Hiragana First Name", "Phone Number", "Extension", "Department",
"Email Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupGroupPagingGetAvailableTargetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupGroupPagingGetAvailableTargetListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name" and "Hiragana First Name", "Phone Number", "Extension", "Department",
"Email Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupGroupPagingGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupGroupPagingGetInstanceListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Phone Number",
"Extension", "Department", "Is Active". The column value for "Is Active" can either be
true, or false.

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|paging_group_table |List(pagingGroupTable) |pagingGroupTable - *Table* array of pagingGroupTable named tuples |
</div>


## `GroupGroupPagingGetOriginatorListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupGroupPagingGetOriginatorListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name             |Type                  |Description                                                     |
|-----------------|----------------------|----------------------------------------------------------------|
|originator_table |List(originatorTable) |originatorTable - *Table* array of originatorTable named tuples |
</div>


## `GroupGroupPagingGetTargetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupGroupPagingGetTargetListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name         |Type              |Description                                             |
|-------------|------------------|--------------------------------------------------------|
|target_table |List(targetTable) |targetTable - *Table* array of targetTable named tuples |
</div>


## `GroupGroupPagingTargetsCapacityGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupGroupPagingTargetsCapacityGetRequest()`.

Replaced by: `GroupGroupPagingTargetsCapacityGetResponse22()` in AS data mode.

**Attributes:**

|Name                                       |Type|Description                           |
|-------------------------------------------|----|--------------------------------------|
|maximum_target_users_from_service_provider |int |maximumTargetUsersFromServiceProvider |
|maximum_target_users                       |int |maximumTargetUsers                    |
</div>


## `GroupGroupPagingTargetsCapacityGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupGroupPagingTargetsCapacityGetRequest22()`.


**Attributes:**

|Name                                       |Type|Description                           |
|-------------------------------------------|----|--------------------------------------|
|maximum_target_users_from_service_provider |int |maximumTargetUsersFromServiceProvider |
|maximum_target_users                       |int |maximumTargetUsers                    |
</div>


## `GroupHolidayScheduleGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupHolidayScheduleGetListRequest()`.

The response contains all the group's holiday schedule name.

**Attributes:**

|Name                  |Type      |Description                    |
|----------------------|----------|-------------------------------|
|holiday_schedule_name |List[str] |holidayScheduleName *Optional* |
</div>


## `GroupHuntGroupGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupHuntGroupGetAvailableUserListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupHuntGroupGetAvailableUserPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupHuntGroupGetAvailableUserPagedSortedListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Is Phone Number Activated",
"Country Code","National Prefix", "Extension", "Department", "Department Type",
"Parent Department", "Parent Department Type", "Email Address", "IMP Id", "Mobile
Number", "Group Id", "Group Name".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupHuntGroupGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupHuntGroupGetInstanceListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Phone Number",
"Extension", "Department", "Is Active", "Policy". The column values for "Is Active"
can either be true, or false.  NOTE: prior to release 14, the policy column did not
match the HuntPolicy enumerated type.

**Attributes:**

|Name             |Type                 |Description                                                   |
|-----------------|---------------------|--------------------------------------------------------------|
|hunt_group_table |List(huntGroupTable) |huntGroupTable - *Table* array of huntGroupTable named tuples |
</div>


## `GroupHuntGroupGetInstancePagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupHuntGroupGetInstancePagedSortedListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Phone Number", "Is
Phone Number Activated", "Country Code","National Prefix", "Extension", "Department",
"Department Type", "Parent Department", "Parent Department Type", "Is Active",
"Policy". The column values for "Is Active" can either be true, or false.  NOTE: prior
to release 14, the policy column did not match the HuntPolicy enumerated type.

**Attributes:**

|Name             |Type                 |Description                                                   |
|-----------------|---------------------|--------------------------------------------------------------|
|hunt_group_table |List(huntGroupTable) |huntGroupTable - *Table* array of huntGroupTable named tuples |
</div>


## `GroupIMRNGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupIMRNGetListRequest()`.


**Attributes:**

|Name |Type      |Description     |
|-----|----------|----------------|
|imrn |List[str] |imrn *Optional* |
</div>


## `GroupInstantGroupCallGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupInstantGroupCallGetInstanceListRequest()`.

Contains a 6 column table with column headings: "Service User Id", "Name", "Phone
Number", "Extension", "Department", "Is Active". The column values for Is Active can
either be true, or false.

**Attributes:**

|Name                     |Type                        |Description                                                                 |
|-------------------------|----------------------------|----------------------------------------------------------------------------|
|instant_group_call_table |List(instantGroupCallTable) |instantGroupCallTable - *Table* array of instantGroupCallTable named tuples |
</div>


## `GroupIntegratedIMPGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupIntegratedIMPGetRequest()`.

The response contains the group Integrated IMP service attributes.  Replaced by:
`GroupIntegratedIMPGetResponse21sp1()` in AS data mode

**Attributes:**

|Name                         |Type |Description               |
|-----------------------------|-----|--------------------------|
|use_service_provider_setting |bool |useServiceProviderSetting |
|service_domain               |str  |serviceDomain *Optional*  |
</div>


## `GroupIntegratedIMPGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupIntegratedIMPGetRequest21sp1()`.

The response contains the group Integrated IMP service attributes.

**Attributes:**

|Name                                |Type |Description                       |
|------------------------------------|-----|----------------------------------|
|use_service_provider_setting        |bool |useServiceProviderSetting         |
|service_domain                      |str  |serviceDomain *Optional*          |
|effective_service_domain            |str  |effectiveServiceDomain *Optional* |
|add_service_provider_in_imp_user_id |bool |addServiceProviderInIMPUserId     |
|default_imp_id_type                 |str  |defaultImpIdType                  |
</div>


## `GroupInterceptGroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupInterceptGroupGetRequest()`.

Replaced By: `GroupInterceptGroupGetResponse16()`

**Attributes:**

|Name                             |Type |Description                     |
|---------------------------------|-----|--------------------------------|
|is_active                        |bool |isActive                        |
|announcement_selection           |str  |announcementSelection           |
|audio_file_description           |str  |audioFileDescription *Optional* |
|video_file_description           |str  |videoFileDescription *Optional* |
|play_new_phone_number            |bool |playNewPhoneNumber              |
|new_phone_number                 |str  |newPhoneNumber *Optional*       |
|transfer_on_zero_to_phone_number |bool |transferOnZeroToPhoneNumber     |
|transfer_phone_number            |str  |transferPhoneNumber *Optional*  |
</div>


## `GroupInterceptGroupGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupInterceptGroupGetRequest16()`.

Replaced By: `GroupInterceptGroupGetResponse16sp1()`

**Attributes:**

|Name                             |Type |Description                     |
|---------------------------------|-----|--------------------------------|
|is_active                        |bool |isActive                        |
|announcement_selection           |str  |announcementSelection           |
|audio_file_description           |str  |audioFileDescription *Optional* |
|audio_media_type                 |str  |audioMediaType *Optional*       |
|video_file_description           |str  |videoFileDescription *Optional* |
|video_media_type                 |str  |videoMediaType *Optional*       |
|play_new_phone_number            |bool |playNewPhoneNumber              |
|new_phone_number                 |str  |newPhoneNumber *Optional*       |
|transfer_on_zero_to_phone_number |bool |transferOnZeroToPhoneNumber     |
|transfer_phone_number            |str  |transferPhoneNumber *Optional*  |
</div>


## `GroupInterceptGroupGetResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupInterceptGroupGetRequest16sp1()`.

Replaced by: `GroupInterceptGroupGetResponse21sp1()` in AS data mode

**Attributes:**

|Name                             |Type |Description                           |
|---------------------------------|-----|--------------------------------------|
|is_active                        |bool |isActive                              |
|announcement_selection           |str  |announcementSelection                 |
|audio_file_description           |str  |audioFileDescription *Optional*       |
|audio_media_type                 |str  |audioMediaType *Optional*             |
|video_file_description           |str  |videoFileDescription *Optional*       |
|video_media_type                 |str  |videoMediaType *Optional*             |
|play_new_phone_number            |bool |playNewPhoneNumber                    |
|new_phone_number                 |str  |newPhoneNumber *Optional*             |
|transfer_on_zero_to_phone_number |bool |transferOnZeroToPhoneNumber           |
|transfer_phone_number            |str  |transferPhoneNumber *Optional*        |
|reroute_outbound_calls           |bool |rerouteOutboundCalls                  |
|outbound_reroute_phone_number    |str  |outboundReroutePhoneNumber *Optional* |
|allow_outbound_local_calls       |bool |allowOutboundLocalCalls               |
|inbound_call_mode                |str  |inboundCallMode                       |
|alternate_blocking_announcement  |bool |alternateBlockingAnnouncement         |
|route_to_voice_mail              |bool |routeToVoiceMail                      |
</div>


## `GroupInterceptGroupGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupInterceptGroupGetRequest21sp1()`.

The following elements are only used in AS data mode: exemptInboundMobilityCalls
exemptOutboundMobilityCalls disableParallelRingingToNetworkLocations

**Attributes:**

|Name                                          |Type |Description                              |
|----------------------------------------------|-----|-----------------------------------------|
|is_active                                     |bool |isActive                                 |
|announcement_selection                        |str  |announcementSelection                    |
|audio_file_description                        |str  |audioFileDescription *Optional*          |
|audio_media_type                              |str  |audioMediaType *Optional*                |
|video_file_description                        |str  |videoFileDescription *Optional*          |
|video_media_type                              |str  |videoMediaType *Optional*                |
|inbound_call_mode                             |str  |inboundCallMode                          |
|alternate_blocking_announcement               |bool |alternateBlockingAnnouncement            |
|exempt_inbound_mobility_calls                 |bool |exemptInboundMobilityCalls               |
|disable_parallel_ringing_to_network_locations |bool |disableParallelRingingToNetworkLocations |
|route_to_voice_mail                           |bool |routeToVoiceMail                         |
|play_new_phone_number                         |bool |playNewPhoneNumber                       |
|new_phone_number                              |str  |newPhoneNumber *Optional*                |
|transfer_on_zero_to_phone_number              |bool |transferOnZeroToPhoneNumber              |
|transfer_phone_number                         |str  |transferPhoneNumber *Optional*           |
|outbound_call_mode                            |str  |outboundCallMode                         |
|exempt_outbound_mobility_calls                |bool |exemptOutboundMobilityCalls              |
|reroute_outbound_calls                        |bool |rerouteOutboundCalls                     |
|outbound_reroute_phone_number                 |str  |outboundReroutePhoneNumber *Optional*    |
</div>


## `GroupInventoryReportGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupInventoryReportGetRequest()`.


**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|inventory_report_table |List(inventoryReportTable) |inventoryReportTable - *Table* array of inventoryReportTable named tuples |
</div>


## `GroupMWIDeliveryToMobileEndpointGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupMWIDeliveryToMobileEndpointGetRequest()`.

The templateActivationTable contains the list of templates defined for the group.  The
column headings are "Enable", "Language", "Type".

**Attributes:**

|Name                      |Type                          |Description                                                                     |
|--------------------------|------------------------------|--------------------------------------------------------------------------------|
|use_setting_level         |str                           |useSettingLevel                                                                 |
|template_activation_table |List(templateActivationTable) |templateActivationTable - *Table* array of templateActivationTable named tuples |
</div>


## `GroupMeetMeConferencingGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMeetMeConferencingGetAvailableUserListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", and "Hiragana First Name", "Phone Number", "Extension", "Department",
"Email Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupMeetMeConferencingGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMeetMeConferencingGetInstanceListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Phone Number",
"Extension", "Department", "Ports", and "Is Active". The column values for "Is Active"
can either be true, or false.

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|conference_bridge_table |List(conferenceBridgeTable) |conferenceBridgeTable - *Table* array of conferenceBridgeTable named tuples |
</div>


## `GroupNetworkClassOfServiceGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupNetworkClassOfServiceGetAssignedListRequest()`.

Contains a table of all Network Classes of Service assigned to the group.  The column
headings are: "Name", "Description" and "Default".

**Attributes:**

|Name                           |Type                             |Description                                                                           |
|-------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|network_class_of_service_table |List(networkClassOfServiceTable) |networkClassOfServiceTable - *Table* array of networkClassOfServiceTable named tuples |
</div>


## `GroupNetworkClassOfServiceGetAssignedUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupNetworkClassOfServiceGetAssignedUserListRequest()`.

Contains a table of users that have the Network Class of Service assigned.  The column
headings are: "User Id", "User Type", "Last Name", "First Name", "Department", "Phone
Number", "Email Address", "Service Provider Id", "Group Id", "Hiragana Last Name" and
"Hiragana First Name" , "Extension".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupNetworkClassOfServiceGetAssignedUserListResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupNetworkClassOfServiceGetAssignedUserListRequest21()`.

Contains a table of users that have the Network Class of Service assigned.  The column
headings are: "User Id", "User Type", "Last Name", "First Name", "Department", "Phone
Number", "Email Address", "Service Provider Id", "Group Id", "Hiragana Last Name" and
"Hiragana First Name" , "Extension". The User type column will display Auto Attendant
and the Call Center subtype.  Call Center - Basic, Call Center - Standard and Call
Center - Premium will be displayed instead of Call Center and Auto Attendant (for the
Basic Auto Attendant) and Auto Attendant - Standard instead of Auto Attendant.

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupOfficeZoneGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOfficeZoneGetAssignedListRequest()`.

Contains a table of all Office Zones assigned to the group.  The column headings are:
"Name", "Description" and "Default".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|office_zone_table |List(officeZoneTable) |officeZoneTable - *Table* array of officeZoneTable named tuples |
</div>


## `GroupOfficeZoneGetAssignedUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOfiiceZoneGetAssignedUserListRequest()`.

Contains a table of users that have the Office Zone assigned.  The column headings
are: "User Id", "User Type", "Last Name", "First Name", "Department", "Phone Number",
"Email Address", "Hiragana Last Name" and "Hiragana First Name", "Extension". Office
Zones can only be unassigned if the Location-Based Calling Restrictions has been
authorized to the group otherwise the request will fail.

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPatternGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanPinholeDigitPatternGetListRequest()`.

Contains a table with column headings: "Name", "Digit Pattern".

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|digit_pattern_table |List(digitPatternTable) |digitPatternTable - *Table* array of digitPatternTable named tuples |
</div>


## `GroupPasswordRulesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPasswordRulesGetRequest()`.

Contains the password rules applicable to users within the group.  Repleced by:
`GroupPasswordRulesGetResponse16()`

**Attributes:**

|Name                                     |Type |Description                                |
|-----------------------------------------|-----|-------------------------------------------|
|service_provider_id                      |str  |serviceProviderId                          |
|group_id                                 |str  |groupId                                    |
|disallow_user_id                         |bool |disallowUserId                             |
|disallow_old_password                    |bool |disallowOldPassword                        |
|disallow_reversed_old_password           |bool |disallowReversedOldPassword                |
|restrict_min_digits                      |bool |restrictMinDigits                          |
|min_digits                               |int  |minDigits                                  |
|restrict_min_upper_case_letters          |bool |restrictMinUpperCaseLetters                |
|min_upper_case_letters                   |int  |minUpperCaseLetters                        |
|restrict_min_lower_case_letters          |bool |restrictMinLowerCaseLetters                |
|min_lower_case_letters                   |int  |minLowerCaseLetters                        |
|restrict_min_non_alphanumeric_characters |bool |restrictMinNonAlphanumericCharacters       |
|min_non_alphanumeric_characters          |int  |minNonAlphanumericCharacters               |
|min_length                               |int  |minLength                                  |
|max_failed_login_attempts                |int  |maxFailedLoginAttempts                     |
|password_expires_days                    |int  |passwordExpiresDays                        |
|send_login_disabled_notify_email         |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address      |str  |loginDisabledNotifyEmailAddress *Optional* |
|disallow_rules_modification              |bool |disallowRulesModification                  |
</div>


## `GroupPasswordRulesGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPasswordRulesGetRequest16()`.

Contains the password rules applicable to users within the group.  Replaced by:
`GroupPasswordRulesGetResponse22()` in AS data mode.

**Attributes:**

|Name                                     |Type |Description                                |
|-----------------------------------------|-----|-------------------------------------------|
|disallow_user_id                         |bool |disallowUserId                             |
|disallow_old_password                    |bool |disallowOldPassword                        |
|disallow_reversed_old_password           |bool |disallowReversedOldPassword                |
|restrict_min_digits                      |bool |restrictMinDigits                          |
|min_digits                               |int  |minDigits                                  |
|restrict_min_upper_case_letters          |bool |restrictMinUpperCaseLetters                |
|min_upper_case_letters                   |int  |minUpperCaseLetters                        |
|restrict_min_lower_case_letters          |bool |restrictMinLowerCaseLetters                |
|min_lower_case_letters                   |int  |minLowerCaseLetters                        |
|restrict_min_non_alphanumeric_characters |bool |restrictMinNonAlphanumericCharacters       |
|min_non_alphanumeric_characters          |int  |minNonAlphanumericCharacters               |
|min_length                               |int  |minLength                                  |
|max_failed_login_attempts                |int  |maxFailedLoginAttempts                     |
|password_expires_days                    |int  |passwordExpiresDays                        |
|send_login_disabled_notify_email         |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address      |str  |loginDisabledNotifyEmailAddress *Optional* |
|disallow_rules_modification              |bool |disallowRulesModification                  |
|disallow_previous_passwords              |bool |disallowPreviousPasswords                  |
|number_of_previous_passwords             |int  |numberOfPreviousPasswords                  |
</div>


## `GroupPasswordRulesGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPasswordRulesGetRequest22()`.

Contains the password rules applicable to users within the group.

**Attributes:**

|Name                                     |Type |Description                                |
|-----------------------------------------|-----|-------------------------------------------|
|disallow_user_id                         |bool |disallowUserId                             |
|disallow_old_password                    |bool |disallowOldPassword                        |
|disallow_reversed_old_password           |bool |disallowReversedOldPassword                |
|restrict_min_digits                      |bool |restrictMinDigits                          |
|min_digits                               |int  |minDigits                                  |
|restrict_min_upper_case_letters          |bool |restrictMinUpperCaseLetters                |
|min_upper_case_letters                   |int  |minUpperCaseLetters                        |
|restrict_min_lower_case_letters          |bool |restrictMinLowerCaseLetters                |
|min_lower_case_letters                   |int  |minLowerCaseLetters                        |
|restrict_min_non_alphanumeric_characters |bool |restrictMinNonAlphanumericCharacters       |
|min_non_alphanumeric_characters          |int  |minNonAlphanumericCharacters               |
|min_length                               |int  |minLength                                  |
|max_failed_login_attempts                |int  |maxFailedLoginAttempts                     |
|password_expires_days                    |int  |passwordExpiresDays                        |
|send_login_disabled_notify_email         |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address      |str  |loginDisabledNotifyEmailAddress *Optional* |
|disallow_rules_modification              |bool |disallowRulesModification                  |
|disallow_previous_passwords              |bool |disallowPreviousPasswords                  |
|number_of_previous_passwords             |int  |numberOfPreviousPasswords                  |
|force_password_change_after_reset        |bool |forcePasswordChangeAfterReset              |
</div>


## `GroupPhoneDirectoryGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPhoneDirectoryGetListRequest()`.

Contains a table with a row for each phone number and column headings : "Name",
"Number", "Extension", "Mobile", "Email Address", "Department", "Hiragana Name",
"Group Id", "Yahoo Id". If extended directory information is requested, the following
columns are also included: "First Name", "Last Name", "User Id", "Pager", "Title",
"Time Zone", "Location", "Address Line 1", "Address Line 2", "City", "State", "Zip",
"Country". Replace by: `GroupPhoneDirectoryGetListResponse17()`

**Attributes:**

|Name            |Type                 |Description                                                   |
|----------------|---------------------|--------------------------------------------------------------|
|directory_table |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `GroupPhoneDirectoryGetListResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPhoneDirectoryGetListRequest17()`.

Contains a table with a row for each phone number and column headings : "Name",
"Number", "Extension", "Mobile", "Email Address", "Department", "Hiragana Name",
"Group Id", "Yahoo Id", "Is Virtual On-Net User" If extended directory information is
requested, the following columns are also included: "First Name", "Last Name", "User
Id", "Pager", "Title", "Time Zone", "Location", "Address Line 1", "Address Line 2",
"City", "State", "Zip", "Country". Replaced by:
`GroupPhoneDirectoryGetListResponse18()`

**Attributes:**

|Name            |Type                 |Description                                                   |
|----------------|---------------------|--------------------------------------------------------------|
|directory_table |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `GroupPhoneDirectoryGetListResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPhoneDirectoryGetListRequest17sp3()`.

Contains a table with a row for each phone number and column headings : "Name",
"Number", "Extension", "Mobile", "Email Address", "Department", "Hiragana Name",
"Group Id", "Yahoo Id", "IMP Id" and "Is Virtual On-Net User" If extended directory
information is requested, the following columns are also included: "First Name", "Last
Name", "User Id", "Pager", "Title", "Time Zone", "Location", "Address Line 1",
"Address Line 2", "City", "State", "Zip", "Country". Replaced by:
`GroupPhoneDirectoryGetListResponse18()`

**Attributes:**

|Name            |Type                 |Description                                                   |
|----------------|---------------------|--------------------------------------------------------------|
|directory_table |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `GroupPhoneDirectoryGetListResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPhoneDirectoryGetListRequest18()`.

Contains a table with a row for each phone number and column headings : "Name",
"Number", "Extension", "Mobile", "Email Address", "Department", "Hiragana Name",
"Group Id", "Yahoo Id", "User Id", "IMP Id" and "Is Virtual On-Net User". If extended
directory information is requested, the following columns are also included: "First
Name", "Last Name", "Pager", "Title", "Time Zone", "Location", "Address Line 1",
"Address Line 2", "City", "State", "Zip", "Country". Finally "Service Name". The
Service Name represents the localized service name for service instances.  The
localized values are taken from the BroadworksLabel.properties file.  Service Name is
currently supporting: AutoAttendant, AutoAttendantStandard, AutoAttendantVideo,
CallCenter, CallCenterStandard, CallCenterPremium HuntGroup, InstantGroupCall,
VoiceMessagingGroup, RoutePoint, BroadWorksAnywhere, GroupPaging, FindmeFollowme,
VoiceXML, FlexibleSeatingGuest, CollaborateAudio, MeetMeConferencing.  For a Regular
User or a Virtual On Network Enterprise Extensions, the Service Name is empty.  The
following columns are returned in AS data mode only: "Service Name"

Replaced By: `GroupPhoneDirectoryGetPagedSortedListResponse()`

**Attributes:**

|Name            |Type                 |Description                                                   |
|----------------|---------------------|--------------------------------------------------------------|
|directory_table |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `GroupPhoneDirectoryGetPagedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPhoneDirectoryGetPagedListRequest()`.

Contains a table with a row for each phone number and column headings : "Name",
"Number", "Extension", "Mobile", "Email Address", "Department", "Hiragana Name",
"Group Id", "Yahoo Id", "User Id", "IMP Id" and "Is Virtual On-Net User". If extended
directory information is requested, the following columns are also included: "First
Name", "Last Name", "Pager", "Title", "Time Zone", "Location", "Address Line 1",
"Address Line 2", "City", "State", "Zip", "Country". Finally "Service Name". The
Service Name represents the localized service name for service instances.  The
localized values are taken from the BroadworksLabel.properties file.  Service Name is
currently supporting: AutoAttendant, AutoAttendantStandard, AutoAttendantVideo,
CallCenter, CallCenterStandard, CallCenterPremium HuntGroup, InstantGroupCall,
VoiceMessagingGroup, MusicOnHold, MusicOnHoldVideo, RoutePoint, BroadWorksAnywhere
GroupPaging, FindmeFollowme, VoiceXML, FlexibleSeatingGuest, CollaborateSharing,
MeetMeConferencing.  For a Regular User or a Virtual On Network Enterprise Extensions,
the Service Name is empty.

Replaced By: `GroupPhoneDirectoryGetPagedSortedListResponse()`

**Attributes:**

|Name                 |Type                 |Description                                                   |
|---------------------|---------------------|--------------------------------------------------------------|
|total_number_of_rows |int                  |totalNumberOfRows                                             |
|directory_table      |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `GroupPhoneDirectoryGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPhoneDirectoryGetPagedSortedListRequest()`.

Contains a table with a row for each phone number and column headings : "Name",
"Number", "Extension", "Mobile", "Email Address", "Department", "Hiragana Name",
"Group Id", "Yahoo Id", "User Id", "IMP Id" and "Is Virtual On-Net User". If extended
directory information is requested, the following columns are also included: "First
Name", "Last Name", "Pager", "Title", "Time Zone", "Location", "Address Line 1",
"Address Line 2", "City", "State", "Zip", "Country". Finally "Service Name". The
Service Name represents the localized service name for service instances.  The
localized values are taken from the BroadworksLabel.properties file.  Service Name is
currently supporting: AutoAttendant, AutoAttendantStandard, AutoAttendantVideo,
CallCenter, CallCenterStandard, CallCenterPremium HuntGroup, InstantGroupCall,
VoiceMessagingGroup, MusicOnHold, MusicOnHoldVideo, RoutePoint, BroadWorksAnywhere
GroupPaging, FindmeFollowme, VoiceXML, FlexibleSeatingGuest, CollaborateSharing,
MeetMeConferencing.  For a Regular User or a Virtual On Network Enterprise Extensions,
the Service Name is empty.  The following columns are populated in AS data mode only:
"IMP Id"

**Attributes:**

|Name                 |Type                 |Description                                                   |
|---------------------|---------------------|--------------------------------------------------------------|
|total_number_of_rows |int                  |totalNumberOfRows                                             |
|directory_table      |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `GroupPolicyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPolicyGetRequest()`.

Contains the policy settings for the group.

**Attributes:**

|Name                         |Type|Description               |
|-----------------------------|----|--------------------------|
|calling_plan_access          |str |callingPlanAccess         |
|extension_access             |str |extensionAccess           |
|ldap_integration_access      |str |ldapIntegrationAccess     |
|voice_messaging_access       |str |voiceMessagingAccess      |
|department_admin_user_access |str |departmentAdminUserAccess |
|user_authentication_access   |str |userAuthenticationAccess  |
|user_group_directory_access  |str |userGroupDirectoryAccess  |
|user_profile_access          |str |userProfileAccess         |
</div>


## `GroupPolicyGetResponse14sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPolicyGetRequest14sp1()`.

Contains the policy settings for the group.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|calling_plan_access                 |str |callingPlanAccess               |
|extension_access                    |str |extensionAccess                 |
|ldap_integration_access             |str |ldapIntegrationAccess           |
|voice_messaging_access              |str |voiceMessagingAccess            |
|department_admin_user_access        |str |departmentAdminUserAccess       |
|department_admin_trunk_group_access |str |departmentAdminTrunkGroupAccess |
|user_authentication_access          |str |userAuthenticationAccess        |
|user_group_directory_access         |str |userGroupDirectoryAccess        |
|user_profile_access                 |str |userProfileAccess               |
</div>


## `GroupPolicyGetResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPolicyGetRequest14sp4()`.

Contains the policy settings for the group.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|calling_plan_access                 |str |callingPlanAccess               |
|extension_access                    |str |extensionAccess                 |
|ldap_integration_access             |str |ldapIntegrationAccess           |
|voice_messaging_access              |str |voiceMessagingAccess            |
|department_admin_user_access        |str |departmentAdminUserAccess       |
|department_admin_trunk_group_access |str |departmentAdminTrunkGroupAccess |
|user_authentication_access          |str |userAuthenticationAccess        |
|user_group_directory_access         |str |userGroupDirectoryAccess        |
|user_profile_access                 |str |userProfileAccess               |
|user_enhanced_call_log_access       |str |userEnhancedCallLogAccess       |
</div>


## `GroupPolicyGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPolicyGetRequest17()`.

Contains the policy settings for the group.  Replaced by: `GroupPolicyGetResponse20()`
in AS data mode

**Attributes:**

|Name                                           |Type|Description                               |
|-----------------------------------------------|----|------------------------------------------|
|calling_plan_access                            |str |callingPlanAccess                         |
|extension_access                               |str |extensionAccess                           |
|ldap_integration_access                        |str |ldapIntegrationAccess                     |
|voice_messaging_access                         |str |voiceMessagingAccess                      |
|department_admin_user_access                   |str |departmentAdminUserAccess                 |
|department_admin_trunk_group_access            |str |departmentAdminTrunkGroupAccess           |
|department_admin_phone_number_extension_access |str |departmentAdminPhoneNumberExtensionAccess |
|department_admin_calling_line_id_number_access |str |departmentAdminCallingLineIdNumberAccess  |
|user_authentication_access                     |str |userAuthenticationAccess                  |
|user_group_directory_access                    |str |userGroupDirectoryAccess                  |
|user_profile_access                            |str |userProfileAccess                         |
|user_enhanced_call_log_access                  |str |userEnhancedCallLogAccess                 |
</div>


## `GroupPolicyGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPolicyGetRequest20()`.

Contains the policy settings for the group.  Replaced by: `GroupPolicyGetResponse22()`
in AS data mode

**Attributes:**

|Name                                           |Type|Description                               |
|-----------------------------------------------|----|------------------------------------------|
|calling_plan_access                            |str |callingPlanAccess                         |
|extension_access                               |str |extensionAccess                           |
|ldap_integration_access                        |str |ldapIntegrationAccess                     |
|voice_messaging_access                         |str |voiceMessagingAccess                      |
|department_admin_user_access                   |str |departmentAdminUserAccess                 |
|department_admin_trunk_group_access            |str |departmentAdminTrunkGroupAccess           |
|department_admin_phone_number_extension_access |str |departmentAdminPhoneNumberExtensionAccess |
|department_admin_calling_line_id_number_access |str |departmentAdminCallingLineIdNumberAccess  |
|user_authentication_access                     |str |userAuthenticationAccess                  |
|user_group_directory_access                    |str |userGroupDirectoryAccess                  |
|user_profile_access                            |str |userProfileAccess                         |
|user_enhanced_call_log_access                  |str |userEnhancedCallLogAccess                 |
|user_auto_attendant_name_dialing_access        |str |userAutoAttendantNameDialingAccess        |
</div>


## `GroupPolicyGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPolicyGetRequest22()`.

Contains the policy settings for the group.

**Attributes:**

|Name                                           |Type|Description                               |
|-----------------------------------------------|----|------------------------------------------|
|calling_plan_access                            |str |callingPlanAccess                         |
|extension_access                               |str |extensionAccess                           |
|voice_messaging_access                         |str |voiceMessagingAccess                      |
|department_admin_user_access                   |str |departmentAdminUserAccess                 |
|department_admin_trunk_group_access            |str |departmentAdminTrunkGroupAccess           |
|department_admin_phone_number_extension_access |str |departmentAdminPhoneNumberExtensionAccess |
|department_admin_calling_line_id_number_access |str |departmentAdminCallingLineIdNumberAccess  |
|user_authentication_access                     |str |userAuthenticationAccess                  |
|user_group_directory_access                    |str |userGroupDirectoryAccess                  |
|user_profile_access                            |str |userProfileAccess                         |
|user_enhanced_call_log_access                  |str |userEnhancedCallLogAccess                 |
|user_auto_attendant_name_dialing_access        |str |userAutoAttendantNameDialingAccess        |
</div>


## `GroupPolycomPhoneServicesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPolycomPhoneServicesGetRequest()`.


**Attributes:**

|Name                                                |Type |Description                                   |
|----------------------------------------------------|-----|----------------------------------------------|
|include_group_common_phone_list_in_directory        |bool |includeGroupCommonPhoneListInDirectory        |
|include_group_custom_contact_directory_in_directory |bool |includeGroupCustomContactDirectoryInDirectory |
|group_custom_contact_directory                      |str  |groupCustomContactDirectory *Optional*        |
</div>


## `GroupPortalPasscodeRulesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPortalPasscodeRulesGetRequest()`.

Contains the group's passcode rules setting.

**Attributes:**

|Name                                          |Type |Description                                |
|----------------------------------------------|-----|-------------------------------------------|
|use_rule_level                                |str  |useRuleLevel                               |
|disallow_repeated_digits                      |bool |disallowRepeatedDigits                     |
|disallow_user_number                          |bool |disallowUserNumber                         |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber                 |
|disallow_old_passcode                         |bool |disallowOldPasscode                        |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode                |
|min_code_length                               |int  |minCodeLength                              |
|max_code_length                               |int  |maxCodeLength                              |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts    |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*          |
|expire_password                               |bool |expirePassword                             |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*             |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional* |
</div>


## `GroupPortalPasscodeRulesGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupPortalPasscodeRulesGetRequest19()`.

Contains the group's passcode rules setting.  The following elements are only used in
AS data mode: numberOfRepeatedDigits disallowRepeatedPatterns
disallowContiguousSequences numberOfAscendingDigits numberOfDescendingDigits
numberOfPreviousPasscodes

**Attributes:**

|Name                                          |Type |Description                                |
|----------------------------------------------|-----|-------------------------------------------|
|use_rule_level                                |str  |useRuleLevel                               |
|disallow_repeated_digits                      |bool |disallowRepeatedDigits                     |
|number_of_repeated_digits                     |int  |numberOfRepeatedDigits                     |
|disallow_repeated_patterns                    |bool |disallowRepeatedPatterns                   |
|disallow_contiguous_sequences                 |bool |disallowContiguousSequences                |
|number_of_ascending_digits                    |int  |numberOfAscendingDigits                    |
|number_of_descending_digits                   |int  |numberOfDescendingDigits                   |
|disallow_user_number                          |bool |disallowUserNumber                         |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber                 |
|disallow_old_passcode                         |bool |disallowOldPasscode                        |
|number_of_previous_passcodes                  |int  |numberOfPreviousPasscodes                  |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode                |
|min_code_length                               |int  |minCodeLength                              |
|max_code_length                               |int  |maxCodeLength                              |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts    |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*          |
|expire_password                               |bool |expirePassword                             |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*             |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional* |
</div>


## `GroupPreAlertingAnnouncementGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Get the group level pre-alerting service settings.

The response is either a `GroupPreAlertingAnnouncementGetResponse()` or an
`ErrorResponse()`. Replaced by: `GroupPreAlertingAnnouncementGetResponse20()` in AS
data mode

**Attributes:**

|Name                        |Type|Description                          |
|----------------------------|----|-------------------------------------|
|announcement_interruption   |str |announcementInterruption             |
|interruption_digit_sequence |str |interruptionDigitSequence *Optional* |
|audio_selection             |str |audioSelection                       |
|audio_file_description      |str |audioFileDescription *Optional*      |
|audio_media_type            |str |audioMediaType *Optional*            |
|audio_file_url              |str |audioFileUrl *Optional*              |
|video_selection             |str |videoSelection                       |
|video_file_description      |str |videoFileDescription *Optional*      |
|video_media_type            |str |videoMediaType *Optional*            |
|video_file_url              |str |videoFileUrl *Optional*              |
</div>


## `GroupRouteListEnterpriseTrunkNumberPrefixGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupRouteListEnterpriseTrunkNumberPrefixGetAvailableListRequest()`.

Contains a list of number prefixess that are assigned to a group and still available
for assignment to users within the group.  The column headings are "Number
Prefix"","Is Active", “Extension Range Start” and “Extension Range End”.

**Attributes:**

|Name                          |Type                             |Description                                                                           |
|------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|available_number_prefix_table |List(availableNumberPrefixTable) |availableNumberPrefixTable - *Table* array of availableNumberPrefixTable named tuples |
</div>


## `GroupRouteListEnterpriseTrunkNumberPrefixGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupRouteListEnterpriseTrunkNumberRangeGetSummaryListRequest()`.

The response contains a table with columns: "Number Prefix", "User Id", "Last Name",
"First Name", "Hiragana Last Name", "Hiragana First Name", "Phone Number",
"Extension", "Department", "Email Address", "Enterprise Trunk"","Is Active",
“Extension Range Start” and “Extension Range End”. The "User Id", "Last Name", "First
Name", "Hiragana Last Name", "Hiragana First Name", "Phone Number", "Extension",
"Department" and "Email Address" columns contains the corresponding attributes of the
user possessing the number range.  The "Enterprise Trunk" column contains the
enterprise trunk the user possessing the number range belongs to.  The "Is Active"
column indicates if the number prefix has been activated.  The “Extension Range Start”
column indicates the start for an extension range.  The “Extension Range End” column
indicates the end for an extension range.

**Attributes:**

|Name                        |Type                           |Description                                                                       |
|----------------------------|-------------------------------|----------------------------------------------------------------------------------|
|number_prefix_summary_table |List(numberPrefixSummaryTable) |numberPrefixSummaryTable - *Table* array of numberPrefixSummaryTable named tuples |
</div>


## `GroupRouteListEnterpriseTrunkNumberRangeGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupRouteListEnterpriseTrunkNumberRangeGetAvailableListRequest()`.

Contains a list of number ranges that are assigned to a group and still available for
assignment to users within the group.  The column headings are "Number Range Start",
"Number Range End" ,"Is Active" and “Extension Length”..

**Attributes:**

|Name                         |Type                            |Description                                                                         |
|-----------------------------|--------------------------------|------------------------------------------------------------------------------------|
|available_number_range_table |List(availableNumberRangeTable) |availableNumberRangeTable - *Table* array of availableNumberRangeTable named tuples |
</div>


## `GroupRouteListEnterpriseTrunkNumberRangeGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupRouteListEnterpriseTrunkNumberRangeGetSummaryListRequest()`.

The response contains a table with columns: "Number Range Start", "Number Range End",
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name",
"Phone Number", "Extension", "Department", "Email Address", "Enterprise Trunk" and "Is
Active". The "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Phone Number", "Extension", "Department" and "Email Address" columns
contains the corresponding attributes of the user possessing the number range.  The
"Enterprise Trunk" column contains the enterprise trunk the user possessing the number
range belongs to.  The "Is Active" column indicates if the number range has been
activated.  The “Extension Length” column indicates the length of the extension for
the enterpris trunk number range.

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|number_range_summary_table |List(numberRangeSummaryTable) |numberRangeSummaryTable - *Table* array of numberRangeSummaryTable named tuples |
</div>


## `GroupRoutePointBouncedCallGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointBouncedCallGetRequest()`.


**Attributes:**

|Name                                 |Type |Description                     |
|-------------------------------------|-----|--------------------------------|
|is_active                            |bool |isActive                        |
|number_of_rings_before_bouncing_call |int  |numberOfRingsBeforeBouncingCall |
|enable_transfer                      |bool |enableTransfer *Optional*       |
|transfer_phone_number                |str  |transferPhoneNumber *Optional*  |
|bounce_call_when_agent_unavailable   |bool |bounceCallWhenAgentUnavailable  |
</div>


## `GroupRoutePointDistinctiveRingingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointDistinctiveRingingGetRequest()`.


**Attributes:**

|Name                                            |Type |Description                                |
|------------------------------------------------|-----|-------------------------------------------|
|enable_distinctive_ringing                      |bool |enableDistinctiveRinging                   |
|distinctive_ringing_ring_pattern                |str  |distinctiveRingingRingPattern              |
|distinctive_ringing_force_delivery_ring_pattern |str  |distinctiveRingingForceDeliveryRingPattern |
</div>


## `GroupRoutePointExternalSystemGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointExternalSystemGetAssignedListRequest()`.

Contains a table of all Route Point External Systems assigned to the group.  The
column headings are: "Name" and "Description".

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|external_system_table |List(externalSystemTable) |externalSystemTable - *Table* array of externalSystemTable named tuples |
</div>


## `GroupRoutePointExternalSystemGetAssignedRoutePointListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointExternalSystemGetAssignedRoutePointListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Video", "Phone
Number", "Extension", "Department". The column values for "Video" can either be
"true", or "false".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|route_point_table |List(routePointTable) |routePointTable - *Table* array of routePointTable named tuples |
</div>


## `GroupRoutePointGetDNISAgentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointGetDNISAgentListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|agent_table |List(agentTable) |agentTable - *Table* array of agentTable named tuples |
</div>


## `GroupRoutePointGetDNISListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointGetDNISListRequest()`.

Contains a table with column headings: "Name", "Phone Number", "Extension".

**Attributes:**

|Name                |Type            |Description                                         |
|--------------------|----------------|----------------------------------------------------|
|display_dnis_number |bool            |displayDNISNumber                                   |
|display_dnis_name   |bool            |displayDNISName                                     |
|dnis_table          |List(dnisTable) |dnisTable - *Table* array of dnisTable named tuples |
</div>


## `GroupRoutePointGetDNISResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointGetDNISRequest()`.


**Attributes:**

|Name                                  |Type |Description                         |
|--------------------------------------|-----|------------------------------------|
|dnis_phone_number                     |str  |dnisPhoneNumber *Optional*          |
|extension                             |str  |extension *Optional*                |
|use_custom_clid_settings              |bool |useCustomCLIDSettings               |
|calling_line_id_phone_number          |str  |callingLineIdPhoneNumber *Optional* |
|calling_line_id_last_name             |str  |callingLineIdLastName *Optional*    |
|calling_line_id_first_name            |str  |callingLineIdFirstName *Optional*   |
|use_custom_dnis_announcement_settings |bool |useCustomDnisAnnouncementSettings   |
|allow_outgoing_acd_call               |bool |allowOutgoingACDCall                |
</div>


## `GroupRoutePointGetFailoverPolicyResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointGetFailoverPolicyRequest()`.


**Attributes:**

|Name                                           |Type |Description                              |
|-----------------------------------------------|-----|-----------------------------------------|
|enable_failover_support                        |bool |enableFailoverSupport                    |
|external_system                                |str  |externalSystem *Optional*                |
|failover_phone_number                          |str  |failoverPhoneNumber *Optional*           |
|failover_status                                |str  |failoverStatus                           |
|per_call_enable_failover_support               |bool |perCallEnableFailoverSupport             |
|per_call_call_failure_timeout_seconds          |int  |perCallCallFailureTimeoutSeconds         |
|per_call_outbound_call_failure_timeout_seconds |int  |perCallOutboundCallFailureTimeoutSeconds |
|per_call_failover_phone_number                 |str  |perCallFailoverPhoneNumber *Optional*    |
</div>


## `GroupRoutePointGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointGetInstanceListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Video", "Phone
Number", "Extension", "Department", "Is Active". The column values for "Video" and "Is
Active" can either be true, or false.

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|route_point_table |List(routePointTable) |routePointTable - *Table* array of routePointTable named tuples |
</div>


## `GroupRoutePointQueueCallDispositionCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointQueueCallDispositionCodeGetListRequest()`.

Contains a table with column headings: "Is Active", "Code", "Description" and "Level".
Level column can be any of the values in the data type CallDispositionCodeLevel.

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|disposition_codes_table |List(dispositionCodesTable) |dispositionCodesTable - *Table* array of dispositionCodesTable named tuples |
</div>


## `GroupRoutePointQueueCallDispositionCodeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointQueueCallDispositionCodeGetRequest()`

**Attributes:**

|Name        |Type |Description            |
|------------|-----|-----------------------|
|is_active   |bool |isActive               |
|description |str  |description *Optional* |
</div>


## `GroupRoutingProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupRoutingProfileGetRequest()`.


**Attributes:**

|Name            |Type|Description               |
|----------------|----|--------------------------|
|routing_profile |str |routingProfile *Optional* |
</div>


## `GroupScheduleGetEventListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupScheduleGetEventListRequest()`.

The response contains a list of events.

**Attributes:**

|Name       |Type      |Description          |
|-----------|----------|---------------------|
|event_name |List[str] |eventName *Optional* |
</div>


## `GroupScheduleGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupScheduleGetListRequest()`.

The response contains a list of system schedules.

**Attributes:**

|Name           |Type      |Description              |
|---------------|----------|-------------------------|
|schedule_name  |List[str] |scheduleName *Optional*  |
|schedule_type  |List[str] |scheduleType *Optional*  |
|schedule_level |List[str] |scheduleLevel *Optional* |
</div>


## `GroupScheduleGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupScheduleGetPagedSortedListRequest()`.

Contains a 3 column table with column headings: "Name", "Type", "Level" and a row for
each schedule.

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|schedule_table |List(scheduleTable) |scheduleTable - *Table* array of scheduleTable named tuples |
</div>


## `GroupScheduleUsageResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupScheduleUsageRequest()`.

The response contains a list of service names.  The response contains the usage for
the requested schedule.  The usage table has columns "Service Name", and "Instance
Name". The Service Name values correspond to string values of the GroupService and
UserService data types.

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|usage_table |List(usageTable) |usageTable - *Table* array of usageTable named tuples |
</div>


## `GroupSecurityClassificationCustomizationGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupClassificationCustomizationGetAvailableListRequest()`.

Returns the available group security classifications.  Contains a table with column
headings: "SystemSecurityClassification", "CustomizedSecurityClassification"

**Attributes:**

|Name                               |Type                                  |Description                                                                                     |
|-----------------------------------|--------------------------------------|------------------------------------------------------------------------------------------------|
|security_classification_name_table |List(securityClassificationNameTable) |securityClassificationNameTable - *Table* array of securityClassificationNameTable named tuples |
</div>


## `GroupSeriesCompletionGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupSeriesCompletionGetAvailableUserListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupSeriesCompletionGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupSeriesCompletionGetInstanceListRequest()`.


**Attributes:**

|Name |Type      |Description     |
|-----|----------|----------------|
|name |List[str] |name *Optional* |
</div>


## `GroupSeriesCompletionGetInstanceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupSeriesCompletionGetInstanceRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupServiceGetAuthorizationListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupServiceGetAuthorizationListRequest()`.

Contains three tables, one for the service packs, one for the group services, and one
for the user services.  The user table has the following column headings: "Service
Name", "Authorized", "Assigned", "Limited", "Quantity", "Usage", "Licensed",
"Allowed", "User Assignable", "Group Service Assignable". The group service table has
the following column headings: "Service Name", "Authorized", "Assigned", "Limited",
"Quantity", "Usage", "Licensed", "Allowed", "Instance Count". The service pack table's
column headings are: "Service Pack Name", "Authorized", "Assigned", "Limited",
"Allocated", "Allowed", "Usage", "Description".

**Attributes:**

|Name                               |Type                                  |Description                                                                                     |
|-----------------------------------|--------------------------------------|------------------------------------------------------------------------------------------------|
|service_packs_authorization_table  |List(servicePacksAuthorizationTable)  |servicePacksAuthorizationTable - *Table* array of servicePacksAuthorizationTable named tuples   |
|group_services_authorization_table |List(groupServicesAuthorizationTable) |groupServicesAuthorizationTable - *Table* array of groupServicesAuthorizationTable named tuples |
|user_services_authorization_table  |List(userServicesAuthorizationTable)  |userServicesAuthorizationTable - *Table* array of userServicesAuthorizationTable named tuples   |
</div>


## `GroupServiceGetAuthorizedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupServiceGetAuthorizedListRequest()`.


**Attributes:**

|Name               |Type      |Description                 |
|-------------------|----------|----------------------------|
|service_pack_name  |List[str] |servicePackName *Optional*  |
|group_service_name |List[str] |groupServiceName *Optional* |
|user_service_name  |List[str] |userServiceName *Optional*  |
</div>


## `GroupServiceInstancePrivacyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupServiceInstancePrivacyGetRequest()`.

Replaced by: `GroupServiceInstancePrivacyGetResponse17sp4()`

**Attributes:**

|Name                                            |Type |Description                                |
|------------------------------------------------|-----|-------------------------------------------|
|enable_directory_privacy                        |bool |enableDirectoryPrivacy                     |
|enable_auto_attendant_extension_dialing_privacy |bool |enableAutoAttendantExtensionDialingPrivacy |
</div>


## `GroupServiceInstancePrivacyGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupServiceInstancePrivacyGetRequest17sp4()`.


**Attributes:**

|Name                                            |Type |Description                                |
|------------------------------------------------|-----|-------------------------------------------|
|enable_directory_privacy                        |bool |enableDirectoryPrivacy                     |
|enable_auto_attendant_extension_dialing_privacy |bool |enableAutoAttendantExtensionDialingPrivacy |
|enable_auto_attendant_name_dialing_privacy      |bool |enableAutoAttendantNameDialingPrivacy      |
</div>


## `GroupServiceIsAssignedResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Returns true if the GroupService is assigned, otherwise false.


**Attributes:**

|Name        |Type |Description|
|------------|-----|-----------|
|is_assigned |bool |isAssigned |
</div>


## `GroupServicePhoneNumberLookupResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupServicePhoneNumberLookupRequest()`.

The column headings for the userTable are: "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name", "Phone Number", "Extension" and
"Department".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupSessionAdmissionControlGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupSessionAdmissionControlGetRequest()`.

The response contains the session admission control capacity allocated for the group.

**Attributes:**

|Name                          |Type |Description                           |
|------------------------------|-----|--------------------------------------|
|restrict_aggregate_sessions   |bool |restrictAggregateSessions             |
|max_sessions                  |int  |maxSessions *Optional*                |
|max_user_originating_sessions |int  |maxUserOriginatingSessions *Optional* |
|max_user_terminating_sessions |int  |maxUserTerminatingSessions *Optional* |
|count_intra_group_sessions    |bool |countIntraGroupSessions               |
</div>


## `GroupSessionAdmissionControlGroupGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupSessionAdmissionControlGroupGetListRequest()`.

Contains a table of session admission control group configured in the group.  The
column headings are: "Name", "Is Default", "Maximum Sessions", "Maximum Originating
Sessions", "Maximum Terminating Sessions".

**Attributes:**

|Name                                  |Type                                    |Description                                                                                         |
|--------------------------------------|----------------------------------------|----------------------------------------------------------------------------------------------------|
|session_admission_control_group_table |List(sessionAdmissionControlGroupTable) |sessionAdmissionControlGroupTable - *Table* array of sessionAdmissionControlGroupTable named tuples |
</div>


## `GroupSpeedDial100GetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupSpeedDial100GetRequest()`.


**Attributes:**

|Name   |Type|Description|
|-------|----|-----------|
|prefix |str |prefix     |
</div>


## `GroupSpeedDial100GetResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupSpeedDial100GetRequest17sp1()`.


**Attributes:**

|Name   |Type|Description       |
|-------|----|------------------|
|prefix |str |prefix *Optional* |
</div>


## `GroupStirShakenGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupStirShakenGetRequest()`.


**Attributes:**

|Name                                                   |Type |Description                                      |
|-------------------------------------------------------|-----|-------------------------------------------------|
|use_parent_level_settings                              |bool |useParentLevelSettings                           |
|signing_policy                                         |str  |signingPolicy                                    |
|tagging_policy                                         |str  |taggingPolicy                                    |
|signing_service_url                                    |str  |signingServiceURL *Optional*                     |
|tag_from_or_pai                                        |str  |tagFromOrPAI                                     |
|verstat_tag                                            |str  |verstatTag                                       |
|use_os_value_for_orig_id                               |bool |useOSValueForOrigId                              |
|orig_uuid                                              |str  |origUUID *Optional*                              |
|attestation_level                                      |str  |attestationLevel                                 |
|enable_verification                                    |bool |enableVerification                               |
|verification_service_url                               |str  |verificationServiceURL *Optional*                |
|verification_error_handling                            |str  |verificationErrorHandling                        |
|proxy_verstat_to_cnam_subscribe                        |bool |proxyVerstatToCNAMSubscribe                      |
|use_unknown_headers_from_cnam_notify                   |bool |useUnknownHeadersFromCNAMNotify                  |
|enable_signing_for_unscreened_trunk_group_originations |bool |enableSigningForUnscreenedTrunkGroupOriginations |
|enable_tagging_for_unscreened_trunk_group_originations |bool |enableTaggingForUnscreenedTrunkGroupOriginations |
|unscreened_trunk_group_origination_attestation_level   |str  |unscreenedTrunkGroupOriginationAttestationLevel  |
</div>


## `GroupTemplateOnlyDeviceFileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTemplateOnlyDeviceFileGetListRequest()`.

Contains a list of template files used to support a Visual Device Management device.

**Attributes:**

|Name              |Type      |Description                |
|------------------|----------|---------------------------|
|template_file_url |List[str] |templateFileUrl *Optional* |
</div>


## `GroupThirdPartyEmergencyCallingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupThirdPartyEmergencyCallingGetRequest()`.

The response contains the third-party emergency call service settings for the Group.

**Attributes:**

|Name                     |Type |Description            |
|-------------------------|-----|-----------------------|
|enable_device_management |bool |enableDeviceManagement |
|enable_routing           |bool |enableRouting          |
</div>


## `GroupThirdPartyVoiceMailSupportGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupThirdPartyVoiceMailSupportGetRequest()`.


**Attributes:**

|Name         |Type |Description            |
|-------------|-----|-----------------------|
|is_active    |bool |isActive               |
|group_server |str  |groupServer *Optional* |
</div>


## `GroupTimeScheduleGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupTimeScheduleGetListRequest()`.

The response contains all the group's time schedule name.

**Attributes:**

|Name          |Type      |Description             |
|--------------|----------|------------------------|
|time_schedule |List[str] |timeSchedule *Optional* |
</div>


## `GroupTrunkGroupGetAvailableDetailListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetAvailableDetailListRequest()`.


**Attributes:**

|Name        |Type                 |Description           |
|------------|---------------------|----------------------|
|trunk_group |List[OCI.trunkGroup] |trunkGroup *Optional* |
</div>


## `GroupTrunkGroupGetAvailableHostedUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupTrunkGroupGetAvailableHostedUserListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupTrunkGroupGetInstanceListResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceListRequest14()`.

Contains a table with column headings "Service User Id", "Name", "Department", "Device
Name", "Device Level", "Group Id". The "Device Level" column contains one of the
AccessDeviceLevel enumerated constants.

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|trunk_group_table |List(trunkGroupTable) |trunkGroupTable - *Table* array of trunkGroupTable named tuples |
</div>


## `GroupTrunkGroupGetInstanceListResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceListRequest14sp4()`.

Contains a table with column headings "Name", "Department", "Device Name", "Device
Level", "Group Id". The "Device Level" column contains one of the AccessDeviceLevel
enumerated constants.

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|trunk_group_table |List(trunkGroupTable) |trunkGroupTable - *Table* array of trunkGroupTable named tuples |
</div>


## `GroupTrunkGroupGetInstanceUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceUserListRequest()`.

The response contains a 7 column table with column headings "User Id", "Last Name",
"First Name", "Department", "Phone Number", "Hiragana Last Name", "Hiragana First
Name".

**Attributes:**

|Name                   |Type                      |Description                                                             |
|-----------------------|--------------------------|------------------------------------------------------------------------|
|trunk_group_user_table |List(trunkGroupUserTable) |trunkGroupUserTable - *Table* array of trunkGroupUserTable named tuples |
</div>


## `GroupTrunkGroupGetInstanceUserListResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceUserListRequest14sp4()`.

The response contains a 9 column table with column headings "User Id", "Last Name",
"First Name", "Department", "Phone Number", "Hiragana Last Name", "Hiragana First
Name", "Extension", "Email Address".

**Attributes:**

|Name                   |Type                      |Description                                                             |
|-----------------------|--------------------------|------------------------------------------------------------------------|
|trunk_group_user_table |List(trunkGroupUserTable) |trunkGroupUserTable - *Table* array of trunkGroupUserTable named tuples |
</div>


## `GroupTrunkGroupSecurityClassificationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupTrunkGroupSecurityClassificationGetRequest()`.


**Attributes:**

|Name                            |Type|Description                              |
|--------------------------------|----|-----------------------------------------|
|default_security_classification |str |defaultSecurityClassification *Optional* |
</div>


## `GroupTrunkGroupStirShakenGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupTrunkGroupStirShakenGetRequest()`.


**Attributes:**

|Name                                                   |Type |Description                                      |
|-------------------------------------------------------|-----|-------------------------------------------------|
|use_parent_level_settings                              |bool |useParentLevelSettings                           |
|signing_policy                                         |str  |signingPolicy                                    |
|tagging_policy                                         |str  |taggingPolicy                                    |
|signing_service_url                                    |str  |signingServiceURL *Optional*                     |
|tag_from_or_pai                                        |str  |tagFromOrPAI                                     |
|verstat_tag                                            |str  |verstatTag                                       |
|use_os_value_for_orig_id                               |bool |useOSValueForOrigId                              |
|orig_uuid                                              |str  |origUUID *Optional*                              |
|attestation_level                                      |str  |attestationLevel                                 |
|enable_signing_for_unscreened_trunk_group_originations |bool |enableSigningForUnscreenedTrunkGroupOriginations |
|enable_tagging_for_unscreened_trunk_group_originations |bool |enableTaggingForUnscreenedTrunkGroupOriginations |
|unscreened_trunk_group_origination_attestation_level   |str  |unscreenedTrunkGroupOriginationAttestationLevel  |
</div>


## `GroupTrunkGroupUserCreationTaskGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupUserCreationTaskGetListRequest()`.

Contains a table with a row for each user creation task and column headings : "Name",
"Status", "Users Created", "Total Users To Create", "Error Count".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|task_table |List(taskTable) |taskTable - *Table* array of taskTable named tuples |
</div>


## `GroupTrunkGroupUserCreationTaskGetListResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupUserCreationTaskGetListRequest14sp4()`.

Contains a table with a row for each user creation task and column headings : "Name",
"Status", "Users Created", "Total Users To Create", "Error Count".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|task_table |List(taskTable) |taskTable - *Table* array of taskTable named tuples |
</div>


## `GroupTrunkGroupUserCreationTaskGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `GroupTrunkGroupUserCreationTaskGetRequest()`.


**Attributes:**

|Name                  |Type      |Description                |
|----------------------|----------|---------------------------|
|user_id_format        |str       |userIdFormat               |
|user_id_domain        |str       |userIdDomain               |
|populate_extension    |bool      |populateExtension          |
|line_port_format      |str       |linePortFormat             |
|line_port_domain      |str       |linePortDomain             |
|populate_contact      |bool      |populateContact            |
|contact_format        |str       |contactFormat *Optional*   |
|contact_domain        |str       |contactDomain *Optional*   |
|users_created         |int       |usersCreated               |
|total_users_to_create |int       |totalUsersToCreate         |
|error_count           |int       |errorCount                 |
|service_pack_name     |List[str] |servicePackName *Optional* |
|user_service_name     |List[str] |userServiceName *Optional* |
|status                |str       |status                     |
|user_creation_mode    |str       |userCreationMode           |
|task_summary          |str       |taskSummary                |
</div>


## `GroupTrunkGroupUserCreationTaskGetResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `GroupTrunkGroupUserCreationTaskGetRequest14sp4()`.


**Attributes:**

|Name                  |Type      |Description                |
|----------------------|----------|---------------------------|
|user_id_format        |str       |userIdFormat               |
|user_id_domain        |str       |userIdDomain               |
|populate_extension    |bool      |populateExtension          |
|line_port_format      |str       |linePortFormat             |
|line_port_domain      |str       |linePortDomain             |
|populate_contact      |bool      |populateContact            |
|contact_format        |str       |contactFormat *Optional*   |
|contact_domain        |str       |contactDomain *Optional*   |
|users_created         |int       |usersCreated               |
|total_users_to_create |int       |totalUsersToCreate         |
|error_count           |int       |errorCount                 |
|service_pack_name     |List[str] |servicePackName *Optional* |
|user_service_name     |List[str] |userServiceName *Optional* |
|status                |str       |status                     |
|user_creation_mode    |str       |userCreationMode           |
|task_summary          |str       |taskSummary                |
|report_file_key       |str       |reportFileKey              |
</div>


## `GroupUserCallForwardingSettingsGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupUserCallForwardingSettingsGetListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", and "Hiragana First Name", "Phone Number", "Extension", "Department", "In
Trunk Group", "Email Address", "Is Active", "Forwarding Address". "Is Active" is
"true" or "false". The "Forwarding Address" is the Call Forwarding service's
forwarding address.  If the service is Call Forwarding Selective, the default
forwarding address is returned.  "Phone Number" is presented in the E164 format.

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|user_call_forwarding_table |List(userCallForwardingTable) |userCallForwardingTable - *Table* array of userCallForwardingTable named tuples |
</div>


## `GroupUserCallWaitingSettingsGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupUserCallWaitingSettingsGetListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", and "Hiragana First Name", "Phone Number", "Extension", "Department", "In
Trunk Group", "Email Address", "Is Active". "Is Active" is "true" or "false". "Phone
Number" is presented in the E164 format.

**Attributes:**

|Name                    |Type                       |Description                                                               |
|------------------------|---------------------------|--------------------------------------------------------------------------|
|user_call_waiting_table |List(userCallWaitingTable) |userCallWaitingTable - *Table* array of userCallWaitingTable named tuples |
</div>


## `GroupUserCallingPlanSettingsGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupUserCallingPlanSettingsGetListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", and "Hiragana First Name", "Phone Number", "Extension", "Department", "In
Trunk Group", "Email Address", "Use Custom Settings". "Use Custom Settings" is "true"
or "false". "Phone Number" is presented in the E164 format.

**Attributes:**

|Name                    |Type                       |Description                                                               |
|------------------------|---------------------------|--------------------------------------------------------------------------|
|user_calling_plan_table |List(userCallingPlanTable) |userCallingPlanTable - *Table* array of userCallingPlanTable named tuples |
</div>


## `GroupUserHotelingGuestSettingsGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupUserHotelingGuestSettingsGetListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", and "Hiragana First Name", "Phone Number", "Extension", "Department", "In
Trunk Group", "Email Address", "Is Active". "Is Active" is "true" or "false". "Phone
Number" is presented in the E164 format.

**Attributes:**

|Name                      |Type                         |Description                                                                   |
|--------------------------|-----------------------------|------------------------------------------------------------------------------|
|user_hoteling_guest_table |List(userHotelingGuestTable) |userHotelingGuestTable - *Table* array of userHotelingGuestTable named tuples |
</div>


## `GroupVirtualOnNetEnterpriseExtensionsGetUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupVirtualOnNetEnterpriseExtensionsGetUserListRequest()`.

Contains a table with column headings: "Last Name", "First Name", "Phone Number",
"Extension", "Virtual On-Net Call Type Name" in a row for each user.

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `GroupVirtualOnNetEnterpriseExtensionsGetUserResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupVirtualOnNetEnterpriseExtensionsGetUserRequest()`.


**Attributes:**

|Name                          |Type|Description              |
|------------------------------|----|-------------------------|
|extension                     |str |extension                |
|first_name                    |str |firstName                |
|last_name                     |str |lastName                 |
|calling_line_id_first_name    |str |callingLineIdFirstName   |
|calling_line_id_last_name     |str |callingLineIdLastName    |
|virtual_on_net_call_type_name |str |virtualOnNetCallTypeName |
</div>


## `GroupVoiceMessagingGroupGetPasscodeRulesResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupVoiceMessagingGroupGetPasscodeRulesRequest()`.

Contains the group's voice portal passcode rules setting.

Replaced By: `GroupPortalPasscodeRulesGetResponse()`

**Attributes:**

|Name                                          |Type |Description                                |
|----------------------------------------------|-----|-------------------------------------------|
|use_rule_level                                |str  |useRuleLevel                               |
|disallow_repeated_digits                      |bool |disallowRepeatedDigits                     |
|disallow_user_number                          |bool |disallowUserNumber                         |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber                 |
|disallow_old_passcode                         |bool |disallowOldPasscode                        |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode                |
|min_code_length                               |int  |minCodeLength                              |
|max_code_length                               |int  |maxCodeLength                              |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts    |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*          |
|expire_password                               |bool |expirePassword                             |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*             |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional* |
</div>


## `GroupVoiceMessagingGroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupVoiceMessagingGroupGetRequest()`.

Contains the group's voice messaging settings.

**Attributes:**

|Name                                             |Type |Description                               |
|-------------------------------------------------|-----|------------------------------------------|
|use_mail_server_setting                          |str  |useMailServerSetting                      |
|warn_caller_before_recording_voice_message       |bool |warnCallerBeforeRecordingVoiceMessage     |
|allow_users_configuring_advanced_settings        |bool |allowUsersConfiguringAdvancedSettings     |
|allow_compose_or_forward_message_to_entire_group |bool |allowComposeOrForwardMessageToEntireGroup |
|mail_server_net_address                          |str  |mailServerNetAddress *Optional*           |
|mail_server_protocol                             |str  |mailServerProtocol                        |
|real_delete_for_imap                             |bool |realDeleteForImap                         |
|max_mailbox_length_minutes                       |int  |maxMailboxLengthMinutes                   |
|does_message_age                                 |bool |doesMessageAge                            |
|hold_period_days                                 |int  |holdPeriodDays                            |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalBrandingResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupVoiceMessagingGroupGetVoicePortalBrandingRequest()`.

Replaced By: `GroupVoiceMessagingGroupGetVoicePortalBrandingResponse16()`

**Attributes:**

|Name                                      |Type|Description                                      |
|------------------------------------------|----|-------------------------------------------------|
|voice_portal_greeting_selection           |str |voicePortalGreetingSelection                     |
|voice_portal_greeting_file_description    |str |voicePortalGreetingFileDescription *Optional*    |
|voice_messaging_greeting_selection        |str |voiceMessagingGreetingSelection                  |
|voice_messaging_greeting_file_description |str |voiceMessagingGreetingFileDescription *Optional* |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalBrandingResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupVoiceMessagingGroupGetVoicePortalBrandingRequest16()`.

Replaced by: `GroupVoiceMessagingGroupGetVoicePortalBrandingResponse20()` in AS data
mode

**Attributes:**

|Name                                      |Type|Description                                      |
|------------------------------------------|----|-------------------------------------------------|
|voice_portal_greeting_selection           |str |voicePortalGreetingSelection                     |
|voice_portal_greeting_file_description    |str |voicePortalGreetingFileDescription *Optional*    |
|voice_portal_greeting_media_type          |str |voicePortalGreetingMediaType *Optional*          |
|voice_messaging_greeting_selection        |str |voiceMessagingGreetingSelection                  |
|voice_messaging_greeting_file_description |str |voiceMessagingGreetingFileDescription *Optional* |
|voice_messaging_greeting_media_type       |str |voiceMessagingGreetingMediaType *Optional*       |
</div>


## `GroupVoiceXmlGetInstanceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupVoiceXmlGetInstanceListRequest()`.

Contains a table with column headings: "Service User Id", "Name", "Phone Number",
"Extension", "Department", "Is Active". The column values for "Is Active" can either
be true, or false.

**Attributes:**

|Name            |Type                |Description                                                 |
|----------------|--------------------|------------------------------------------------------------|
|voice_xml_table |List(voiceXmlTable) |voiceXmlTable - *Table* array of voiceXmlTable named tuples |
</div>


## `GroupXsiPolicyProfileGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupXsiPolicyProfileGetAssignedListRequest()`.

Contains a table of all Xsi Policy Profile assigned to.  The column headings are:
"Name", "Level", "Description" and "Default".

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|assigned_table |List(assignedTable) |assignedTable - *Table* array of assignedTable named tuples |
</div>


## `GroupXsiPolicyProfileGetAssignedUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupXsiPolicyProfileGetAssignedUserListRequest()`.

Contains a table of user that have the user Xsi Policy Profile assigned.  The column
headings are: "User Id", "Last Name", "First Name", "Phone Number" "Department" and
"Extension".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `LoginResponse13mp10`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
`LoginRequest13mp10()`/Response13mp10 is 2nd stage of the 2 stage OCI login process.


**Attributes:**

|Name       |Type|Description|
|-----------|----|-----------|
|login_type |str |loginType  |
|locale     |str |locale     |
|encoding   |str |encoding   |
</div>


## `LoginResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
`LoginRequest14sp4()`/Response14sp4 is 2nd stage of the 2 stage OCI login process.


**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|user_domain           |str  |userDomain                     |
</div>


## `LoginResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
`LoginRequest21sp1()`/Response21sp1 is 2nd stage of the 2 stage OCI login process.

The parameter tokenRevocationTime is represented in the number of milliseconds since
January 1, 1970, 00:00:00 GMT, and it is set to the more current time between the
system level token revocation time and user level token revocation time.  Replaced by
`LoginResponse22V3()` in AS data mode.

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|user_domain           |str  |userDomain                     |
|token_revocation_time |int  |tokenRevocationTime *Optional* |
</div>


## `LoginResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the OCI login request.

Replaced by `LoginResponse22V2()` in AS data mode.

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|user_domain           |str  |userDomain                     |
</div>


## `LoginResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the OCI login request.

Replaced by `LoginResponse22V3()` in AS data mode.

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|user_domain           |str  |userDomain                     |
|reseller_id           |str  |resellerId *Optional*          |
</div>


## `LoginResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the OCI login request.

The following data elements are only returned in AS data mode: resellerId
tokenRevocationTime The parameter tokenRevocationTime is represented in the number of
milliseconds since January 1, 1970, 00:00:00 GMT, and it is set to the more current
time between the system level token revocation time and user level token revocation
time.  Replaced by `LoginRequest22V4()` in AS data mode.

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|user_domain           |str  |userDomain                     |
|reseller_id           |str  |resellerId *Optional*          |
|token_revocation_time |int  |tokenRevocationTime *Optional* |
</div>


## `LoginResponse22V4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the OCI login request.

Replaced by: `LoginResponse22V5()`. The following data elements are only returned in
AS data mode: resellerId The parameter tokenRevocationTime is represented in the
number of milliseconds since January 1, 1970, 00:00:00 GMT, and it is set to the more
current time between the system level token revocation time and user level token
revocation time.

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|user_domain           |str  |userDomain                     |
|reseller_id           |str  |resellerId *Optional*          |
|token_revocation_time |int  |tokenRevocationTime *Optional* |
</div>


## `LoginResponse22V5`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the OCI login request.

The following data elements are only returned in AS data mode: resellerId The
parameter tokenRevocationTime is represented in the number of milliseconds since
January 1, 1970, 00:00:00 GMT, and it is set to the more current time between the
system level token revocation time and user level token revocation time.

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|user_domain           |str  |userDomain                     |
|reseller_id           |str  |resellerId *Optional*          |
|token_revocation_time |int  |tokenRevocationTime *Optional* |
</div>


## `PasswordGenerateResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `PasswordGenerateRequest()`.

The response contains the requested passwords.

**Attributes:**

|Name                                    |Type|Description                                     |
|----------------------------------------|----|------------------------------------------------|
|system_administrator_password           |str |systemAdministratorPassword *Optional*          |
|service_provider_administrator_password |str |serviceProviderAdministratorPassword *Optional* |
|group_administrator_password            |str |groupAdministratorPassword *Optional*           |
|user_password                           |str |userPassword *Optional*                         |
|user_passcode                           |str |userPasscode *Optional*                         |
|user_sip_authentication_password        |str |userSIPAuthenticationPassword *Optional*        |
|access_device_authentication_password   |str |accessDeviceAuthenticationPassword *Optional*   |
|trunk_group_authentication_password     |str |trunkGroupAuthenticationPassword *Optional*     |
</div>


## `PrimaryInfoGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Information about the primary server in the high-availablity cluster.

For optimization, we only get the hostname and addresses for primary if they are
explicitly requested or if the current server is not the primary.

**Attributes:**

|Name                        |Type      |Description                         |
|----------------------------|----------|------------------------------------|
|is_primary                  |bool      |isPrimary                           |
|hostname_for_primary        |str       |hostnameForPrimary *Optional*       |
|address_for_primary         |List[str] |addressForPrimary *Optional*        |
|private_address_for_primary |List[str] |privateAddressForPrimary *Optional* |
</div>


## `PublicClusterGetFullyQualifiedDomainNameResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `PublicClusterGetFullyQualifiedDomainNameRequest()`.


**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|public_cluster_fqdn |str |publicClusterFQDN *Optional* |
</div>


## `ResellerAdminAlternateIdGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerAdminAlternateIdGetListRequest()`.

Contains a table of the main admin user id and the alternate admin user ids, the
column headings are: "User Id", "Description", "Alternate". The possible values for
"Alternate" are "true" and "false". The "Description" is only present for alternate
admin user Ids.

**Attributes:**

|Name                |Type                   |Description                                                       |
|--------------------|-----------------------|------------------------------------------------------------------|
|admin_user_id_table |List(adminUserIdTable) |adminUserIdTable - *Table* array of adminUserIdTable named tuples |
</div>


## `ResellerAdminGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerAdminGetListRequest()`.

Contains a 4 column table with column headings "Administrator ID", "Last Name", "First
Name", "Language".

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|reseller_admin_table |List(resellerAdminTable) |resellerAdminTable - *Table* array of resellerAdminTable named tuples |
</div>


## `ResellerAdminGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ResellerAdminGetRequest()`.

The response contains the reseller administrators profile information.  Replaced by
`ResellerAdminGetResponse22()`

**Attributes:**

|Name        |Type|Description          |
|------------|----|---------------------|
|reseller_id |str |resellerId           |
|first_name  |str |firstName *Optional* |
|last_name   |str |lastName *Optional*  |
|language    |str |language             |
</div>


## `ResellerAdminGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ResellerAdminGetRequest22()`.

The response contains the reseller administrators profile information.

**Attributes:**

|Name        |Type|Description          |
|------------|----|---------------------|
|reseller_id |str |resellerId           |
|first_name  |str |firstName *Optional* |
|last_name   |str |lastName *Optional*  |
|language    |str |language             |
</div>


## `ResellerCallAdmissionControlPoliciesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ResellerCallAdmissionControlPoliciesGetRequest()`.

The response contains the reseller call admission control policies information.

**Attributes:**

|Name                                              |Type |Description                                             |
|--------------------------------------------------|-----|--------------------------------------------------------|
|enable_call_admission_control                     |bool |enableCallAdmissionControl                              |
|max_concurrent_network_sessions                   |int  |maxConcurrentNetworkSessions                            |
|max_concurrent_network_sessions_threshold         |int  |maxConcurrentNetworkSessionsThreshold *Optional*        |
|max_network_calls_per_second                      |int  |maxNetworkCallsPerSecond                                |
|max_network_calls_per_second_threshold            |int  |maxNetworkCallsPerSecondThreshold *Optional*            |
|max_concurrent_external_siprec_sessions           |int  |maxConcurrentExternalSIPRECSessions                     |
|max_concurrent_external_siprec_sessions_threshold |int  |maxConcurrentExternalSIPRECSessionsThreshold *Optional* |
</div>


## `ResellerCallCenterGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerCallCenterGetRequest()`.


**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|default_from_address |str |defaultFromAddress *Optional* |
</div>


## `ResellerCallNotifyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerCallNotifyGetRequest()`.


**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|default_from_address |str |defaultFromAddress *Optional* |
</div>


## `ResellerCallPoliciesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerCallPoliciesGetRequest()`.

Replaced by: `ResellerCallPoliciesGetRequest22()` in AS data mode.

**Attributes:**

|Name                                                 |Type |Description                                    |
|-----------------------------------------------------|-----|-----------------------------------------------|
|force_redirecting_user_identity_for_redirected_calls |bool |forceRedirectingUserIdentityForRedirectedCalls |
</div>


## `ResellerCallPoliciesGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerCallPoliciesGetRequest22()`.


**Attributes:**

|Name                                                 |Type |Description                                    |
|-----------------------------------------------------|-----|-----------------------------------------------|
|force_redirecting_user_identity_for_redirected_calls |bool |forceRedirectingUserIdentityForRedirectedCalls |
|apply_redirecting_user_identity_to_network_locations |bool |applyRedirectingUserIdentityToNetworkLocations |
</div>


## `ResellerCallRecordingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ResellerCallRecordingGetRequest()`.

The response contains the reseller’s Call Recording attribute.

**Attributes:**

|Name |Type|Description     |
|-----|----|----------------|
|fqdn |str |FQDN *Optional* |
</div>


## `ResellerCollaborateGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerCollaborateGetRequest()`.


**Attributes:**

|Name                     |Type|Description                       |
|-------------------------|----|----------------------------------|
|collaborate_from_address |str |collaborateFromAddress *Optional* |
</div>


## `ResellerDeviceActivationPolicyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerDeviceActivationPolicyGetRequest()`.


**Attributes:**

|Name                                  |Type |Description                      |
|--------------------------------------|-----|---------------------------------|
|use_reseller_settings                 |bool |useResellerSettings              |
|allow_activation_code_request_by_user |bool |allowActivationCodeRequestByUser |
|send_activation_code_in_email         |bool |sendActivationCodeInEmail        |
</div>


## `ResellerEmergencyCallNotificationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerEmergencyCallNotificationGetRequest()`.


**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|default_from_address |str |defaultFromAddress *Optional* |
</div>


## `ResellerEmergencyZonesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerEmergencyZonesGetRequest()`.


**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|default_from_address |str |defaultFromAddress *Optional* |
</div>


## `ResellerGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ResellerGetListRequest()`.

Contains a 2 column table with column headings "Reseller Id", "Reseller Name" and
"Reseller External Id". A row for each reseller.

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|reseller_table |List(resellerTable) |resellerTable - *Table* array of resellerTable named tuples |
</div>


## `ResellerGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ResellerGetRequest()`.

Replaced by: `ResellerGetResponse22()`

**Attributes:**

|Name          |Type|Description             |
|--------------|----|------------------------|
|reseller_name |str |resellerName *Optional* |
</div>


## `ResellerGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ResellerGetRequest22()`.

Replaced by: `ResellerGetResponse22V2()`

**Attributes:**

|Name          |Type|Description             |
|--------------|----|------------------------|
|reseller_name |str |resellerName *Optional* |
</div>


## `ResellerGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ResellerGetRequest22V2()`.


**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|reseller_name        |str |resellerName *Optional*       |
|reseller_id          |str |resellerId                    |
|reseller_external_id |str |resellerExternalId *Optional* |
</div>


## `ResellerIntegratedIMPGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ResellerIntegratedIMPGetRequest()`.

The response contains the reseller Integrated IMP service attributes.  Replaced by:
`ResellerIntegratedIMPGetResponse22()` in AS data mode

**Attributes:**

|Name                        |Type |Description                   |
|----------------------------|-----|------------------------------|
|use_system_service_domain   |bool |useSystemServiceDomain        |
|service_domain              |str  |serviceDomain *Optional*      |
|service_port                |int  |servicePort *Optional*        |
|use_system_messaging_server |bool |useSystemMessagingServer      |
|provisioning_url            |str  |provisioningUrl *Optional*    |
|provisioning_user_id        |str  |provisioningUserId *Optional* |
|bosh_url                    |str  |boshURL *Optional*            |
</div>


## `ResellerIntegratedIMPGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ResellerIntegratedIMPGetRequest22()`.

The response contains the reseller Integrated IMP service attributes.

**Attributes:**

|Name                        |Type |Description                   |
|----------------------------|-----|------------------------------|
|use_system_service_domain   |bool |useSystemServiceDomain        |
|service_domain              |str  |serviceDomain *Optional*      |
|service_port                |int  |servicePort *Optional*        |
|use_system_messaging_server |bool |useSystemMessagingServer      |
|provisioning_url            |str  |provisioningUrl *Optional*    |
|provisioning_user_id        |str  |provisioningUserId *Optional* |
|bosh_url                    |str  |boshURL *Optional*            |
|default_imp_id_type         |str  |defaultImpIdType              |
</div>


## `ResellerMailParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerMailParametersGetRequest()`.


**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|default_from_address |str |defaultFromAddress *Optional* |
</div>


## `ResellerMeetMeConferencingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerMeetMeConferencingGetRequest()`.


**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|conference_from_address |str |conferenceFromAddress *Optional* |
|max_allocated_ports     |int |maxAllocatedPorts *Optional*     |
</div>


## `ResellerMeetMeConferencingGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerMeetMeConferencingGetRequest22()`.


**Attributes:**

|Name                            |Type |Description                            |
|--------------------------------|-----|---------------------------------------|
|conference_from_address         |str  |conferenceFromAddress *Optional*       |
|max_allocated_ports             |int  |maxAllocatedPorts *Optional*           |
|disable_unlimited_meet_me_ports |bool |disableUnlimitedMeetMePorts *Optional* |
|enable_max_allocated_ports      |bool |enableMaxAllocatedPorts *Optional*     |
</div>


## `ResellerNetworkClassOfServiceGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerNetworkClassOfServiceGetAssignedListRequest()`.

Contains a table of all Network Classes of Service assigned to the reseller.  The
column headings are: "Name", "Description" and "Default".

**Attributes:**

|Name                           |Type                             |Description                                                                           |
|-------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|network_class_of_service_table |List(networkClassOfServiceTable) |networkClassOfServiceTable - *Table* array of networkClassOfServiceTable named tuples |
</div>


## `ResellerNetworkClassOfServiceGetAssignedServiceProviderListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerNetworkClassOfServiceGetAssignedServiceProviderListRequest()`.

Contains a table of Service Providers that have the Network Class of Service assigned.
The column headings are: "Service Provider Id" and "Service Provider Name".

**Attributes:**

|Name     |Type          |Description                                     |
|---------|--------------|------------------------------------------------|
|sp_table |List(spTable) |spTable - *Table* array of spTable named tuples |
</div>


## `ResellerResourcePriorityGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ResellerResourcePriorityGetRequest()`.

The response contains the reseller Resource Priority service attributes.  If
useSystemSettings is true, the parameters sendResourcePriorityToNetwork and
resourcePriority will not be returned in the response.

**Attributes:**

|Name                              |Type |Description                   |
|----------------------------------|-----|------------------------------|
|use_system_settings               |bool |useSystemSettings             |
|send_resource_priority_to_network |bool |sendResourcePriorityToNetwork |
|resource_priority                 |str  |resourcePriority              |
</div>


## `ResellerServiceAuthorizationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ResellerServiceAuthorizationGetRequest()`.


**Attributes:**

|Name             |Type|Description                |
|-----------------|----|---------------------------|
|service_offering |str |serviceOffering *Optional* |
</div>


## `ResellerStirShakenGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ResellerStirShakenGetRequest()`.


**Attributes:**

|Name                                                   |Type |Description                                      |
|-------------------------------------------------------|-----|-------------------------------------------------|
|use_parent_level_settings                              |bool |useParentLevelSettings                           |
|signing_policy                                         |str  |signingPolicy                                    |
|tagging_policy                                         |str  |taggingPolicy                                    |
|sign_emergency_calls                                   |bool |signEmergencyCalls                               |
|tag_emergency_calls                                    |bool |tagEmergencyCalls                                |
|signing_service_url                                    |str  |signingServiceURL *Optional*                     |
|tag_from_or_pai                                        |str  |tagFromOrPAI                                     |
|verstat_tag                                            |str  |verstatTag                                       |
|use_os_value_for_orig_id                               |bool |useOSValueForOrigId                              |
|orig_uuid                                              |str  |origUUID *Optional*                              |
|attestation_level                                      |str  |attestationLevel                                 |
|enable_verification                                    |bool |enableVerification                               |
|verification_service_url                               |str  |verificationServiceURL *Optional*                |
|verification_error_handling                            |str  |verificationErrorHandling                        |
|proxy_verstat_to_cnam_subscribe                        |bool |proxyVerstatToCNAMSubscribe                      |
|use_unknown_headers_from_cnam_notify                   |bool |useUnknownHeadersFromCNAMNotify                  |
|enable_signing_for_unscreened_trunk_group_originations |bool |enableSigningForUnscreenedTrunkGroupOriginations |
|enable_tagging_for_unscreened_trunk_group_originations |bool |enableTaggingForUnscreenedTrunkGroupOriginations |
|unscreened_trunk_group_origination_attestation_level   |str  |unscreenedTrunkGroupOriginationAttestationLevel  |
|verify_gets_calls                                      |bool |verifyGETSCalls                                  |
</div>


## `ResellerVoiceMessagingGroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerVoiceMessagingGroupGetRequest()`.


**Attributes:**

|Name                              |Type|Description                              |
|----------------------------------|----|-----------------------------------------|
|delivery_from_address             |str |deliveryFromAddress *Optional*           |
|notification_from_address         |str |notificationFromAddress *Optional*       |
|voice_portal_lockout_from_address |str |voicePortalLockoutFromAddress *Optional* |
</div>


## `ResellerXsiPolicyProfileGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerXsiPolicyProfileGetAssignedListRequest()`.

Contains a table of all Xsi Policy Profile assigned to.  The column headings are:
"Name", "Level", "Description" and "Default".

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|assigned_table |List(assignedTable) |assignedTable - *Table* array of assignedTable named tuples |
</div>


## `ResellerXsiPolicyProfileGetAssignedServiceProviderListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ResellerXsiPolicyProfileGetAssignedServiceProviderListRequest()`.

Contains a table of Service Providers that have the Xsi Policy Profile assigned.  The
column headings are: "Organization ID", "Organization Name", "Organization Type".

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|svc_provider_table |List(svcProviderTable) |svcProviderTable - *Table* array of svcProviderTable named tuples |
</div>


## `ServiceProviderAccessDeviceCustomTagGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceCustomTagGetListRequest()`.

Contains a table of custom configuration tags managed by the Device Management System
on a per-device profile basis.  In AS data mode, the column headings are: "Tag Name",
"Tag Value", "Actual Tag Value". In XS data mode, the column headings are: "Tag Name",
"Tag Value", "Actual Tag Value" if request is invoked by an admin without system
privileges.  "Tag Name", "Tag Value", "Is Encrypted", "Actual Tag Value" if request is
invoked by an admin with system privileges.

**Attributes:**

|Name                     |Type                        |Description                                                                 |
|-------------------------|----------------------------|----------------------------------------------------------------------------|
|device_custom_tags_table |List(deviceCustomTagsTable) |deviceCustomTagsTable - *Table* array of deviceCustomTagsTable named tuples |
</div>


## `ServiceProviderAccessDeviceDeviceActivationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceDeviceActivationGetRequest()`.

The response contains the activation code (if available), the expiry time (if
available) and the activation state.  The expiryTime is represented as a timestamp,
i.e.  the number of milliseconds since January 1, 1970, 00:00:00 GMT.

**Attributes:**

|Name             |Type|Description               |
|-----------------|----|--------------------------|
|activation_code  |str |activationCode *Optional* |
|expiry_time      |int |expiryTime *Optional*     |
|activation_state |str |activationState           |
</div>


## `ServiceProviderAccessDeviceFileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceFileGetListRequest()`.

Contains a table of device files managed by the Device Management System on a per-
device profile basis.  The column headings are: "File Type", "File Format", "Is
Authenticated".

Replaced By: `ServiceProviderAccessDeviceFileGetListResponse14sp8()`

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|device_files_table |List(deviceFilesTable) |deviceFilesTable - *Table* array of deviceFilesTable named tuples |
</div>


## `ServiceProviderAccessDeviceFileGetListResponse14sp8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceFileGetListRequest14sp8()`.

Contains a table of device files managed by the Device Management System on a per-
device profile basis.  The column headings are: "File Format", "Is Authenticated",
"Access URL", "Repository URL", "Template URL", "Extended Capture URL", "Is File
Linked". The following column is only populated in AS data mode for leaf devices.  "Is
File Linked"

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|device_files_table |List(deviceFilesTable) |deviceFilesTable - *Table* array of deviceFilesTable named tuples |
</div>


## `ServiceProviderAccessDeviceFileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceFileGetRequest()`.

Replaced By: `ServiceProviderAccessDeviceFileGetResponse14sp8()`

**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|file_source             |str |fileSource                       |
|configuration_file_name |str |configurationFileName *Optional* |
</div>


## `ServiceProviderAccessDeviceFileGetResponse14sp8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceFileGetRequest14sp8()`.

Replaced by: `ServiceProviderAccessDeviceFileGetResponse16sp1()`

**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|file_source             |str |fileSource                       |
|configuration_file_name |str |configurationFileName *Optional* |
</div>


## `ServiceProviderAccessDeviceFileGetResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceFileGetRequest16sp1()`.

Replaced by: `ServiceProviderAccessDeviceFileGetResponse20()`

**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|file_source             |str |fileSource                       |
|configuration_file_name |str |configurationFileName *Optional* |
|access_url              |str |accessUrl                        |
|repository_url          |str |repositoryUrl *Optional*         |
|template_url            |str |templateUrl *Optional*           |
</div>


## `ServiceProviderAccessDeviceFileGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceFileGetRequest21()`.


**Attributes:**

|Name                     |Type |Description                       |
|-------------------------|-----|----------------------------------|
|file_source              |str  |fileSource                        |
|configuration_file_name  |str  |configurationFileName *Optional*  |
|access_url               |str  |accessUrl                         |
|repository_url           |str  |repositoryUrl *Optional*          |
|template_url             |str  |templateUrl *Optional*            |
|extended_capture_enabled |bool |extendedCaptureEnabled *Optional* |
|extended_capture_url     |str  |extendedCaptureURL *Optional*     |
|allow_upload_from_device |bool |allowUploadFromDevice *Optional*  |
</div>


## `ServiceProviderAccessDeviceGetAvailableCustomTagListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetAvailableCustomTagListRequest()`.

Contains a table of all available custom tags managed by the Device Management System
on a per-device profile basis.  In AS data mode, the column headings are: "Tag Name",
"Tag Value", "Tag Level", "Tag Set Name", "Region Name". In XS data mode: the column
headings are: "Tag Name", "Tag Value", "Tag Level", "Tag Set Name", "Is Encrypted" if
request is invoked by a System administrator or by an administrator with higher
priviledges, otherwise the column headings are: "Tag Name", "Tag Value", "Tag Level",
"Tag Source", "Tag Set Name". "Tag Level" can take the value: "System Default",
"System", "Service Provider", "Group" or "Device Profile".

**Attributes:**

|Name                               |Type                                 |Description                                                                                   |
|-----------------------------------|-------------------------------------|----------------------------------------------------------------------------------------------|
|device_available_custom_tags_table |List(deviceAvailableCustomTagsTable) |deviceAvailableCustomTagsTable - *Table* array of deviceAvailableCustomTagsTable named tuples |
</div>


## `ServiceProviderAccessDeviceGetEnhancedConfigurationTypeListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetEnhancedConfigurationTypeListRequest()`.


**Attributes:**

|Name        |Type      |Description           |
|------------|----------|----------------------|
|device_type |List[str] |deviceType *Optional* |
</div>


## `ServiceProviderAccessDeviceGetEnhancedConfigurationTypeResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetEnhancedConfigurationTypeRequest()`.


**Attributes:**

|Name                            |Type |Description                      |
|--------------------------------|-----|---------------------------------|
|supports_enhanced_configuration |bool |supportsEnhancedConfiguration    |
|supports_reset                  |bool |supportsReset                    |
|configuration_type              |str  |configurationType *Optional*     |
|configuration_file_name         |str  |configurationFileName *Optional* |
</div>


## `ServiceProviderAccessDeviceGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetListRequest()`.

Contains a table of devices configured in the service provider.  The column headings
are: "Device Name", "Device Type", "Available Ports", "Net Address", "MAC Address",
"Status", "Version", and "Access Device External Id". The following columns are only
populated in AS data mode: "Access Device External Id"

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|access_device_table |List(accessDeviceTable) |accessDeviceTable - *Table* array of accessDeviceTable named tuples |
</div>


## `ServiceProviderAccessDeviceGetNativeTagsWithLogicListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetNativeTagsWithLogicListRequest()`.

Contains a table of all native tags with logic managed by the Device Management System
on a per-device profile basis.  The column headings are: "Tag Name", "Tag Value".

**Attributes:**

|Name                                |Type                                 |Description                                                                                   |
|------------------------------------|-------------------------------------|----------------------------------------------------------------------------------------------|
|device_native_tags_with_logic_table |List(deviceNativeTagsWithLogicTable) |deviceNativeTagsWithLogicTable - *Table* array of deviceNativeTagsWithLogicTable named tuples |
</div>


## `ServiceProviderAccessDeviceGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetPagedSortedListRequest()`.

Contains a table of devices configured at service provider level.  The column headings
are: "Device Name", "Device Type", "Available Ports", "Net Address", "MAC Address",
"Status", "Version", and "Support Visual Device Management API". When CloudPBX is not
licensed, the column "Support Visual Device Management API" values are not returned.

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|access_device_table |List(accessDeviceTable) |accessDeviceTable - *Table* array of accessDeviceTable named tuples |
</div>


## `ServiceProviderAccessDeviceGetUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetUserListRequest()`.

The column headings for the deviceUserTable are: "Line/Port", "Last Name", "First
Name", "Phone Number", "Group Id", "User Id", "User Type", "Endpoint Type", "Primary
Line/Port", "Order", "Extension", "Department", "Email Address", "Private Identity".
In IMS mode, the table will contain a row for each TEL-URI in the Phone Number column.
In standalone mode, rows for the alternate numbers are not included.  The User Type
column contains one of the enumerated UserType values.  The Endpoint Type column
contains one of the enumerated EndpointType values.  The Private Identity column is
empty is AS mode.  Replaced by:
`ServiceProviderAccessDeviceGetUserListResponse21sp1()` in AS data mode.

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|device_user_table |List(deviceUserTable) |deviceUserTable - *Table* array of deviceUserTable named tuples |
</div>


## `ServiceProviderAccessDeviceGetUserListResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetUserListRequest21sp1()`.

The column headings for the deviceUserTable are: "Line/Port", "Last Name", "First
Name", "Phone Number", "Group Id", "User Id", "User Type", "Endpoint Type", "Primary
Line/Port", "Order", "Extension", "Department", "Email Address", "Private Identity".
In IMS mode, the table will contain a row for each TEL-URI in the Phone Number column.
In standalone mode, rows for the alternate numbers are not included.  The User Type
column contains one of the enumerated UserType values.  The Endpoint Type column
contains one of the enumerated EndpointType21sp1 values.  The value Mobility in
Endpoint Type column is only applicable in AS data mode.  The Private Identity column
is empty is AS mode.

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|device_user_table |List(deviceUserTable) |deviceUserTable - *Table* array of deviceUserTable named tuples |
</div>


## `ServiceProviderAccessDeviceTagSetGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceTagSetGetRequest()`.

The response includes a tag set name defined in the access device.

**Attributes:**

|Name         |Type|Description           |
|-------------|----|----------------------|
|tag_set_name |str |tagSetName *Optional* |
</div>


## `ServiceProviderAdminAlternateIdGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAdminAlternateIdGetListRequest()`.

Contains a table of the main admin user id and the alternate admin user ids, the
column headings are: "User Id", "Description", "Alternate". The possible values for
"Alternate" are "true" and "false". The "Description" is only present for alternate
admin user Ids.

**Attributes:**

|Name                |Type                   |Description                                                       |
|--------------------|-----------------------|------------------------------------------------------------------|
|admin_user_id_table |List(adminUserIdTable) |adminUserIdTable - *Table* array of adminUserIdTable named tuples |
</div>


## `ServiceProviderAdminGetListResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAdminGetListRequest14()`.

Contains a 7 column table with column headings "Administrator ID", "Last Name", "First
Name", "Administrator Type", "Language", "Locale" and "Encoding". The following
columns are only returned in AS data mode: "Locale" and "Encoding"

**Attributes:**

|Name                         |Type                            |Description                                                                         |
|-----------------------------|--------------------------------|------------------------------------------------------------------------------------|
|service_provider_admin_table |List(serviceProviderAdminTable) |serviceProviderAdminTable - *Table* array of serviceProviderAdminTable named tuples |
</div>


## `ServiceProviderAdminGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAdminGetPagedSortedListRequest()`.

Contains a 7 column table with column headings "Administrator ID", "Last Name", "First
Name", "Administrator Type", "Language", "Locale" and "Encoding". The following
columns are only returned in AS data mode: "Locale" and "Encoding".

**Attributes:**

|Name                         |Type                            |Description                                                                         |
|-----------------------------|--------------------------------|------------------------------------------------------------------------------------|
|service_provider_admin_table |List(serviceProviderAdminTable) |serviceProviderAdminTable - *Table* array of serviceProviderAdminTable named tuples |
</div>


## `ServiceProviderAdminGetPolicyResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAdminGetPolicyRequest14()`.

Contains the policy settings for the service provider administrator.  The
networkPolicyAccess is returned only for the enterprise administrator.

**Attributes:**

|Name                          |Type|Description                    |
|------------------------------|----|-------------------------------|
|profile_access                |str |profileAccess                  |
|group_access                  |str |groupAccess                    |
|user_access                   |str |userAccess                     |
|admin_access                  |str |adminAccess                    |
|department_access             |str |departmentAccess               |
|access_device_access          |str |accessDeviceAccess             |
|phone_number_extension_access |str |phoneNumberExtensionAccess     |
|service_access                |str |serviceAccess                  |
|service_pack_access           |str |servicePackAccess              |
|web_branding_access           |str |webBrandingAccess              |
|network_policy_access         |str |networkPolicyAccess *Optional* |
</div>


## `ServiceProviderAdminGetPolicyResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAdminGetPolicyRequest16sp1()`.

Contains the policy settings for the service provider administrator.  The
networkPolicyAccess is returned only for the enterprise administrator.  Replaced by:
`ServiceProviderAdminGetPolicyResponse17()`

**Attributes:**

|Name                             |Type|Description                    |
|---------------------------------|----|-------------------------------|
|profile_access                   |str |profileAccess                  |
|group_access                     |str |groupAccess                    |
|user_access                      |str |userAccess                     |
|admin_access                     |str |adminAccess                    |
|department_access                |str |departmentAccess               |
|access_device_access             |str |accessDeviceAccess             |
|phone_number_extension_access    |str |phoneNumberExtensionAccess     |
|service_access                   |str |serviceAccess                  |
|service_pack_access              |str |servicePackAccess              |
|session_admission_control_access |str |sessionAdmissionControlAccess  |
|web_branding_access              |str |webBrandingAccess              |
|network_policy_access            |str |networkPolicyAccess *Optional* |
</div>


## `ServiceProviderAdminGetPolicyResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAdminGetPolicyRequest16sp1()`.

Response to `ServiceProviderAdminGetPolicyRequest16sp2()`. Contains the policy
settings for the service provider administrator.  The networkPolicyAccess is returned
only for the enterprise administrator.

**Attributes:**

|Name                             |Type|Description                    |
|---------------------------------|----|-------------------------------|
|profile_access                   |str |profileAccess                  |
|group_access                     |str |groupAccess                    |
|user_access                      |str |userAccess                     |
|admin_access                     |str |adminAccess                    |
|department_access                |str |departmentAccess               |
|access_device_access             |str |accessDeviceAccess             |
|phone_number_extension_access    |str |phoneNumberExtensionAccess     |
|service_access                   |str |serviceAccess                  |
|service_pack_access              |str |servicePackAccess              |
|session_admission_control_access |str |sessionAdmissionControlAccess  |
|web_branding_access              |str |webBrandingAccess              |
|network_policy_access            |str |networkPolicyAccess *Optional* |
|dialable_caller_id_access        |str |dialableCallerIDAccess         |
</div>


## `ServiceProviderAdminGetPolicyResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAdminGetPolicyRequest17()`.

Contains the policy settings for the service provider administrator.  The
networkPolicyAccess is returned only for the enterprise administrator.

**Attributes:**

|Name                             |Type|Description                    |
|---------------------------------|----|-------------------------------|
|profile_access                   |str |profileAccess                  |
|group_access                     |str |groupAccess                    |
|user_access                      |str |userAccess                     |
|admin_access                     |str |adminAccess                    |
|department_access                |str |departmentAccess               |
|access_device_access             |str |accessDeviceAccess             |
|phone_number_extension_access    |str |phoneNumberExtensionAccess     |
|calling_line_id_number_access    |str |callingLineIdNumberAccess      |
|service_access                   |str |serviceAccess                  |
|service_pack_access              |str |servicePackAccess              |
|session_admission_control_access |str |sessionAdmissionControlAccess  |
|web_branding_access              |str |webBrandingAccess              |
|office_zone_access               |str |officeZoneAccess               |
|network_policy_access            |str |networkPolicyAccess *Optional* |
</div>


## `ServiceProviderAdminGetPolicyResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAdminGetPolicyRequest17sp1()`.

Contains the policy settings for the service provider administrator.  The
networkPolicyAccess is returned only for the enterprise administrator.  The following
elements are only used in XS data mode: communicationBarringAccess

**Attributes:**

|Name                             |Type|Description                    |
|---------------------------------|----|-------------------------------|
|profile_access                   |str |profileAccess                  |
|group_access                     |str |groupAccess                    |
|user_access                      |str |userAccess                     |
|admin_access                     |str |adminAccess                    |
|department_access                |str |departmentAccess               |
|access_device_access             |str |accessDeviceAccess             |
|phone_number_extension_access    |str |phoneNumberExtensionAccess     |
|calling_line_id_number_access    |str |callingLineIdNumberAccess      |
|service_access                   |str |serviceAccess                  |
|service_pack_access              |str |servicePackAccess              |
|session_admission_control_access |str |sessionAdmissionControlAccess  |
|web_branding_access              |str |webBrandingAccess              |
|office_zone_access               |str |officeZoneAccess               |
|communication_barring_access     |str |communicationBarringAccess     |
|network_policy_access            |str |networkPolicyAccess *Optional* |
</div>


## `ServiceProviderAdminGetPolicyResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAdminGetPolicyRequest17sp3()`.

Contains the policy settings for the service provider administrator.  The
networkPolicyAccess is returned only for the enterprise administrator.  The following
elements are only used in AS data mode: dialableCallerIDAccess The following elements
are only used in XS data mode: communicationBarringAccess

**Attributes:**

|Name                             |Type|Description                    |
|---------------------------------|----|-------------------------------|
|profile_access                   |str |profileAccess                  |
|group_access                     |str |groupAccess                    |
|user_access                      |str |userAccess                     |
|admin_access                     |str |adminAccess                    |
|department_access                |str |departmentAccess               |
|access_device_access             |str |accessDeviceAccess             |
|phone_number_extension_access    |str |phoneNumberExtensionAccess     |
|calling_line_id_number_access    |str |callingLineIdNumberAccess      |
|service_access                   |str |serviceAccess                  |
|service_pack_access              |str |servicePackAccess              |
|session_admission_control_access |str |sessionAdmissionControlAccess  |
|web_branding_access              |str |webBrandingAccess              |
|office_zone_access               |str |officeZoneAccess               |
|communication_barring_access     |str |communicationBarringAccess     |
|network_policy_access            |str |networkPolicyAccess *Optional* |
|dialable_caller_id_access        |str |dialableCallerIDAccess         |
</div>


## `ServiceProviderAdminGetPolicyResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAdminGetPolicyRequest18()`.

Contains the policy settings for the service provider administrator.  The
networkPolicyAccess and numberActivationAccess are returned only for the enterprise
administrator.  The following elements are only used in AS data mode:
dialableCallerIDAccess Replaced by: `ServiceProviderAdminGetPolicyResponse20()` in AS
data mode

**Attributes:**

|Name                             |Type|Description                       |
|---------------------------------|----|----------------------------------|
|profile_access                   |str |profileAccess                     |
|group_access                     |str |groupAccess                       |
|user_access                      |str |userAccess                        |
|admin_access                     |str |adminAccess                       |
|department_access                |str |departmentAccess                  |
|access_device_access             |str |accessDeviceAccess                |
|phone_number_extension_access    |str |phoneNumberExtensionAccess        |
|calling_line_id_number_access    |str |callingLineIdNumberAccess         |
|service_access                   |str |serviceAccess                     |
|service_pack_access              |str |servicePackAccess                 |
|session_admission_control_access |str |sessionAdmissionControlAccess     |
|web_branding_access              |str |webBrandingAccess                 |
|office_zone_access               |str |officeZoneAccess                  |
|communication_barring_access     |str |communicationBarringAccess        |
|network_policy_access            |str |networkPolicyAccess *Optional*    |
|number_activation_access         |str |numberActivationAccess *Optional* |
|dialable_caller_id_access        |str |dialableCallerIDAccess            |
</div>


## `ServiceProviderAdminGetPolicyResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAdminGetPolicyRequest20()`.

Contains the policy settings for the service provider administrator.  The
networkPolicyAccess and numberActivationAccess are returned only for the enterprise
administrator.  The following elements are only used in AS data mode:
dialableCallerIDAccess verifyTranslationAndRoutingAccess

**Attributes:**

|Name                                  |Type|Description                       |
|--------------------------------------|----|----------------------------------|
|profile_access                        |str |profileAccess                     |
|group_access                          |str |groupAccess                       |
|user_access                           |str |userAccess                        |
|admin_access                          |str |adminAccess                       |
|department_access                     |str |departmentAccess                  |
|access_device_access                  |str |accessDeviceAccess                |
|phone_number_extension_access         |str |phoneNumberExtensionAccess        |
|calling_line_id_number_access         |str |callingLineIdNumberAccess         |
|service_access                        |str |serviceAccess                     |
|service_pack_access                   |str |servicePackAccess                 |
|session_admission_control_access      |str |sessionAdmissionControlAccess     |
|web_branding_access                   |str |webBrandingAccess                 |
|office_zone_access                    |str |officeZoneAccess                  |
|communication_barring_access          |str |communicationBarringAccess        |
|network_policy_access                 |str |networkPolicyAccess *Optional*    |
|number_activation_access              |str |numberActivationAccess *Optional* |
|dialable_caller_id_access             |str |dialableCallerIDAccess            |
|verify_translation_and_routing_access |str |verifyTranslationAndRoutingAccess |
</div>


## `ServiceProviderAdminGetResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderAdminGetRequest14()`.

The response contains the service provider administrators profile information.
Replaced by `ServiceProviderAdminGetResponse21sp1()`.

**Attributes:**

|Name                |Type|Description          |
|--------------------|----|---------------------|
|service_provider_id |str |serviceProviderId    |
|first_name          |str |firstName *Optional* |
|last_name           |str |lastName *Optional*  |
|language            |str |language             |
|administrator_type  |str |administratorType    |
</div>


## `ServiceProviderAdminGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderAdminGetRequest21sp1()`.

The response contains the service provider administrators profile information.
Replaced by: `ServiceProviderAdminGetResponse22()`.

**Attributes:**

|Name                |Type|Description          |
|--------------------|----|---------------------|
|service_provider_id |str |serviceProviderId    |
|first_name          |str |firstName *Optional* |
|last_name           |str |lastName *Optional*  |
|language            |str |language             |
|administrator_type  |str |administratorType    |
|locale              |str |locale               |
|encoding            |str |encoding             |
</div>


## `ServiceProviderAdminGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderAdminGetRequest22()`.

The response contains the service provider administrators profile information.

**Attributes:**

|Name                |Type|Description          |
|--------------------|----|---------------------|
|service_provider_id |str |serviceProviderId    |
|first_name          |str |firstName *Optional* |
|last_name           |str |lastName *Optional*  |
|language            |str |language             |
|administrator_type  |str |administratorType    |
|locale              |str |locale               |
|encoding            |str |encoding             |
</div>


## `ServiceProviderAdministratorPasswordRulesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAdministratorPasswordRulesGetRequest()`.


**Attributes:**

|Name                                        |Type |Description                                       |
|--------------------------------------------|-----|--------------------------------------------------|
|use_external_authentication                 |bool |useExternalAuthentication *Optional*              |
|allow_web_add_external_authentication_users |bool |allowWebAddExternalAuthenticationUsers *Optional* |
|disallow_user_id                            |bool |disallowUserId *Optional*                         |
|disallow_old_password                       |bool |disallowOldPassword *Optional*                    |
|disallow_reversed_old_password              |bool |disallowReversedOldPassword *Optional*            |
|restrict_min_digits                         |bool |restrictMinDigits *Optional*                      |
|min_digits                                  |int  |minDigits *Optional*                              |
|restrict_min_upper_case_letters             |bool |restrictMinUpperCaseLetters *Optional*            |
|min_upper_case_letters                      |int  |minUpperCaseLetters *Optional*                    |
|restrict_min_lower_case_letters             |bool |restrictMinLowerCaseLetters *Optional*            |
|min_lower_case_letters                      |int  |minLowerCaseLetters *Optional*                    |
|restrict_min_non_alphanumeric_characters    |bool |restrictMinNonAlphanumericCharacters *Optional*   |
|min_non_alphanumeric_characters             |int  |minNonAlphanumericCharacters *Optional*           |
|min_length                                  |int  |minLength *Optional*                              |
|max_failed_login_attempts                   |int  |maxFailedLoginAttempts *Optional*                 |
|password_expires_days                       |int  |passwordExpiresDays *Optional*                    |
|send_login_disabled_notify_email            |bool |sendLoginDisabledNotifyEmail *Optional*           |
|login_disabled_notify_email_address         |str  |loginDisabledNotifyEmailAddress *Optional*        |
|disallow_previous_passwords                 |bool |disallowPreviousPasswords *Optional*              |
|number_of_previous_passwords                |int  |numberOfPreviousPasswords *Optional*              |
</div>


## `ServiceProviderAdviceOfChargeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAdviceOfChargeGetRequest()`.

Contains a list of Advice of Charge service provider parameters.

**Attributes:**

|Name                               |Type |Description                     |
|-----------------------------------|-----|--------------------------------|
|use_sp_level_ao_c_settings         |bool |useSPLevelAoCSettings           |
|delay_between_notification_seconds |int  |delayBetweenNotificationSeconds |
</div>


## `ServiceProviderAnswerConfirmationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderAnswerConfirmationGetRequest()`.

Replaced By: `ServiceProviderAnswerConfirmationGetResponse16()`

**Attributes:**

|Name                                        |Type|Description                                        |
|--------------------------------------------|----|---------------------------------------------------|
|announcement_message_selection              |str |announcementMessageSelection                       |
|confirmation_message_audio_file_description |str |confirmationMessageAudioFileDescription *Optional* |
|confirmation_timout_seconds                 |int |confirmationTimoutSeconds                          |
</div>


## `ServiceProviderAnswerConfirmationGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderAnswerConfirmationGetRequest16()`.


**Attributes:**

|Name                                        |Type|Description                                        |
|--------------------------------------------|----|---------------------------------------------------|
|announcement_message_selection              |str |announcementMessageSelection                       |
|confirmation_message_audio_file_description |str |confirmationMessageAudioFileDescription *Optional* |
|confirmation_message_media_type             |str |confirmationMessageMediaType *Optional*            |
|confirmation_timout_seconds                 |int |confirmationTimoutSeconds                          |
</div>


## `ServiceProviderApplicationServerSetGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderApplicationServerSetGetRequest()`.

The response contains the service provider or enterprise's Application Server set
information.

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|application_server_set_name |str |applicationServerSetName *Optional* |
</div>


## `ServiceProviderBroadWorksCommunicatorGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderBroadWorksCommunicatorGetRequest()`.


**Attributes:**

|Name                     |Type|Description                       |
|-------------------------|----|----------------------------------|
|configuration_server_url |str |configurationServerURL *Optional* |
</div>


## `ServiceProviderBroadWorksMobilityGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `ServiceProviderBroadWorksMobilityGetRequest()`.


**Attributes:**

|Name                         |Type |Description               |
|-----------------------------|-----|--------------------------|
|use_setting_level            |str  |useSettingLevel           |
|enable_location_services     |bool |enableLocationServices    |
|enable_msrn_lookup           |bool |enableMSRNLookup          |
|enable_mobile_state_checking |bool |enableMobileStateChecking |
|deny_call_originations       |bool |denyCallOriginations      |
|deny_call_terminations       |bool |denyCallTerminations      |
</div>


## `ServiceProviderBroadWorksMobilityGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `ServiceProviderBroadWorksMobilityGetRequest19sp1()`.

Replaced by: `ServiceProviderBroadWorksMobilityGetResponse22()` in AS data mode

**Attributes:**

|Name                            |Type |Description                   |
|--------------------------------|-----|------------------------------|
|use_setting_level               |str  |useSettingLevel               |
|enable_location_services        |bool |enableLocationServices        |
|enable_msrn_lookup              |bool |enableMSRNLookup              |
|enable_mobile_state_checking    |bool |enableMobileStateChecking     |
|deny_call_originations          |bool |denyCallOriginations          |
|deny_call_terminations          |bool |denyCallTerminations          |
|enable_announcement_suppression |bool |enableAnnouncementSuppression |
</div>


## `ServiceProviderBroadWorksMobilityGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `ServiceProviderBroadWorksMobilityGetRequest21sp1()`.

Replaced by `ServiceProviderBroadWorksMobilityGetResponse22V2()`.

**Attributes:**

|Name                                           |Type |Description                               |
|-----------------------------------------------|-----|------------------------------------------|
|use_setting_level                              |str  |useSettingLevel                           |
|enable_location_services                       |bool |enableLocationServices                    |
|enable_msrn_lookup                             |bool |enableMSRNLookup                          |
|enable_mobile_state_checking                   |bool |enableMobileStateChecking                 |
|deny_call_originations                         |bool |denyCallOriginations                      |
|deny_call_terminations                         |bool |denyCallTerminations                      |
|enable_announcement_suppression                |bool |enableAnnouncementSuppression             |
|enable_internal_clid_delivery_access_locations |bool |enableInternalCLIDDeliveryAccessLocations |
</div>


## `ServiceProviderBroadWorksMobilityGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `ServiceProviderBroadWorksMobilityGetRequest22()`.

Replaced by `ServiceProviderBroadWorksMobilityGetResponse22V2()`.

**Attributes:**

|Name                            |Type |Description                   |
|--------------------------------|-----|------------------------------|
|use_setting_level               |str  |useSettingLevel               |
|enable_location_services        |bool |enableLocationServices        |
|enable_msrn_lookup              |bool |enableMSRNLookup              |
|enable_mobile_state_checking    |bool |enableMobileStateChecking     |
|deny_call_originations          |bool |denyCallOriginations          |
|deny_call_terminations          |bool |denyCallTerminations          |
|enable_announcement_suppression |bool |enableAnnouncementSuppression |
|enable_internal_clid_delivery   |bool |enableInternalCLIDDelivery    |
</div>


## `ServiceProviderBroadWorksMobilityGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `ServiceProviderBroadWorksMobilityGetRequest22V2()`.

Replaced by `ServiceProviderBroadWorksMobilityGetResponse22V3()`.

**Attributes:**

|Name                                           |Type |Description                               |
|-----------------------------------------------|-----|------------------------------------------|
|use_setting_level                              |str  |useSettingLevel                           |
|enable_location_services                       |bool |enableLocationServices                    |
|enable_msrn_lookup                             |bool |enableMSRNLookup                          |
|enable_mobile_state_checking                   |bool |enableMobileStateChecking                 |
|deny_call_originations                         |bool |denyCallOriginations                      |
|deny_call_terminations                         |bool |denyCallTerminations                      |
|enable_announcement_suppression                |bool |enableAnnouncementSuppression             |
|enable_internal_clid_delivery                  |bool |enableInternalCLIDDelivery                |
|enable_internal_clid_delivery_access_locations |bool |enableInternalCLIDDeliveryAccessLocations |
|enable_enhanced_unreachable_state_checking     |bool |enableEnhancedUnreachableStateChecking    |
|enable_network_call_barring_status_check       |bool |enableNetworkCallBarringStatusCheck       |
</div>


## `ServiceProviderBroadWorksMobilityGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `ServiceProviderBroadWorksMobilityGetRequest22V3()`.


**Attributes:**

|Name                                           |Type |Description                               |
|-----------------------------------------------|-----|------------------------------------------|
|use_setting_level                              |str  |useSettingLevel                           |
|enable_location_services                       |bool |enableLocationServices                    |
|enable_msrn_lookup                             |bool |enableMSRNLookup                          |
|enable_mobile_state_checking                   |bool |enableMobileStateChecking                 |
|deny_call_originations                         |bool |denyCallOriginations                      |
|deny_call_terminations                         |bool |denyCallTerminations                      |
|enable_announcement_suppression                |bool |enableAnnouncementSuppression             |
|enable_internal_clid_delivery                  |bool |enableInternalCLIDDelivery                |
|enable_internal_clid_delivery_access_locations |bool |enableInternalCLIDDeliveryAccessLocations |
|enable_enhanced_unreachable_state_checking     |bool |enableEnhancedUnreachableStateChecking    |
|enable_network_call_barring_status_check       |bool |enableNetworkCallBarringStatusCheck       |
|network_translation_index                      |str  |networkTranslationIndex *Optional*        |
</div>


## `ServiceProviderBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`ServiceProviderBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListRequest()`.

Contains a list of available Mobile Subscriber Directory Numbers not yet assigned to
any group.

**Attributes:**

|Name                                         |Type      |Description                                         |
|---------------------------------------------|----------|----------------------------------------------------|
|available_mobile_subscriber_directory_number |List[str] |availableMobileSubscriberDirectoryNumber *Optional* |
</div>


## `ServiceProviderBroadWorksMobilityMobileSubscriberDirectoryNumberGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`ServiceProviderBroadWorksMobilityMobileSubscriberDirectoryNumberGetSummaryListRequest()`.

The column headings are "Phone Number", "Group Id" and "Mobile Network".

**Attributes:**

|Name                                              |Type                                               |Description                                                                                                               |
|--------------------------------------------------|---------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------|
|mobile_subscriber_directory_numbers_summary_table |List(mobileSubscriberDirectoryNumbersSummaryTable) |mobileSubscriberDirectoryNumbersSummaryTable - *Table* array of mobileSubscriberDirectoryNumbersSummaryTable named tuples |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest14()`.


**Attributes:**

|Name                                                 |Type |Description                                     |
|-----------------------------------------------------|-----|------------------------------------------------|
|use_max_simultaneous_calls                           |bool |useMaxSimultaneousCalls                         |
|max_simultaneous_calls                               |int  |maxSimultaneousCalls                            |
|use_max_simultaneous_video_calls                     |bool |useMaxSimultaneousVideoCalls                    |
|max_simultaneous_video_calls                         |int  |maxSimultaneousVideoCalls                       |
|use_max_call_time_for_answered_calls                 |bool |useMaxCallTimeForAnsweredCalls                  |
|max_call_time_for_answered_calls_minutes             |int  |maxCallTimeForAnsweredCallsMinutes              |
|use_max_call_time_for_unanswered_calls               |bool |useMaxCallTimeForUnansweredCalls                |
|max_call_time_for_unanswered_calls_minutes           |int  |maxCallTimeForUnansweredCallsMinutes            |
|media_policy_selection                               |str  |mediaPolicySelection                            |
|supported_media_set_name                             |str  |supportedMediaSetName *Optional*                |
|network_usage_selection                              |str  |networkUsageSelection                           |
|enforce_group_calling_line_identity_restriction      |bool |enforceGroupCallingLineIdentityRestriction      |
|enforce_enterprise_calling_line_identity_restriction |bool |enforceEnterpriseCallingLineIdentityRestriction |
|use_setting_level                                    |str  |useSettingLevel                                 |
|conference_uri                                       |str  |conferenceURI *Optional*                        |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse14sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest14sp1()`.


**Attributes:**

|Name                                                 |Type |Description                                     |
|-----------------------------------------------------|-----|------------------------------------------------|
|use_max_simultaneous_calls                           |bool |useMaxSimultaneousCalls                         |
|max_simultaneous_calls                               |int  |maxSimultaneousCalls                            |
|use_max_simultaneous_video_calls                     |bool |useMaxSimultaneousVideoCalls                    |
|max_simultaneous_video_calls                         |int  |maxSimultaneousVideoCalls                       |
|use_max_call_time_for_answered_calls                 |bool |useMaxCallTimeForAnsweredCalls                  |
|max_call_time_for_answered_calls_minutes             |int  |maxCallTimeForAnsweredCallsMinutes              |
|use_max_call_time_for_unanswered_calls               |bool |useMaxCallTimeForUnansweredCalls                |
|max_call_time_for_unanswered_calls_minutes           |int  |maxCallTimeForUnansweredCallsMinutes            |
|media_policy_selection                               |str  |mediaPolicySelection                            |
|supported_media_set_name                             |str  |supportedMediaSetName *Optional*                |
|network_usage_selection                              |str  |networkUsageSelection                           |
|enforce_group_calling_line_identity_restriction      |bool |enforceGroupCallingLineIdentityRestriction      |
|enforce_enterprise_calling_line_identity_restriction |bool |enforceEnterpriseCallingLineIdentityRestriction |
|use_setting_level                                    |str  |useSettingLevel                                 |
|conference_uri                                       |str  |conferenceURI *Optional*                        |
|use_max_concurrent_redirected_calls                  |bool |useMaxConcurrentRedirectedCalls                 |
|max_concurrent_redirected_calls                      |int  |maxConcurrentRedirectedCalls                    |
|use_max_find_me_follow_me_depth                      |bool |useMaxFindMeFollowMeDepth                       |
|max_find_me_follow_me_depth                          |int  |maxFindMeFollowMeDepth                          |
|max_redirection_depth                                |int  |maxRedirectionDepth                             |
|use_max_concurrent_find_me_follow_me_invocations     |bool |useMaxConcurrentFindMeFollowMeInvocations       |
|max_concurrent_find_me_follow_me_invocations         |int  |maxConcurrentFindMeFollowMeInvocations          |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest14sp4()`.

Replaced By : `ServiceProviderCallProcessingGetPolicyResponse15()`

**Attributes:**

|Name                                                                  |Type |Description                                                  |
|----------------------------------------------------------------------|-----|-------------------------------------------------------------|
|use_max_simultaneous_calls                                            |bool |useMaxSimultaneousCalls                                      |
|max_simultaneous_calls                                                |int  |maxSimultaneousCalls                                         |
|use_max_simultaneous_video_calls                                      |bool |useMaxSimultaneousVideoCalls                                 |
|max_simultaneous_video_calls                                          |int  |maxSimultaneousVideoCalls                                    |
|use_max_call_time_for_answered_calls                                  |bool |useMaxCallTimeForAnsweredCalls                               |
|max_call_time_for_answered_calls_minutes                              |int  |maxCallTimeForAnsweredCallsMinutes                           |
|use_max_call_time_for_unanswered_calls                                |bool |useMaxCallTimeForUnansweredCalls                             |
|max_call_time_for_unanswered_calls_minutes                            |int  |maxCallTimeForUnansweredCallsMinutes                         |
|media_policy_selection                                                |str  |mediaPolicySelection                                         |
|supported_media_set_name                                              |str  |supportedMediaSetName *Optional*                             |
|network_usage_selection                                               |str  |networkUsageSelection                                        |
|enforce_group_calling_line_identity_restriction                       |bool |enforceGroupCallingLineIdentityRestriction                   |
|allow_enterprise_group_call_typing_for_private_dialing_plan           |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan          |
|allow_enterprise_group_call_typing_for_public_dialing_plan            |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan           |
|override_clid_restriction_for_external_calls_via_private_dialing_plan |bool |overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan |
|enable_enterprise_extension_dialing                                   |bool |enableEnterpriseExtensionDialing                             |
|enforce_enterprise_calling_line_identity_restriction                  |bool |enforceEnterpriseCallingLineIdentityRestriction              |
|use_setting_level                                                     |str  |useSettingLevel                                              |
|conference_uri                                                        |str  |conferenceURI *Optional*                                     |
|use_max_concurrent_redirected_calls                                   |bool |useMaxConcurrentRedirectedCalls                              |
|max_concurrent_redirected_calls                                       |int  |maxConcurrentRedirectedCalls                                 |
|use_max_find_me_follow_me_depth                                       |bool |useMaxFindMeFollowMeDepth                                    |
|max_find_me_follow_me_depth                                           |int  |maxFindMeFollowMeDepth                                       |
|max_redirection_depth                                                 |int  |maxRedirectionDepth                                          |
|use_max_concurrent_find_me_follow_me_invocations                      |bool |useMaxConcurrentFindMeFollowMeInvocations                    |
|max_concurrent_find_me_follow_me_invocations                          |int  |maxConcurrentFindMeFollowMeInvocations                       |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse14sp7`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest14sp7()`.


**Attributes:**

|Name                                                                  |Type |Description                                                  |
|----------------------------------------------------------------------|-----|-------------------------------------------------------------|
|use_max_simultaneous_calls                                            |bool |useMaxSimultaneousCalls                                      |
|max_simultaneous_calls                                                |int  |maxSimultaneousCalls                                         |
|use_max_simultaneous_video_calls                                      |bool |useMaxSimultaneousVideoCalls                                 |
|max_simultaneous_video_calls                                          |int  |maxSimultaneousVideoCalls                                    |
|use_max_call_time_for_answered_calls                                  |bool |useMaxCallTimeForAnsweredCalls                               |
|max_call_time_for_answered_calls_minutes                              |int  |maxCallTimeForAnsweredCallsMinutes                           |
|use_max_call_time_for_unanswered_calls                                |bool |useMaxCallTimeForUnansweredCalls                             |
|max_call_time_for_unanswered_calls_minutes                            |int  |maxCallTimeForUnansweredCallsMinutes                         |
|media_policy_selection                                                |str  |mediaPolicySelection                                         |
|supported_media_set_name                                              |str  |supportedMediaSetName *Optional*                             |
|network_usage_selection                                               |str  |networkUsageSelection                                        |
|enforce_group_calling_line_identity_restriction                       |bool |enforceGroupCallingLineIdentityRestriction                   |
|allow_enterprise_group_call_typing_for_private_dialing_plan           |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan          |
|allow_enterprise_group_call_typing_for_public_dialing_plan            |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan           |
|override_clid_restriction_for_external_calls_via_private_dialing_plan |bool |overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan |
|enable_enterprise_extension_dialing                                   |bool |enableEnterpriseExtensionDialing                             |
|enforce_enterprise_calling_line_identity_restriction                  |bool |enforceEnterpriseCallingLineIdentityRestriction              |
|use_setting_level                                                     |str  |useSettingLevel                                              |
|conference_uri                                                        |str  |conferenceURI *Optional*                                     |
|use_max_concurrent_redirected_calls                                   |bool |useMaxConcurrentRedirectedCalls                              |
|max_concurrent_redirected_calls                                       |int  |maxConcurrentRedirectedCalls                                 |
|use_max_find_me_follow_me_depth                                       |bool |useMaxFindMeFollowMeDepth                                    |
|max_find_me_follow_me_depth                                           |int  |maxFindMeFollowMeDepth                                       |
|max_redirection_depth                                                 |int  |maxRedirectionDepth                                          |
|use_max_concurrent_find_me_follow_me_invocations                      |bool |useMaxConcurrentFindMeFollowMeInvocations                    |
|max_concurrent_find_me_follow_me_invocations                          |int  |maxConcurrentFindMeFollowMeInvocations                       |
|clid_policy                                                           |str  |clidPolicy                                                   |
|emergency_clid_policy                                                 |str  |emergencyClidPolicy                                          |
|allow_alternate_numbers_for_redirecting_identity                      |bool |allowAlternateNumbersForRedirectingIdentity                  |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse15`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest15()`.


**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|use_setting_level                                           |str  |useSettingLevel                                     |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse15sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest15sp2()`.


**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|use_setting_level                                           |str  |useSettingLevel                                     |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest16()`.


**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|use_setting_level                                           |str  |useSettingLevel                                     |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest16sp2()`.


**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_service_provider_dclid_setting                          |bool |useServiceProviderDCLIDSetting                      |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|use_setting_level                                           |str  |useSettingLevel                                     |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest17()`.


**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|use_setting_level                                           |str  |useSettingLevel                                     |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest17sp3()`.

The following elements are only used in AS data mode: useServiceProviderDCLIDSetting
enableDialableCallerID

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_service_provider_dclid_setting                          |bool |useServiceProviderDCLIDSetting                      |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|use_setting_level                                           |str  |useSettingLevel                                     |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest17sp4()`.

The following elements are only used in AS data mode: useServiceProviderDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity

Replaced By : `ServiceProviderCallProcessingGetPolicyResponse18sp1()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_service_provider_dclid_setting                          |bool |useServiceProviderDCLIDSetting                      |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|use_setting_level                                           |str  |useSettingLevel                                     |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse18sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest18sp1()`.

The following elements are only used in AS data mode : useServiceProviderDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
enterpriseCallsCLIDPolicy, value "Use Location Code plus Extension" is returned in XS
data mode.  groupCallsCLIDPolicy, value "Use Extension" is returned in XS data mode.
Replaced by: `ServiceProviderCallProcessingGetPolicyResponse19sp1()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_service_provider_dclid_setting                          |bool |useServiceProviderDCLIDSetting                      |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|use_setting_level                                           |str  |useSettingLevel                                     |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|group_calls_clid_policy                                     |str  |groupCallsCLIDPolicy                                |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest19sp1()`.

The following elements are only used in AS data mode : useServiceProviderDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
enterpriseCallsCLIDPolicy, value "Use Location Code plus Extension" is returned in XS
data mode.  groupCallsCLIDPolicy, value "Use Extension" is returned in XS data mode.
Replaced by: `ServiceProviderCallProcessingGetPolicyResponse21sp1()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_service_provider_dclid_setting                          |bool |useServiceProviderDCLIDSetting                      |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|use_setting_level                                           |str  |useSettingLevel                                     |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|group_calls_clid_policy                                     |str  |groupCallsCLIDPolicy                                |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest21sp1()`.

The following elements are only used in AS data mode : useServiceProviderDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
enterpriseCallsCLIDPolicy, value "Use Location Code plus Extension" is returned in XS
data mode.  groupCallsCLIDPolicy, value "Use Extension" is returned in XS data mode.
enablePhoneListLookup, value "false" is returned in XS data mode.  Replaced by:
`ServiceProviderCallProcessingGetPolicyResponse21sp2()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_service_provider_dclid_setting                          |bool |useServiceProviderDCLIDSetting                      |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|use_setting_level                                           |str  |useSettingLevel                                     |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|group_calls_clid_policy                                     |str  |groupCallsCLIDPolicy                                |
|enable_phone_list_lookup                                    |bool |enablePhoneListLookup                               |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse21sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest21sp2()`.

The following elements are only used in AS data mode: useServiceProviderDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
enterpriseCallsCLIDPolicy, value "Use Location Code plus Extension" is returned in XS
data mode.  groupCallsCLIDPolicy, value "Use Extension" is returned in XS data mode.
enablePhoneListLookup, value "false" is returned in XS data mode.  The following
elements are only used in XS data mode and not returned in AS data mode:
routeOverrideDomain routeOverridePrefix Replaced by:
`ServiceProviderCallProcessingGetPolicyResponse22()` in AS data mode

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_service_provider_dclid_setting                          |bool |useServiceProviderDCLIDSetting                      |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|use_setting_level                                           |str  |useSettingLevel                                     |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|group_calls_clid_policy                                     |str  |groupCallsCLIDPolicy                                |
|enable_phone_list_lookup                                    |bool |enablePhoneListLookup                               |
|route_override_domain                                       |str  |routeOverrideDomain *Optional*                      |
|route_override_prefix                                       |str  |routeOverridePrefix *Optional*                      |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest22()`.

The following elements are only used in AS data mode: useServiceProviderDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
enterpriseCallsCLIDPolicy, value "Use Location Code plus Extension" is returned in XS
data mode.  groupCallsCLIDPolicy, value "Use Extension" is returned in XS data mode.
enablePhoneListLookup, value "false" is returned in XS data mode.
useMaxConcurrentTerminatingAlertingRequests, value "false" is returned in XS data
mode.  maxConcurrentTerminatingAlertingRequests, value "10" is returned in XS data
mode.  includeRedirectionsInMaximumNumberOfConcurrentCalls, value "false" is returned
in XS data mode.  useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable, value
"false" is returned in XS data mode.
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable, value "false" is
returned in XS data mode.  The following elements are only used in XS data mode and
not returned in AS data mode: routeOverrideDomain routeOverridePrefix Replaced by:
`ServiceProviderCallProcessingGetPolicyResponse22V2()` in AS data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_service_provider_dclid_setting                                        |bool |useServiceProviderDCLIDSetting                                  |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|use_setting_level                                                         |str  |useSettingLevel                                                 |
|conference_uri                                                            |str  |conferenceURI *Optional*                                        |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|group_calls_clid_policy                                                   |str  |groupCallsCLIDPolicy                                            |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                  |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                  |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest22V2()`.

The following elements are only used in AS data mode: useServiceProviderDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
enterpriseCallsCLIDPolicy, value "Use Location Code plus Extension" is returned in XS
data mode.  groupCallsCLIDPolicy, value "Use Extension" is returned in XS data mode.
enablePhoneListLookup, value "false" is returned in XS data mode.
useMaxConcurrentTerminatingAlertingRequests, value "false" is returned in XS data
mode.  maxConcurrentTerminatingAlertingRequests, value "10" is returned in XS data
mode.  includeRedirectionsInMaximumNumberOfConcurrentCalls, value "false" is returned
in XS data mode.  useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable, value
"false" is returned in XS data mode.
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable, value "false" is
returned in XS data mode.  allowMobileDNForRedirectingIdentity, value "false" is
returned in XS data mode.  The following elements are only used in XS data mode and
not returned in AS data mode: routeOverrideDomain routeOverridePrefix Replaced by:
`ServiceProviderCallProcessingGetPolicyResponse22V3()` in AS data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_service_provider_dclid_setting                                        |bool |useServiceProviderDCLIDSetting                                  |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|use_setting_level                                                         |str  |useSettingLevel                                                 |
|conference_uri                                                            |str  |conferenceURI *Optional*                                        |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|group_calls_clid_policy                                                   |str  |groupCallsCLIDPolicy                                            |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                  |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                  |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity                             |
</div>


## `ServiceProviderCallProcessingGetPolicyResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCallProcessingGetPolicyRequest22V3()`.

The following elements are not returned for a service provider:
enableGatewayRoutePolicy networkCallsGatewayRouteIdentity
networkURLCallsGatewayRouteIdentity emergencyCallsGatewayRouteIdentity
repairCallsGatewayRouteIdentity callTypingErrorsGatewayRouteIdentity The following
elements are only used in AS data mode: useServiceProviderDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
enterpriseCallsCLIDPolicy, value "Use Location Code plus Extension" is returned in XS
data mode.  groupCallsCLIDPolicy, value "Use Extension" is returned in XS data mode.
enablePhoneListLookup, value "false" is returned in XS data mode.
useMaxConcurrentTerminatingAlertingRequests, value "false" is returned in XS data
mode.  maxConcurrentTerminatingAlertingRequests, value "10" is returned in XS data
mode.  includeRedirectionsInMaximumNumberOfConcurrentCalls, value "false" is returned
in XS data mode.  useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable, value
"false" is returned in XS data mode.
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable, value "false" is
returned in XS data mode.  allowMobileDNForRedirectingIdentity, value "false" is
returned in XS data mode.  The following elements are only used in AS data mode and
not returned in XS data mode: enableGatewayRoutePolicy
networkCallsGatewayRouteIdentity networkURLCallsGatewayRouteIdentity
emergencyCallsGatewayRouteIdentity repairCallsGatewayRouteIdentity
callTypingErrorsGatewayRouteIdentity The following elements are only used in XS data
mode and not returned in AS data mode: routeOverrideDomain routeOverridePrefix

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_service_provider_dclid_setting                                        |bool |useServiceProviderDCLIDSetting                                  |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|use_setting_level                                                         |str  |useSettingLevel                                                 |
|conference_uri                                                            |str  |conferenceURI *Optional*                                        |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|group_calls_clid_policy                                                   |str  |groupCallsCLIDPolicy                                            |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                  |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                  |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity                             |
|enable_gateway_route_policy                                               |bool |enableGatewayRoutePolicy *Optional*                             |
|network_calls_gateway_route_identity                                      |str  |networkCallsGatewayRouteIdentity *Optional*                     |
|network_url_calls_gateway_route_identity                                  |str  |networkURLCallsGatewayRouteIdentity *Optional*                  |
|emergency_calls_gateway_route_identity                                    |str  |emergencyCallsGatewayRouteIdentity *Optional*                   |
|repair_calls_gateway_route_identity                                       |str  |repairCallsGatewayRouteIdentity *Optional*                      |
|call_typing_errors_gateway_route_identity                                 |str  |callTypingErrorsGatewayRouteIdentity *Optional*                 |
</div>


## `ServiceProviderCommunicationBarringCriteriaGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCommunicationBarringCriteriaGetAssignedListRequest()`.

Contains a table of all Communication Barring Criteria assigned to the service
provider.  The column headings are: "Name" and "Description".

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|criteria_table |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `ServiceProviderCommunicationBarringDigitPatternCriteriaGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`ServiceProviderCommunicationBarringDigitPatternCriteriaGetListRequest()`.

The response contains a table of all Digit Pattern Criteria defined for the service
provider.  The column headings are "Name" and "Description"

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|criteria_table |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `ServiceProviderCommunicationBarringDigitPatternCriteriaGetPatternListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`ServiceProviderCommunicationBarringDigitPatternCriteriaGetPatternListRequest()`.

The response contains the Digit Pattern Criteria information.

**Attributes:**

|Name                |Type      |Description                  |
|--------------------|----------|-----------------------------|
|match_digit_pattern |List[str] |matchDigitPattern *Optional* |
</div>


## `ServiceProviderCommunicationBarringDigitPatternCriteriaGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderCommunicationBarringDigitPatternCriteriaGetRequest()`.

The response contains the Digit Pattern Criteria information.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|description |str |description *Optional* |
</div>


## `ServiceProviderCommunicationBarringIncomingCriteriaGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`ServiceProviderCommunicationBarringIncomingCriteriaGetAssignedListRequest()`.

Contains a table of all Communication Barring Incoming Criteria assigned to the
service provider.  The column headings are: "Name" and "Description".

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|criteria_table |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `ServiceProviderCommunicationBarringProfileGetAssignedGroupListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderCommunicationBarringProfileGetAssignedGroupListRequest()`.

Contains a table of groups that have the Communication Barring Profile assigned.  The
column headings are: "Group Id" and "Group Name".

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|group_table |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
</div>


## `ServiceProviderCommunicationBarringProfileGetCriteriaUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to ServiceProviderCommunicationBarring
`ProfileGetCriteriaUsageListRequest()`.

Contains a table of profiles that have the Communication Barring Criteria assigned.
The column headings are: "Name" and "Description".

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|profile_table |List(profileTable) |profileTable - *Table* array of profileTable named tuples |
</div>


## `ServiceProviderCommunicationBarringProfileGetDigitPatternCriteriaUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`ServiceProviderCommunicationBarringProfileGetDigitPatternCriteriaUsageListRequest()`.

The response contains a table of all Profiles that use the specific Digit Pattern
Criteria.  The column headings are "Name" and "Description"

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|profile_table |List(profileTable) |profileTable - *Table* array of profileTable named tuples |
</div>


## `ServiceProviderCommunicationBarringProfileGetIncomingCriteriaUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`ServiceProviderCommunicationBarringProfileGetIncomingCriteriaUsageListRequest()`.

Contains a table of profiles that have the Communication Barring Incoming Criteria
assigned.  The column headings are: "Name" and "Description".

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|profile_table |List(profileTable) |profileTable - *Table* array of profileTable named tuples |
</div>


## `ServiceProviderCommunicationBarringProfileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderCommunicationBarringProfileGetListRequest()`.

The response contains a table of all Communication Barring Profiles for the service
provider.  The column headings are "Default" , "Name" and "Description"

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|profile_table |List(profileTable) |profileTable - *Table* array of profileTable named tuples |
</div>


## `ServiceProviderDeviceActivationPolicyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDeviceActivationPolicyGetRequest()`.


**Attributes:**

|Name                                  |Type |Description                      |
|--------------------------------------|-----|---------------------------------|
|use_service_provider_settings         |bool |useServiceProviderSettings       |
|allow_activation_code_request_by_user |bool |allowActivationCodeRequestByUser |
|send_activation_code_in_email         |bool |sendActivationCodeInEmail        |
</div>


## `ServiceProviderDeviceManagementEventGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDeviceManagementEventGetListRequest()`.

Contains a table with column headings: "Event Id", "Status", "Action", "Level",
"Type", "Additional Info", "Is Local", "Completion %", "Pushed/ Same Hash/ Not
Pushed", "Login Id", "Start Time", "Process Time". "Event Id" is a unique identifer
for the event.  "Status" can be: Pending, Queued, In Progress, Process On Other Host,
Stale, Completed, Canceled.  "Action" can be: Delete, Download, Rebuild, Reset,
Upload.  "Level" can be: Device, Device Type, Device Type Group, Group, User.  "Type"
can be: Automatic, Manual.  "Additional Info" includes the affected device type,
device or group.  It depends on the level of the event: Device Profile: "Device Name"
"Service Provider Id" "Group Id" Device Type: "Device Type Name" Device Type Group:
"Service Provider Id" "Group Id" "Device Type Name" Group: "Service Provider Id"
"Group Id" User: "User Id" "Is Local" is set to "yes" if the event is processed on the
server who received the request, "no" otherwise meaning that the event is processed on
another server.  "Completion %" provides an estimate of the completion of the event.
A percentage is given, the current number of completed expanded event, and the total
number of expanded event.  "Pushed/ Same Hash/ Not Pushed" gives the total number of
files that were pushed, not pushed because of same hash, and not pushed when
processing the event.  "LoginId" is the user or admin id who triggered the event.
"Start Time" is the date when the event was started.  The display shows the month,
days, hours, and minutes (MM-dd hh:mm). "Process Time" is the time taken to process
the event in hours, minutes, seconds, and milliseconds (hhhh:mm:ss.SSS). Each row
represents an event sorted by priority of processing.  The first row in the table is
an event that has an associated expanded event currently being processed or next in
line to be processed.  Deprecated by:
`ServiceProviderDeviceManagementEventGetListResponse22()`.

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|event_table |List(eventTable) |eventTable - *Table* array of eventTable named tuples |
</div>


## `ServiceProviderDeviceManagementEventGetListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDeviceManagementEventGetListRequest22()`.

Contains a table with column headings: "Event Id", "Status", "Action", "Level",
"Type", "Additional Info", "Is Local", "Completion %", "Pushed/ Same Hash/ Not
Pushed", "Login Id", "Start Time", "Process Time", "Rx Time", "Total Time", "Request",
"Priority". "Event Id" is a unique identifer for the event.  "Status" can be: Pending,
Queued, In Progress, Process On Other Host, Stale, Completed, Canceled.  "Action" can
be: Delete, Download, Rebuild, Reset, Upload.  "Level" can be: Device, Device Type,
Device Type Group, Group, User.  "Type" can be: Automatic, Manual.  "Additional Info"
includes the affected device type, device or group.  It depends on the level of the
event: Device Profile: "Device Name" "Service Provider Id" "Group Id" Device Type:
"Device Type Name" Device Type Service Provider: "Service Provider Id" "Device Type
Name" Service Provider: "Service Provider Id" Device Type Group: "Service Provider Id"
"Group Id" "Device Type Name" Group: "Service Provider Id" "Group Id" User: "User Id"
"Is Local" is set to "yes" if the event is processed on the server who received the
request, "no" otherwise meaning that the event is processed on another server.
"Completion %" provides an estimate of the completion of the event.  A percentage is
given, the current number of completed expanded event, and the total number of
expanded event.  "Pushed/ Same Hash/ Not Pushed" gives the total number of files that
were pushed, not pushed because of same hash, and not pushed when processing the
event.  "LoginId" is the user or admin id who triggered the event.  "Start Time" is
the date when the event's processing started.  The display shows the month, day,
hours, minutes, and seconds (MM-dd hh:mm:ss). "Process Time" is the time taken to
process the event in hours, minutes, seconds, and milliseconds (hhhh:mm:ss.SSS). "Rx
Time" is the date when the event was received via OCI-P and stored in the system.  The
display shows the month, day, hours, minutes, and seconds (MM-dd hh:mm:ss). "Total
Time" is the total time the event was in the system, from the moment it was received
and stored until its processing ended, in hours, minutes, seconds, and milliseconds
(hhhh:mm:ss.SSS). "Request" is the name of the OCI-P request that triggered the event.
"Priority" is the priority of the event.

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|event_table |List(eventTable) |eventTable - *Table* array of eventTable named tuples |
</div>


## `ServiceProviderDeviceManagementGetAccessDeviceCountForDeviceTypeServiceProviderResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`ServiceProviderDeviceManagementGetAccessDeviceCountForDeviceTypeServiceProviderRequest()`.


**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|access_device_count |int |accessDeviceCount |
</div>


## `ServiceProviderDeviceProfileAuthenticationPasswordRulesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDeviceProfileAuthenticationPasswordRulesGetRequest()`.

Contains the device profile authentication password rules for the service provider.

**Attributes:**

|Name                                       |Type |Description                                   |
|-------------------------------------------|-----|----------------------------------------------|
|use_service_provider_settings              |bool |useServiceProviderSettings                    |
|disallow_authentication_name               |bool |disallowAuthenticationName                    |
|disallow_old_password                      |bool |disallowOldPassword                           |
|disallow_reversed_old_password             |bool |disallowReversedOldPassword                   |
|restrict_min_digits                        |bool |restrictMinDigits                             |
|min_digits                                 |int  |minDigits                                     |
|restrict_min_upper_case_letters            |bool |restrictMinUpperCaseLetters                   |
|min_upper_case_letters                     |int  |minUpperCaseLetters                           |
|restrict_min_lower_case_letters            |bool |restrictMinLowerCaseLetters                   |
|min_lower_case_letters                     |int  |minLowerCaseLetters                           |
|restrict_min_non_alphanumeric_characters   |bool |restrictMinNonAlphanumericCharacters          |
|min_non_alphanumeric_characters            |int  |minNonAlphanumericCharacters                  |
|min_length                                 |int  |minLength                                     |
|send_permanent_lockout_notification        |bool |sendPermanentLockoutNotification              |
|permanent_lockout_notify_email_address     |str  |permanentLockoutNotifyEmailAddress *Optional* |
|device_profile_authentication_lockout_type |str  |deviceProfileAuthenticationLockoutType        |
|device_profile_temporary_lockout_threshold |int  |deviceProfileTemporaryLockoutThreshold        |
|device_profile_wait_algorithm              |str  |deviceProfileWaitAlgorithm                    |
|device_profile_lockout_fixed_minutes       |str  |deviceProfileLockoutFixedMinutes              |
|device_profile_permanent_lockout_threshold |int  |deviceProfilePermanentLockoutThreshold        |
</div>


## `ServiceProviderDeviceTypeCustomTagGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDeviceTypeCustomTagGetListRequest()`.

Contains a table of custom configuration tags managed by the Device Management System
on a per-device type basis for a service provider.  In As data mode, the column
headings are: "Tag Name", "Tag Value". In XS data mode, the column headings are: "Tag
Name", "Tag Value" if request is invoked by an admin without system privileges.  "Tag
Name", "Tag Value", "Is Encrypted" if request is invoked by an admin with system
privileges.

**Attributes:**

|Name                                           |Type                                           |Description                                                                                                       |
|-----------------------------------------------|-----------------------------------------------|------------------------------------------------------------------------------------------------------------------|
|service_provider_device_type_custom_tags_table |List(serviceProviderDeviceTypeCustomTagsTable) |serviceProviderDeviceTypeCustomTagsTable - *Table* array of serviceProviderDeviceTypeCustomTagsTable named tuples |
</div>


## `ServiceProviderDeviceTypeFileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDeviceTypeFileGetListRequest()`.

Contains a table of device type files managed by the Device Management System, on a
per-service provider basis.  The column headings are: "File Format", "Is
Authenticated", "Access URL", "Repository URL", "Template URL".

**Attributes:**

|Name                                            |Type                                      |Description                                                                                             |
|------------------------------------------------|------------------------------------------|--------------------------------------------------------------------------------------------------------|
|service_provider_device_type_files_table        |List(serviceProviderDeviceTypeFilesTable) |serviceProviderDeviceTypeFilesTable - *Table* array of serviceProviderDeviceTypeFilesTable named tuples |
|service_provider_has_customizable_dynamic_files |bool                                      |serviceProviderHasCustomizableDynamicFiles                                                              |
</div>


## `ServiceProviderDeviceTypeFileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDeviceTypeFileGetRequest()`.


**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|file_source             |str |fileSource *Optional*            |
|configuration_file_name |str |configurationFileName *Optional* |
|access_url              |str |accessUrl                        |
|repository_url          |str |repositoryUrl *Optional*         |
|template_url            |str |templateUrl *Optional*           |
</div>


## `ServiceProviderDeviceTypeTagSetGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDeviceTypeGetRequest()`.


**Attributes:**

|Name         |Type|Description           |
|-------------|----|----------------------|
|tag_set_name |str |tagSetName *Optional* |
</div>


## `ServiceProviderDialPlanPolicyGetAccessCodeListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDialPlanPolicyGetAccessCodeListRequest()`.

Contains a table with column headings: "Access Code", "Enable Secondary Dial Tone",
"Description".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|access_code_table |List(accessCodeTable) |accessCodeTable - *Table* array of accessCodeTable named tuples |
</div>


## `ServiceProviderDialPlanPolicyGetAccessCodeResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDialPlanPolicyGetAccessCodeRequest()`

**Attributes:**

|Name                                              |Type |Description                                 |
|--------------------------------------------------|-----|--------------------------------------------|
|include_code_for_network_translations_and_routing |bool |includeCodeForNetworkTranslationsAndRouting |
|include_code_for_screening_services               |bool |includeCodeForScreeningServices             |
|enable_secondary_dial_tone                        |bool |enableSecondaryDialTone                     |
|description                                       |str  |description *Optional*                      |
</div>


## `ServiceProviderDialPlanPolicyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDialPlanPolicyGetRequest()` Replaced by:
`ServiceProviderDialPlanPolicyGetResponse17()`

**Attributes:**

|Name                                  |Type |Description                      |
|--------------------------------------|-----|---------------------------------|
|requires_access_code_for_public_calls |bool |requiresAccessCodeForPublicCalls |
|allow_e164_public_calls               |bool |allowE164PublicCalls             |
|public_digit_map                      |str  |publicDigitMap *Optional*        |
|private_digit_map                     |str  |privateDigitMap *Optional*       |
</div>


## `ServiceProviderDialPlanPolicyGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDialPlanPolicyGetRequest17()`

**Attributes:**

|Name                                            |Type |Description                               |
|------------------------------------------------|-----|------------------------------------------|
|requires_access_code_for_public_calls           |bool |requiresAccessCodeForPublicCalls          |
|allow_e164_public_calls                         |bool |allowE164PublicCalls                      |
|prefer_e164_number_format_for_callback_services |bool |preferE164NumberFormatForCallbackServices |
|public_digit_map                                |str  |publicDigitMap *Optional*                 |
|private_digit_map                               |str  |privateDigitMap *Optional*                |
</div>


## `ServiceProviderDialPlanPolicyGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDialPlanPolicyGetRequest22()` The following elements are
only used in AS data mode: overrideResolvedDeviceDigitMap The following elements are
only used in AS data mode and not returned in XS data mode: deviceDigitMap

**Attributes:**

|Name                                            |Type |Description                               |
|------------------------------------------------|-----|------------------------------------------|
|requires_access_code_for_public_calls           |bool |requiresAccessCodeForPublicCalls          |
|allow_e164_public_calls                         |bool |allowE164PublicCalls                      |
|prefer_e164_number_format_for_callback_services |bool |preferE164NumberFormatForCallbackServices |
|public_digit_map                                |str  |publicDigitMap *Optional*                 |
|private_digit_map                               |str  |privateDigitMap *Optional*                |
|override_resolved_device_digit_map              |bool |overrideResolvedDeviceDigitMap            |
|device_digit_map                                |str  |deviceDigitMap *Optional*                 |
</div>


## `ServiceProviderDialableCallerIDCriteriaGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderDialableCallerIDCriteriaGetRequest()`.

The response contains the Dialable Caller ID Criteria information.

**Attributes:**

|Name                           |Type      |Description                            |
|-------------------------------|----------|---------------------------------------|
|description                    |str       |description *Optional*                 |
|prefix_digits                  |str       |prefixDigits *Optional*                |
|match_call_type                |List[str] |matchCallType *Optional*               |
|match_alternate_call_indicator |List[str] |matchAlternateCallIndicator *Optional* |
|match_local_category           |bool      |matchLocalCategory                     |
|match_national_category        |bool      |matchNationalCategory                  |
|match_interlata_category       |bool      |matchInterlataCategory                 |
|match_intralata_category       |bool      |matchIntralataCategory                 |
|match_international_category   |bool      |matchInternationalCategory             |
|match_private_category         |bool      |matchPrivateCategory                   |
|match_emergency_category       |bool      |matchEmergencyCategory                 |
|match_other_category           |bool      |matchOtherCategory                     |
</div>


## `ServiceProviderDialableCallerIDGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderDialableCallerIDGetRequest()`.

The criteria table?s column headings are ?Active?, "Name", "Description", ?Prefix
Digits?, and ?Priority?.

**Attributes:**

|Name                          |Type                |Description                                                 |
|------------------------------|--------------------|------------------------------------------------------------|
|use_service_provider_criteria |bool                |useServiceProviderCriteria                                  |
|ns_screening_failure_policy   |str                 |nsScreeningFailurePolicy                                    |
|criteria_table                |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `ServiceProviderDigitCollectionGetResponse13mp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDigitCollectionGetRequest13mp4()`.


**Attributes:**

|Name              |Type|Description                |
|------------------|----|---------------------------|
|access_code       |str |accessCode *Optional*      |
|public_digit_map  |str |publicDigitMap *Optional*  |
|private_digit_map |str |privateDigitMap *Optional* |
</div>


## `ServiceProviderDnGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDnGetAvailableListRequest()`.

Contains a list of available DNs not yet assigned to any group.

**Attributes:**

|Name         |Type      |Description            |
|-------------|----------|-----------------------|
|available_dn |List[str] |availableDn *Optional* |
</div>


## `ServiceProviderDnGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDnGetSummaryListRequest()`.

The column headings are "Phone Numbers, "Group Id" and "Can Delete"

**Attributes:**

|Name             |Type                 |Description                                                   |
|-----------------|---------------------|--------------------------------------------------------------|
|dn_summary_table |List(dnSummaryTable) |dnSummaryTable - *Table* array of dnSummaryTable named tuples |
</div>


## `ServiceProviderDomainGetAssignedGroupListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDomainGetAssignedGroupListRequest()`.

Contains a table with column headings: "Group Id", "Group Name" and a row for each
group.

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|group_table |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
</div>


## `ServiceProviderDomainGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains a simple list of service provider domain names.

Replaced by `ServiceProviderDomainGetAssignedListResponse22()`

**Attributes:**

|Name                            |Type      |Description                  |
|--------------------------------|----------|-----------------------------|
|service_provider_default_domain |str       |serviceProviderDefaultDomain |
|domain                          |List[str] |domain *Optional*            |
</div>


## `ServiceProviderDomainGetAssignedListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains a simple list of service provider domain names.


**Attributes:**

|Name                            |Type      |Description                  |
|--------------------------------|----------|-----------------------------|
|service_provider_default_domain |str       |serviceProviderDefaultDomain |
|domain                          |List[str] |domain *Optional*            |
</div>


## `ServiceProviderEmergencyCallNotificationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderEmergencyCallNotificationGetRequest()`.


**Attributes:**

|Name                                   |Type |Description                                |
|---------------------------------------|-----|-------------------------------------------|
|send_emergency_call_notification_email |bool |sendEmergencyCallNotificationEmail         |
|emergency_call_notify_email_address    |str  |emergencyCallNotifyEmailAddress *Optional* |
|allow_group_override                   |bool |allowGroupOverride                         |
</div>


## `ServiceProviderEndpointGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderEndpointGetListRequest()`.

The column headings for the endpointTable are: "Group Id", "Line/Port", "Last Name",
"First Name", "User Id", "User Type", "Phone Number", "Extension", "Device Type",
"Device Name", "Net Address", "MAC Address", "Department", "Email Address". Possible
values for User Type are "User", "CCBasic", "CCStandard", "CCPremium", "RP", "MOH",
"MOHVideo".

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|endpoint_table |List(endpointTable) |endpointTable - *Table* array of endpointTable named tuples |
</div>


## `ServiceProviderEnhancedCallLogsGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderEnhancedCallLogsGetRequest()`.


**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|max_logged_calls     |int |maxLoggedCalls     |
|call_expiration_days |int |callExpirationDays |
</div>


## `ServiceProviderEnhancedCallLogsGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderEnhancedCallLogsGetRequest17sp4()`.


**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|max_logged_calls     |int |maxLoggedCalls     |
|call_expiration_days |int |callExpirationDays |
</div>


## `ServiceProviderEnhancedCallLogsSchemaInstanceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderEnhancedCallLogsSchemaInstanceGetRequest()`.


**Attributes:**

|Name |Type|Description     |
|-----|----|----------------|
|name |str |name *Optional* |
</div>


## `ServiceProviderExtensionLengthGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderExtensionLengthGetRequest()`.


**Attributes:**

|Name                          |Type|Description                           |
|------------------------------|----|--------------------------------------|
|default_extension_length      |int |defaultExtensionLength *Optional*     |
|location_routing_prefix_digit |int |locationRoutingPrefixDigit *Optional* |
|location_code_length          |int |locationCodeLength *Optional*         |
</div>


## `ServiceProviderExternalCustomRingbackGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderExternalCustomRingbackGetRequest()`.


**Attributes:**

|Name               |Type|Description                 |
|-------------------|----|----------------------------|
|prefix_digits      |str |prefixDigits *Optional*     |
|server_net_address |str |serverNetAddress *Optional* |
|server_port        |int |serverPort *Optional*       |
|timeout_seconds    |int |timeoutSeconds              |
</div>


## `ServiceProviderFileRepositoryDeviceUserGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderFileRepositoryDeviceUserGetListRequest()`.

Contains a table with column headings : "User Name","Allow Delete","Allow Get","Allow
Put" in a row for each file repository service provider user.

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|file_repository_user_table |List(fileRepositoryUserTable) |fileRepositoryUserTable - *Table* array of fileRepositoryUserTable named tuples |
</div>


## `ServiceProviderGetDefaultResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderGetDefaultRequest()`.

All values are default values for a service provider or enterprise's profile.  The
following elements are only used in AS and XS data mode and not returned in Amplify
data mode.  defaultDomain

**Attributes:**

|Name           |Type |Description              |
|---------------|-----|-------------------------|
|is_enterprise  |bool |isEnterprise             |
|default_domain |str  |defaultDomain *Optional* |
</div>


## `ServiceProviderGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderGetListRequest()`.

Contains a 3 column table with column headings "Service Provider Id", "Service
Provider Name", "Is Enterprise" and "Reseller Id" and a row for each service provider
or enterprise.  The following columns are only returned in AS data mode: "Reseller Id"

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|service_provider_table |List(serviceProviderTable) |serviceProviderTable - *Table* array of serviceProviderTable named tuples |
</div>


## `ServiceProviderGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderGetPagedSortedListRequest()`.

Contains a table with column headings "Service Provider Id", "Service Provider Name"
and "Is Enterprise", "Reseller Id" and "Service Provider External Id" and a row for
each service provider or enterprise.  The following columns are only populated in AS
data mode: "Reseller Id", "Service Provider External Id

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|service_provider_table |List(serviceProviderTable) |serviceProviderTable - *Table* array of serviceProviderTable named tuples |
</div>


## `ServiceProviderGroupPagingTargetsCapacityGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderGroupPagingTargetsCapacityGetRequest()`.

Replaced by: `ServiceProviderGroupPagingTargetsCapacityGetResponse22()` in AS data
mode.

**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|maximum_target_users |int |maximumTargetUsers |
</div>


## `ServiceProviderGroupPagingTargetsCapacityGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderGroupPagingTargetsCapacityGetRequest22()`.


**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|maximum_target_users |int |maximumTargetUsers |
</div>


## `ServiceProviderHPBXAlternateCarrierSelectionGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderHPBXAlternateCarrierSelectionGetRequest()`.


**Attributes:**

|Name                          |Type |Description                          |
|------------------------------|-----|-------------------------------------|
|process_cbc_carrier_selection |bool |processCbcCarrierSelection           |
|preselected_local_carrier     |str  |preselectedLocalCarrier *Optional*   |
|preselected_distant_carrier   |str  |preselectedDistantCarrier *Optional* |
</div>


## `ServiceProviderIMRNGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderIMRNGetListRequest()`.


**Attributes:**

|Name |Type      |Description     |
|-----|----------|----------------|
|imrn |List[str] |imrn *Optional* |
</div>


## `ServiceProviderInCallServiceActivationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderInCallServiceActivationGetRequest()`.

Replaced by: `ServiceProviderInCallServiceActivationGetResponse17()`

**Attributes:**

|Name              |Type|Description      |
|------------------|----|-----------------|
|activation_digits |str |activationDigits |
</div>


## `ServiceProviderInCallServiceActivationGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderInCallServiceActivationGetRequest17()`.


**Attributes:**

|Name                            |Type|Description                  |
|--------------------------------|----|-----------------------------|
|flash_activation_digits         |str |flashActivationDigits        |
|call_transfer_activation_digits |str |callTransferActivationDigits |
</div>


## `ServiceProviderIntegratedIMPGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderIntegratedIMPGetRequest()`.

The response contains the service provider Integrated IMP service attributes.
Replaced by: `ServiceProviderIntegratedIMPGetResponse21()` in AS data mode

**Attributes:**

|Name                      |Type |Description              |
|--------------------------|-----|-------------------------|
|use_system_service_domain |bool |useSystemServiceDomain   |
|service_domain            |str  |serviceDomain *Optional* |
</div>


## `ServiceProviderIntegratedIMPGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderIntegratedIMPGetRequest21()`.

The response contains the service provider Integrated IMP service attributes.  If the
service provider is within a reseller, useSystemServiceDomain means using reseller
level service domain setting.  And useSystemMessagingServer means using the reseller
level messaging server setting.  Replaced by:
`ServiceProviderIntegratedIMPGetResponse21sp1()` in AS data mode

**Attributes:**

|Name                        |Type |Description                   |
|----------------------------|-----|------------------------------|
|use_system_service_domain   |bool |useSystemServiceDomain        |
|service_domain              |str  |serviceDomain *Optional*      |
|service_port                |int  |servicePort *Optional*        |
|use_system_messaging_server |bool |useSystemMessagingServer      |
|provisioning_url            |str  |provisioningUrl *Optional*    |
|provisioning_user_id        |str  |provisioningUserId *Optional* |
|bosh_url                    |str  |boshURL *Optional*            |
</div>


## `ServiceProviderIntegratedIMPGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderIntegratedIMPGetRequest21sp1()`.

The response contains the service provider Integrated IMP service attributes.
Replaced by: `ServiceProviderIntegratedIMPGetResponse22()` in AS data mode

**Attributes:**

|Name                        |Type |Description                   |
|----------------------------|-----|------------------------------|
|use_system_service_domain   |bool |useSystemServiceDomain        |
|service_domain              |str  |serviceDomain *Optional*      |
|service_port                |int  |servicePort *Optional*        |
|use_system_messaging_server |bool |useSystemMessagingServer      |
|provisioning_url            |str  |provisioningUrl *Optional*    |
|provisioning_user_id        |str  |provisioningUserId *Optional* |
|bosh_url                    |str  |boshURL *Optional*            |
|default_imp_id_type         |str  |defaultImpIdType              |
</div>


## `ServiceProviderIntegratedIMPGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderIntegratedIMPGetRequest22()`.

The response contains the service provider Integrated IMP service attributes.  If the
service provider is within a reseller, useSystemServiceDomain means using reseller
level service domain setting.  And useSystemMessagingServer means using the reseller
level messaging server setting.  The element useResellerIMPIdSetting means using the
reseller level IMP User ID setting.

**Attributes:**

|Name                        |Type |Description                        |
|----------------------------|-----|-----------------------------------|
|use_system_service_domain   |bool |useSystemServiceDomain             |
|service_domain              |str  |serviceDomain *Optional*           |
|service_port                |int  |servicePort *Optional*             |
|use_system_messaging_server |bool |useSystemMessagingServer           |
|provisioning_url            |str  |provisioningUrl *Optional*         |
|provisioning_user_id        |str  |provisioningUserId *Optional*      |
|bosh_url                    |str  |boshURL *Optional*                 |
|default_imp_id_type         |str  |defaultImpIdType *Optional*        |
|use_reseller_imp_id_setting |bool |useResellerIMPIdSetting *Optional* |
</div>


## `ServiceProviderLanguageGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderLanguageGetAvailableListRequest()`.

The language table column headings are: "Language", "Locale" and "Encoding".

**Attributes:**

|Name             |Type                |Description                                                 |
|-----------------|--------------------|------------------------------------------------------------|
|default_language |str                 |defaultLanguage                                             |
|language_table   |List(languageTable) |languageTable - *Table* array of languageTable named tuples |
</div>


## `ServiceProviderLanguageGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderLanguageGetListRequest()`.


**Attributes:**

|Name             |Type      |Description                |
|-----------------|----------|---------------------------|
|language         |List[str] |language *Optional*        |
|default_language |str       |defaultLanguage *Optional* |
</div>


## `ServiceProviderMWIDeliveryToMobileEndpointGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderMWIDeliveryToMobileEndpointGetRequest()`.

The templateActivationTable contains the list of templates defined for the service
provider.  The column headings are "Enable", "Language", "Type".

**Attributes:**

|Name                      |Type                          |Description                                                                     |
|--------------------------|------------------------------|--------------------------------------------------------------------------------|
|template_activation_table |List(templateActivationTable) |templateActivationTable - *Table* array of templateActivationTable named tuples |
</div>


## `ServiceProviderMaliciousCallTraceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderMaliciousCallTraceGetRequest()`.

The response contains the service provider Malicious Call Trace settings.

**Attributes:**

|Name                                     |Type |Description                         |
|-----------------------------------------|-----|------------------------------------|
|use_system_play_mct_warning_announcement |bool |useSystemPlayMCTWarningAnnouncement |
|play_mct_warning_announcement            |bool |playMCTWarningAnnouncement          |
</div>


## `ServiceProviderNetworkClassOfServiceGetAssignedGroupListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderNetworkClassOfServiceGetAssignedGroupListRequest()`.

Contains a table of groups that have the Network Class of Service assigned.  The
column headings are: "Group Id" and "Group Name".

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|group_table |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
</div>


## `ServiceProviderNetworkClassOfServiceGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderNetworkClassOfServiceGetAssignedListRequest()`.

Contains a table of all Network Classes of Service assigned to the service provider.
The column headings are: "Name", "Description" and "Default".

**Attributes:**

|Name                           |Type                             |Description                                                                           |
|-------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|network_class_of_service_table |List(networkClassOfServiceTable) |networkClassOfServiceTable - *Table* array of networkClassOfServiceTable named tuples |
</div>


## `ServiceProviderNumberPortabilityQueryGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderNumberPortabilityQueryGetRequest()`.

The response contains the service provider number portability query information.

**Attributes:**

|Name                                                   |Type      |Description                                     |
|-------------------------------------------------------|----------|------------------------------------------------|
|enable_number_portability_query_for_outgoing_calls     |bool      |enableNumberPortabilityQueryForOutgoingCalls    |
|enable_number_portability_query_for_incoming_calls     |bool      |enableNumberPortabilityQueryForIncomingCalls    |
|enable_number_portability_query_for_network_calls_only |bool      |enableNumberPortabilityQueryForNetworkCallsOnly |
|digit_pattern                                          |List[str] |digitPattern *Optional*                         |
</div>


## `ServiceProviderOfficeZoneGetAssignedGroupListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderOfficeZoneGetAssignedGroupListRequest()`.

Contains a table of groups that have the Office Zone assigned.  The column headings
are: "Group Id" and "Group Name".

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|group_table |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
</div>


## `ServiceProviderOfficeZoneGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderOfficeZoneGetAssignedListRequest()`.

Contains a table of all Office Zones assigned to the service provider.  The column
headings are: "Name", "Description" and "Default".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|office_zone_table |List(officeZoneTable) |officeZoneTable - *Table* array of officeZoneTable named tuples |
</div>


## `ServiceProviderPasswordRulesGetResponse13mp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderPasswordRulesGetRequest13mp2()`.

Contains the group, department administrator and/or user password rules setting.

Replaced By: `ServiceProviderPasswordRulesGetResponse16()`

**Attributes:**

|Name                                        |Type |Description                                |
|--------------------------------------------|-----|-------------------------------------------|
|service_provider_id                         |str  |serviceProviderId                          |
|rules_apply_to                              |str  |rulesApplyTo                               |
|allow_web_add_external_authentication_users |bool |allowWebAddExternalAuthenticationUsers     |
|disallow_user_id                            |bool |disallowUserId                             |
|disallow_old_password                       |bool |disallowOldPassword                        |
|disallow_reversed_old_password              |bool |disallowReversedOldPassword                |
|restrict_min_digits                         |bool |restrictMinDigits                          |
|min_digits                                  |int  |minDigits                                  |
|restrict_min_upper_case_letters             |bool |restrictMinUpperCaseLetters                |
|min_upper_case_letters                      |int  |minUpperCaseLetters                        |
|restrict_min_lower_case_letters             |bool |restrictMinLowerCaseLetters                |
|min_lower_case_letters                      |int  |minLowerCaseLetters                        |
|restrict_min_non_alphanumeric_characters    |bool |restrictMinNonAlphanumericCharacters       |
|min_non_alphanumeric_characters             |int  |minNonAlphanumericCharacters               |
|min_length                                  |int  |minLength                                  |
|max_failed_login_attempts                   |int  |maxFailedLoginAttempts                     |
|password_expires_days                       |int  |passwordExpiresDays                        |
|send_login_disabled_notify_email            |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address         |str  |loginDisabledNotifyEmailAddress *Optional* |
|disallow_rules_modification                 |bool |disallowRulesModification                  |
</div>


## `ServiceProviderPasswordRulesGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderPasswordRulesGetRequest16()`.

Contains the group, department administrator and/or user password rules setting.
Replaced by: `ServiceProviderPasswordRulesGetResponse22()` in AS data mode.

**Attributes:**

|Name                                        |Type |Description                                |
|--------------------------------------------|-----|-------------------------------------------|
|rules_apply_to                              |str  |rulesApplyTo                               |
|allow_web_add_external_authentication_users |bool |allowWebAddExternalAuthenticationUsers     |
|disallow_user_id                            |bool |disallowUserId                             |
|disallow_old_password                       |bool |disallowOldPassword                        |
|disallow_reversed_old_password              |bool |disallowReversedOldPassword                |
|restrict_min_digits                         |bool |restrictMinDigits                          |
|min_digits                                  |int  |minDigits                                  |
|restrict_min_upper_case_letters             |bool |restrictMinUpperCaseLetters                |
|min_upper_case_letters                      |int  |minUpperCaseLetters                        |
|restrict_min_lower_case_letters             |bool |restrictMinLowerCaseLetters                |
|min_lower_case_letters                      |int  |minLowerCaseLetters                        |
|restrict_min_non_alphanumeric_characters    |bool |restrictMinNonAlphanumericCharacters       |
|min_non_alphanumeric_characters             |int  |minNonAlphanumericCharacters               |
|min_length                                  |int  |minLength                                  |
|max_failed_login_attempts                   |int  |maxFailedLoginAttempts                     |
|password_expires_days                       |int  |passwordExpiresDays                        |
|send_login_disabled_notify_email            |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address         |str  |loginDisabledNotifyEmailAddress *Optional* |
|disallow_rules_modification                 |bool |disallowRulesModification                  |
|disallow_previous_passwords                 |bool |disallowPreviousPasswords                  |
|number_of_previous_passwords                |int  |numberOfPreviousPasswords                  |
</div>


## `ServiceProviderPasswordRulesGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderPasswordRulesGetRequest22()`.

Contains the group, department administrator and/or user password rules setting.

**Attributes:**

|Name                                        |Type |Description                                |
|--------------------------------------------|-----|-------------------------------------------|
|rules_apply_to                              |str  |rulesApplyTo                               |
|allow_web_add_external_authentication_users |bool |allowWebAddExternalAuthenticationUsers     |
|disallow_user_id                            |bool |disallowUserId                             |
|disallow_old_password                       |bool |disallowOldPassword                        |
|disallow_reversed_old_password              |bool |disallowReversedOldPassword                |
|restrict_min_digits                         |bool |restrictMinDigits                          |
|min_digits                                  |int  |minDigits                                  |
|restrict_min_upper_case_letters             |bool |restrictMinUpperCaseLetters                |
|min_upper_case_letters                      |int  |minUpperCaseLetters                        |
|restrict_min_lower_case_letters             |bool |restrictMinLowerCaseLetters                |
|min_lower_case_letters                      |int  |minLowerCaseLetters                        |
|restrict_min_non_alphanumeric_characters    |bool |restrictMinNonAlphanumericCharacters       |
|min_non_alphanumeric_characters             |int  |minNonAlphanumericCharacters               |
|min_length                                  |int  |minLength                                  |
|max_failed_login_attempts                   |int  |maxFailedLoginAttempts                     |
|password_expires_days                       |int  |passwordExpiresDays                        |
|send_login_disabled_notify_email            |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address         |str  |loginDisabledNotifyEmailAddress *Optional* |
|disallow_rules_modification                 |bool |disallowRulesModification                  |
|disallow_previous_passwords                 |bool |disallowPreviousPasswords                  |
|number_of_previous_passwords                |int  |numberOfPreviousPasswords                  |
|force_password_change_after_reset           |bool |forcePasswordChangeAfterReset              |
</div>


## `ServiceProviderPortalPasscodeRulesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderPortalPasscodeRulesGetRequest()`.

Contains the service provider's passcode rules setting.

**Attributes:**

|Name                                          |Type |Description                                |
|----------------------------------------------|-----|-------------------------------------------|
|disallow_repeated_digits                      |bool |disallowRepeatedDigits                     |
|disallow_user_number                          |bool |disallowUserNumber                         |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber                 |
|disallow_old_passcode                         |bool |disallowOldPasscode                        |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode                |
|min_code_length                               |int  |minCodeLength                              |
|max_code_length                               |int  |maxCodeLength                              |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts    |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*          |
|expire_password                               |bool |expirePassword                             |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*             |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional* |
</div>


## `ServiceProviderPortalPasscodeRulesGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderPortalPasscodeRulesGetRequest19()`.

Contains the service provider's passcode rules setting.  The following elements are
only used in AS data mode: numberOfRepeatedDigits disallowRepeatedPatterns
disallowContiguousSequences numberOfAscendingDigits numberOfDescendingDigits
numberOfPreviousPasscodes Replaced by:
`ServiceProviderPortalPasscodeRulesGetResponse22()` in AS data mode.

**Attributes:**

|Name                                          |Type |Description                                |
|----------------------------------------------|-----|-------------------------------------------|
|disallow_repeated_digits                      |bool |disallowRepeatedDigits                     |
|number_of_repeated_digits                     |int  |numberOfRepeatedDigits                     |
|disallow_repeated_patterns                    |bool |disallowRepeatedPatterns                   |
|disallow_contiguous_sequences                 |bool |disallowContiguousSequences                |
|number_of_ascending_digits                    |int  |numberOfAscendingDigits                    |
|number_of_descending_digits                   |int  |numberOfDescendingDigits                   |
|disallow_user_number                          |bool |disallowUserNumber                         |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber                 |
|disallow_old_passcode                         |bool |disallowOldPasscode                        |
|number_of_previous_passcodes                  |int  |numberOfPreviousPasscodes                  |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode                |
|min_code_length                               |int  |minCodeLength                              |
|max_code_length                               |int  |maxCodeLength                              |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts    |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*          |
|expire_password                               |bool |expirePassword                             |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*             |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional* |
</div>


## `ServiceProviderPortalPasscodeRulesGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderPortalPasscodeRulesGetRequest22()`.

Contains the service provider's passcode rules setting.  The following elements are
only used in AS data mode: numberOfRepeatedDigits disallowRepeatedPatterns
disallowContiguousSequences numberOfAscendingDigits numberOfDescendingDigits
numberOfPreviousPasscodes enableDefaultPasscode defaultPasscode

**Attributes:**

|Name                                          |Type |Description                                |
|----------------------------------------------|-----|-------------------------------------------|
|disallow_repeated_digits                      |bool |disallowRepeatedDigits                     |
|number_of_repeated_digits                     |int  |numberOfRepeatedDigits                     |
|disallow_repeated_patterns                    |bool |disallowRepeatedPatterns                   |
|disallow_contiguous_sequences                 |bool |disallowContiguousSequences                |
|number_of_ascending_digits                    |int  |numberOfAscendingDigits                    |
|number_of_descending_digits                   |int  |numberOfDescendingDigits                   |
|disallow_user_number                          |bool |disallowUserNumber                         |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber                 |
|disallow_old_passcode                         |bool |disallowOldPasscode                        |
|number_of_previous_passcodes                  |int  |numberOfPreviousPasscodes                  |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode                |
|min_code_length                               |int  |minCodeLength                              |
|max_code_length                               |int  |maxCodeLength                              |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts    |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*          |
|expire_password                               |bool |expirePassword                             |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*             |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional* |
|enable_default_passcode                       |bool |enableDefaultPasscode                      |
|default_passcode                              |str  |defaultPasscode *Optional*                 |
</div>


## `ServiceProviderPreferredCarrierGetAvailableCountryCodeListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `ServiceProviderPreferredCarrierGetAvailableCountryCodeListRequest()`.

Contains the default country code and the list of unused country codes for a service
provider / enterprise.

**Attributes:**

|Name                 |Type      |Description                   |
|---------------------|----------|------------------------------|
|default_country_code |str       |defaultCountryCode *Optional* |
|country_code         |List[str] |countryCode *Optional*        |
</div>


## `ServiceProviderPreferredCarrierGetCarrierListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `ServiceProviderPreferredCarrierGetCarrierListRequest()`.

Contains the lists of carriers for a specified country code for a service provider /
enterprise.

**Attributes:**

|Name                  |Type      |Description                     |
|----------------------|----------|--------------------------------|
|intra_lata_carrier    |List[str] |intraLataCarrier *Optional*     |
|inter_lata_carrier    |List[str] |interLataCarrier *Optional*     |
|international_carrier |List[str] |internationalCarrier *Optional* |
</div>


## `ServiceProviderPreferredCarrierGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `ServiceProviderPreferredCarrierGetListRequest()`.

Contains a table with one row per carrier.  The table columns are: "Country Code",
"Intra-Lata PIC", "Inter-Lata PIC", "International PIC".

**Attributes:**

|Name                           |Type                              |Description                                                                             |
|-------------------------------|----------------------------------|----------------------------------------------------------------------------------------|
|service_provider_carrier_table |List(serviceProviderCarrierTable) |serviceProviderCarrierTable - *Table* array of serviceProviderCarrierTable named tuples |
</div>


## `ServiceProviderPreferredCarrierGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `ServiceProviderPreferredCarrierGetRequest()`.

Contains the currently configured carriers for a specified country code for a service
provider / enterprise.

**Attributes:**

|Name                  |Type|Description                     |
|----------------------|----|--------------------------------|
|intra_lata_carrier    |str |intraLataCarrier *Optional*     |
|inter_lata_carrier    |str |interLataCarrier *Optional*     |
|international_carrier |str |internationalCarrier *Optional* |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberPrefixGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`ServiceProviderRouteListEnterpriseTrunkNumberPrefixGetAvailableListRequest()`.

Contains a list of available number prefixes not yet assigned to any group.  The
column headings are "Number Prefix"","Is Active", “Extension Range Start” and
“Extension Range End”.

**Attributes:**

|Name                          |Type                             |Description                                                                           |
|------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|available_number_prefix_table |List(availableNumberPrefixTable) |availableNumberPrefixTable - *Table* array of availableNumberPrefixTable named tuples |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberPrefixGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderRouteListEnterpriseTrunkPrefixGetSummaryListRequest()`.

The column headings are "Number Prefix", "Group Id" ","Is Active", “Extension Range
Start” and “Extension Range End”.

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|prefix_summary_table |List(prefixSummaryTable) |prefixSummaryTable - *Table* array of prefixSummaryTable named tuples |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberRangeGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`ServiceProviderRouteListEnterpriseTrunkNumberRangeGetAvailableListRequest()`.

Contains a list of available number ranges not yet assigned to any group.  The column
headings are "Number Range Start", "Number Range End","Is Active" and "Extension
Length".

**Attributes:**

|Name                         |Type                            |Description                                                                         |
|-----------------------------|--------------------------------|------------------------------------------------------------------------------------|
|available_number_range_table |List(availableNumberRangeTable) |availableNumberRangeTable - *Table* array of availableNumberRangeTable named tuples |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberRangeGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`ServiceProviderRouteListEnterpriseTrunkNumberRangeGetSummaryListRequest()`.

The column headings are "Number Range Start", "Number Range End", "Group Id", "Is
Active" and "Extension Length".

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|number_range_summary_table |List(numberRangeSummaryTable) |numberRangeSummaryTable - *Table* array of numberRangeSummaryTable named tuples |
</div>


## `ServiceProviderRoutePointExternalSystemGetAssignedGroupListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderRoutePointExternalSystemGetAssignedGroupListRequest()`.

Contains a table with column headings: "Group Id", "Group Name" and a row for each
group.

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|group_table |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
</div>


## `ServiceProviderRoutePointExternalSystemGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderRoutePointExternalSystemGetAssignedListRequest()`.

Contains a table of all Route Point External Systems assigned to the service provider.
The column headings are: "Name" and "Description".

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|external_system_table |List(externalSystemTable) |externalSystemTable - *Table* array of externalSystemTable named tuples |
</div>


## `ServiceProviderRoutingProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderRoutingProfileGetRequest()`.


**Attributes:**

|Name            |Type|Description               |
|----------------|----|--------------------------|
|routing_profile |str |routingProfile *Optional* |
</div>


## `ServiceProviderSIPAuthenticationPasswordRulesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderSIPAuthenticationPasswordRulesGetRequest()`.

Contains the SIP authentication password rules for the service provider.

**Attributes:**

|Name                                     |Type |Description                                   |
|-----------------------------------------|-----|----------------------------------------------|
|use_service_provider_settings            |bool |useServiceProviderSettings                    |
|disallow_authentication_name             |bool |disallowAuthenticationName                    |
|disallow_old_password                    |bool |disallowOldPassword                           |
|disallow_reversed_old_password           |bool |disallowReversedOldPassword                   |
|restrict_min_digits                      |bool |restrictMinDigits                             |
|min_digits                               |int  |minDigits                                     |
|restrict_min_upper_case_letters          |bool |restrictMinUpperCaseLetters                   |
|min_upper_case_letters                   |int  |minUpperCaseLetters                           |
|restrict_min_lower_case_letters          |bool |restrictMinLowerCaseLetters                   |
|min_lower_case_letters                   |int  |minLowerCaseLetters                           |
|restrict_min_non_alphanumeric_characters |bool |restrictMinNonAlphanumericCharacters          |
|min_non_alphanumeric_characters          |int  |minNonAlphanumericCharacters                  |
|min_length                               |int  |minLength                                     |
|send_permanent_lockout_notification      |bool |sendPermanentLockoutNotification              |
|permanent_lockout_notify_email_address   |str  |permanentLockoutNotifyEmailAddress *Optional* |
|endpoint_authentication_lockout_type     |str  |endpointAuthenticationLockoutType             |
|endpoint_temporary_lockout_threshold     |int  |endpointTemporaryLockoutThreshold             |
|endpoint_wait_algorithm                  |str  |endpointWaitAlgorithm                         |
|endpoint_lockout_fixed_minutes           |str  |endpointLockoutFixedMinutes                   |
|endpoint_permanent_lockout_threshold     |int  |endpointPermanentLockoutThreshold             |
|trunk_group_temporary_lockout_threshold  |int  |trunkGroupTemporaryLockoutThreshold           |
|trunk_group_authentication_lockout_type  |str  |trunkGroupAuthenticationLockoutType           |
|trunk_group_wait_algorithm               |str  |trunkGroupWaitAlgorithm                       |
|trunk_group_lockout_fixed_minutes        |str  |trunkGroupLockoutFixedMinutes                 |
|trunk_group_permanent_lockout_threshold  |int  |trunkGroupPermanentLockoutThreshold           |
</div>


## `ServiceProviderScheduleGetEventListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderScheduleGetEventListRequest()`.

The response contains a list of events.

**Attributes:**

|Name       |Type      |Description          |
|-----------|----------|---------------------|
|event_name |List[str] |eventName *Optional* |
</div>


## `ServiceProviderServiceGetAuthorizationListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderServiceGetAuthorizationListRequest()`.

Contains two tables, one for the group services and one for the user services.  The
Group Service table has column headings: "Service Name", "Authorized", "Assigned",
"Limited", "Quantity", "Allocated", "Licensed", "Service Pack Allocation" The User
Service table has column headings: "Service Name", "Authorized", "Assigned",
"Limited", "Quantity", "Allocated", "Licensed", "Service Pack Allocation", "User
Assignable", "Service Pack Assignable".

**Attributes:**

|Name                               |Type                                  |Description                                                                                     |
|-----------------------------------|--------------------------------------|------------------------------------------------------------------------------------------------|
|group_services_authorization_table |List(groupServicesAuthorizationTable) |groupServicesAuthorizationTable - *Table* array of groupServicesAuthorizationTable named tuples |
|user_services_authorization_table  |List(userServicesAuthorizationTable)  |userServicesAuthorizationTable - *Table* array of userServicesAuthorizationTable named tuples   |
</div>


## `ServiceProviderServiceGetUserAssignableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderServiceGetUserAssignableListRequest()`.


**Attributes:**

|Name         |Type      |Description            |
|-------------|----------|-----------------------|
|service_name |List[str] |serviceName *Optional* |
</div>


## `ServiceProviderServicePackGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderServicePackGetListRequest()`.


**Attributes:**

|Name              |Type      |Description                |
|------------------|----------|---------------------------|
|service_pack_name |List[str] |servicePackName *Optional* |
</div>


## `ServiceProviderServicePackGetServiceUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderServicePackGetServiceUsageListRequest()`.

The column headings are "Service Pack Name", "Total Packs" and "Allocated to Groups"

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|service_usage_table |List(serviceUsageTable) |serviceUsageTable - *Table* array of serviceUsageTable named tuples |
</div>


## `ServiceProviderServicePackGetUtilizationListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderServicePackGetUtilizationListRequest()`.

For each service pack, a table of groups utilizing the pack is returned.  The
utilization table column headings are "Group", "Total Packs" and "Assigned".

**Attributes:**

|Name                      |Type                          |Description                                                                                |
|--------------------------|------------------------------|-------------------------------------------------------------------------------------------|
|service_pack_name         |List[str]                     |servicePackName *Optional*                                                                 |
|service_utilization_table |List(serviceUtilizationTable) |serviceUtilizationTable - *Table* array of serviceUtilizationTable named tuples *Optional* |
</div>


## `ServiceProviderServicePackMigrationTaskGetAvailableGroupListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderServicePackMigrationTaskGetAvailableGroupListRequest()`.

The groupTable column headings are: "Group Id", "Group Name", "User Count".

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|group_table |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
</div>


## `ServiceProviderServicePackMigrationTaskGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderServicePackMigrationTaskGetListRequest()`.

Contains a table with a row for each service pack migration task and column headings :
"Start Timestamp Milliseconds", "Name", "Status", "Error Count", "Users Processed",
"Users Total". The start timestamp column is the number of milliseconds since the
standard base time known as "the epoch", namely January 1, 1970, 00:00:00 GMT.

Replaced By : `ServiceProviderServicePackMigrationTaskGetListResponse21()` in AS data
mode

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|task_table |List(taskTable) |taskTable - *Table* array of taskTable named tuples |
</div>


## `ServiceProviderServicePackMigrationTaskGetListResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderServicePackMigrationTaskGetListRequest21()`.

Contains a table with a row for each service pack migration task and column headings :
"Start Timestamp Milliseconds", "Name", "Status", "Error Count", "Users Processed",
"Users Total". The start timestamp column is the number of milliseconds since the
standard base time known as "the epoch", namely January 1, 1970, 00:00:00 GMT. The
status column is the task status which can be Awaiting edit, Pending, Processing,
Terminating, Terminated, Stopped by system, Completed, or Expired.

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|task_table |List(taskTable) |taskTable - *Table* array of taskTable named tuples |
</div>


## `ServiceProviderServicePackMigrationTaskGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderServicePackMigrationTaskGetRequest()`.

The groupTable column headings are: "Migrate", "Group Id", "Group Name", "User Count".

Replaced By: `ServiceProviderServicePackMigrationTaskGetResponse14sp4()`

**Attributes:**

|Name                                     |Type             |Description                                           |
|-----------------------------------------|-----------------|------------------------------------------------------|
|task_name                                |str              |taskName                                              |
|start_timestamp                          |str              |startTimestamp *Optional*                             |
|max_duration_hours                       |int              |maxDurationHours                                      |
|send_report_email                        |bool             |sendReportEmail                                       |
|report_delivery_email_address            |str              |reportDeliveryEmailAddress *Optional*                 |
|abort_on_error                           |bool             |abortOnError                                          |
|abort_error_threshold                    |int              |abortErrorThreshold *Optional*                        |
|report_all_users                         |bool             |reportAllUsers                                        |
|automatically_increment_service_quantity |bool             |automaticallyIncrementServiceQuantity                 |
|error_count                              |int              |errorCount                                            |
|status                                   |str              |status                                                |
|groups_processed                         |int              |groupsProcessed                                       |
|groups_total                             |int              |groupsTotal                                           |
|users_processed                          |int              |usersProcessed                                        |
|users_total                              |int              |usersTotal                                            |
|user_selection_type                      |str              |userSelectionType                                     |
|report_file_path_name                    |str              |reportFilePathName                                    |
|group_table                              |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
|user_selection_service_pack_name         |List[str]        |userSelectionServicePackName *Optional*               |
|user_selection_service_name              |List[str]        |userSelectionServiceName *Optional*                   |
|remove_service_pack_name                 |List[str]        |removeServicePackName *Optional*                      |
|remove_service_name                      |List[str]        |removeServiceName *Optional*                          |
|assign_service_pack_name                 |List[str]        |assignServicePackName *Optional*                      |
|assign_service_name                      |List[str]        |assignServiceName *Optional*                          |
</div>


## `ServiceProviderServicePackMigrationTaskGetResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderServicePackMigrationTaskGetRequest14sp4()`.

The groupTable column headings are: "Group Id", "Group Name", "User Count".

Replaced By: `ServiceProviderServicePackMigrationTaskGetResponse21()` in AS data mode

**Attributes:**

|Name                                     |Type             |Description                                                      |
|-----------------------------------------|-----------------|-----------------------------------------------------------------|
|task_name                                |str              |taskName                                                         |
|start_timestamp                          |str              |startTimestamp *Optional*                                        |
|max_duration_hours                       |int              |maxDurationHours                                                 |
|send_report_email                        |bool             |sendReportEmail                                                  |
|report_delivery_email_address            |str              |reportDeliveryEmailAddress *Optional*                            |
|abort_on_error                           |bool             |abortOnError                                                     |
|abort_error_threshold                    |int              |abortErrorThreshold *Optional*                                   |
|report_all_users                         |bool             |reportAllUsers                                                   |
|automatically_increment_service_quantity |bool             |automaticallyIncrementServiceQuantity                            |
|error_count                              |int              |errorCount                                                       |
|status                                   |str              |status                                                           |
|groups_processed                         |int              |groupsProcessed                                                  |
|groups_total                             |int              |groupsTotal                                                      |
|users_processed                          |int              |usersProcessed                                                   |
|users_total                              |int              |usersTotal                                                       |
|user_selection_type                      |str              |userSelectionType                                                |
|report_file_path_name                    |str              |reportFilePathName                                               |
|migrate_all_groups                       |bool             |migrateAllGroups *Optional*                                      |
|group_table                              |List(groupTable) |groupTable - *Table* array of groupTable named tuples *Optional* |
|user_selection_service_pack_name         |List[str]        |userSelectionServicePackName *Optional*                          |
|user_selection_service_name              |List[str]        |userSelectionServiceName *Optional*                              |
|remove_service_pack_name                 |List[str]        |removeServicePackName *Optional*                                 |
|remove_service_name                      |List[str]        |removeServiceName *Optional*                                     |
|assign_service_pack_name                 |List[str]        |assignServicePackName *Optional*                                 |
|assign_service_name                      |List[str]        |assignServiceName *Optional*                                     |
</div>


## `ServiceProviderServicePackMigrationTaskGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderServicePackMigrationTaskGetRequest21()`.

The groupTable column headings are: "Group Id", "Group Name", and "User Count".

**Attributes:**

|Name                                     |Type             |Description                                                      |
|-----------------------------------------|-----------------|-----------------------------------------------------------------|
|task_name                                |str              |taskName                                                         |
|start_timestamp                          |str              |startTimestamp *Optional*                                        |
|actual_start_timestamp                   |str              |actualStartTimestamp *Optional*                                  |
|expire_after_num_hours                   |int              |expireAfterNumHours                                              |
|max_duration_hours                       |int              |maxDurationHours                                                 |
|send_report_email                        |bool             |sendReportEmail                                                  |
|report_delivery_email_address            |str              |reportDeliveryEmailAddress *Optional*                            |
|abort_on_error                           |bool             |abortOnError                                                     |
|abort_error_threshold                    |int              |abortErrorThreshold *Optional*                                   |
|report_all_users                         |bool             |reportAllUsers                                                   |
|automatically_increment_service_quantity |bool             |automaticallyIncrementServiceQuantity                            |
|error_count                              |int              |errorCount                                                       |
|status                                   |str              |status                                                           |
|groups_processed                         |int              |groupsProcessed                                                  |
|groups_total                             |int              |groupsTotal                                                      |
|users_processed                          |int              |usersProcessed                                                   |
|users_total                              |int              |usersTotal                                                       |
|user_selection_type                      |str              |userSelectionType                                                |
|report_file_path_name                    |str              |reportFilePathName                                               |
|migrate_all_groups                       |bool             |migrateAllGroups *Optional*                                      |
|group_table                              |List(groupTable) |groupTable - *Table* array of groupTable named tuples *Optional* |
|user_selection_service_pack_name         |List[str]        |userSelectionServicePackName *Optional*                          |
|user_selection_service_name              |List[str]        |userSelectionServiceName *Optional*                              |
|remove_service_pack_name                 |List[str]        |removeServicePackName *Optional*                                 |
|remove_service_name                      |List[str]        |removeServiceName *Optional*                                     |
|assign_service_pack_name                 |List[str]        |assignServicePackName *Optional*                                 |
|assign_service_name                      |List[str]        |assignServiceName *Optional*                                     |
</div>


## `ServiceProviderServicePhoneNumberLookupResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderServicePhoneNumberLookupRequest()`.

The column headings for the userTable are: "Group Id", "User Id", "Last Name", "First
Name", "Hiragana Last Name", "Hiragana First Name", "Phone Number", "Extension" and
"Department".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `ServiceProviderSessionAdmissionControlGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderSessionAdmissionControlGetRequest()`.

The response contains the session admission control capacity allocated for the service
provider.

**Attributes:**

|Name                                  |Type |Description                           |
|--------------------------------------|-----|--------------------------------------|
|restrict_aggregate_sessions           |bool |restrictAggregateSessions             |
|max_sessions                          |int  |maxSessions *Optional*                |
|max_user_originating_sessions         |int  |maxUserOriginatingSessions *Optional* |
|max_user_terminating_sessions         |int  |maxUserTerminatingSessions *Optional* |
|count_intra_service_provider_sessions |bool |countIntraServiceProviderSessions     |
</div>


## `ServiceProviderSessionAdmissionControlWhiteListGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderSessionAdmissionControlWhiteListGetRequest()`.

The response contains the White List information.

**Attributes:**

|Name                |Type      |Description                  |
|--------------------|----------|-----------------------------|
|match_digit_pattern |List[str] |matchDigitPattern *Optional* |
|enable_white_list   |bool      |enableWhiteList              |
</div>


## `ServiceProviderStirShakenGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderStirShakenGetRequest()`.


**Attributes:**

|Name                                                   |Type |Description                                      |
|-------------------------------------------------------|-----|-------------------------------------------------|
|use_parent_level_settings                              |bool |useParentLevelSettings                           |
|signing_policy                                         |str  |signingPolicy                                    |
|tagging_policy                                         |str  |taggingPolicy                                    |
|signing_service_url                                    |str  |signingServiceURL *Optional*                     |
|tag_from_or_pai                                        |str  |tagFromOrPAI                                     |
|verstat_tag                                            |str  |verstatTag                                       |
|use_os_value_for_orig_id                               |bool |useOSValueForOrigId                              |
|orig_uuid                                              |str  |origUUID *Optional*                              |
|attestation_level                                      |str  |attestationLevel                                 |
|enable_verification                                    |bool |enableVerification                               |
|verification_service_url                               |str  |verificationServiceURL *Optional*                |
|verification_error_handling                            |str  |verificationErrorHandling                        |
|proxy_verstat_to_cnam_subscribe                        |bool |proxyVerstatToCNAMSubscribe                      |
|use_unknown_headers_from_cnam_notify                   |bool |useUnknownHeadersFromCNAMNotify                  |
|enable_signing_for_unscreened_trunk_group_originations |bool |enableSigningForUnscreenedTrunkGroupOriginations |
|enable_tagging_for_unscreened_trunk_group_originations |bool |enableTaggingForUnscreenedTrunkGroupOriginations |
|unscreened_trunk_group_origination_attestation_level   |str  |unscreenedTrunkGroupOriginationAttestationLevel  |
</div>


## `ServiceProviderTemplateOnlyDeviceFileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderTemplateOnlyDeviceFileGetListRequest()`.

Contains a list of template files used to support a Visual Device Management device.

**Attributes:**

|Name              |Type      |Description                |
|------------------|----------|---------------------------|
|template_file_url |List[str] |templateFileUrl *Optional* |
</div>


## `ServiceProviderThirdPartyEmergencyCallingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderThirdPartyEmergencyCallingGetRequest()`.

The response contains the third-party emergency call service settings for the service
provider.

**Attributes:**

|Name              |Type |Description           |
|------------------|-----|----------------------|
|allow_activation  |bool |allowActivation       |
|customer_id       |str  |customerId *Optional* |
|has_group_enabled |bool |hasGroupEnabled       |
</div>


## `ServiceProviderVoiceMessagingGroupGetPasscodeRulesResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderVoiceMessagingGroupGetPasscodeRulesRequest()`.

Contains the service provider's voice portal passcode rules setting.

Replaced By: `ServiceProviderPortalPasscodeRulesGetResponse()`

**Attributes:**

|Name                                          |Type |Description                                |
|----------------------------------------------|-----|-------------------------------------------|
|disallow_repeated_digits                      |bool |disallowRepeatedDigits                     |
|disallow_user_number                          |bool |disallowUserNumber                         |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber                 |
|disallow_old_passcode                         |bool |disallowOldPasscode                        |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode                |
|min_code_length                               |int  |minCodeLength                              |
|max_code_length                               |int  |maxCodeLength                              |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts    |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*          |
|expire_password                               |bool |expirePassword                             |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*             |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional* |
</div>


## `ServiceProviderVoiceMessagingGroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderVoiceMessagingGroupGetRequest()`.

Contains the service provider's or enterprise's voice messaging settings.

**Attributes:**

|Name                                                 |Type |Description                                   |
|-----------------------------------------------------|-----|----------------------------------------------|
|delivery_from_address                                |str  |deliveryFromAddress *Optional*                |
|notification_from_address                            |str  |notificationFromAddress *Optional*            |
|voice_portal_lockout_from_address                    |str  |voicePortalLockoutFromAddress *Optional*      |
|use_system_default_delivery_from_address             |bool |useSystemDefaultDeliveryFromAddress           |
|use_system_default_notification_from_address         |bool |useSystemDefaultNotificationFromAddress       |
|use_system_default_voice_portal_lockout_from_address |bool |useSystemDefaultVoicePortalLockoutFromAddress |
</div>


## `ServiceProviderVoiceMessagingGroupGetVoicePortalBrandingResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderVoiceMessagingGroupGetVoicePortalBrandingRequest()`.

Replaced By: `ServiceProviderVoiceMessagingGroupGetVoicePortalBrandingResponse16()`

**Attributes:**

|Name                                      |Type|Description                                      |
|------------------------------------------|----|-------------------------------------------------|
|voice_portal_greeting_selection           |str |voicePortalGreetingSelection                     |
|voice_portal_greeting_file_description    |str |voicePortalGreetingFileDescription *Optional*    |
|voice_messaging_greeting_selection        |str |voiceMessagingGreetingSelection                  |
|voice_messaging_greeting_file_description |str |voiceMessagingGreetingFileDescription *Optional* |
</div>


## `ServiceProviderVoiceMessagingGroupGetVoicePortalBrandingResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderVoiceMessagingGroupGetVoicePortalBrandingRequest16()`.


**Attributes:**

|Name                                      |Type|Description                                      |
|------------------------------------------|----|-------------------------------------------------|
|voice_portal_greeting_selection           |str |voicePortalGreetingSelection                     |
|voice_portal_greeting_file_description    |str |voicePortalGreetingFileDescription *Optional*    |
|voice_portal_greeting_media_file_type     |str |voicePortalGreetingMediaFileType *Optional*      |
|voice_messaging_greeting_selection        |str |voiceMessagingGreetingSelection                  |
|voice_messaging_greeting_file_description |str |voiceMessagingGreetingFileDescription *Optional* |
|voice_messaging_greeting_media_file_type  |str |voiceMessagingGreetingMediaFileType *Optional*   |
</div>


## `ServiceProviderVoiceMessagingGroupGetVoicePortalResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderVoiceMessagingGroupGetVoicePortalRequest()`.


**Attributes:**

|Name               |Type|Description      |
|-------------------|----|-----------------|
|voice_portal_scope |str |voicePortalScope |
</div>


## `ServiceProviderXsiPolicyProfileGetAssignedGroupListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderXsiPolicyProfileGetAssignedGroupListRequest()`.

Contains a table of group that have the group Xsi Policy Profile assigned.  The column
headings are: "Group Id", "Group Name".

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|group_table |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
</div>


## `ServiceProviderXsiPolicyProfileGetAssignedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderXsiPolicyProfileGetAssignedListRequest()`.

Contains a table of all Xsi Policy Profile assigned to.  The column headings are:
"Name", "Level", "Description" and "Default".

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|assigned_table |List(assignedTable) |assignedTable - *Table* array of assignedTable named tuples |
</div>


## `ServiceProviderZoneCallingRestrictionsGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderZoneCallingRestrictionsGetRequest()`

**Attributes:**

|Name                                              |Type |Description                                   |
|--------------------------------------------------|-----|----------------------------------------------|
|enable_zone_calling_restrictions                  |bool |enableZoneCallingRestrictions                 |
|enable_origination_roaming_restrictions           |bool |enableOriginationRoamingRestrictions          |
|enable_emergency_origination_roaming_restrictions |bool |enableEmergencyOriginationRoamingRestrictions |
|enable_termination_roaming_restrictions           |bool |enableTerminationRoamingRestrictions          |
</div>


## `SystemASRParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemASRParametersGetRequest()`.

Contains a list of system Application Server Registration parameters.

Replaced By: `SystemASRParametersGetResponse14sp5()`

**Attributes:**

|Name                               |Type|Description                     |
|-----------------------------------|----|--------------------------------|
|max_transmissions                  |int |maxTransmissions                |
|retransmission_delay_milli_seconds |int |retransmissionDelayMilliSeconds |
|listening_port                     |int |listeningPort                   |
</div>


## `SystemASRParametersGetResponse14sp5`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemASRParametersGetRequest14sp5()`.

Contains a list of system Application Server Registration parameters.

**Attributes:**

|Name                               |Type|Description                     |
|-----------------------------------|----|--------------------------------|
|max_transmissions                  |int |maxTransmissions                |
|retransmission_delay_milli_seconds |int |retransmissionDelayMilliSeconds |
|listening_port                     |int |listeningPort                   |
|source_address                     |str |sourceAddress *Optional*        |
</div>


## `SystemASRParametersGetResponse14sp7`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemASRParametersGetRequest14sp7()`.

Contains a list of system Application Server Registration parameters.  Replaced by:
`SystemASRParametersGetResponse23()` in AS data mode.

**Attributes:**

|Name                               |Type|Description                     |
|-----------------------------------|----|--------------------------------|
|max_transmissions                  |int |maxTransmissions                |
|retransmission_delay_milli_seconds |int |retransmissionDelayMilliSeconds |
|listening_port                     |int |listeningPort                   |
</div>


## `SystemASRParametersGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemASRParametersGetRequest23()`.

Contains a list of system Application Server Registration parameters.  The following
elements are only used in AS data mode: enableCustomMessageControl, value "false" is
returned in XS data mode customNumberOfUsersPerMessage, value "10" is returned in XS
data mode customMessageIntervalMilliseconds, value "100000" is returned in XS data
mode

**Attributes:**

|Name                                 |Type |Description                       |
|-------------------------------------|-----|----------------------------------|
|max_transmissions                    |int  |maxTransmissions                  |
|retransmission_delay_milli_seconds   |int  |retransmissionDelayMilliSeconds   |
|listening_port                       |int  |listeningPort                     |
|enable_custom_message_control        |bool |enableCustomMessageControl        |
|custom_number_of_users_per_message   |int  |customNumberOfUsersPerMessage     |
|custom_message_interval_milliseconds |int  |customMessageIntervalMilliseconds |
</div>


## `SystemAccessDeviceCustomTagGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceCustomTagGetListRequest()`.

Contains a table of custom configuration tags managed by the Device Management System
on a per-device profile basis.  In AS data mode, the column headings are: "Tag Name",
"Tag Value", "Actual Tag Value". In XS data mode, the column headings are: "Tag Name",
"Tag Value", "Is Encrypted", "Actual Tag Value".

**Attributes:**

|Name                     |Type                        |Description                                                                 |
|-------------------------|----------------------------|----------------------------------------------------------------------------|
|device_custom_tags_table |List(deviceCustomTagsTable) |deviceCustomTagsTable - *Table* array of deviceCustomTagsTable named tuples |
</div>


## `SystemAccessDeviceDeviceActivationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceDeviceActivationGetRequest()`.

The response contains the activation code (if available), the expiry time (if
available) and the activation state.  The expiryTime is represented as a timestamp,
i.e.  the number of milliseconds since January 1, 1970, 00:00:00 GMT.

**Attributes:**

|Name             |Type|Description               |
|-----------------|----|--------------------------|
|activation_code  |str |activationCode *Optional* |
|expiry_time      |int |expiryTime *Optional*     |
|activation_state |str |activationState           |
</div>


## `SystemAccessDeviceFileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceFileGetListRequest()`.

Contains a table of device files managed by the Device Management System on a per-
device profile basis.  The column headings are: "File Type", "File Format", "Is
Authenticated".

Replaced By: `SystemAccessDeviceFileGetListResponse14sp8()`

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|device_files_table |List(deviceFilesTable) |deviceFilesTable - *Table* array of deviceFilesTable named tuples |
</div>


## `SystemAccessDeviceFileGetListResponse14sp8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceFileGetListRequest14sp8()`.

Contains a table of device files managed by the Device Management System on a per-
device profile basis.  The column headings are: "File Format", "Is Authenticated",
"Access URL", "Repository URL", "Template URL", "Extended Capture URL", "Is File
Linked". The following column is only populated in AS data mode for leaf devices.  "Is
File Linked"

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|device_files_table |List(deviceFilesTable) |deviceFilesTable - *Table* array of deviceFilesTable named tuples |
</div>


## `SystemAccessDeviceFileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceFileGetRequest()`.

Replaced By: `SystemAccessDeviceFileGetResponse14sp8()`

**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|file_source             |str |fileSource                       |
|configuration_file_name |str |configurationFileName *Optional* |
</div>


## `SystemAccessDeviceFileGetResponse14sp8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceFileGetRequest14sp8()`.

Replaced by: `SystemAccessDeviceFileGetResponse16sp1()`

**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|file_source             |str |fileSource                       |
|configuration_file_name |str |configurationFileName *Optional* |
</div>


## `SystemAccessDeviceFileGetResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceFileGetRequest16sp1()`.

Replaced by: `SystemAccessDeviceFileGetResponse20()`

**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|file_source             |str |fileSource                       |
|configuration_file_name |str |configurationFileName *Optional* |
|access_url              |str |accessUrl                        |
|repository_url          |str |repositoryUrl *Optional*         |
|template_url            |str |templateUrl *Optional*           |
</div>


## `SystemAccessDeviceFileGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceFileGetRequest20()`.


**Attributes:**

|Name                     |Type |Description                       |
|-------------------------|-----|----------------------------------|
|file_source              |str  |fileSource                        |
|configuration_file_name  |str  |configurationFileName *Optional*  |
|access_url               |str  |accessUrl                         |
|repository_url           |str  |repositoryUrl *Optional*          |
|template_url             |str  |templateUrl *Optional*            |
|extended_capture_enabled |bool |extendedCaptureEnabled *Optional* |
|extended_capture_url     |str  |extendedCaptureURL *Optional*     |
</div>


## `SystemAccessDeviceGetAllResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetAllRequest()`.

Contains a table of devices configured in the entire system.  The column headings are:
"Service Provider Id", "Is Enterprise", "Group Id", "Device Name", "Device Type", "Net
Address", "MAC Address", "Status", "Reseller Id", "Access Device External Id". The
following columns are only returned in AS data mode: "Reseller Id" "Access Device
External Id"

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|access_device_table |List(accessDeviceTable) |accessDeviceTable - *Table* array of accessDeviceTable named tuples |
</div>


## `SystemAccessDeviceGetAvailableCustomTagListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetAvailableCustomTagListRequest()`.

Contains a table of all available custom tags managed by the Device Management System
on a per-device profile basis.  In AS data mode, the column headings are: "Tag Name",
"Tag Value", "Tag Level", "Tag Set Name", "Region Name". In XS data mode, the column
headings are: "Tag Name", "Tag Value", "Tag Level", "Tag Set Name", "Is Encrypted".
"Tag Level" can take the value: "System Default", "System", "Service Provider",
"Group" or "Device Profile".

**Attributes:**

|Name                               |Type                                 |Description                                                                                   |
|-----------------------------------|-------------------------------------|----------------------------------------------------------------------------------------------|
|device_available_custom_tags_table |List(deviceAvailableCustomTagsTable) |deviceAvailableCustomTagsTable - *Table* array of deviceAvailableCustomTagsTable named tuples |
</div>


## `SystemAccessDeviceGetListResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetListRequest14()`.

Contains a table of devices defined at the System-level.  The column headings are:
"Device Name", "Device Type", "Available Ports", "Net Address" and "MAC Address",
"Status", "Version", and "Access Device External Id". The following columns are only
returned in AS data mode: "Access Device External Id"

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|access_device_table |List(accessDeviceTable) |accessDeviceTable - *Table* array of accessDeviceTable named tuples |
</div>


## `SystemAccessDeviceGetNativeTagsWithLogicListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetNativeTagsWithLogicListRequest()`.

Contains a table of all native tags with logic managed by the Device Management System
on a per-device profile basis.  The column headings are: "Tag Name", "Tag Value".

**Attributes:**

|Name                                |Type                                 |Description                                                                                   |
|------------------------------------|-------------------------------------|----------------------------------------------------------------------------------------------|
|device_native_tags_with_logic_table |List(deviceNativeTagsWithLogicTable) |deviceNativeTagsWithLogicTable - *Table* array of deviceNativeTagsWithLogicTable named tuples |
</div>


## `SystemAccessDeviceGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetPagedSortedListRequest()`.

Contains a table of devices configured at system level.  The column headings are:
"Device Name", "Device Type", "Available Ports", "Net Address", "MAC Address",
"Status", "Version", and "Support Visual Device Management API". When CloudPBX is not
licensed, the column "Support Visual Device Management API" values are not returned.

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|access_device_table |List(accessDeviceTable) |accessDeviceTable - *Table* array of accessDeviceTable named tuples |
</div>


## `SystemAccessDeviceGetUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetUserListRequest()`.

The column headings for the deviceUserTable are: "Line/Port", "Last Name", "First
Name", "Phone Number", "Service Provider Id", "Group Id", "User Id", "User Type",
"Endpoint Type", "Primary Line/Port", "Order", "Extension", "Department", "Email
Address", "Private Identity". If the identity/device profile is an identity, the table
will contain a row for each TEL-URI in the Phone Number column.  If the
identity/device profile is a real device, rows for the alternate numbers are not
included.  The User Type column contains one of the enumerated UserType values.  The
Endpoint Type column contains one of the enumerated EndpointType values.  The Private
Identity column is empty is AS mode.  Replaced by:
`SystemAccessDeviceGetUserListResponse21sp1()` in AS data mode.

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|device_user_table |List(deviceUserTable) |deviceUserTable - *Table* array of deviceUserTable named tuples |
</div>


## `SystemAccessDeviceGetUserListResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetUserListRequest21sp1()`.

The column headings for the deviceUserTable are: "Line/Port", "Last Name", "First
Name", "Phone Number", "Service Provider Id", "Group Id", "User Id", "User Type",
"Endpoint Type", "Primary Line/Port", "Order", "Extension", "Department", "Email
Address", "Private Identity". If the identity/device profile is an identity, the table
will contain a row for each TEL-URI in the Phone Number column.  If the
identity/device profile is a real device, rows for the alternate numbers are not
included.  The User Type column contains one of the enumerated UserType values.  The
Endpoint Type column contains one of the enumerated EndpointType21sp1 values.  The
value Mobility in Endpoint Type column is only applicable in AS data mode.  The
Private Identity column is empty is AS mode.

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|device_user_table |List(deviceUserTable) |deviceUserTable - *Table* array of deviceUserTable named tuples |
</div>


## `SystemAccessDeviceMonitorGetDeviceTypeListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceMonitorGetDeviceTypeListRequest()`.


**Attributes:**

|Name        |Type      |Description           |
|------------|----------|----------------------|
|device_type |List[str] |deviceType *Optional* |
</div>


## `SystemAccessDeviceMonitorParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceMonitorParametersGetListRequest()`.

Contains a list of system Access Device Monitor parameters.

**Attributes:**

|Name                     |Type|Description            |
|-------------------------|----|-----------------------|
|polling_interval_minutes |int |pollingIntervalMinutes |
</div>


## `SystemAccessDeviceTagSetGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceTagSetGetRequest()`.

The response includes a tag set name defined in the access device.

**Attributes:**

|Name         |Type|Description           |
|-------------|----|----------------------|
|tag_set_name |str |tagSetName *Optional* |
</div>


## `SystemAccessDeviceTypeGetEnhancedConfigurableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceTypeGetEnhancedConfigurableListRequest()`.

Contains a table with columns: "Access Device Type", "Enhanced Configuration Type",
"Supports Reset". The "Enhanced Configuration Type" column contains one of the
AccessDeviceEnhancedConfigurationType14 enumerated values.  The "Supports Reset"
column is a boolean flag indicating the device can be remotely reset.

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|device_type_table |List(deviceTypeTable) |deviceTypeTable - *Table* array of deviceTypeTable named tuples |
</div>


## `SystemAccessDeviceTypeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceTypeGetListRequest()`.


**Attributes:**

|Name        |Type      |Description|
|------------|----------|-----------|
|device_type |List[str] |deviceType |
</div>


## `SystemAccountingGetChargingFunctionElementServerListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccountingGetChargingFunctionElementServerListRequest()`.

The accounting charging function element Server table column headings are: "Address",
"Extended Net Address", "Type", "Description".

**Attributes:**

|Name                                   |Type                                     |Description                                                                                           |
|---------------------------------------|-----------------------------------------|------------------------------------------------------------------------------------------------------|
|charging_function_element_server_table |List(chargingFunctionElementServerTable) |chargingFunctionElementServerTable - *Table* array of chargingFunctionElementServerTable named tuples |
</div>


## `SystemAccountingGetRadiusServerListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccountingGetRadiusServerListRequest()`.

The Radius Server table column headings are: "Net Address", "Port", "Description"

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|radius_server_table |List(radiusServerTable) |radiusServerTable - *Table* array of radiusServerTable named tuples |
</div>


## `SystemAccountingInhibitedAttributeValuePairCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccountingInhibitedAttributeValuePairCodeGetListRequest()`.

Contains a 2 column table with column headings "Attribute Value Pair Code" and "Vendor
Id".

**Attributes:**

|Name                                      |Type                                       |Description                                                                                               |
|------------------------------------------|-------------------------------------------|----------------------------------------------------------------------------------------------------------|
|inhibited_attribute_value_pair_code_table |List(inhibitedAttributeValuePairCodeTable) |inhibitedAttributeValuePairCodeTable - *Table* array of inhibitedAttributeValuePairCodeTable named tuples |
</div>


## `SystemAdminGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAdminGetListRequest()`.

Contains a 6 column table with column headings "Administrator ID", "Last Name", "First
Name", "Type", "Read Only", "Language".

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|system_admin_table |List(systemAdminTable) |systemAdminTable - *Table* array of systemAdminTable named tuples |
</div>


## `SystemAdminGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemAdminGetRequest()`.

The response contains the system or provisioning administrators profile information.

**Attributes:**

|Name       |Type |Description          |
|-----------|-----|---------------------|
|first_name |str  |firstName *Optional* |
|last_name  |str  |lastName *Optional*  |
|language   |str  |language             |
|admin_type |str  |adminType            |
|read_only  |bool |readOnly             |
</div>


## `SystemAdviceOfChargeCostInformationSourceGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAdviceOfChargeCostInformationSourceGetListRequest()`.

Contains a table with column headings: "PeerIdentity", "Priority"

**Attributes:**

|Name                          |Type                             |Description                                                                           |
|------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|cost_information_source_table |List(costInformationSourceTable) |costInformationSourceTable - *Table* array of costInformationSourceTable named tuples |
</div>


## `SystemAdviceOfChargeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAdviceOfChargeGetRequest()`.

Contains a list of system Advice of Charge parameters.  Replaced by:
`SystemAdviceOfChargeGetResponse19sp1()`

**Attributes:**

|Name                               |Type|Description                      |
|-----------------------------------|----|---------------------------------|
|delay_between_notification_seconds |int |delayBetweenNotificationSeconds  |
|incoming_aoc_handling              |str |incomingAocHandling              |
|cost_information_source            |str |costInformationSource *Optional* |
</div>


## `SystemAdviceOfChargeGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAdviceOfChargeGetRequest()`.

Contains a list of system Advice of Charge parameters.

**Attributes:**

|Name                               |Type |Description                     |
|-----------------------------------|-----|--------------------------------|
|delay_between_notification_seconds |int  |delayBetweenNotificationSeconds |
|incoming_aoc_handling              |str  |incomingAocHandling             |
|use_ocs_enquiry                    |bool |useOCSEnquiry                   |
|ocs_enquiry_type                   |str  |OCSEnquiryType                  |
</div>


## `SystemAliasGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAliasGetListRequest()`.

Contains the list of all network alias' for the Application Server.

**Attributes:**

|Name              |Type      |Description                |
|------------------|----------|---------------------------|
|alias_net_address |List[str] |aliasNetAddress *Optional* |
</div>


## `SystemAlternateUserIdGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAlternateUserIdGetListRequest()`.

The "User Type" column contains the corresponding enumerated UserType value.  Contains
a table of alternate user ids, the column headings are: "User Id", "Alternate User
Id", "Group Id", "Organization Id", "Reseller Id" and "User Type". The following
columns are only returned in AS data mode: "Reseller Id"

**Attributes:**

|Name                    |Type                       |Description                                                               |
|------------------------|---------------------------|--------------------------------------------------------------------------|
|alternate_user_id_table |List(alternateUserIdTable) |alternateUserIdTable - *Table* array of alternateUserIdTable named tuples |
</div>


## `SystemAnonymousCallRejectionGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemAnonymousCallRejectionGetRequest()`.

The response contains the anonymous call rejection system.".

**Attributes:**

|Name                    |Type |Description          |
|------------------------|-----|---------------------|
|pai_required            |bool |paiRequired          |
|screen_only_local_calls |bool |screenOnlyLocalCalls |
</div>


## `SystemApplicationControllerGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemApplicationControllerGetListRequest()`.

Contains a table with column headings: "Name", "Subscriber Id", "Channel Set Id",
"Status". The column values for "Status" can either be "ready" or "notReady".

**Attributes:**

|Name                         |Type                             |Description                                                                           |
|-----------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|application_controller_table |List(applicationControllerTable) |applicationControllerTable - *Table* array of applicationControllerTable named tuples |
</div>


## `SystemAuthenticationLockoutSettingsGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAuthenticationLockoutSettingsGetRequest()`.

Contains the authentication lockout settings in the system.

**Attributes:**

|Name                         |Type |Description               |
|-----------------------------|-----|--------------------------|
|counter_reset_interval_days  |int  |counterResetIntervalDays  |
|counter_reset_hour           |int  |counterResetHour          |
|counter_reset_minute         |int  |counterResetMinute        |
|emergency_sip_bypass_allowed |bool |emergencySIPBypassAllowed |
</div>


## `SystemAutomaticCallbackGetReleaseCauseListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAutomaticCallbackGetReleaseCauseListRequest()`.


**Attributes:**

|Name          |Type      |Description             |
|--------------|----------|------------------------|
|release_cause |List[str] |releaseCause *Optional* |
</div>


## `SystemAutomaticCallbackGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAutomaticCallbackGetRequest()`.

Replaced By: `SystemAutomaticCallbackGetResponse15()`

**Attributes:**

|Name                                  |Type|Description                       |
|--------------------------------------|----|----------------------------------|
|monitor_minutes                       |int |monitorMinutes                    |
|wait_between_retry_originator_minutes |int |waitBetweenRetryOriginatorMinutes |
|max_monitors_per_originator           |int |maxMonitorsPerOriginator          |
|max_callback_rings                    |int |maxCallbackRings                  |
|max_retry_originator_minutes          |int |maxRetryOriginatorMinutes         |
</div>


## `SystemAutomaticCallbackGetResponse15`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAutomaticCallbackGetRequest15()`.

Replaced By: `SystemAutomaticCallbackGetResponse15sp2()`

**Attributes:**

|Name                          |Type|Description                |
|------------------------------|----|---------------------------|
|monitor_minutes               |int |monitorMinutes             |
|max_monitors_per_originator   |int |maxMonitorsPerOriginator   |
|max_callback_rings            |int |maxCallbackRings           |
|max_monitors_per_terminator   |int |maxMonitorsPerTerminator   |
|terminator_idle_guard_seconds |int |terminatorIdleGuardSeconds |
</div>


## `SystemAutomaticCallbackGetResponse15sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAutomaticCallbackGetRequest15sp2()`.


**Attributes:**

|Name                          |Type|Description                |
|------------------------------|----|---------------------------|
|monitor_minutes               |int |monitorMinutes             |
|max_monitors_per_originator   |int |maxMonitorsPerOriginator   |
|max_callback_rings            |int |maxCallbackRings           |
|max_monitors_per_terminator   |int |maxMonitorsPerTerminator   |
|terminator_idle_guard_seconds |int |terminatorIdleGuardSeconds |
|callback_method               |str |callbackMethod             |
|polling_interval_seconds      |int |pollingIntervalSeconds     |
</div>


## `SystemAutomaticCallbackGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAutomaticCallbackGetRequest17()`.


**Attributes:**

|Name                          |Type|Description                |
|------------------------------|----|---------------------------|
|monitor_minutes               |int |monitorMinutes             |
|max_monitors_per_originator   |int |maxMonitorsPerOriginator   |
|max_callback_rings            |int |maxCallbackRings           |
|max_monitors_per_terminator   |int |maxMonitorsPerTerminator   |
|terminator_idle_guard_seconds |int |terminatorIdleGuardSeconds |
|callback_method               |str |callbackMethod             |
|polling_interval_seconds      |int |pollingIntervalSeconds     |
|activation_digit              |int |activationDigit            |
</div>


## `SystemAutomaticCollectCallGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemAutomaticCollectCallGetRequest()`.

Returns system Automatic Collect Call service settings.  Replaced by
`SystemAutomaticCollectCallGetResponse22()` in AS mode.

**Attributes:**

|Name                          |Type |Description                |
|------------------------------|-----|---------------------------|
|enable_automatic_collect_call |bool |enableAutomaticCollectCall |
|enable_connect_tone           |bool |enableConnectTone          |
</div>


## `SystemAutomaticCollectCallGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemAutomaticCollectCallGetRequest22()`.

Returns system Automatic Collect Call service settings.

**Attributes:**

|Name                          |Type |Description                |
|------------------------------|-----|---------------------------|
|enable_automatic_collect_call |bool |enableAutomaticCollectCall |
|enable_connect_tone           |bool |enableConnectTone          |
|include_country_code_in_cic   |bool |includeCountryCodeInCic    |
</div>


## `SystemAutomaticCollectCallPrefixDigitsGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemAutomaticCollectCallPrefixDigitsGetListRequest()`.

Contains a table with column headings: "Country Code", "Prefix".

**Attributes:**

|Name         |Type              |Description                                             |
|-------------|------------------|--------------------------------------------------------|
|prefix_table |List(prefixTable) |prefixTable - *Table* array of prefixTable named tuples |
</div>


## `SystemBCCTGetOCIInterfaceAddressListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBCCTGetOCIInterfaceAddressListRequest()`.


**Attributes:**

|Name                  |Type      |Description                    |
|----------------------|----------|-------------------------------|
|interface_net_address |List[str] |interfaceNetAddress *Optional* |
</div>


## `SystemBroadCloudGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemBroadCloudGetRequest()`.

The response contains the system interface attributes for Messaging Server/BroadCloud.

**Attributes:**

|Name                   |Type |Description                   |
|-----------------------|-----|------------------------------|
|provisioning_url       |str  |provisioningUrl *Optional*    |
|provisioning_user_id   |str  |provisioningUserId *Optional* |
|enable_synchronization |bool |enableSynchronization         |
</div>


## `SystemBroadWorksAnywhereGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `SystemBroadWorksAnywhereGetRequest()`.


**Attributes:**

|Name                         |Type |Description                |
|-----------------------------|-----|---------------------------|
|enable_transfer_notification |bool |enableTransferNotification |
</div>


## `SystemBroadWorksMobileManagerGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemBroadWorksMobileManagerGetRequest()`

**Attributes:**

|Name                 |Type |Description                   |
|---------------------|-----|------------------------------|
|scf_api_net_address1 |str  |scfApiNetAddress1 *Optional*  |
|scf_api_net_address2 |str  |scfApiNetAddress2 *Optional*  |
|user_name            |str  |userName *Optional*           |
|email_from_address   |str  |emailFromAddress *Optional*   |
|scf_ims_only         |bool |scfIMSOnly                    |
|signaling_ip_address |str  |signalingIPAddress *Optional* |
|signaling_port       |int  |signalingPort *Optional*      |
</div>


## `SystemBroadWorksMobilityGeographicalPoolGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemBroadWorksMobilityGeographicalPoolGetListRequest()`.

Contains a table with column headings: “Pool”, "Country Code", "Is Default",
“Description”.

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|geographical_pool_table |List(geographicalPoolTable) |geographicalPoolTable - *Table* array of geographicalPoolTable named tuples |
</div>


## `SystemBroadWorksMobilityGeographicalPoolIMRNGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBroadWorksMobilityGeographicalPoolIMRNGetListRequest()`.


**Attributes:**

|Name         |Type      |Description           |
|-------------|----------|----------------------|
|country_code |str       |countryCode           |
|imrn_number  |List[str] |imrnNumber *Optional* |
</div>


## `SystemBroadWorksMobilityGeographicalPoolPrefixGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemBroadWorksMobilityGetGeographicalPoolPrefixListRequest()`.


**Attributes:**

|Name         |Type      |Description       |
|-------------|----------|------------------|
|country_code |str       |countryCode       |
|prefix       |List[str] |prefix *Optional* |
</div>


## `SystemBroadWorksMobilityGetIMRNListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBroadWorksMobilityDnGetListRequest()`.


**Attributes:**

|Name        |Type      |Description           |
|------------|----------|----------------------|
|imrn_number |List[str] |imrnNumber *Optional* |
</div>


## `SystemBroadWorksMobilityGetMobileNetworkIMRNListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBroadWorksMobilityGetMobileNetworkIMRNListRequest()`.


**Attributes:**

|Name        |Type      |Description           |
|------------|----------|----------------------|
|imrn_number |List[str] |imrnNumber *Optional* |
</div>


## `SystemBroadWorksMobilityGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `SystemBroadWorksMobilityGetRequest()`.

Replaced by: `SystemBroadWorksMobilityGetResponse17sp4()`.

**Attributes:**

|Name                         |Type |Description                      |
|-----------------------------|-----|---------------------------------|
|enable_location_services     |bool |enableLocationServices           |
|enable_msrn_lookup           |bool |enableMSRNLookup                 |
|enable_mobile_state_checking |bool |enableMobileStateChecking        |
|deny_call_originations       |bool |denyCallOriginations             |
|deny_call_terminations       |bool |denyCallTerminations             |
|imrn_timeout_millisecnds     |int  |imrnTimeoutMillisecnds           |
|scf_signaling_ip_address     |str  |scfSignalingIPAddress *Optional* |
|scf_signaling_port           |int  |scfSignalingPort *Optional*      |
</div>


## `SystemBroadWorksMobilityGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `SystemBroadWorksMobilityGetRequest17sp4()`.


**Attributes:**

|Name                                |Type |Description                       |
|------------------------------------|-----|----------------------------------|
|enable_location_services            |bool |enableLocationServices            |
|enable_msrn_lookup                  |bool |enableMSRNLookup                  |
|enable_mobile_state_checking        |bool |enableMobileStateChecking         |
|deny_call_originations              |bool |denyCallOriginations              |
|deny_call_terminations              |bool |denyCallTerminations              |
|imrn_timeout_millisecnds            |int  |imrnTimeoutMillisecnds            |
|scf_signaling_net_address           |str  |scfSignalingNetAddress *Optional* |
|scf_signaling_port                  |int  |scfSignalingPort *Optional*       |
|refresh_period_seconds              |int  |refreshPeriodSeconds              |
|max_consecutive_failures            |int  |maxConsecutiveFailures            |
|max_response_wait_time_milliseconds |int  |maxResponseWaitTimeMilliseconds   |
</div>


## `SystemBroadWorksMobilityGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `SystemBroadWorksMobilityGetRequest19sp1()`.

Replaced by `SystemBroadWorksMobilityGetResponse21()`

**Attributes:**

|Name                                |Type |Description                       |
|------------------------------------|-----|----------------------------------|
|enable_location_services            |bool |enableLocationServices            |
|enable_msrn_lookup                  |bool |enableMSRNLookup                  |
|enable_mobile_state_checking        |bool |enableMobileStateChecking         |
|deny_call_originations              |bool |denyCallOriginations              |
|deny_call_terminations              |bool |denyCallTerminations              |
|imrn_timeout_millisecnds            |int  |imrnTimeoutMillisecnds            |
|scf_signaling_net_address           |str  |scfSignalingNetAddress *Optional* |
|scf_signaling_port                  |int  |scfSignalingPort *Optional*       |
|refresh_period_seconds              |int  |refreshPeriodSeconds              |
|max_consecutive_failures            |int  |maxConsecutiveFailures            |
|max_response_wait_time_milliseconds |int  |maxResponseWaitTimeMilliseconds   |
|enable_announcement_suppression     |bool |enableAnnouncementSuppression     |
</div>


## `SystemBroadWorksMobilityGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `SystemBroadWorksMobilityGetRequest21()`.

Replaced by: `SystemBroadWorksMobilityGetResponse22()` in AS data mode

**Attributes:**

|Name                         |Type |Description               |
|-----------------------------|-----|--------------------------|
|enable_location_services     |bool |enableLocationServices    |
|enable_msrn_lookup           |bool |enableMSRNLookup          |
|enable_mobile_state_checking |bool |enableMobileStateChecking |
|deny_call_originations       |bool |denyCallOriginations      |
|deny_call_terminations       |bool |denyCallTerminations      |
|imrn_timeout_millisecnds     |int  |imrnTimeoutMillisecnds    |
</div>


## `SystemBroadWorksMobilityGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `SystemBroadWorksMobilityGetRequest21sp1()`.

Replaced by `SystemBroadWorksMobilityGetResponse22V2()`.

**Attributes:**

|Name                                           |Type |Description                               |
|-----------------------------------------------|-----|------------------------------------------|
|enable_location_services                       |bool |enableLocationServices                    |
|enable_msrn_lookup                             |bool |enableMSRNLookup                          |
|enable_mobile_state_checking                   |bool |enableMobileStateChecking                 |
|deny_call_originations                         |bool |denyCallOriginations                      |
|deny_call_terminations                         |bool |denyCallTerminations                      |
|imrn_timeout_millisecnds                       |int  |imrnTimeoutMillisecnds                    |
|enable_internal_clid_delivery_access_locations |bool |enableInternalCLIDDeliveryAccessLocations |
</div>


## `SystemBroadWorksMobilityGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `SystemBroadWorksMobilityGetRequest22()`.

Replaced by `SystemBroadWorksMobilityGetResponse22V2()`.

**Attributes:**

|Name                                      |Type |Description                           |
|------------------------------------------|-----|--------------------------------------|
|enable_location_services                  |bool |enableLocationServices                |
|enable_msrn_lookup                        |bool |enableMSRNLookup                      |
|enable_mobile_state_checking              |bool |enableMobileStateChecking             |
|deny_call_originations                    |bool |denyCallOriginations                  |
|deny_call_terminations                    |bool |denyCallTerminations                  |
|imrn_timeout_millisecnds                  |int  |imrnTimeoutMillisecnds                |
|enable_internal_clid_delivery             |bool |enableInternalCLIDDelivery            |
|include_redirect_for_mobility_termination |bool |includeRedirectForMobilityTermination |
</div>


## `SystemBroadWorksMobilityGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `SystemBroadWorksMobilityGetRequest22V2()`.

Replaced by `SystemBroadWorksMobilityGetResponse22V3()`.

**Attributes:**

|Name                                           |Type |Description                               |
|-----------------------------------------------|-----|------------------------------------------|
|enable_location_services                       |bool |enableLocationServices                    |
|enable_msrn_lookup                             |bool |enableMSRNLookup                          |
|enable_mobile_state_checking                   |bool |enableMobileStateChecking                 |
|deny_call_originations                         |bool |denyCallOriginations                      |
|deny_call_terminations                         |bool |denyCallTerminations                      |
|imrn_timeout_millisecnds                       |int  |imrnTimeoutMillisecnds                    |
|enable_internal_clid_delivery                  |bool |enableInternalCLIDDelivery                |
|include_redirect_for_mobility_termination      |bool |includeRedirectForMobilityTermination     |
|enable_internal_clid_delivery_access_locations |bool |enableInternalCLIDDeliveryAccessLocations |
|enable_enhanced_unreachable_state_checking     |bool |enableEnhancedUnreachableStateChecking    |
|enable_network_call_barring_status_check       |bool |enableNetworkCallBarringStatusCheck       |
</div>


## `SystemBroadWorksMobilityGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `SystemBroadWorksMobilityGetRequest22V3()`.


**Attributes:**

|Name                                           |Type |Description                               |
|-----------------------------------------------|-----|------------------------------------------|
|enable_location_services                       |bool |enableLocationServices                    |
|enable_msrn_lookup                             |bool |enableMSRNLookup                          |
|enable_mobile_state_checking                   |bool |enableMobileStateChecking                 |
|deny_call_originations                         |bool |denyCallOriginations                      |
|deny_call_terminations                         |bool |denyCallTerminations                      |
|imrn_timeout_millisecnds                       |int  |imrnTimeoutMillisecnds                    |
|enable_internal_clid_delivery                  |bool |enableInternalCLIDDelivery                |
|include_redirect_for_mobility_termination      |bool |includeRedirectForMobilityTermination     |
|enable_internal_clid_delivery_access_locations |bool |enableInternalCLIDDeliveryAccessLocations |
|enable_enhanced_unreachable_state_checking     |bool |enableEnhancedUnreachableStateChecking    |
|enable_network_call_barring_status_check       |bool |enableNetworkCallBarringStatusCheck       |
|network_translation_index                      |str  |networkTranslationIndex *Optional*        |
</div>


## `SystemBroadWorksMobilityMobileNetworkGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `SystemBroadWorksMobilityMobileNetworkGetListRequest()`.

Contains a table with column headings: "Name", "SCF Signaling Net Address", "SCF
Signaling Port"

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|mobile_network_table |List(mobileNetworkTable) |mobileNetworkTable - *Table* array of mobileNetworkTable named tuples |
</div>


## `SystemBroadWorksMobilityMobileNetworkGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `SystemBroadWorksMobilityMobileNetworkGetRequest()`.


**Attributes:**

|Name                                |Type |Description                          |
|------------------------------------|-----|-------------------------------------|
|scf_signaling_net_address           |str  |scfSignalingNetAddress *Optional*    |
|scf_signaling_port                  |int  |scfSignalingPort *Optional*          |
|refresh_period_seconds              |int  |refreshPeriodSeconds                 |
|max_consecutive_failures            |int  |maxConsecutiveFailures               |
|max_response_wait_time_milliseconds |int  |maxResponseWaitTimeMilliseconds      |
|enable_announcement_suppression     |bool |enableAnnouncementSuppression        |
|service_access_code_list_name       |str  |serviceAccessCodeListName *Optional* |
</div>


## `SystemBroadWorksMobilityMobileSubscriberDirectoryNumberGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`SystemBroadWorksMobilityMobileSubscriberDirectoryNumberGetSummaryListRequest()`.

The response contains a table with columns: "Mobile Number", "Mobile Network",
"Service Provider Id", "Is Enterprise", "Group Id", "User Id", "Last Name", "First
Name", "Hiragana Last Name", "Hiragana First Name", "Phone Number", "Extension" and
"Reseller Id". The following columns are only returned in AS data mode: "Reseller Id"

**Attributes:**

|Name                                              |Type                                               |Description                                                                                                               |
|--------------------------------------------------|---------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------|
|mobile_subscriber_directory_numbers_summary_table |List(mobileSubscriberDirectoryNumbersSummaryTable) |mobileSubscriberDirectoryNumbersSummaryTable - *Table* array of mobileSubscriberDirectoryNumbersSummaryTable named tuples |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBroadWorksMobilityServiceAccessCodeGetListRequest()`.

Contains a table with column headings: "Country Code", "Service Access Code",
"Description". Replaced by SystemBroadWorksMobilityServiceAccessCodeGetListReponse21.

**Attributes:**

|Name                      |Type                         |Description                                                                   |
|--------------------------|-----------------------------|------------------------------------------------------------------------------|
|service_access_code_table |List(serviceAccessCodeTable) |serviceAccessCodeTable - *Table* array of serviceAccessCodeTable named tuples |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeGetListResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBroadWorksMobilityServiceAccessCodeGetListRequest21()`.

Contains a table with column headings: "Country Code", "Service Access Code",
"Description"

**Attributes:**

|Name                      |Type                         |Description                                                                   |
|--------------------------|-----------------------------|------------------------------------------------------------------------------|
|service_access_code_table |List(serviceAccessCodeTable) |serviceAccessCodeTable - *Table* array of serviceAccessCodeTable named tuples |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeListGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBroadWorksMobilityServiceAccessCodeListGetListRequest()`.


**Attributes:**

|Name |Type      |Description     |
|-----|----------|----------------|
|name |List[str] |name *Optional* |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeListUsageGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBroadWorksMobilityServiceAccessCodeListUsageGetRequest()`.


**Attributes:**

|Name                |Type      |Description                  |
|--------------------|----------|-----------------------------|
|mobile_network_name |List[str] |mobileNetworkName *Optional* |
</div>


## `SystemBroadWorksReceptionistEnterpriseGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBroadWorksReceptionistEnterpriseGetRequest()`.

Contains a list of BroadWorks Receptionist - Enterprise parameters.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|max_monitored_users |int |maxMonitoredUsers |
</div>


## `SystemBusyLampFieldGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBusyLampFieldGetRequest()`.


**Attributes:**

|Name                                        |Type |Description                           |
|--------------------------------------------|-----|--------------------------------------|
|display_local_user_identity_last_name_first |bool |displayLocalUserIdentityLastNameFirst |
</div>


## `SystemBusyLampFieldGetResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBusyLampFieldGetRequest18()`.

The following elements are only used in AS data mode: forceUseOfTCP Replaced by:
`SystemBusyLampFieldGetResponse23()` in AS data mode.

**Attributes:**

|Name                                        |Type |Description                           |
|--------------------------------------------|-----|--------------------------------------|
|display_local_user_identity_last_name_first |bool |displayLocalUserIdentityLastNameFirst |
|force_use_of_tcp                            |bool |forceUseOfTCP                         |
</div>


## `SystemBusyLampFieldGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBusyLampFieldGetRequest22()`.

The following elements are only used in AS data mode: forceUseOfTCP Replaced by:
`SystemBusyLampFieldGetResponse23V2()` in AS data mode.

**Attributes:**

|Name                                        |Type |Description                           |
|--------------------------------------------|-----|--------------------------------------|
|display_local_user_identity_last_name_first |bool |displayLocalUserIdentityLastNameFirst |
|force_use_of_tcp                            |bool |forceUseOfTCP                         |
</div>


## `SystemBusyLampFieldGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBusyLampFieldGetRequest23()`.

The following elements are only used in AS data mode: forceUseOfTCP enableRedundancy,
value "false" is returned in XS data mode redundancyTaskDelayMilliseconds, value
"10000" is returned in Amplify and XS data mode redundancyTaskIntervalMilliseconds,
value of "1000" is returned in Amplify and XS data mode
maxNumberOfSubscriptionsPerRedundancyTaskInterval, value of "50" is returned in
Amplify and XS data mode Replaced by: `SystemBusyLampFieldGetResponse23V2()` in AS
data mode.

**Attributes:**

|Name                                                     |Type |Description                                       |
|---------------------------------------------------------|-----|--------------------------------------------------|
|display_local_user_identity_last_name_first              |bool |displayLocalUserIdentityLastNameFirst             |
|force_use_of_tcp                                         |bool |forceUseOfTCP                                     |
|enable_redundancy                                        |bool |enableRedundancy                                  |
|redundancy_task_delay_milliseconds                       |int  |redundancyTaskDelayMilliseconds                   |
|redundancy_task_interval_milliseconds                    |int  |redundancyTaskIntervalMilliseconds                |
|max_number_of_subscriptions_per_redundancy_task_interval |int  |maxNumberOfSubscriptionsPerRedundancyTaskInterval |
</div>


## `SystemBusyLampFieldGetResponse23V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBusyLampFieldGetRequest23V2()`.

The following elements are only used in AS data mode: forceUseOfTCP enableRedundancy,
value "false" is returned in XS data mode redundancyTaskDelayMilliseconds, value
"10000" is returned in Amplify and XS data mode redundancyTaskIntervalMilliseconds,
value of "1000" is returned in Amplify and XS data mode
maxNumberOfSubscriptionsPerRedundancyTaskInterval, value of "50" is returned in
Amplify and XS data mode ignoreUnansweredTerminatingCalls, value “false” is returned
in XS data mode

**Attributes:**

|Name                                                     |Type |Description                                       |
|---------------------------------------------------------|-----|--------------------------------------------------|
|display_local_user_identity_last_name_first              |bool |displayLocalUserIdentityLastNameFirst             |
|force_use_of_tcp                                         |bool |forceUseOfTCP                                     |
|enable_redundancy                                        |bool |enableRedundancy                                  |
|redundancy_task_delay_milliseconds                       |int  |redundancyTaskDelayMilliseconds                   |
|redundancy_task_interval_milliseconds                    |int  |redundancyTaskIntervalMilliseconds                |
|max_number_of_subscriptions_per_redundancy_task_interval |int  |maxNumberOfSubscriptionsPerRedundancyTaskInterval |
|ignore_unanswered_terminating_calls                      |bool |ignoreUnansweredTerminatingCalls                  |
</div>


## `SystemBwDiameterBaseDataGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBwDiameterBaseDataGetRequest()`.

Contains a list of System Diameter base parameters.

**Attributes:**

|Name                                      |Type |Description                          |
|------------------------------------------|-----|-------------------------------------|
|xs_realm                                  |str  |xsRealm *Optional*                   |
|xs_listening_port                         |int  |xsListeningPort                      |
|ps_realm                                  |str  |psRealm *Optional*                   |
|ps_listening_port                         |int  |psListeningPort                      |
|ps_relay_through_xs                       |bool |psRelayThroughXs                     |
|xs_relay_listening_port                   |int  |xsRelayListeningPort                 |
|tc_timer_seconds                          |int  |tcTimerSeconds                       |
|tw_timer_seconds                          |int  |twTimerSeconds                       |
|request_timer_seconds                     |int  |requestTimerSeconds                  |
|busy_peer_detection_outstanding_txn_count |int  |busyPeerDetectionOutstandingTxnCount |
|busy_peer_restore_outstanding_txn_count   |int  |busyPeerRestoreOutstandingTxnCount   |
|dynamic_entry_inactivity_timer_hours      |int  |dynamicEntryInactivityTimerHours     |
</div>


## `SystemBwDiameterBaseDataGetResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBwDiameterBaseDataGetRequest17sp3()`.

Contains a list of System Diameter base parameters.

**Attributes:**

|Name                                      |Type |Description                          |
|------------------------------------------|-----|-------------------------------------|
|xs_realm                                  |str  |xsRealm *Optional*                   |
|xs_listening_port                         |int  |xsListeningPort                      |
|ps_realm                                  |str  |psRealm *Optional*                   |
|ps_listening_port                         |int  |psListeningPort                      |
|ps_relay_through_xs                       |bool |psRelayThroughXs                     |
|xs_relay_listening_port                   |int  |xsRelayListeningPort                 |
|tc_timer_seconds                          |int  |tcTimerSeconds                       |
|tw_timer_seconds                          |int  |twTimerSeconds                       |
|request_timer_seconds                     |int  |requestTimerSeconds                  |
|busy_peer_detection_outstanding_txn_count |int  |busyPeerDetectionOutstandingTxnCount |
|busy_peer_restore_outstanding_txn_count   |int  |busyPeerRestoreOutstandingTxnCount   |
|dynamic_entry_inactivity_timer_hours      |int  |dynamicEntryInactivityTimerHours     |
|advertised_offline_billing_application    |str  |advertisedOfflineBillingApplication  |
|advertised_online_billing_application     |str  |advertisedOnlineBillingApplication   |
</div>


## `SystemBwDiameterBaseDataGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemBwDiameterBaseDataGetRequest22()`.

Contains a list of System Diameter base parameters.

**Attributes:**

|Name                                      |Type |Description                          |
|------------------------------------------|-----|-------------------------------------|
|xs_realm                                  |str  |xsRealm *Optional*                   |
|xs_listening_port                         |int  |xsListeningPort                      |
|xs_listening_port_enabled                 |bool |xsListeningPortEnabled               |
|xs_listening_secure_port                  |int  |xsListeningSecurePort                |
|xs_listening_secure_port_enabled          |bool |xsListeningSecurePortEnabled         |
|ps_realm                                  |str  |psRealm *Optional*                   |
|ps_listening_port                         |int  |psListeningPort                      |
|ps_listening_port_enabled                 |bool |psListeningPortEnabled               |
|ps_listening_secure_port                  |int  |psListeningSecurePort                |
|ps_listening_secure_port_enabled          |bool |psListeningSecurePortEnabled         |
|ps_relay_through_xs                       |bool |psRelayThroughXs                     |
|xs_relay_listening_port                   |int  |xsRelayListeningPort                 |
|tc_timer_seconds                          |int  |tcTimerSeconds                       |
|tw_timer_seconds                          |int  |twTimerSeconds                       |
|request_timer_seconds                     |int  |requestTimerSeconds                  |
|busy_peer_detection_outstanding_txn_count |int  |busyPeerDetectionOutstandingTxnCount |
|busy_peer_restore_outstanding_txn_count   |int  |busyPeerRestoreOutstandingTxnCount   |
|dynamic_entry_inactivity_timer_hours      |int  |dynamicEntryInactivityTimerHours     |
|advertised_offline_billing_application    |str  |advertisedOfflineBillingApplication  |
|advertised_online_billing_application     |str  |advertisedOnlineBillingApplication   |
|peer_discovery_mode                       |str  |peerDiscoveryMode                    |
|default_port                              |int  |defaultPort                          |
|default_secure_port                       |int  |defaultSecurePort                    |
</div>


## `SystemBwDiameterPeerGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains a 6 column table with column headings 'Instance', 'Identity', 'IP Address',
'Port', 'Enabled' and 'Secure'.

One row is present for each peer.

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|peer_table |List(peerTable) |peerTable - *Table* array of peerTable named tuples |
</div>


## `SystemBwDiameterRoutingPeerGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains a 6 column table with column headings 'Instance', 'Realm', 'ApplicationID',
'Identity, 'Priority', and 'Weight'.

One row is present for each Diameter Routing Peer.

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|routing_peer_table |List(routingPeerTable) |routingPeerTable - *Table* array of routingPeerTable named tuples |
</div>


## `SystemBwDiameterRoutingRealmGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains a 4 column table with column headings 'Instance', 'Realm', 'ApplicationID',
and 'Default'.

One row is present for each Diameter routing realm.

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|routing_realm_table |List(routingRealmTable) |routingRealmTable - *Table* array of routingRealmTable named tuples |
</div>


## `SystemCLIDDeliveryPrefixGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCLIDDeliveryPrefixGetListRequest()`.


**Attributes:**

|Name   |Type      |Description       |
|-------|----------|------------------|
|prefix |List[str] |prefix *Optional* |
</div>


## `SystemCPEConfigGetFileServerListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCPEConfigGetFileServerListRequest()`.

The table columns are: "Device Type", "FTP Host Net Address", "FTP User Id",
"Directory" and "Passive FTP".

Replaced By: `SystemCPEConfigGetFileServerListResponse14sp6()`

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|file_server_table |List(fileServerTable) |fileServerTable - *Table* array of fileServerTable named tuples |
</div>


## `SystemCPEConfigGetFileServerListResponse14sp6`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCPEConfigGetFileServerListRequest14sp6()`.

The table columns are: "Device Type", "File Repository Name", "Directory", "Extended
File Repository Name".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|file_server_table |List(fileServerTable) |fileServerTable - *Table* array of fileServerTable named tuples |
</div>


## `SystemCPEConfigParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCPEConfigParametersGetListRequest()`.

Contains a list of system CPE Config parameters.

Replaced By: `SystemCPEConfigParametersGetResponse14sp6()`

**Attributes:**

|Name                              |Type |Description                   |
|----------------------------------|-----|------------------------------|
|enable_ip_device_management       |bool |enableIPDeviceManagement      |
|ftp_connect_timeout_seconds       |int  |ftpConnectTimeoutSeconds      |
|ftp_file_transfer_timeout_seconds |int  |ftpFileTransferTimeoutSeconds |
</div>


## `SystemCPEConfigParametersGetResponse14sp6`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCPEConfigParametersGetListRequest14sp6()`.

Contains a list of system CPE Config parameters.  Replaced by:
`SystemCPEConfigParametersGetResponse20()`

**Attributes:**

|Name                                    |Type                     |Description                                 |
|----------------------------------------|-------------------------|--------------------------------------------|
|enable_ip_device_management             |bool                     |enableIPDeviceManagement                    |
|ftp_connect_timeout_seconds             |int                      |ftpConnectTimeoutSeconds                    |
|ftp_file_transfer_timeout_seconds       |int                      |ftpFileTransferTimeoutSeconds               |
|pause_between_file_rebuild_milliseconds |int                      |pauseBetweenFileRebuildMilliseconds         |
|max_busy_time_minutes                   |int                      |maxBusyTimeMinutes                          |
|device_access_app_server_cluster_name   |str                      |deviceAccessAppServerClusterName *Optional* |
|file_rebuild_immediate                  |OCI.fileRebuildImmediate |fileRebuildImmediate *Optional*             |
|file_rebuild_daily                      |OCI.fileRebuildDaily     |fileRebuildDaily *Optional*                 |
|file_rebuild_hourly                     |OCI.fileRebuildHourly    |fileRebuildHourly *Optional*                |
</div>


## `SystemCPEConfigParametersGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCPEConfigParametersGetListRequest20()`.

Contains a list of system CPE Config parameters.  Replaced by:
`SystemCPEConfigParametersGetResponse21()`

**Attributes:**

|Name                                    |Type |Description                                 |
|----------------------------------------|-----|--------------------------------------------|
|enable_ip_device_management             |bool |enableIPDeviceManagement                    |
|ftp_connect_timeout_seconds             |int  |ftpConnectTimeoutSeconds                    |
|ftp_file_transfer_timeout_seconds       |int  |ftpFileTransferTimeoutSeconds               |
|pause_between_file_rebuild_milliseconds |int  |pauseBetweenFileRebuildMilliseconds         |
|max_busy_time_minutes                   |int  |maxBusyTimeMinutes                          |
|device_access_app_server_cluster_name   |str  |deviceAccessAppServerClusterName *Optional* |
</div>


## `SystemCPEConfigParametersGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCPEConfigParametersGetRequest21()`.

Contains a list of system CPE Config parameters.  The following elements are only used
in AS data mode: allowDeviceCredentialsRetrieval, value "false" is returned in XS data
mode

**Attributes:**

|Name                                    |Type |Description                                 |
|----------------------------------------|-----|--------------------------------------------|
|enable_ip_device_management             |bool |enableIPDeviceManagement                    |
|ftp_connect_timeout_seconds             |int  |ftpConnectTimeoutSeconds                    |
|ftp_file_transfer_timeout_seconds       |int  |ftpFileTransferTimeoutSeconds               |
|pause_between_file_rebuild_milliseconds |int  |pauseBetweenFileRebuildMilliseconds         |
|device_access_app_server_cluster_name   |str  |deviceAccessAppServerClusterName *Optional* |
|min_time_between_reset_milliseconds     |int  |minTimeBetweenResetMilliseconds             |
|always_push_files_on_rebuild            |bool |alwaysPushFilesOnRebuild                    |
|max_file_operation_retry_attempts       |int  |maxFileOperationRetryAttempts               |
|enable_auto_rebuild_config              |bool |enableAutoRebuildConfig                     |
|event_queue_size                        |int  |eventQueueSize                              |
|allow_device_credentials_retrieval      |bool |allowDeviceCredentialsRetrieval             |
</div>


## `SystemCallCenterEnhancedReportingBrandingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCallCenterEnhancedReportingBrandingGetRequest()`.


**Attributes:**

|Name                             |Type|Description                              |
|---------------------------------|----|-----------------------------------------|
|branding_choice                  |str |brandingChoice                           |
|custom_branding_file_description |str |customBrandingFileDescription *Optional* |
</div>


## `SystemCallCenterEnhancedReportingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterEnhancedReportingGetRequest()`.


**Attributes:**

|Name                       |Type |Description                         |
|---------------------------|-----|------------------------------------|
|archive_reports            |bool |archiveReports                      |
|report_application_url     |str  |reportApplicationURL *Optional*     |
|repository_application_url |str  |repositoryApplicationURL *Optional* |
</div>


## `SystemCallCenterEnhancedReportingReportTemplateGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterEnhancedReportingReportTemplateGetListRequest()`.

Contains a table with column headings: "Name", "Description", "Is Custom", "Type" and
"Enabled"

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|report_template_table |List(reportTemplateTable) |reportTemplateTable - *Table* array of reportTemplateTable named tuples |
</div>


## `SystemCallCenterEnhancedReportingReportTemplateGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterEnhancedReportingReportTemplateGetRequest()`.


**Attributes:**

|Name                                    |Type      |Description                                    |
|----------------------------------------|----------|-----------------------------------------------|
|description                             |str       |description *Optional*                         |
|data_template                           |str       |dataTemplate                                   |
|filter_number                           |int       |filterNumber *Optional*                        |
|xslt_template_description               |str       |xsltTemplateDescription                        |
|scope                                   |str       |scope                                          |
|is_enabled                              |bool      |isEnabled                                      |
|is_realtime_report                      |bool      |isRealtimeReport *Optional*                    |
|call_completion_threshold_param         |str       |callCompletionThresholdParam *Optional*        |
|short_duration_threshold_param          |str       |shortDurationThresholdParam *Optional*         |
|service_level_threshold_param           |str       |serviceLevelThresholdParam *Optional*          |
|service_level_inclusions_param          |str       |serviceLevelInclusionsParam *Optional*         |
|service_level_objective_threshold_param |str       |serviceLevelObjectiveThresholdParam *Optional* |
|abandoned_call_threshold_param          |str       |abandonedCallThresholdParam *Optional*         |
|service_level_threshold_param_number    |int       |serviceLevelThresholdParamNumber *Optional*    |
|abandoned_call_threshold_param_number   |int       |abandonedCallThresholdParamNumber *Optional*   |
|filter_value                            |List[str] |filterValue *Optional*                         |
</div>


## `SystemCallCenterEnhancedReportingScheduledReportGetActiveListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterEnhancedReportingScheduledReportGetActiveListRequest()`
Contains a table with column headings : "Scheduled Report Name", "Description",
"Service Provider Id", "Is Enterprise", "Group Id", "Created By", "Is Supervisor
Report", "Report Template Name", "Report Template Level" and "Recurring".

The "Created By" can be either "Administrator" or user id if created by supervisor.
The possible values for "Recurring" are "None", "Daily", "Weekly", "Monthly" and
"Yearly". The possible values for "Report Template Level" are "System", "Enterprise"
and "Group". For the rows with "Is Enterprise" column value "true", the "Group Id"
column will be empty.

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|scheduled_report_table |List(scheduledReportTable) |scheduledReportTable - *Table* array of scheduledReportTable named tuples |
</div>


## `SystemCallCenterEnhancedReportingScheduledReportGetCompletedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`SystemCallCenterEnhancedReportingScheduledReportGetCompletedListRequest()` Contains a
table with column headings : "Scheduled Report Name", "Description", "Service Provider
Id", "Is Enterprise", "Group Id", "Created By", "Is Supervisor Report", "Report
Template Name", "Report Template Level" and "Recurring".

The "Created By" can be either "Administrator" or user id if created by supervisor.
The possible values for "Recurring" are "None", "Daily", "Weekly", "Monthly" and
"Yearly". The possible values for "Report Template Level" are "System", "Enterprise"
and "Group". For the rows with "Is Enterprise" column value "true", the "Group Id"
column will be empty.

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|scheduled_report_table |List(scheduledReportTable) |scheduledReportTable - *Table* array of scheduledReportTable named tuples |
</div>


## `SystemCallCenterEnhancedReportingScheduledReportGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterEnhancedReportingScheduledReportGetListRequest()`.

Contains a table with column headings : "Scheduled Report Name", "Description",
"Service Provider Id", "Is Enterprise", "Group Id", "Created By", "Is Supervisor
Report", "Status", "Report Template Name", "Report Template Level" and "Recurring".
The "Created By" can be either "Administrator" or user id if created by supervisor.
The possible values for "Status" are "Active", and "Completed". The possible values
for "Recurring" are "None", "Daily", "Weekly", "Monthly" and "Yearly". The possible
values for "Report Template Level" are "System", "Enterprise" and "Group". For the
rows with "Is Enterprise" column value "true", the "Group Id" column will be empty.

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|scheduled_report_table |List(scheduledReportTable) |scheduledReportTable - *Table* array of scheduledReportTable named tuples |
</div>


## `SystemCallCenterEnhancedReportingScheduledReportGetReportTemplateUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`SystemCallCenterEnhancedReportingScheduledReportGetReportTemplateUsageListRequest()`.

Contains a table with column headings: "Schedule Name", "Organization Type", "Service
Provider Id", "Group Id", "Created By", "Created By Supervisor", and "Is Active". The
"Organization Type" is either "Service Provider" or "Enterprise". The "Created By" can
be either "Administrator" or user id if created by supervisor.  The possible values
for "Created By Supervisor" are "true" and "false".

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|schedule_report_table |List(scheduleReportTable) |scheduleReportTable - *Table* array of scheduleReportTable named tuples |
</div>


## `SystemCallCenterEnhancedReportingScheduledTaskParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterEnhancedReportingScheduledTaskParametersGetRequest()`
Replaced by: `SystemCallCenterEnhancedReportingScheduledTaskParametersGetResponse22()`

**Attributes:**

|Name                                          |Type|Description                              |
|----------------------------------------------|----|-----------------------------------------|
|scheduled_report_search_interval_minutes      |int |scheduledReportSearchIntervalMinutes     |
|maximum_scheduled_reports_per_interval        |int |maximumScheduledReportsPerInterval       |
|delete_scheduled_report_days_after_completion |int |deleteScheduledReportDaysAfterCompletion |
</div>


## `SystemCallCenterEnhancedReportingScheduledTaskParametersGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterEnhancedReportingScheduledTaskParametersGetRequest22()`
The following elements are only used in AS data mode: callCenterEventMode, value
“Legacy ECCR" is returned in Amplify data mode

**Attributes:**

|Name                                          |Type|Description                              |
|----------------------------------------------|----|-----------------------------------------|
|scheduled_report_search_interval_minutes      |int |scheduledReportSearchIntervalMinutes     |
|maximum_scheduled_reports_per_interval        |int |maximumScheduledReportsPerInterval       |
|delete_scheduled_report_days_after_completion |int |deleteScheduledReportDaysAfterCompletion |
|call_center_event_mode                        |str |callCenterEventMode                      |
</div>


## `SystemCallCenterEventRecordingFileParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterEventRecordingFileParametersGetRequest()`.

Contains a list of system Call Center Event Recording File parameters.

**Attributes:**

|Name                         |Type|Description               |
|-----------------------------|----|--------------------------|
|file_retention_time_days     |int |fileRetentionTimeDays     |
|file_rotation_period_minutes |str |fileRotationPeriodMinutes |
|file_rotation_offset_minutes |int |fileRotationOffsetMinutes |
|remote_url                   |str |remoteUrl *Optional*      |
|remote_user_id               |str |remoteUserId *Optional*   |
</div>


## `SystemCallCenterGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterGetRequest()`.

Replaced By: `SystemCallCenterGetResponse14sp9()`

**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|default_from_address |str |defaultFromAddress |
</div>


## `SystemCallCenterGetResponse14sp9`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterGetRequest14sp9()`.


**Attributes:**

|Name                               |Type|Description                     |
|-----------------------------------|----|--------------------------------|
|default_from_address               |str |defaultFromAddress              |
|statistics_sampling_period_minutes |int |statisticsSamplingPeriodMinutes |
</div>


## `SystemCallCenterGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterGetRequest16()`.


**Attributes:**

|Name                                                        |Type |Description                                          |
|------------------------------------------------------------|-----|-----------------------------------------------------|
|default_from_address                                        |str  |defaultFromAddress                                   |
|statistics_sampling_period_minutes                          |int  |statisticsSamplingPeriodMinutes                      |
|default_enable_guard_timer                                  |bool |defaultEnableGuardTimer                              |
|default_guard_timer_seconds                                 |int  |defaultGuardTimerSeconds                             |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable |
</div>


## `SystemCallCenterGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterGetRequest17()`.

Replaced by `SystemCallCenterGetResponse17sp4()`.

**Attributes:**

|Name                                                        |Type |Description                                          |
|------------------------------------------------------------|-----|-----------------------------------------------------|
|default_from_address                                        |str  |defaultFromAddress                                   |
|statistics_sampling_period_minutes                          |int  |statisticsSamplingPeriodMinutes                      |
|default_enable_guard_timer                                  |bool |defaultEnableGuardTimer                              |
|default_guard_timer_seconds                                 |int  |defaultGuardTimerSeconds                             |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable |
|default_play_ring_when_offer_call                           |bool |defaultPlayRingWhenOfferCall                         |
|uniform_call_distribution_policy_scope                      |str  |uniformCallDistributionPolicyScope                   |
|call_handling_sampling_period_minutes                       |int  |callHandlingSamplingPeriodMinutes                    |
|call_handling_minimum_sampling_size                         |int  |callHandlingMinimumSamplingSize                      |
|play_tone_to_agent_for_emergency_call                       |bool |playToneToAgentForEmergencyCall                      |
|emergency_call_clid_prefix                                  |str  |emergencyCallCLIDPrefix                              |
</div>


## `SystemCallCenterGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterGetRequest17sp4()`.

Replaced by: `SystemCallCenterGetResponse19()`.

**Attributes:**

|Name                                                        |Type |Description                                          |
|------------------------------------------------------------|-----|-----------------------------------------------------|
|default_from_address                                        |str  |defaultFromAddress                                   |
|statistics_sampling_period_minutes                          |int  |statisticsSamplingPeriodMinutes                      |
|default_enable_guard_timer                                  |bool |defaultEnableGuardTimer                              |
|default_guard_timer_seconds                                 |int  |defaultGuardTimerSeconds                             |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable |
|force_agent_unavailable_on_not_reachable                    |bool |forceAgentUnavailableOnNotReachable                  |
|default_play_ring_when_offer_call                           |bool |defaultPlayRingWhenOfferCall                         |
|uniform_call_distribution_policy_scope                      |str  |uniformCallDistributionPolicyScope                   |
|call_handling_sampling_period_minutes                       |int  |callHandlingSamplingPeriodMinutes                    |
|call_handling_minimum_sampling_size                         |int  |callHandlingMinimumSamplingSize                      |
|play_tone_to_agent_for_emergency_call                       |bool |playToneToAgentForEmergencyCall                      |
|emergency_call_clid_prefix                                  |str  |emergencyCallCLIDPrefix                              |
</div>


## `SystemCallCenterGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterGetRequest19()`.

Replaced by `SystemCallCenterGetRequest21()`.

**Attributes:**

|Name                                                        |Type |Description                                          |
|------------------------------------------------------------|-----|-----------------------------------------------------|
|default_from_address                                        |str  |defaultFromAddress                                   |
|statistics_sampling_period_minutes                          |int  |statisticsSamplingPeriodMinutes                      |
|default_enable_guard_timer                                  |bool |defaultEnableGuardTimer                              |
|default_guard_timer_seconds                                 |int  |defaultGuardTimerSeconds                             |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable |
|force_agent_unavailable_on_not_reachable                    |bool |forceAgentUnavailableOnNotReachable                  |
|default_play_ring_when_offer_call                           |bool |defaultPlayRingWhenOfferCall                         |
|uniform_call_distribution_policy_scope                      |str  |uniformCallDistributionPolicyScope                   |
|call_handling_sampling_period_minutes                       |int  |callHandlingSamplingPeriodMinutes                    |
|call_handling_minimum_sampling_size                         |int  |callHandlingMinimumSamplingSize                      |
|play_tone_to_agent_for_emergency_call                       |bool |playToneToAgentForEmergencyCall                      |
|emergency_call_clid_prefix                                  |str  |emergencyCallCLIDPrefix                              |
|threshold_crossing_notification_email_guard_timer_seconds   |int  |thresholdCrossingNotificationEmailGuardTimerSeconds  |
</div>


## `SystemCallCenterGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterGetRequest21()`.

The following elements are only used in AS data mode:
callHandlingSamplingPeriodMinutes, value "15" is returned in Amplify data mode
callHandlingMinimumSamplingSize, value "5" is returned in Amplify data mode
thresholdCrossingNotificationEmailGuardTimerSeconds, value "5" is returned in Amplify
mode

**Attributes:**

|Name                                                        |Type |Description                                          |
|------------------------------------------------------------|-----|-----------------------------------------------------|
|default_from_address                                        |str  |defaultFromAddress                                   |
|statistics_sampling_period_minutes                          |int  |statisticsSamplingPeriodMinutes                      |
|default_enable_guard_timer                                  |bool |defaultEnableGuardTimer                              |
|default_guard_timer_seconds                                 |int  |defaultGuardTimerSeconds                             |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable |
|force_agent_unavailable_on_not_reachable                    |bool |forceAgentUnavailableOnNotReachable                  |
|default_play_ring_when_offer_call                           |bool |defaultPlayRingWhenOfferCall                         |
|uniform_call_distribution_policy_scope                      |str  |uniformCallDistributionPolicyScope                   |
|call_handling_sampling_period_minutes                       |int  |callHandlingSamplingPeriodMinutes                    |
|call_handling_minimum_sampling_size                         |int  |callHandlingMinimumSamplingSize                      |
|play_tone_to_agent_for_emergency_call                       |bool |playToneToAgentForEmergencyCall                      |
|emergency_call_clid_prefix                                  |str  |emergencyCallCLIDPrefix                              |
|threshold_crossing_notification_email_guard_timer_seconds   |int  |thresholdCrossingNotificationEmailGuardTimerSeconds  |
|allow_agent_device_initiated_forward                        |bool |allowAgentDeviceInitiatedForward                     |
</div>


## `SystemCallCenterReportingServerGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterReportingServerGetListRequest()`.

The table columns are: "Name", "URL", "Net Address", and "Description".

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|reporting_server_table |List(reportingServerTable) |reportingServerTable - *Table* array of reportingServerTable named tuples |
</div>


## `SystemCallMeNowGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallMeNowGetRequest()`.


**Attributes:**

|Name                     |Type|Description            |
|-------------------------|----|-----------------------|
|passcode_length          |int |passcodeLength         |
|passcode_timeout_seconds |int |passcodeTimeoutSeconds |
</div>


## `SystemCallNotifyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallNotifyGetRequest()`.


**Attributes:**

|Name                   |Type |Description         |
|-----------------------|-----|--------------------|
|default_from_address   |str  |defaultFromAddress  |
|use_short_subject_line |bool |useShortSubjectLine |
|use_dn_in_mail_body    |bool |useDnInMailBody     |
</div>


## `SystemCallProcessingGetPolicyResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest14()`.


**Attributes:**

|Name                                                 |Type |Description                                     |
|-----------------------------------------------------|-----|------------------------------------------------|
|use_max_simultaneous_calls                           |bool |useMaxSimultaneousCalls                         |
|max_simultaneous_calls                               |int  |maxSimultaneousCalls                            |
|use_max_simultaneous_video_calls                     |bool |useMaxSimultaneousVideoCalls                    |
|max_simultaneous_video_calls                         |int  |maxSimultaneousVideoCalls                       |
|use_max_call_time_for_answered_calls                 |bool |useMaxCallTimeForAnsweredCalls                  |
|max_call_time_for_answered_calls_minutes             |int  |maxCallTimeForAnsweredCallsMinutes              |
|use_max_call_time_for_unanswered_calls               |bool |useMaxCallTimeForUnansweredCalls                |
|max_call_time_for_unanswered_calls_minutes           |int  |maxCallTimeForUnansweredCallsMinutes            |
|media_policy_selection                               |str  |mediaPolicySelection                            |
|supported_media_set_name                             |str  |supportedMediaSetName *Optional*                |
|network_usage_selection                              |str  |networkUsageSelection                           |
|enforce_group_calling_line_identity_restriction      |bool |enforceGroupCallingLineIdentityRestriction      |
|enforce_enterprise_calling_line_identity_restriction |bool |enforceEnterpriseCallingLineIdentityRestriction |
|conference_uri                                       |str  |conferenceURI *Optional*                        |
|max_conference_parties                               |int  |maxConferenceParties                            |
</div>


## `SystemCallProcessingGetPolicyResponse14sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest14sp1()`.


**Attributes:**

|Name                                                 |Type |Description                                     |
|-----------------------------------------------------|-----|------------------------------------------------|
|use_max_simultaneous_calls                           |bool |useMaxSimultaneousCalls                         |
|max_simultaneous_calls                               |int  |maxSimultaneousCalls                            |
|use_max_simultaneous_video_calls                     |bool |useMaxSimultaneousVideoCalls                    |
|max_simultaneous_video_calls                         |int  |maxSimultaneousVideoCalls                       |
|use_max_call_time_for_answered_calls                 |bool |useMaxCallTimeForAnsweredCalls                  |
|max_call_time_for_answered_calls_minutes             |int  |maxCallTimeForAnsweredCallsMinutes              |
|use_max_call_time_for_unanswered_calls               |bool |useMaxCallTimeForUnansweredCalls                |
|max_call_time_for_unanswered_calls_minutes           |int  |maxCallTimeForUnansweredCallsMinutes            |
|media_policy_selection                               |str  |mediaPolicySelection                            |
|supported_media_set_name                             |str  |supportedMediaSetName *Optional*                |
|network_usage_selection                              |str  |networkUsageSelection                           |
|enforce_group_calling_line_identity_restriction      |bool |enforceGroupCallingLineIdentityRestriction      |
|enforce_enterprise_calling_line_identity_restriction |bool |enforceEnterpriseCallingLineIdentityRestriction |
|conference_uri                                       |str  |conferenceURI *Optional*                        |
|max_conference_parties                               |int  |maxConferenceParties                            |
|use_max_concurrent_redirected_calls                  |bool |useMaxConcurrentRedirectedCalls                 |
|max_concurrent_redirected_calls                      |int  |maxConcurrentRedirectedCalls                    |
|use_max_find_me_follow_me_depth                      |bool |useMaxFindMeFollowMeDepth                       |
|max_find_me_follow_me_depth                          |int  |maxFindMeFollowMeDepth                          |
|max_redirection_depth                                |int  |maxRedirectionDepth                             |
|use_max_concurrent_find_me_follow_me_invocations     |bool |useMaxConcurrentFindMeFollowMeInvocations       |
|max_concurrent_find_me_follow_me_invocations         |int  |maxConcurrentFindMeFollowMeInvocations          |
</div>


## `SystemCallProcessingGetPolicyResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest14sp4()`.

Replaced By : `SystemCallProcessingGetPolicyResponse15()`

**Attributes:**

|Name                                                                  |Type |Description                                                  |
|----------------------------------------------------------------------|-----|-------------------------------------------------------------|
|use_max_simultaneous_calls                                            |bool |useMaxSimultaneousCalls                                      |
|max_simultaneous_calls                                                |int  |maxSimultaneousCalls                                         |
|use_max_simultaneous_video_calls                                      |bool |useMaxSimultaneousVideoCalls                                 |
|max_simultaneous_video_calls                                          |int  |maxSimultaneousVideoCalls                                    |
|use_max_call_time_for_answered_calls                                  |bool |useMaxCallTimeForAnsweredCalls                               |
|max_call_time_for_answered_calls_minutes                              |int  |maxCallTimeForAnsweredCallsMinutes                           |
|use_max_call_time_for_unanswered_calls                                |bool |useMaxCallTimeForUnansweredCalls                             |
|max_call_time_for_unanswered_calls_minutes                            |int  |maxCallTimeForUnansweredCallsMinutes                         |
|media_policy_selection                                                |str  |mediaPolicySelection                                         |
|supported_media_set_name                                              |str  |supportedMediaSetName *Optional*                             |
|network_usage_selection                                               |str  |networkUsageSelection                                        |
|enforce_group_calling_line_identity_restriction                       |bool |enforceGroupCallingLineIdentityRestriction                   |
|enforce_enterprise_calling_line_identity_restriction                  |bool |enforceEnterpriseCallingLineIdentityRestriction              |
|allow_enterprise_group_call_typing_for_private_dialing_plan           |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan          |
|allow_enterprise_group_call_typing_for_public_dialing_plan            |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan           |
|override_clid_restriction_for_external_calls_via_private_dialing_plan |bool |overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan |
|enable_enterprise_extension_dialing                                   |bool |enableEnterpriseExtensionDialing                             |
|conference_uri                                                        |str  |conferenceURI *Optional*                                     |
|max_conference_parties                                                |int  |maxConferenceParties                                         |
|use_max_concurrent_redirected_calls                                   |bool |useMaxConcurrentRedirectedCalls                              |
|max_concurrent_redirected_calls                                       |int  |maxConcurrentRedirectedCalls                                 |
|use_max_find_me_follow_me_depth                                       |bool |useMaxFindMeFollowMeDepth                                    |
|max_find_me_follow_me_depth                                           |int  |maxFindMeFollowMeDepth                                       |
|max_redirection_depth                                                 |int  |maxRedirectionDepth                                          |
|use_max_concurrent_find_me_follow_me_invocations                      |bool |useMaxConcurrentFindMeFollowMeInvocations                    |
|max_concurrent_find_me_follow_me_invocations                          |int  |maxConcurrentFindMeFollowMeInvocations                       |
</div>


## `SystemCallProcessingGetPolicyResponse14sp7`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest14sp7()`.


**Attributes:**

|Name                                                                  |Type |Description                                                  |
|----------------------------------------------------------------------|-----|-------------------------------------------------------------|
|use_max_simultaneous_calls                                            |bool |useMaxSimultaneousCalls                                      |
|max_simultaneous_calls                                                |int  |maxSimultaneousCalls                                         |
|use_max_simultaneous_video_calls                                      |bool |useMaxSimultaneousVideoCalls                                 |
|max_simultaneous_video_calls                                          |int  |maxSimultaneousVideoCalls                                    |
|use_max_call_time_for_answered_calls                                  |bool |useMaxCallTimeForAnsweredCalls                               |
|max_call_time_for_answered_calls_minutes                              |int  |maxCallTimeForAnsweredCallsMinutes                           |
|use_max_call_time_for_unanswered_calls                                |bool |useMaxCallTimeForUnansweredCalls                             |
|max_call_time_for_unanswered_calls_minutes                            |int  |maxCallTimeForUnansweredCallsMinutes                         |
|media_policy_selection                                                |str  |mediaPolicySelection                                         |
|supported_media_set_name                                              |str  |supportedMediaSetName *Optional*                             |
|network_usage_selection                                               |str  |networkUsageSelection                                        |
|enforce_group_calling_line_identity_restriction                       |bool |enforceGroupCallingLineIdentityRestriction                   |
|enforce_enterprise_calling_line_identity_restriction                  |bool |enforceEnterpriseCallingLineIdentityRestriction              |
|allow_enterprise_group_call_typing_for_private_dialing_plan           |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan          |
|allow_enterprise_group_call_typing_for_public_dialing_plan            |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan           |
|override_clid_restriction_for_external_calls_via_private_dialing_plan |bool |overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan |
|enable_enterprise_extension_dialing                                   |bool |enableEnterpriseExtensionDialing                             |
|conference_uri                                                        |str  |conferenceURI *Optional*                                     |
|max_conference_parties                                                |int  |maxConferenceParties                                         |
|use_max_concurrent_redirected_calls                                   |bool |useMaxConcurrentRedirectedCalls                              |
|max_concurrent_redirected_calls                                       |int  |maxConcurrentRedirectedCalls                                 |
|use_max_find_me_follow_me_depth                                       |bool |useMaxFindMeFollowMeDepth                                    |
|max_find_me_follow_me_depth                                           |int  |maxFindMeFollowMeDepth                                       |
|max_redirection_depth                                                 |int  |maxRedirectionDepth                                          |
|use_max_concurrent_find_me_follow_me_invocations                      |bool |useMaxConcurrentFindMeFollowMeInvocations                    |
|max_concurrent_find_me_follow_me_invocations                          |int  |maxConcurrentFindMeFollowMeInvocations                       |
|clid_policy                                                           |str  |clidPolicy                                                   |
|emergency_clid_policy                                                 |str  |emergencyClidPolicy                                          |
|allow_alternate_numbers_for_redirecting_identity                      |bool |allowAlternateNumbersForRedirectingIdentity                  |
</div>


## `SystemCallProcessingGetPolicyResponse15`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest15()`.


**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|max_conference_parties                                      |int  |maxConferenceParties                                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
</div>


## `SystemCallProcessingGetPolicyResponse15sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest15sp2()`.


**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|max_conference_parties                                      |int  |maxConferenceParties                                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
</div>


## `SystemCallProcessingGetPolicyResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest16()`.


**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|max_conference_parties                                      |int  |maxConferenceParties                                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
</div>


## `SystemCallProcessingGetPolicyResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest16sp2()`.


**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|max_conference_parties                                      |int  |maxConferenceParties                                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `SystemCallProcessingGetPolicyResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest17()`.


**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|max_conference_parties                                      |int  |maxConferenceParties                                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
</div>


## `SystemCallProcessingGetPolicyResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest17sp3()`.

The following elements are only used in AS data mode: enableDialableCallerID Replaced
by: `SystemCallProcessingGetPolicyResponse17sp4()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|max_conference_parties                                      |int  |maxConferenceParties                                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `SystemCallProcessingGetPolicyResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest17sp4()`.

The following elements are only used in AS data mode: enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity

Replaced By : `SystemCallProcessingGetPolicyResponse18sp1()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|max_conference_parties                                      |int  |maxConferenceParties                                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
</div>


## `SystemCallProcessingGetPolicyResponse18sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest18sp1()`.

The following elements are only used in AS data: enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity enterpriseCallsCLIDPolicy, value "Use
Location Code plus Extension" is returned in XS data mode.
enterpriseGroupCallsCLIDPolicy value "Use Extension" is returned in XS data mode.
serviceProviderGroupCallsCLIDPolicy value "Use Extension" is returned in XS data mode.
Replaced by: `SystemCallProcessingGetPolicyResponse19sp1()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|max_conference_parties                                      |int  |maxConferenceParties                                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
</div>


## `SystemCallProcessingGetPolicyResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest19sp1()`.

The following elements are only used in AS data mode : enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity enterpriseCallsCLIDPolicy, value "Use
Location Code plus Extension" is returned in XS data mode.
enterpriseGroupCallsCLIDPolicy value "Use Extension" is returned in XS data mode.
serviceProviderGroupCallsCLIDPolicy value "Use Extension" is returned in XS data mode.
Replaced by: `SystemCallProcessingGetPolicyResponse21sp1()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|max_conference_parties                                      |int  |maxConferenceParties                                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
</div>


## `SystemCallProcessingGetPolicyResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest21sp1()`.

The following elements are only used in AS data mode : enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity enterpriseCallsCLIDPolicy, value "Use
Location Code plus Extension" is returned in XS data mode.
enterpriseGroupCallsCLIDPolicy value "Use Extension" is returned in XS data mode.
serviceProviderGroupCallsCLIDPolicy value "Use Extension" is returned in XS data mode.
enablePhoneListLookup value "false" is returned in XS data mode.  Replaced by:
`SystemCallProcessingGetPolicyResponse21sp2()`.

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|max_conference_parties                                      |int  |maxConferenceParties                                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|enable_phone_list_lookup                                    |bool |enablePhoneListLookup                               |
</div>


## `SystemCallProcessingGetPolicyResponse21sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest21sp2()`.

The following elements are only used in AS data mode: enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity enterpriseCallsCLIDPolicy, value "Use
Location Code plus Extension" is returned in XS data mode.
enterpriseGroupCallsCLIDPolicy value "Use Location" is returned in XS data mode.
serviceProviderGroupCallsCLIDPolicy value "Use Location" is returned in XS data mode.
enablePhoneListLookup value "false" is returned in XS data mode.  The following
elements are only used in XS data mode and not returned in AS data mode:
routeOverrideDomain routeOverridePrefix Replaced by:
`SystemCallProcessingGetPolicyResponse22()` in AS data mode.

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|conference_uri                                              |str  |conferenceURI *Optional*                            |
|max_conference_parties                                      |int  |maxConferenceParties                                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|enable_phone_list_lookup                                    |bool |enablePhoneListLookup                               |
|route_override_domain                                       |str  |routeOverrideDomain *Optional*                      |
|route_override_prefix                                       |str  |routeOverridePrefix *Optional*                      |
</div>


## `SystemCallProcessingGetPolicyResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest22()`.

The following elements are only used in AS data mode: enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity enterpriseCallsCLIDPolicy, value "Use
Location Code plus Extension" is returned in XS data mode.
enterpriseGroupCallsCLIDPolicy, value "Use Location" is returned in XS data mode.
serviceProviderGroupCallsCLIDPolicy, value "Use Location" is returned in XS data mode.
enablePhoneListLookup, value "false" is returned in XS data mode.
useMaxConcurrentTerminatingAlertingRequests, value "false" is returned in XS data
mode.  maxConcurrentTerminatingAlertingRequests, value "10" is returned in XS data
mode.  delayTimerToRemoveCancelledCallsInSeconds, value "4" is returned in XS data
mode.  includeRedirectionsInMaximumNumberOfConcurrentCalls, value "false" is returned
in XS data mode.  useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable, value
"false" is returned in XS data mode.
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable, value "false" is
returned in XS data mode.  The following elements are only used in XS data mode and
not returned in AS data mode: routeOverrideDomain routeOverridePrefix Replaced by:
`SystemCallProcessingGetPolicyResponse22V2()` in AS data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|conference_uri                                                            |str  |conferenceURI *Optional*                                        |
|max_conference_parties                                                    |int  |maxConferenceParties                                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|delay_timer_to_remove_cancelled_calls_in_seconds                          |int  |delayTimerToRemoveCancelledCallsInSeconds                       |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                  |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                  |
</div>


## `SystemCallProcessingGetPolicyResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest22V2()`.

The following elements are only used in AS data mode: enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity enterpriseCallsCLIDPolicy, value "Use
Location Code plus Extension" is returned in XS data mode.
enterpriseGroupCallsCLIDPolicy, value "Use Location" is returned in XS data mode.
serviceProviderGroupCallsCLIDPolicy, value "Use Location" is returned in XS data mode.
enablePhoneListLookup, value "false" is returned in XS data mode.
useMaxConcurrentTerminatingAlertingRequests, value "false" is returned in XS data
mode.  maxConcurrentTerminatingAlertingRequests, value "10" is returned in XS data
mode.  delayTimerToRemoveCancelledCallsInSeconds, value "4" is returned in XS data
mode.  includeRedirectionsInMaximumNumberOfConcurrentCalls, value "false" is returned
in XS data mode.  useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable, value
"false" is returned in XS data mode.
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable, value "false" is
returned in XS data mode.  allowMobileDNForRedirectingIdentity, value "false" is
returned in XS data mode.  The following elements are only used in XS data mode and
not returned in AS data mode: routeOverrideDomain routeOverridePrefix Replaced by:
`SystemCallProcessingGetPolicyResponse23()` in AS data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|conference_uri                                                            |str  |conferenceURI *Optional*                                        |
|max_conference_parties                                                    |int  |maxConferenceParties                                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|delay_timer_to_remove_cancelled_calls_in_seconds                          |int  |delayTimerToRemoveCancelledCallsInSeconds                       |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                  |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                  |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity                             |
</div>


## `SystemCallProcessingGetPolicyResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest22V3()`.

The following elements are only used in AS data mode: enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity enterpriseCallsCLIDPolicy, value "Use
Location Code plus Extension" is returned in XS data mode.
enterpriseGroupCallsCLIDPolicy, value "Use Location" is returned in XS data mode.
serviceProviderGroupCallsCLIDPolicy, value "Use Location" is returned in XS data mode.
enablePhoneListLookup, value "false" is returned in XS data mode.
useMaxConcurrentTerminatingAlertingRequests, value "false" is returned in XS data
mode.  maxConcurrentTerminatingAlertingRequests, value "10" is returned in XS data
mode.  delayTimerToRemoveCancelledCallsInSeconds, value "4" is returned in XS data
mode.  includeRedirectionsInMaximumNumberOfConcurrentCalls, value "false" is returned
in XS data mode.  useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable, value
"false" is returned in XS data mode.
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable, value "false" is
returned in XS data mode.  allowMobileDNForRedirectingIdentity, value "false" is
returned in XS data mode.  useMaxCallsPerSecond, value "false" is returned in XS data
mode.  maxCallsPerSecond, value "1" is returned in XS data mode.  The following
elements are only used in XS data mode and not returned in AS data mode:
routeOverrideDomain routeOverridePrefix Replaced by:
`SystemCallProcessingGetPolicyResponse23V2()` in AS data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|conference_uri                                                            |str  |conferenceURI *Optional*                                        |
|max_conference_parties                                                    |int  |maxConferenceParties                                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|delay_timer_to_remove_cancelled_calls_in_seconds                          |int  |delayTimerToRemoveCancelledCallsInSeconds                       |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                  |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                  |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity                             |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallProcessingGetPolicyResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest23()`.

The following elements are only used in AS data mode: enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity enterpriseCallsCLIDPolicy, value "Use
Location Code plus Extension" is returned in XS data mode.
enterpriseGroupCallsCLIDPolicy, value "Use Location" is returned in XS data mode.
serviceProviderGroupCallsCLIDPolicy, value "Use Location" is returned in XS data mode.
enablePhoneListLookup, value "false" is returned in XS data mode.
useMaxConcurrentTerminatingAlertingRequests, value "false" is returned in XS data
mode.  maxConcurrentTerminatingAlertingRequests, value "10" is returned in XS data
mode.  delayTimerToRemoveCancelledCallsInSeconds, value "4" is returned in XS data
mode.  includeRedirectionsInMaximumNumberOfConcurrentCalls, value "false" is returned
in XS data mode.  useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable, value
"false" is returned in XS data mode.
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable, value "false" is
returned in XS data mode.  allowMobileDNForRedirectingIdentity, value "false" is
returned in XS data mode.  conferenceDisableClampTones, value "false" is returned in
XS data mode.  The following elements are only used in XS data mode and not returned
in AS data mode: routeOverrideDomain routeOverridePrefix Replaced by:
`SystemCallProcessingGetPolicyResponse23V2()` in AS data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|conference_uri                                                            |str  |conferenceURI *Optional*                                        |
|max_conference_parties                                                    |int  |maxConferenceParties                                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|delay_timer_to_remove_cancelled_calls_in_seconds                          |int  |delayTimerToRemoveCancelledCallsInSeconds                       |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                  |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                  |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity                             |
|conference_disable_clamp_tones                                            |bool |conferenceDisableClampTones                                     |
</div>


## `SystemCallProcessingGetPolicyResponse23V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingGetPolicyRequest23V2()`.

The following elements are only used in AS data mode: enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity enterpriseCallsCLIDPolicy, value "Use
Location Code plus Extension" is returned in XS data mode.
enterpriseGroupCallsCLIDPolicy, value "Use Location" is returned in XS data mode.
serviceProviderGroupCallsCLIDPolicy, value "Use Location" is returned in XS data mode.
enablePhoneListLookup, value "false" is returned in XS data mode.
useMaxConcurrentTerminatingAlertingRequests, value "false" is returned in XS data
mode.  maxConcurrentTerminatingAlertingRequests, value "10" is returned in XS data
mode.  delayTimerToRemoveCancelledCallsInSeconds, value "4" is returned in XS data
mode.  includeRedirectionsInMaximumNumberOfConcurrentCalls, value "false" is returned
in XS data mode.  useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable, value
"false" is returned in XS data mode.
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable, value "false" is
returned in XS data mode.  allowMobileDNForRedirectingIdentity, value "false" is
returned in XS data mode.  conferenceDisableClampTones, value "false" is returned in
XS data mode.  useMaxCallsPerSecond, value "false" is returned in XS data mode.
maxCallsPerSecond, value "1" is returned in XS data mode.  The following elements are
only used in XS data mode and not returned in AS data mode: routeOverrideDomain
routeOverridePrefix

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|conference_uri                                                            |str  |conferenceURI *Optional*                                        |
|max_conference_parties                                                    |int  |maxConferenceParties                                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|delay_timer_to_remove_cancelled_calls_in_seconds                          |int  |delayTimerToRemoveCancelledCallsInSeconds                       |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                  |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                  |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity                             |
|conference_disable_clamp_tones                                            |bool |conferenceDisableClampTones                                     |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallProcessingPolicyProfileAutoAttendantProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileAutoAttendantProfileGetRequest()`.

Replaced by: `SystemCallProcessingPolicyProfileAutoAttendantProfileGetRequest22()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|use_incoming_clid_policy                                    |bool |useIncomingCLIDPolicy                               |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `SystemCallProcessingPolicyProfileAutoAttendantProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileAutoAttendantProfileGetRequest22()`.

Replaced by: `SystemCallProcessingPolicyProfileAutoAttendantProfileGetResponse22V2()`
in AS data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileAutoAttendantProfileGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileAutoAttendantProfileGetRequest22V2()`.

The following elements are only used in AS data mode: useMaxCallsPerSecond, value
"false" is returned in XS data mode.  maxCallsPerSecond, value "1" is returned in XS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetRequest()`.

Replaced by:
`SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetResponse22()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|use_incoming_clid_policy                                    |bool |useIncomingCLIDPolicy                               |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetRequest22()`.

Replaced by:
`SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetResponse22V2()` in AS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetRequest22V2()`.

The following elements are only used in AS data mode: useMaxCallsPerSecond, value
"false" is returned in XS data mode.  maxCallsPerSecond, value "1" is returned in XS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallProcessingPolicyProfileCallCenterProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileCallCenterProfileGetRequest()`.

Replaced by: `SystemCallProcessingPolicyProfileCallCenterProfileGetResponse22()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_incoming_clid_policy                                    |bool |useIncomingCLIDPolicy                               |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `SystemCallProcessingPolicyProfileCallCenterProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileCallCenterProfileGetRequest22()`.

Replaced by: `SystemCallProcessingPolicyProfileCallCenterProfileGetResponse22V2()` in
AS data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileCallCenterProfileGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileCallCenterProfileGetRequest22V2()`.

The following elements are only used in AS data mode: useMaxCallsPerSecond, value
"false" is returned in XS data mode.  maxCallsPerSecond, value "1" is returned in XS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallProcessingPolicyProfileCollaborateProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileCollaborateProfileGetRequest()`.

Replaced by: `SystemCallProcessingPolicyProfileCollaborateProfileGetResponse22()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|use_incoming_clid_policy                                    |bool |useIncomingCLIDPolicy                               |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `SystemCallProcessingPolicyProfileCollaborateProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileCollaborateProfileGetRequest22()`.

Replaced by: `SystemCallProcessingPolicyProfileCollaborateProfileGetResponse22V2()` in
AS data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileCollaborateProfileGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileCollaborateProfileGetRequest22V2()`.

The following elements are only used in AS data mode: useMaxCallsPerSecond, value
"false" is returned in XS data mode.  maxCallsPerSecond, value "1" is returned in XS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetRequest()`.

Replaced by: `SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetResponse22()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_incoming_clid_policy                                    |bool |useIncomingCLIDPolicy                               |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetRequest22()`.

Replaced by: `SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetResponse22V2()`
in AS data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetRequest22V2()`.

The following elements are only used in AS data mode: useMaxCallsPerSecond, value
"false" is returned in XS data mode.  maxCallsPerSecond, value "1" is returned in XS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetRequest()`.

Replaced by:
`SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetResponse22()`

**Attributes:**

|Name                                                        |Type |Description                                            |
|------------------------------------------------------------|-----|-------------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                          |
|clid_policy                                                 |str  |clidPolicy                                             |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                    |
|use_group_name                                              |bool |useGroupName                                           |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                       |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity *Optional* |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                        |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                              |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                         |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                    |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                    |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                                |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                   |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                           |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                              |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                         |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                     |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                       |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                   |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                            |
|network_usage_selection                                     |str  |networkUsageSelection                                  |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                       |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction             |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction        |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan    |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan     |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory          |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory                |
</div>


## `SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetRequest22()`.

Replaced by:
`SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetResponse22V2()`

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*          |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetRequest22V2()`.

The following elements are only used in AS data mode: useMaxCallsPerSecond, value
"false" is returned in XS data mode.  maxCallsPerSecond, value "1" is returned in XS
data mode

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*          |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallProcessingPolicyProfileGetAssignedNCOSListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCallProcessingPolicyProfileGetAssignedNCOSListRequest()`.

The response contains a table of all Network Classes of Service that contain the
specific CAllP Policy Profile.  The column headings are "Name" and "Description".

**Attributes:**

|Name                           |Type                             |Description                                                                           |
|-------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|network_class_of_service_table |List(networkClassOfServiceTable) |networkClassOfServiceTable - *Table* array of networkClassOfServiceTable named tuples |
</div>


## `SystemCallProcessingPolicyProfileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCallProcessingPolicyProfileGetListRequest()`.

The response contains a table of all Call Processing Policy Profiles in the system.
The column headings are "Name" and "Description".

**Attributes:**

|Name                                  |Type                                    |Description                                                                                         |
|--------------------------------------|----------------------------------------|----------------------------------------------------------------------------------------------------|
|call_processing_policy_profiles_table |List(callProcessingPolicyProfilesTable) |callProcessingPolicyProfilesTable - *Table* array of callProcessingPolicyProfilesTable named tuples |
</div>


## `SystemCallProcessingPolicyProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemCallProcessingPolicyProfileGetRequest()`.


**Attributes:**

|Name                     |Type      |Description                       |
|-------------------------|----------|----------------------------------|
|description              |str       |description *Optional*            |
|assigned_subscriber_type |List[str] |assignedSubscriberType *Optional* |
</div>


## `SystemCallProcessingPolicyProfileGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemCallProcessingPolicyProfileGetRequest20()`.


**Attributes:**

|Name                     |Type      |Description                       |
|-------------------------|----------|----------------------------------|
|description              |str       |description *Optional*            |
|assigned_subscriber_type |List[str] |assignedSubscriberType *Optional* |
</div>


## `SystemCallProcessingPolicyProfileGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemCallProcessingPolicyProfileGetRequest21()`.


**Attributes:**

|Name                     |Type      |Description                       |
|-------------------------|----------|----------------------------------|
|description              |str       |description *Optional*            |
|assigned_subscriber_type |List[str] |assignedSubscriberType *Optional* |
</div>


## `SystemCallProcessingPolicyProfileGroupPagingProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileGroupPagingProfileGetRequest()`.

Replaced by: `SystemCallProcessingPolicyProfileGroupPagingProfileGetResponse22()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
</div>


## `SystemCallProcessingPolicyProfileGroupPagingProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileGroupPagingProfileGetRequest22()`.


**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileHuntGroupProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileHuntGroupProfileGetRequest()`.

Replaced by: `SystemCallProcessingPolicyProfileHuntGroupProfileGetResponse22()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_incoming_clid_policy                                    |bool |useIncomingCLIDPolicy                               |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `SystemCallProcessingPolicyProfileHuntGroupProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileHuntGroupProfileGetRequest22()`.

Replaced by: `SystemCallProcessingPolicyProfileHuntGroupProfileGetResponse22V2()`.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileHuntGroupProfileGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileHuntGroupProfileGetRequest22V2()`.

The following elements are only used in AS data mode: useMaxCallsPerSecond, value
"false" is returned in XS data mode.  maxCallsPerSecond, value "1" is returned in XS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallProcessingPolicyProfileInstantGroupCallProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileInstantGroupCallProfileGetRequest22()`.

`SystemCallProcessingPolicyProfileInstantGroupCallProfileGetResponse22()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
</div>


## `SystemCallProcessingPolicyProfileInstantGroupCallProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileInstantGroupCallProfileGetRequest22()`.


**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetRequest()`.

Replaced by:
`SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetResponse22()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|use_incoming_clid_policy                                    |bool |useIncomingCLIDPolicy                               |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetRequest22()`.

Replaced by:
`SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetResponse22V2()`.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to
`SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetRequest22V2()`.

The following elements are only used in AS data mode: useMaxCallsPerSecond, value
"false" is returned in XS data mode.  maxCallsPerSecond, value "1" is returned in XS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallProcessingPolicyProfileRoutePointProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileRoutePointProfileGetRequest()`.

Replaced by: `SystemCallProcessingPolicyProfileRoutePointProfileGetResponse22()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|use_incoming_clid_policy                                    |bool |useIncomingCLIDPolicy                               |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `SystemCallProcessingPolicyProfileRoutePointProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileRoutePointProfileGetRequest22()`.

Replaced by: `SystemCallProcessingPolicyProfileRoutePointProfileGetResponse22V2()`

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileRoutePointProfileGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileRoutePointProfileGetRequest22V2()`.

The following elements are only used in AS data mode: useMaxCallsPerSecond, value
"false" is returned in XS data mode.  maxCallsPerSecond, value "1" is returned in XS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetRequest()`.

Replaced by: `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetResponse22()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_media_policy                                            |bool |useMediaPolicy                                      |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|use_incoming_clid_policy                                    |bool |useIncomingCLIDPolicy                               |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetRequest22()`.

Replaced by:
`SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetResponse22V2()` in AS data
mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_media_policy                                                          |bool |useMediaPolicy                                                  |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetRequest22V2()`.

Replaced by:
`SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetResponse22V3()` in AS data
mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_media_policy                                                          |bool |useMediaPolicy                                                  |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity                             |
</div>


## `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetRequest22V3()`.

The following elements are only used in AS data mode: useMaxCallsPerSecond, value
"false" is returned in XS data mode.  maxCallsPerSecond, value "1" is returned in XS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_media_policy                                                          |bool |useMediaPolicy                                                  |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity                             |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallProcessingPolicyProfileUserProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileUserProfileGetRequest()`.

Replaced by: `SystemCallProcessingPolicyProfileUserProfileGetResponse21sp1()` in AS
data mode

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_media_policy                                            |bool |useMediaPolicy                                      |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|use_incoming_clid_policy                                    |bool |useIncomingCLIDPolicy                               |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `SystemCallProcessingPolicyProfileUserProfileGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileUserProfileGetRequest21sp1()`.

Replaced by: `SystemCallProcessingPolicyProfileUserProfileGetResponse22()` in AS data
mode

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_media_policy                                            |bool |useMediaPolicy                                      |
|media_policy_selection                                      |str  |mediaPolicySelection                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                    |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations              |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|use_incoming_clid_policy                                    |bool |useIncomingCLIDPolicy                               |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
|use_phone_list_lookup_policy                                |bool |usePhoneListLookupPolicy                            |
|enable_phone_list_lookup                                    |bool |enablePhoneListLookup                               |
</div>


## `SystemCallProcessingPolicyProfileUserProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileUserProfileGetRequest22()`.

Replaced by: `SystemCallProcessingPolicyProfileUserProfileGetResponse22V2()` in AS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_media_policy                                                          |bool |useMediaPolicy                                                  |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|use_phone_list_lookup_policy                                              |bool |usePhoneListLookupPolicy                                        |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileUserProfileGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileUserProfileGetRequest22V2()`.

Replaced by: `SystemCallProcessingPolicyProfileUserProfileGetRequest22V2()` in AS data
mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_media_policy                                                          |bool |useMediaPolicy                                                  |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|use_phone_list_lookup_policy                                              |bool |usePhoneListLookupPolicy                                        |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity                             |
</div>


## `SystemCallProcessingPolicyProfileUserProfileGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileUserProfileGetRequest22V3()`.

The following elements are only used in AS data mode: useMaxCallsPerSecond, value
"false" is returned in XS data mode.  maxCallsPerSecond, value "1" is returned in XS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_media_policy                                                          |bool |useMediaPolicy                                                  |
|media_policy_selection                                                    |str  |mediaPolicySelection                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|use_phone_list_lookup_policy                                              |bool |usePhoneListLookupPolicy                                        |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity                             |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallProcessingPolicyProfileVoicePortalProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileVoicePortalProfileGetRequest()`.

Replaced by: `SystemCallProcessingPolicyProfileVoicePortalProfileGetResponse22()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
</div>


## `SystemCallProcessingPolicyProfileVoicePortalProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileVoicePortalProfileGetRequest22()`.

Replaced by: `SystemCallProcessingPolicyProfileVoicePortalProfileGetResponse22V2()`.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileVoicePortalProfileGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileVoicePortalProfileGetRequest22V2()`.

The following elements are only used in AS data mode: useMaxCallsPerSecond, value
"false" is returned in XS data mode.  maxCallsPerSecond, value "1" is returned in XS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                 |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                    |
</div>


## `SystemCallProcessingPolicyProfileVoiceXMLProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileVoiceXMLProfileGetRequest()`.

Replaced by: `SystemCallProcessingPolicyProfileVoiceXMLProfileGetResponse22()`

**Attributes:**

|Name                                                        |Type |Description                                         |
|------------------------------------------------------------|-----|----------------------------------------------------|
|use_clid_policy                                             |bool |useCLIDPolicy                                       |
|clid_policy                                                 |str  |clidPolicy                                          |
|emergency_clid_policy                                       |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity            |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                              |bool |useGroupName                                        |
|block_calling_name_for_external_calls                       |bool |blockCallingNameForExternalCalls                    |
|allow_configurable_clid_for_redirecting_identity            |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                         |bool |allowDepartmentCLIDNameOverride                     |
|enterprise_calls_clid_policy                                |str  |enterpriseCallsCLIDPolicy                           |
|enterprise_group_calls_clid_policy                          |str  |enterpriseGroupCallsCLIDPolicy                      |
|service_provider_group_calls_clid_policy                    |str  |serviceProviderGroupCallsCLIDPolicy                 |
|use_call_limits_policy                                      |bool |useCallLimitsPolicy                                 |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes                |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls                        |
|max_redirection_depth                                       |int  |maxRedirectionDepth                                 |
|use_translation_routing_policy                              |bool |useTranslationRoutingPolicy                         |
|network_usage_selection                                     |str  |networkUsageSelection                               |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing                    |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction          |
|enforce_enterprise_calling_line_identity_restriction        |bool |enforceEnterpriseCallingLineIdentityRestriction     |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory             |
|use_incoming_clid_policy                                    |bool |useIncomingCLIDPolicy                               |
|enable_dialable_caller_id                                   |bool |enableDialableCallerID                              |
</div>


## `SystemCallProcessingPolicyProfileVoiceXMLProfileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileVoiceXMLProfileGetRequest22()`.

Replaced by: `SystemCallProcessingPolicyProfileVoiceXMLProfileGetResponse22V2()`.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
</div>


## `SystemCallProcessingPolicyProfileVoiceXMLProfileGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallProcessingPolicyProfileVoiceXMLProfileGetRequest22V2()`.

The following elements are only used in AS data mode: useMaxCallsPerSecond, value
"false" is returned in XS data mode.  maxCallsPerSecond, value "1" is returned in XS
data mode.

**Attributes:**

|Name                                                                      |Type |Description                                                     |
|--------------------------------------------------------------------------|-----|----------------------------------------------------------------|
|use_clid_policy                                                           |bool |useCLIDPolicy                                                   |
|clid_policy                                                               |str  |clidPolicy                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity                     |
|use_group_name                                                            |bool |useGroupName                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy                                     |
|network_usage_selection                                                   |str  |networkUsageSelection                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond                                               |
</div>


## `SystemCallRecordingGetPlatformListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallRecordingGetPlatformListRequest()`.

Contains the default system Call Recording platform and a table with columns headings
"Name", "Net Address", "Port", "Transport Type", "Media Stream", "Description",
"Schema Version", "Support Video Rec". The system default recording platform also
appears in the table with the other platforms.  The possible values for "Support Video
Rec" can be either true or false.  Schema version values include: 1.0, 2.0, 3.0
Replaced by: `SystemCallRecordingGetPlatformListResponse20sp1()` in AS data mode

**Attributes:**

|Name                          |Type                             |Description                                                                           |
|------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|system_default                |str                              |systemDefault *Optional*                                                              |
|call_recording_platform_table |List(callRecordingPlatformTable) |callRecordingPlatformTable - *Table* array of callRecordingPlatformTable named tuples |
</div>


## `SystemCallRecordingGetPlatformListResponse20sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallRecordingGetPlatformListRequest20sp1()`.

Contains the default system Call Recording platform and a table with columns headings
"Name", "Net Address", "Port", "Transport Type", "Media Stream", "Description",
"Schema Version", "Support Video Rec". The system default recording platform also
appears in the table with the other platforms.  The port can be empty if it is not
defined in the recording platform.  The possible values for "Support Video Rec" can be
either true or false.  Schema version values include: 1.0, 2.0, 3.0 Replaced by
`SystemCallRecordingGetPlatformListResponse22()` in AS data mode.

**Attributes:**

|Name                          |Type                             |Description                                                                           |
|------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|system_default                |str                              |systemDefault *Optional*                                                              |
|call_recording_platform_table |List(callRecordingPlatformTable) |callRecordingPlatformTable - *Table* array of callRecordingPlatformTable named tuples |
</div>


## `SystemCallRecordingGetPlatformListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallRecordingGetPlatformListRequest22()`.

Contains the default system Call Recording platform, default reseller Call Recording
Platform (when applicable) and a table with columns headings "Name", "Net Address",
"Port", "Transport Type", "Media Stream", "Description", "Schema Version", "Support
Video Rec", "Reseller Id". The system default recording platform also appears in the
table with the other platforms.  The port can be empty if it is not defined in the
recording platform.  The possible values for "Support Video Rec" can be either true or
false.  Schema version values include: 1.0, 2.0, 3.0 Replaced by:
`SystemCallRecordingGetPlatformListResponse22V2()`

**Attributes:**

|Name                          |Type                             |Description                                                                           |
|------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|system_default                |str                              |systemDefault *Optional*                                                              |
|reseller_default              |str                              |resellerDefault *Optional*                                                            |
|call_recording_platform_table |List(callRecordingPlatformTable) |callRecordingPlatformTable - *Table* array of callRecordingPlatformTable named tuples |
</div>


## `SystemCallRecordingGetPlatformListResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallRecordingGetPlatformListRequest22V2()`.

Contains the default system Call Recording platform, default reseller Call Recording
Platform (when applicable) and a table with columns headings "Name", "Net Address",
"Port", "Transport Type", "Media Stream", "Description", "Schema Version", "Support
Video Rec", "Reseller Id", "Route". The system default recording platform also appears
in the table with the other platforms.  The port can be empty if it is not defined in
the recording platform.  The possible values for "Support Video Rec" can be either
true or false.  Schema version values include: 1.0, 2.0, 3.0

**Attributes:**

|Name                          |Type                             |Description                                                                           |
|------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|system_default                |str                              |systemDefault *Optional*                                                              |
|reseller_default              |str                              |resellerDefault *Optional*                                                            |
|call_recording_platform_table |List(callRecordingPlatformTable) |callRecordingPlatformTable - *Table* array of callRecordingPlatformTable named tuples |
</div>


## `SystemCallRecordingGetPlatformUsageResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallRecordingGetPlatformUsageRequest()`.

The response contains a table with columns headings "Service Provider Id", "Group Id".
Replaced by `SystemCallRecordingGetPlatformUsageResponse22()` in AS data mode.

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|group_table |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
</div>


## `SystemCallRecordingGetPlatformUsageResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallRecordingGetPlatformUsageRequest()`.

The response contains a table with columns headings "Organization Id", "Organization
Type", "Group Id".

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|group_table |List(groupTable) |groupTable - *Table* array of groupTable named tuples |
</div>


## `SystemCallRecordingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallRecordingGetRequest()`.

Replaced By: `SystemCallRecordingGetResponse22()`

**Attributes:**

|Name                                        |Type |Description                            |
|--------------------------------------------|-----|---------------------------------------|
|continue_call_after_recording_failure       |bool |continueCallAfterRecordingFailure      |
|refresh_period_seconds                      |int  |refreshPeriodSeconds                   |
|max_consecutive_failures                    |int  |maxConsecutiveFailures                 |
|max_response_wait_time_milliseconds         |int  |maxResponseWaitTimeMilliseconds        |
|continue_call_after_video_recording_failure |bool |continueCallAfterVideoRecordingFailure |
</div>


## `SystemCallRecordingGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallRecordingGetRequest22()`.

Replaced by: `SystemCallRecordingGetResponse23()`

**Attributes:**

|Name                                        |Type |Description                            |
|--------------------------------------------|-----|---------------------------------------|
|continue_call_after_recording_failure       |bool |continueCallAfterRecordingFailure      |
|max_response_wait_time_milliseconds         |int  |maxResponseWaitTimeMilliseconds        |
|continue_call_after_video_recording_failure |bool |continueCallAfterVideoRecordingFailure |
</div>


## `SystemCallRecordingGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallRecordingGetRequest23()`.


**Attributes:**

|Name                                                                              |Type |Description                                                           |
|----------------------------------------------------------------------------------|-----|----------------------------------------------------------------------|
|continue_call_after_recording_failure                                             |bool |continueCallAfterRecordingFailure                                     |
|max_response_wait_time_milliseconds                                               |int  |maxResponseWaitTimeMilliseconds                                       |
|continue_call_after_video_recording_failure                                       |bool |continueCallAfterVideoRecordingFailure                                |
|use_continue_call_after_recording_failure_for_on_demand_mode                      |bool |useContinueCallAfterRecordingFailureForOnDemandMode                   |
|use_continue_call_after_recording_failure_for_on_demand_user_initiated_start_mode |bool |useContinueCallAfterRecordingFailureForOnDemandUserInitiatedStartMode |
|restrict_call_recording_provisioning_access                                       |bool |restrictCallRecordingProvisioningAccess                               |
</div>


## `SystemCallReturnGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallReturnGetRequest()`.


**Attributes:**

|Name                                     |Type |Description                         |
|-----------------------------------------|-----|------------------------------------|
|two_level_activation                     |bool |twoLevelActivation                  |
|provide_date                             |bool |provideDate                         |
|last_unanswered_call_only                |bool |lastUnansweredCallOnly              |
|confirmation_key                         |str  |confirmationKey *Optional*          |
|allow_restricted_number                  |bool |allowRestrictedNumber               |
|delete_number_after_answered_call_return |bool |deleteNumberAfterAnsweredCallReturn |
</div>


## `SystemCallTypeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallTypeGetListRequest()`.


**Attributes:**

|Name      |Type      |Description|
|----------|----------|-----------|
|call_type |List[str] |callType   |
</div>


## `SystemCallTypeGetMappingListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallTypeGetMappingListRequest()`.

The table columns are: "Country Code", "Digit Map" and "Call Type".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|call_type_mapping |List(callTypeMapping) |callTypeMapping - *Table* array of callTypeMapping named tuples |
</div>


## `SystemCallWaitingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallWaitingGetRequest()`.


**Attributes:**

|Name                      |Type |Description             |
|--------------------------|-----|------------------------|
|play_distinctive_ringback |bool |playDistinctiveRingback |
</div>


## `SystemCallingNameRetrievalGetResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallingNameRetrievalGetRequest14()`.


**Attributes:**

|Name                      |Type|Description                 |
|--------------------------|----|----------------------------|
|query_timer_milli_seconds |int |queryTimerMilliSeconds      |
|server_net_address        |str |serverNetAddress *Optional* |
|server_port               |int |serverPort *Optional*       |
|server_transport_protocol |str |serverTransportProtocol     |
</div>


## `SystemCallingNameRetrievalGetResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallingNameRetrievalGetRequest16sp1()`.


**Attributes:**

|Name                                                |Type |Description                                  |
|----------------------------------------------------|-----|---------------------------------------------|
|trigger_cnam_queries_for_all_network_calls          |bool |triggerCNAMQueriesForAllNetworkCalls         |
|trigger_cnam_queries_for_group_and_enterprise_calls |bool |triggerCNAMQueriesForGroupAndEnterpriseCalls |
|query_protocol                                      |str  |queryProtocol                                |
|query_timeout_milliseconds                          |int  |queryTimeoutMilliseconds                     |
|sip_external_database_net_address                   |str  |sipExternalDatabaseNetAddress *Optional*     |
|sip_external_database_port                          |int  |sipExternalDatabasePort *Optional*           |
|sip_external_database_transport                     |str  |sipExternalDatabaseTransport                 |
|soap_external_database_net_address                  |str  |soapExternalDatabaseNetAddress *Optional*    |
|soap_supports_dnssrv                                |bool |soapSupportsDNSSRV                           |
</div>


## `SystemCallingNameRetrievalGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallingNameRetrievalGetRequest17sp4()`.

Replaced by: `SystemCallingNameRetrievalGetResponse24()`

**Attributes:**

|Name                                                |Type |Description                                  |
|----------------------------------------------------|-----|---------------------------------------------|
|trigger_cnam_queries_for_all_network_calls          |bool |triggerCNAMQueriesForAllNetworkCalls         |
|trigger_cnam_queries_for_group_and_enterprise_calls |bool |triggerCNAMQueriesForGroupAndEnterpriseCalls |
|query_protocol                                      |str  |queryProtocol                                |
|query_timeout_milliseconds                          |int  |queryTimeoutMilliseconds                     |
|sip_external_database_net_address                   |str  |sipExternalDatabaseNetAddress *Optional*     |
|sip_external_database_port                          |int  |sipExternalDatabasePort *Optional*           |
|sip_external_database_transport                     |str  |sipExternalDatabaseTransport                 |
|soap_external_database_net_address                  |str  |soapExternalDatabaseNetAddress *Optional*    |
|soap_supports_dnssrv                                |bool |soapSupportsDNSSRV                           |
|calling_name_source                                 |str  |callingNameSource                            |
</div>


## `SystemCallingNameRetrievalGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallingNameRetrievalGetRequest20()`.

Replaced by: `SystemCallingNameRetrievalGetResponse24()`

**Attributes:**

|Name                                                |Type |Description                                  |
|----------------------------------------------------|-----|---------------------------------------------|
|trigger_cnam_queries_for_all_network_calls          |bool |triggerCNAMQueriesForAllNetworkCalls         |
|trigger_cnam_queries_for_group_and_enterprise_calls |bool |triggerCNAMQueriesForGroupAndEnterpriseCalls |
|query_protocol                                      |str  |queryProtocol                                |
|query_timeout_milliseconds                          |int  |queryTimeoutMilliseconds                     |
|sip_external_database_net_address                   |str  |sipExternalDatabaseNetAddress *Optional*     |
|sip_external_database_port                          |int  |sipExternalDatabasePort *Optional*           |
|sip_external_database_transport                     |str  |sipExternalDatabaseTransport                 |
|soap_external_database_net_address                  |str  |soapExternalDatabaseNetAddress *Optional*    |
|calling_name_source                                 |str  |callingNameSource                            |
|route_advance_timer                                 |int  |routeAdvanceTimer                            |
|retry_failed_cnam_server_interval                   |int  |retryFailedCNAMServerInterval                |
|ignore_restricted_presentation_indicator            |bool |ignoreRestrictedPresentationIndicator        |
|supports_dnssrv                                     |bool |supportsDNSSRV                               |
</div>


## `SystemCallingNameRetrievalGetResponse24`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallingNameRetrievalGetRequest24()`.


**Attributes:**

|Name                                                |Type |Description                                  |
|----------------------------------------------------|-----|---------------------------------------------|
|trigger_cnam_queries_for_all_network_calls          |bool |triggerCNAMQueriesForAllNetworkCalls         |
|trigger_cnam_queries_for_group_and_enterprise_calls |bool |triggerCNAMQueriesForGroupAndEnterpriseCalls |
|query_protocol                                      |str  |queryProtocol                                |
|query_timeout_milliseconds                          |int  |queryTimeoutMilliseconds                     |
|sip_external_database_net_address                   |str  |sipExternalDatabaseNetAddress *Optional*     |
|sip_external_database_port                          |int  |sipExternalDatabasePort *Optional*           |
|sip_external_database_transport                     |str  |sipExternalDatabaseTransport                 |
|soap_external_database_net_address                  |str  |soapExternalDatabaseNetAddress *Optional*    |
|calling_name_source                                 |str  |callingNameSource                            |
|route_advance_timer                                 |int  |routeAdvanceTimer                            |
|retry_failed_cnam_server_interval                   |int  |retryFailedCNAMServerInterval                |
|ignore_restricted_presentation_indicator            |bool |ignoreRestrictedPresentationIndicator        |
|supports_dnssrv                                     |bool |supportsDNSSRV                               |
</div>


## `SystemCallingPartyCategoryGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallingPartyCategoryGetListRequest()`.

Contains a table of Calling Party Category defined in system.  The column headings
are: "Category Name", "User Category", "Collect Call", "Default" and "Web Display
Key".

**Attributes:**

|Name                         |Type                            |Description                                                                         |
|-----------------------------|--------------------------------|------------------------------------------------------------------------------------|
|calling_party_category_table |List(callingPartyCategoryTable) |callingPartyCategoryTable - *Table* array of callingPartyCategoryTable named tuples |
</div>


## `SystemCallingPartyCategoryGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallingPartyCategoryGetRequest()`.

Contains information of a Calling Party Category defined in system.

**Attributes:**

|Name            |Type |Description              |
|----------------|-----|-------------------------|
|cpc_value       |str  |cpcValue *Optional*      |
|isup_oli_value  |int  |isupOliValue *Optional*  |
|gtd_oli_value   |str  |gtdOliValue *Optional*   |
|user_category   |bool |userCategory             |
|pay_phone       |bool |payPhone                 |
|operator        |bool |operator                 |
|default         |bool |default                  |
|collect_call    |bool |collectCall              |
|web_display_key |str  |webDisplayKey *Optional* |
</div>


## `SystemClassmarkGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemClassmarkGetListRequest()`.

Contains a table of with the column headings: "Class Mark", "Value" and "Web Display
Key".

**Attributes:**

|Name            |Type                 |Description                                                   |
|----------------|---------------------|--------------------------------------------------------------|
|classmark_table |List(classmarkTable) |classmarkTable - *Table* array of classmarkTable named tuples |
</div>


## `SystemClassmarkGetUtilizationListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemClassmarkGetUtilizationListRequest()`.

Contains a table with the column headings: "User Id", "Group Id", "Service Provider
Id", "Last Name", "First Name", and "Phone Number", "Extension", "Department", "Email
Address".

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|classmark_user_table |List(classmarkUserTable) |classmarkUserTable - *Table* array of classmarkUserTable named tuples |
</div>


## `SystemClientIdentityGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemClientIdentityGetListRequest()`.

Returns a table with column headings: "Client Identity".

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|client_identity_table |List(clientIdentityTable) |clientIdentityTable - *Table* array of clientIdentityTable named tuples |
</div>


## `SystemClientSessionParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemClientSessionParametersGetRequest()`.

Contains a list of system Client Session (web and CLI) parameters.

**Attributes:**

|Name                       |Type |Description              |
|---------------------------|-----|-------------------------|
|enable_inactivity_timeout  |bool |enableInactivityTimeout  |
|inactivity_timeout_minutes |int  |inactivityTimeoutMinutes |
</div>


## `SystemCodecGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCodecGetListRequest()`.


**Attributes:**

|Name  |Type      |Description      |
|------|----------|-----------------|
|codec |List[str] |codec *Optional* |
</div>


## `SystemCommunicationBarringAlternateCallIndicatorGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemCommunicationBarringAlternateCallIndicatorGetListRequest()`.

Contains a table with one row per Communication Barring Alternate Call Indicator.  The
table column headings are: "Alternate Call Indicator" and "Network Server Alternate
Call Indicator".

**Attributes:**

|Name                           |Type                              |Description                                                                             |
|-------------------------------|----------------------------------|----------------------------------------------------------------------------------------|
|alternate_call_indicator_table |List(alternateCallIndicatorTable) |alternateCallIndicatorTable - *Table* array of alternateCallIndicatorTable named tuples |
</div>


## `SystemCommunicationBarringCallTypeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemCommunicationBarringCallTypeGetListRequest()`.

Contains a table with one row per Communication Barring Call Type.  The table column
headings are: "Call Type" and "Network Server Call Type".

**Attributes:**

|Name            |Type                |Description                                                 |
|----------------|--------------------|------------------------------------------------------------|
|call_type_table |List(callTypeTable) |callTypeTable - *Table* array of callTypeTable named tuples |
</div>


## `SystemCommunicationBarringCriteriaGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringCriteriaGetListRequest()`.

The response contains a table of all Communication Barring Criteria in the system.
The column headings are "Name" and "Description".

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|criteria_table |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `SystemCommunicationBarringCriteriaGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringCriteriaGetRequest()`.

The response contains the Communication Barring Criteria information.  Replaced by:
`SystemCommunicationBarringCriteriaGetResponse17()`

**Attributes:**

|Name                           |Type      |Description                            |
|-------------------------------|----------|---------------------------------------|
|description                    |str       |description *Optional*                 |
|match_call_type                |List[str] |matchCallType *Optional*               |
|match_alternate_call_indicator |List[str] |matchAlternateCallIndicator *Optional* |
|match_public_network           |bool      |matchPublicNetwork                     |
|match_private_network          |bool      |matchPrivateNetwork                    |
|match_local_category           |bool      |matchLocalCategory                     |
|match_national_category        |bool      |matchNationalCategory                  |
|match_interlata_category       |bool      |matchInterlataCategory                 |
|match_intralata_category       |bool      |matchIntralataCategory                 |
|match_international_category   |bool      |matchInternationalCategory             |
|match_private_category         |bool      |matchPrivateCategory                   |
|match_emergency_category       |bool      |matchEmergencyCategory                 |
|match_other_category           |bool      |matchOtherCategory                     |
|match_inter_network            |bool      |matchInterNetwork                      |
|match_inter_hosting_ne         |bool      |matchInterHostingNE                    |
|match_inter_as                 |bool      |matchInterAS                           |
|match_intra_as                 |bool      |matchIntraAS                           |
|match_charge_calls             |bool      |matchChargeCalls                       |
|match_no_charge_calls          |bool      |matchNoChargeCalls                     |
|match_group_calls              |bool      |matchGroupCalls                        |
|match_enterprise_calls         |bool      |matchEnterpriseCalls                   |
|match_network_calls            |bool      |matchNetworkCalls                      |
|match_network_url_calls        |bool      |matchNetworkURLCalls                   |
|match_repair_calls             |bool      |matchRepairCalls                       |
|match_emergency_calls          |bool      |matchEmergencyCalls                    |
|match_internal_calls           |bool      |matchInternalCalls                     |
|time_schedule                  |str       |timeSchedule *Optional*                |
|holiday_schedule               |str       |holidaySchedule *Optional*             |
</div>


## `SystemCommunicationBarringCriteriaGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringCriteriaGetRequest17()`.

The response contains the Communication Barring Criteria information.

**Attributes:**

|Name                           |Type      |Description                            |
|-------------------------------|----------|---------------------------------------|
|description                    |str       |description *Optional*                 |
|match_call_type                |List[str] |matchCallType *Optional*               |
|match_alternate_call_indicator |List[str] |matchAlternateCallIndicator *Optional* |
|match_virtual_on_net_call_type |List[str] |matchVirtualOnNetCallType *Optional*   |
|match_public_network           |bool      |matchPublicNetwork                     |
|match_private_network          |bool      |matchPrivateNetwork                    |
|match_local_category           |bool      |matchLocalCategory                     |
|match_national_category        |bool      |matchNationalCategory                  |
|match_interlata_category       |bool      |matchInterlataCategory                 |
|match_intralata_category       |bool      |matchIntralataCategory                 |
|match_international_category   |bool      |matchInternationalCategory             |
|match_private_category         |bool      |matchPrivateCategory                   |
|match_emergency_category       |bool      |matchEmergencyCategory                 |
|match_other_category           |bool      |matchOtherCategory                     |
|match_inter_network            |bool      |matchInterNetwork                      |
|match_inter_hosting_ne         |bool      |matchInterHostingNE                    |
|match_inter_as                 |bool      |matchInterAS                           |
|match_intra_as                 |bool      |matchIntraAS                           |
|match_charge_calls             |bool      |matchChargeCalls                       |
|match_no_charge_calls          |bool      |matchNoChargeCalls                     |
|match_group_calls              |bool      |matchGroupCalls                        |
|match_enterprise_calls         |bool      |matchEnterpriseCalls                   |
|match_network_calls            |bool      |matchNetworkCalls                      |
|match_network_url_calls        |bool      |matchNetworkURLCalls                   |
|match_repair_calls             |bool      |matchRepairCalls                       |
|match_emergency_calls          |bool      |matchEmergencyCalls                    |
|match_internal_calls           |bool      |matchInternalCalls                     |
|match_location                 |str       |matchLocation                          |
|match_roaming                  |str       |matchRoaming                           |
|time_schedule                  |str       |timeSchedule *Optional*                |
|holiday_schedule               |str       |holidaySchedule *Optional*             |
</div>


## `SystemCommunicationBarringCriteriaGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringCriteriaGetRequest19sp1()`.

The response contains the Communication Barring Criteria information.

**Attributes:**

|Name                            |Type      |Description                             |
|--------------------------------|----------|----------------------------------------|
|description                     |str       |description *Optional*                  |
|match_call_type                 |List[str] |matchCallType *Optional*                |
|match_alternate_call_indicator  |List[str] |matchAlternateCallIndicator *Optional*  |
|match_virtual_on_net_call_type  |List[str] |matchVirtualOnNetCallType *Optional*    |
|match_public_network            |bool      |matchPublicNetwork                      |
|match_private_network           |bool      |matchPrivateNetwork                     |
|match_local_category            |bool      |matchLocalCategory                      |
|match_national_category         |bool      |matchNationalCategory                   |
|match_interlata_category        |bool      |matchInterlataCategory                  |
|match_intralata_category        |bool      |matchIntralataCategory                  |
|match_international_category    |bool      |matchInternationalCategory              |
|match_private_category          |bool      |matchPrivateCategory                    |
|match_emergency_category        |bool      |matchEmergencyCategory                  |
|match_other_category            |bool      |matchOtherCategory                      |
|match_inter_network             |bool      |matchInterNetwork                       |
|match_inter_hosting_ne          |bool      |matchInterHostingNE                     |
|match_inter_as                  |bool      |matchInterAS                            |
|match_intra_as                  |bool      |matchIntraAS                            |
|match_charge_calls              |bool      |matchChargeCalls                        |
|match_no_charge_calls           |bool      |matchNoChargeCalls                      |
|match_group_calls               |bool      |matchGroupCalls                         |
|match_enterprise_calls          |bool      |matchEnterpriseCalls                    |
|match_network_calls             |bool      |matchNetworkCalls                       |
|match_network_url_calls         |bool      |matchNetworkURLCalls                    |
|match_repair_calls              |bool      |matchRepairCalls                        |
|match_emergency_calls           |bool      |matchEmergencyCalls                     |
|match_internal_calls            |bool      |matchInternalCalls                      |
|match_location                  |str       |matchLocation                           |
|match_roaming                   |str       |matchRoaming                            |
|time_schedule                   |str       |timeSchedule *Optional*                 |
|holiday_schedule                |str       |holidaySchedule *Optional*              |
|match_number_portability_status |List[str] |matchNumberPortabilityStatus *Optional* |
</div>


## `SystemCommunicationBarringDigitPatternCriteriaGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringDigitPatternCriteriaGetListRequest()`.

The response contains a table of all Digit Pattern Criteria defined at the system
level.  The column headings are "Name" and "Description"

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|criteria_table |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `SystemCommunicationBarringDigitPatternCriteriaGetPatternListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`SystemCommunicationBarringDigitPatternCriteriaGetPatternListRequest()`.

The response contains the Digit Pattern Criteria information.

**Attributes:**

|Name                |Type      |Description                  |
|--------------------|----------|-----------------------------|
|match_digit_pattern |List[str] |matchDigitPattern *Optional* |
</div>


## `SystemCommunicationBarringDigitPatternCriteriaGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `SystemCommunicationBarringDigitPatternCriteriaGetRequest()`.


**Attributes:**

|Name          |Type      |Description             |
|--------------|----------|------------------------|
|description   |str       |description *Optional*  |
|digit_pattern |List[str] |digitPattern *Optional* |
</div>


## `SystemCommunicationBarringGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCommunicationBarringGetRequest()`.

Replaced by: `SystemCommunicationBarringGetResponse21sp1()` in AS data mode.

**Attributes:**

|Name                      |Type |Description             |
|--------------------------|-----|------------------------|
|direct_transfer_screening |bool |directTransferScreening |
</div>


## `SystemCommunicationBarringGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCommunicationBarringGetRequest21sp1()`.

The following elements are only used in AS data mode: vmCallbackScreening, value
"false" is returned in XS data mode.

**Attributes:**

|Name                      |Type |Description             |
|--------------------------|-----|------------------------|
|direct_transfer_screening |bool |directTransferScreening |
|vm_callback_screening     |bool |vmCallbackScreening     |
</div>


## `SystemCommunicationBarringIncomingCriteriaGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringIncomingCriteriaGetListRequest()`.

The response contains a table of all Communication Barring Incoming Criteria in the
system.  The column headings are "Name" and "Description".

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|criteria_table |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `SystemCommunicationBarringIncomingCriteriaGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringIncomingCriteriaGetRequest()`.

The response contains the Communication Barring Incoming Criteria information.
Replaced by: `SystemCommunicationBarringIncomingCriteriaGetResponse22()`

**Attributes:**

|Name                            |Type      |Description                             |
|--------------------------------|----------|----------------------------------------|
|description                     |str       |description *Optional*                  |
|time_schedule                   |str       |timeSchedule *Optional*                 |
|holiday_schedule                |str       |holidaySchedule *Optional*              |
|match_number_portability_status |List[str] |matchNumberPortabilityStatus *Optional* |
</div>


## `SystemCommunicationBarringIncomingCriteriaGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringIncomingCriteriaGetRequest()`.

The response contains the Communication Barring Incoming Criteria information.

**Attributes:**

|Name                            |Type      |Description                             |
|--------------------------------|----------|----------------------------------------|
|description                     |str       |description *Optional*                  |
|time_schedule                   |str       |timeSchedule *Optional*                 |
|holiday_schedule                |str       |holidaySchedule *Optional*              |
|match_number_portability_status |List[str] |matchNumberPortabilityStatus *Optional* |
|call_tagged_as_spam             |bool      |callTaggedAsSpam                        |
</div>


## `SystemCommunicationBarringProfileGetCriteriaUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringProfileGetCriteriaUsageListRequest()`.

The response contains a table of system Communication Barring Profiles that use the
specific Communication Barring Criteria.  The column headings are "Name" and
"Description"

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|profile_table |List(profileTable) |profileTable - *Table* array of profileTable named tuples |
</div>


## `SystemCommunicationBarringProfileGetDigitPatternCriteriaUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`SystemCommunicationBarringProfileGetDigitPatternCriteriaUsageListRequest()`.

The response contains a table of all Profiles that use the specific Digit Pattern
Criteria.  The column headings are "Name" and "Description"

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|profile_table |List(profileTable) |profileTable - *Table* array of profileTable named tuples |
</div>


## `SystemCommunicationBarringProfileGetIncomingCriteriaUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`SystemCommunicationBarringProfileGetIncomingCriteriaUsageListRequest()`.

The response contains a table of system Communication Barring Profiles that use the
specific Communication Barring Incoming Criteria.  The column headings are "Name" and
"Description"

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|profile_table |List(profileTable) |profileTable - *Table* array of profileTable named tuples |
</div>


## `SystemCommunicationBarringProfileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringProfileGetListRequest()`.

The response contains a table of all Communication Barring Profiles in the system.
The column headings are "Name" and "Description"

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|profile_table |List(profileTable) |profileTable - *Table* array of profileTable named tuples |
</div>


## `SystemCommunicationBarringServiceProviderGetCriteriaUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`SystemCommunicationBarringServiceProviderGetCriteriaUsageListRequest()`.

The response contains a table of all Service Providers that use the specific
Communication Barring criteria.  The column headings are "Service Provider Id",
"Service Provider Name" and "Is Enterprise"

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|service_provider_table |List(serviceProviderTable) |serviceProviderTable - *Table* array of serviceProviderTable named tuples |
</div>


## `SystemCommunicationBarringServiceProviderGetIncomingCriteriaUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`SystemCommunicationBarringServiceProviderGetIncomingCriteriaUsageListRequest()`.

The response contains a table of all Service Providers that use the specific
Communication Barring Incoming criteria.  The column headings are "Service Provider
Id", "Service Provider Name" and "Is Enterprise"

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|service_provider_table |List(serviceProviderTable) |serviceProviderTable - *Table* array of serviceProviderTable named tuples |
</div>


## `SystemCommunicationBarringUserControlGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringUserControlGetRequest()`.

Contains the settings to whole system for Communication Barring User-Control

**Attributes:**

|Name                          |Type |Description               |
|------------------------------|-----|--------------------------|
|enable_lockout                |bool |enableLockout             |
|max_number_of_failed_attempts |int  |maxNumberOfFailedAttempts |
|lockout_minutes               |int  |lockoutMinutes            |
</div>


## `SystemConfigurableFileSystemGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemConfigurableFileSystemGetRequest()`.

Regardless of element password being there in the response, the request is never going
to return the password in response.  Contains the File System parameters.

**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|media_directory  |str                |mediaDirectory            |
|protocol_file    |OCI.protocolFile   |protocolFile *Optional*   |
|protocol_web_dav |OCI.protocolWebDAV |protocolWebDAV *Optional* |
</div>


## `SystemConfigurableFileSystemGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemConfigurableFileSystemGetRequest22()`.

Contains the File System parameters.  The following elements are only used in AS data
mode: protocolFile-secure value "false" is returned in XS data mode

**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|media_directory  |str                |mediaDirectory            |
|protocol_file    |OCI.protocolFile   |protocolFile *Optional*   |
|protocol_web_dav |OCI.protocolWebDAV |protocolWebDAV *Optional* |
</div>


## `SystemConfigurableFileSystemGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemConfigurableFileSystemGetRequest23()`.

Contains the File System parameters.

**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|media_directory  |str                |mediaDirectory            |
|protocol_file    |OCI.protocolFile   |protocolFile *Optional*   |
|protocol_web_dav |OCI.protocolWebDAV |protocolWebDAV *Optional* |
</div>


## `SystemConfigurableFileSystemGetResponse23V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemConfigurableFileSystemGetRequest23V2()`.

Contains the File System parameters.  The following elements are only used in AS data
mode: protocolFile-secure value "false" is returned in XS data mode

**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|media_directory  |str                |mediaDirectory            |
|protocol_file    |OCI.protocolFile   |protocolFile *Optional*   |
|protocol_web_dav |OCI.protocolWebDAV |protocolWebDAV *Optional* |
</div>


## `SystemConfigurableTreatmentGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemConfigurableTreatmentGetListRequest()`.

Contains a table with one row per treatment.  The table columns are: "Treatment Id",
"Description".

**Attributes:**

|Name            |Type                 |Description                                                   |
|----------------|---------------------|--------------------------------------------------------------|
|treatment_table |List(treatmentTable) |treatmentTable - *Table* array of treatmentTable named tuples |
</div>


## `SystemConfigurableTreatmentGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemConfigurableTreatmentGetRequest()`.

The response contains the treatment configurable information.

Replaced By: `SystemConfigurableTreatmentGetResponse16()`

**Attributes:**

|Name                         |Type |Description                          |
|-----------------------------|-----|-------------------------------------|
|description                  |str  |description *Optional*               |
|charge_indicator             |str  |chargeIndicator                      |
|access_sip_status_code       |int  |accessSIPStatusCode *Optional*       |
|access_sip_status_message    |str  |accessSIPStatusMessage *Optional*    |
|network_sip_status_code      |int  |networkSIPStatusCode *Optional*      |
|network_sip_status_message   |str  |networkSIPStatusMessage *Optional*   |
|q850_cause_value             |int  |q850CauseValue *Optional*            |
|q850_text                    |str  |q850Text *Optional*                  |
|access_treatment_audio_file  |str  |accessTreatmentAudioFile *Optional*  |
|access_treatment_video_file  |str  |accessTreatmentVideoFile *Optional*  |
|network_treatment_audio_file |str  |networkTreatmentAudioFile *Optional* |
|network_treatment_video_file |str  |networkTreatmentVideoFile *Optional* |
|cdr_termination_cause        |str  |cdrTerminationCause *Optional*       |
|route_advance                |bool |routeAdvance                         |
|internal_release_cause       |str  |internalReleaseCause *Optional*      |
|access_send_reason_header    |bool |accessSendReasonHeader               |
|network_send_reason_header   |bool |networkSendReasonHeader              |
</div>


## `SystemConfigurableTreatmentGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemConfigurableTreatmentGetRequest16()`.

The response contains the treatment configurable information.

**Attributes:**

|Name                         |Type |Description                          |
|-----------------------------|-----|-------------------------------------|
|description                  |str  |description *Optional*               |
|charge_indicator             |str  |chargeIndicator                      |
|access_sip_status_code       |int  |accessSIPStatusCode *Optional*       |
|access_sip_status_message    |str  |accessSIPStatusMessage *Optional*    |
|network_sip_status_code      |int  |networkSIPStatusCode *Optional*      |
|network_sip_status_message   |str  |networkSIPStatusMessage *Optional*   |
|q850_cause_value             |int  |q850CauseValue *Optional*            |
|q850_text                    |str  |q850Text *Optional*                  |
|access_treatment_audio_file  |str  |accessTreatmentAudioFile *Optional*  |
|access_treatment_video_file  |str  |accessTreatmentVideoFile *Optional*  |
|network_treatment_audio_file |str  |networkTreatmentAudioFile *Optional* |
|network_treatment_video_file |str  |networkTreatmentVideoFile *Optional* |
|cdr_termination_cause        |str  |cdrTerminationCause *Optional*       |
|route_advance                |bool |routeAdvance                         |
|internal_release_cause       |str  |internalReleaseCause *Optional*      |
|access_send_reason_header    |bool |accessSendReasonHeader               |
|network_send_reason_header   |bool |networkSendReasonHeader              |
</div>


## `SystemConnectedLineIdentificationPresentationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemConnectedLineIdentificationPresentationGetRequest()`.


**Attributes:**

|Name                            |Type |Description                  |
|--------------------------------|-----|-----------------------------|
|enforce_user_service_assignment |bool |enforceUserServiceAssignment |
</div>


## `SystemCountryCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemCountryCodeGetListRequest()`.

Contains the default country code and a table with one row per country code.  The
table columns are "Country Code", "Country Name", "Off Hook Warning Seconds", "Ring
Period Milliseconds", "National Prefix", "Use Prefix", "Maximum Call Waiting Tones",
"Time Between Call Waiting Tones Milliseconds" and "Disable National Prefix for OffNet
Calls". The following columns are only returned in AS data mode: "Disable National
Prefix for OffNet Calls"

**Attributes:**

|Name                 |Type                   |Description                                                       |
|---------------------|-----------------------|------------------------------------------------------------------|
|default_country_code |str                    |defaultCountryCode                                                |
|country_code_table   |List(countryCodeTable) |countryCodeTable - *Table* array of countryCodeTable named tuples |
</div>


## `SystemCrInterfaceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCrInterfaceGetRequest()`.


**Attributes:**

|Name                               |Type |Description                     |
|-----------------------------------|-----|--------------------------------|
|cr_audit_enabled                   |bool |crAuditEnabled                  |
|cr_audit_interval_milliseconds     |int  |crAuditIntervalMilliseconds     |
|cr_audit_timeout_milliseconds      |int  |crAuditTimeoutMilliseconds      |
|cr_connection_enabled              |bool |crConnectionEnabled             |
|cr_connection_timeout_milliseconds |int  |crConnectionTimeoutMilliseconds |
</div>


## `SystemCrInterfaceGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCrInterfaceGetRequest22()`.


**Attributes:**

|Name                               |Type |Description                     |
|-----------------------------------|-----|--------------------------------|
|cr_audit_enabled                   |bool |crAuditEnabled                  |
|cr_audit_interval_milliseconds     |int  |crAuditIntervalMilliseconds     |
|cr_audit_timeout_milliseconds      |int  |crAuditTimeoutMilliseconds      |
|cr_connection_enabled              |bool |crConnectionEnabled             |
|cr_connection_timeout_milliseconds |int  |crConnectionTimeoutMilliseconds |
|cr_tcp_connection_timeout_seconds  |int  |crTcpConnectionTimeoutSeconds   |
|cr_number_of_reconnection_attempts |int  |crNumberOfReconnectionAttempts  |
</div>


## `SystemCustomerOriginatedTraceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCustomerOriginatedTraceGetRequest()`.


**Attributes:**

|Name                     |Type |Description            |
|-------------------------|-----|-----------------------|
|screen_malicious_callers |bool |screenMaliciousCallers |
</div>


## `SystemDTMFTransmissionGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemDTMFTransmissionGetRequest()`.


**Attributes:**

|Name                   |Type|Description                     |
|-----------------------|----|--------------------------------|
|transmission_method    |str |transmissionMethod              |
|signaling_content_type |str |signalingContentType *Optional* |
</div>


## `SystemDeviceActivationPolicyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceActivationPolicyGetRequest()`.


**Attributes:**

|Name                                  |Type |Description                      |
|--------------------------------------|-----|---------------------------------|
|allow_activation_code_request_by_user |bool |allowActivationCodeRequestByUser |
|send_activation_code_in_email         |bool |sendActivationCodeInEmail        |
</div>


## `SystemDeviceFamilyExportResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceFamilyExportRequest()`.


**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|file |str |file       |
</div>


## `SystemDeviceFamilyGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceFamilyGetListRequest()`.

The response includes a table of device family defined in the system.  Column headings
are: "Device Family Name", "Reseller Id". The following columns are only returned in
AS data mode: "Reseller Id"

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|device_family_table |List(deviceFamilyTable) |deviceFamilyTable - *Table* array of deviceFamilyTable named tuples |
</div>


## `SystemDeviceFamilyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceFamilyGetRequest()`.

The response includes the tag sets and device types associated to a device family
defined in the system.  Column headings for deviceTypeTable are : Device Type(s)
Column headings for tagSetTable are :Tag Set(s)

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|device_type_table |List(deviceTypeTable) |deviceTypeTable - *Table* array of deviceTypeTable named tuples |
|tag_set_table     |List(tagSetTable)     |tagSetTable - *Table* array of tagSetTable named tuples         |
</div>


## `SystemDeviceFamilyImportDryRunResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceFamilyImportDryRunRequest()`.


**Attributes:**

|Name             |Type |Description     |
|-----------------|-----|----------------|
|file             |str  |file            |
|difference_found |bool |differenceFound |
</div>


## `SystemDeviceManagementAutoRebuildConfigGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceManagementAutoRebuildConfigGetListRequest()`.

Contains a table with column headings: "OCI Request Prefix", "Auto Rebuild Enabled".
"OCI Request Prefix" is the prefix of the OCI request name.  It does not include the
request's version '17.sp4, 18...' since the disabled flag applies to the whole series
of requests, independent of the version.  "Auto Rebuild Enabled": 'True' if the
request prefix triggers DM events automatically.  Otherwise, automatic DM events are
not generated.

**Attributes:**

|Name                      |Type                         |Description                                                                   |
|--------------------------|-----------------------------|------------------------------------------------------------------------------|
|auto_rebuild_config_table |List(autoRebuildConfigTable) |autoRebuildConfigTable - *Table* array of autoRebuildConfigTable named tuples |
</div>


## `SystemDeviceManagementEventGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceManagementEventGetListRequest()`.

Contains a table with column headings: "Event Id", "Status", "Action", "Level",
"Type", "Additional Info", "Is Local", "Completion %", "Pushed/ Same Hash/ Not
Pushed", "Login Id", "Start Time", "Process Time". "Event Id" is a unique identifer
for the event.  "Status" can be: Pending, Queued, In Progress, Process On Other Host,
Stale, Completed, Canceled.  "Action" can be: Delete, Download, Rebuild, Reset,
Upload.  "Level" can be: Device, Device Type, Device Type Group, Group, User.  "Type"
can be: Automatic, Manual.  "Additional Info" includes the affected device type,
device or group.  It depends on the level of the event: Device Profile: "Device Name"
"Service Provider Id" "Group Id" Device Type: "Device Type Name" Device Type Group:
"Service Provider Id" "Group Id" "Device Type Name" Group: "Service Provider Id"
"Group Id" User: "User Id" "Is Local" is set to "yes" if the event is processed on the
server who received the request, "no" otherwise meaning that the event is processed on
another server.  "Completion %" provides an estimate of the completion of the event.
A percentage is given, the current number of completed expanded event, and the total
number of expanded event.  "Pushed/ Same Hash/ Not Pushed" gives the total number of
files that were pushed, not pushed because of same hash, and not pushed when
processing the event.  "LoginId" is the user or admin id who triggered the event.
"Start Time" is the date when the event was started.  The display shows the month,
days, hours, and minutes (MM-dd hh:mm). "Process Time" is the time taken to process
the event in hours, minutes, seconds, and milliseconds (hhhh:mm:ss.SSS). Each row
represents an event sorted by priority of processing.  The first row in the table is
an event that has an associated expanded event currently being processed or next in
line to be processed.  Deprecated by:
`SystemDeviceManagementEventGetListResponse22()`.

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|event_table |List(eventTable) |eventTable - *Table* array of eventTable named tuples |
</div>


## `SystemDeviceManagementEventGetListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceManagementEventGetListRequest22()`.

Contains a table with column headings: "Event Id", "Status", "Action", "Level",
"Type", "Additional Info", "Is Local", "Completion %", "Pushed/ Same Hash/ Not
Pushed", "Login Id", "Start Time", "Process Time", "Rx Time", "Total Time", "Request",
"Priority". "Event Id" is a unique identifer for the event.  "Status" can be: Pending,
Queued, In Progress, Process On Other Host, Stale, Completed, Canceled.  "Action" can
be: Delete, Download, Rebuild, Reset, Upload.  "Level" can be: Device, Device Type,
Device Type Group, Group, User.  "Type" can be: Automatic, Manual.  "Additional Info"
includes the affected device type, device or group.  It depends on the level of the
event: Device Profile: "Device Name" "Service Provider Id" "Group Id" Device Type:
"Device Type Name" Device Type Service Provider: "Service Provider Id" "Device Type
Name" Service Provider: "Service Provider Id" Device Type Group: "Service Provider Id"
"Group Id" "Device Type Name" Group: "Service Provider Id" "Group Id" User: "User Id"
"Is Local" is set to "yes" if the event is processed on the server who received the
request, "no" otherwise meaning that the event is processed on another server.
"Completion %" provides an estimate of the completion of the event.  A percentage is
given, the current number of completed expanded event, and the total number of
expanded event.  "Pushed/ Same Hash/ Not Pushed" gives the total number of files that
were pushed, not pushed because of same hash, and not pushed when processing the
event.  "LoginId" is the user or admin id who triggered the event.  "Start Time" is
the date when the event's processing started.  The display shows the month, day,
hours, minutes, and seconds (MM-dd hh:mm:ss). "Process Time" is the time taken to
process the event in hours, minutes, seconds, and milliseconds (hhhh:mm:ss.SSS). "Rx
Time" is the date when the event was received via OCI-P and stored in the system.  The
display shows the month, day, hours, minutes, and seconds (MM-dd hh:mm:ss). "Total
Time" is the total time the event was in the system, from the moment it was received
and stored until its processing ended, in hours, minutes, seconds, and milliseconds
(hhhh:mm:ss.SSS). "Request" is the name of the OCI-P request that triggered the event.
"Priority" is the priority of the event.

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|event_table |List(eventTable) |eventTable - *Table* array of eventTable named tuples |
</div>


## `SystemDeviceManagementGetAccessDeviceCountForDeviceTypeResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceManagementGetAccessDeviceCountForDeviceTypeRequest()`.


**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|access_device_count |int |accessDeviceCount |
</div>


## `SystemDeviceManagementGetEventStatusSummaryCountResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceManagementGetEventStatusSummaryCountRequest()`.

The column headings are "Action, "Pending", "Queued Internally", and "Completed"

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|status_count_table |List(statusCountTable) |statusCountTable - *Table* array of statusCountTable named tuples |
</div>


## `SystemDeviceManagementTagGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceManagementTagGetListRequest()`.

Contains a table of custom configuration tags managed by the Device Management System.
In AS data mode, the column headings are: "Tag Name", "Tag Value", "Is Overridable".
In XS data mode, the column headings are: "Tag Name", "Tag Value", "Is Overridable",
"Is Encrypted".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|tags_table |List(tagsTable) |tagsTable - *Table* array of tagsTable named tuples |
</div>


## `SystemDeviceManagementTagSetCountryGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceManagementTagSetCountryGetListRequest()`.

The response includes the list of countries defined in a region of a specified tag
set.

**Attributes:**

|Name         |Type      |Description            |
|-------------|----------|-----------------------|
|country_name |List[str] |countryName *Optional* |
</div>


## `SystemDeviceManagementTagSetExportResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceManagementTagSetExportRequest()`.


**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|file |str |file       |
</div>


## `SystemDeviceManagementTagSetGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceManagementTagSetGetListRequest()`.

The response includes an array of tag set names defined in the system.  The system
default tag set name is not part of this response.  Replaced by
`SystemDeviceManagementTagSetGetListResponse22()` in AS data mode

**Attributes:**

|Name         |Type      |Description           |
|-------------|----------|----------------------|
|tag_set_name |List[str] |tagSetName *Optional* |
</div>


## `SystemDeviceManagementTagSetGetListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceManagementTagSetGetListRequest22()`.

The response includes a table of tag set names defined in the system.  Column headings
are: "Tag Set Name", "Reseller Id". The following columns are only returned in AS data
mode: "Reseller Id" The system default tag set name is not part of this response.

**Attributes:**

|Name          |Type              |Description                                             |
|--------------|------------------|--------------------------------------------------------|
|tag_set_table |List(tagSetTable) |tagSetTable - *Table* array of tagSetTable named tuples |
</div>


## `SystemDeviceManagementTagSetImportDryRunResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceManagementTagSetImportDryRunRequest()`.


**Attributes:**

|Name             |Type |Description     |
|-----------------|-----|----------------|
|file             |str  |file            |
|difference_found |bool |differenceFound |
</div>


## `SystemDeviceManagementTagSetRegionGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceManagementTagSetGetListRequest()`.

The response includes the list of region names defined in the specified tag set.

**Attributes:**

|Name        |Type      |Description           |
|------------|----------|----------------------|
|region_name |List[str] |regionName *Optional* |
</div>


## `SystemDeviceManagementTagSetRegionTagGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceManagementTagSetRegionTagGetListRequest()`.

The column headings for the tagsTable are: "Tag Name", "Tag Value".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|tags_table |List(tagsTable) |tagsTable - *Table* array of tagsTable named tuples |
</div>


## `SystemDeviceProfileAuthenticationLockoutGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceProfileAuthenticationLockoutGetRequest()`.

The column headings for the lockoutTable are: "Organization Id", "Organization Type",
"Group Id", "Identity/Device Profile Name", " Identity/Device Profile Type", "Lockout
Started", "Lockout Expires", "Lockout Count". Lockout times are shown in the system
GMT time.  When a permanent lockout is shown, the "Lockout Expires" column is empty
and the "Lockout Count" column contains the word Permanent.

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|lockout_table |List(lockoutTable) |lockoutTable - *Table* array of lockoutTable named tuples |
</div>


## `SystemDeviceProfileAuthenticationPasswordRulesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceProfileAuthenticationPasswordRulesGetRequest()`.

Contains the device profile authentication password rules for the system.

**Attributes:**

|Name                                       |Type |Description                                   |
|-------------------------------------------|-----|----------------------------------------------|
|disallow_authentication_name               |bool |disallowAuthenticationName                    |
|disallow_old_password                      |bool |disallowOldPassword                           |
|disallow_reversed_old_password             |bool |disallowReversedOldPassword                   |
|restrict_min_digits                        |bool |restrictMinDigits                             |
|min_digits                                 |int  |minDigits                                     |
|restrict_min_upper_case_letters            |bool |restrictMinUpperCaseLetters                   |
|min_upper_case_letters                     |int  |minUpperCaseLetters                           |
|restrict_min_lower_case_letters            |bool |restrictMinLowerCaseLetters                   |
|min_lower_case_letters                     |int  |minLowerCaseLetters                           |
|restrict_min_non_alphanumeric_characters   |bool |restrictMinNonAlphanumericCharacters          |
|min_non_alphanumeric_characters            |int  |minNonAlphanumericCharacters                  |
|min_length                                 |int  |minLength                                     |
|send_permanent_lockout_notification        |bool |sendPermanentLockoutNotification              |
|permanent_lockout_notify_email_address     |str  |permanentLockoutNotifyEmailAddress *Optional* |
|device_profile_authentication_lockout_type |str  |deviceProfileAuthenticationLockoutType        |
|device_profile_temporary_lockout_threshold |int  |deviceProfileTemporaryLockoutThreshold        |
|device_profile_wait_algorithm              |str  |deviceProfileWaitAlgorithm                    |
|device_profile_lockout_fixed_minutes       |str  |deviceProfileLockoutFixedMinutes              |
|device_profile_permanent_lockout_threshold |int  |deviceProfilePermanentLockoutThreshold        |
</div>


## `SystemDeviceTypeExportResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeExportRequest()`.


**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|file |str |file       |
</div>


## `SystemDeviceTypeGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetAvailableListRequest()`.


**Attributes:**

|Name        |Type               |Description           |
|------------|-------------------|----------------------|
|device_type |List[str]          |deviceType *Optional* |
|type_info   |List[OCI.typeInfo] |typeInfo *Optional*   |
</div>


## `SystemDeviceTypeGetAvailableListResponse14sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetAvailableListRequest14sp1()`.

Replaced By: `SystemDeviceTypeGetAvailableListResponse14sp3()`

**Attributes:**

|Name        |Type               |Description           |
|------------|-------------------|----------------------|
|device_type |List[str]          |deviceType *Optional* |
|type_info   |List[OCI.typeInfo] |typeInfo *Optional*   |
</div>


## `SystemDeviceTypeGetAvailableListResponse14sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetAvailableListRequest14sp3()`.


**Attributes:**

|Name        |Type               |Description           |
|------------|-------------------|----------------------|
|device_type |List[str]          |deviceType *Optional* |
|type_info   |List[OCI.typeInfo] |typeInfo *Optional*   |
</div>


## `SystemDeviceTypeGetAvailableListResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetAvailableListRequest19()`.

Note: element numberOfPorts is only used by devices types with static line ordering
enabled Replaced by `SystemDeviceTypeGetAvailableListResponse22()` in AS data mode.

**Attributes:**

|Name        |Type               |Description           |
|------------|-------------------|----------------------|
|device_type |List[str]          |deviceType *Optional* |
|type_info   |List[OCI.typeInfo] |typeInfo *Optional*   |
</div>


## `SystemDeviceTypeGetAvailableListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetAvailableListRequest22()`.

Note: element numberOfPorts is only used by devices types with static line ordering
enabled

**Attributes:**

|Name        |Type               |Description           |
|------------|-------------------|----------------------|
|device_type |List[str]          |deviceType *Optional* |
|type_info   |List[OCI.typeInfo] |typeInfo *Optional*   |
</div>


## `SystemDeviceTypeImportDryRunResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeImportDryRunRequest()`.


**Attributes:**

|Name             |Type |Description     |
|-----------------|-----|----------------|
|file             |str  |file            |
|difference_found |bool |differenceFound |
</div>


## `SystemDialPlanPolicyGetAccessCodeListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDialPlanPolicyGetAccessCodeListRequest()`.

Contains a table with column headings: "Access Code", "Enable Secondary Dial Tone",
"Description"

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|access_code_table |List(accessCodeTable) |accessCodeTable - *Table* array of accessCodeTable named tuples |
</div>


## `SystemDialPlanPolicyGetAccessCodeResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDialPlanPolicyGetAccessCodeRequest()`

**Attributes:**

|Name                                              |Type |Description                                 |
|--------------------------------------------------|-----|--------------------------------------------|
|include_code_for_network_translations_and_routing |bool |includeCodeForNetworkTranslationsAndRouting |
|include_code_for_screening_services               |bool |includeCodeForScreeningServices             |
|enable_secondary_dial_tone                        |bool |enableSecondaryDialTone                     |
|description                                       |str  |description *Optional*                      |
</div>


## `SystemDialPlanPolicyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDialPlanPolicyGetRequest()` Replaced by:
`SystemDialPlanPolicyGetResponse17()`

**Attributes:**

|Name                                  |Type |Description                      |
|--------------------------------------|-----|---------------------------------|
|requires_access_code_for_public_calls |bool |requiresAccessCodeForPublicCalls |
|allow_e164_public_calls               |bool |allowE164PublicCalls             |
|public_digit_map                      |str  |publicDigitMap                   |
|private_digit_map                     |str  |privateDigitMap *Optional*       |
</div>


## `SystemDialPlanPolicyGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDialPlanPolicyGetRequest17()`

**Attributes:**

|Name                                            |Type |Description                               |
|------------------------------------------------|-----|------------------------------------------|
|requires_access_code_for_public_calls           |bool |requiresAccessCodeForPublicCalls          |
|allow_e164_public_calls                         |bool |allowE164PublicCalls                      |
|prefer_e164_number_format_for_callback_services |bool |preferE164NumberFormatForCallbackServices |
|public_digit_map                                |str  |publicDigitMap                            |
|private_digit_map                               |str  |privateDigitMap *Optional*                |
</div>


## `SystemDialPlanPolicyGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDialPlanPolicyGetRequest22()` The following elements are only used
in AS data mode: overrideResolvedDeviceDigitMap The following elements are only used
in AS data mode and not returned in XS data mode: deviceDigitMap

**Attributes:**

|Name                                            |Type |Description                               |
|------------------------------------------------|-----|------------------------------------------|
|requires_access_code_for_public_calls           |bool |requiresAccessCodeForPublicCalls          |
|allow_e164_public_calls                         |bool |allowE164PublicCalls                      |
|prefer_e164_number_format_for_callback_services |bool |preferE164NumberFormatForCallbackServices |
|public_digit_map                                |str  |publicDigitMap                            |
|private_digit_map                               |str  |privateDigitMap *Optional*                |
|override_resolved_device_digit_map              |bool |overrideResolvedDeviceDigitMap            |
|device_digit_map                                |str  |deviceDigitMap *Optional*                 |
</div>


## `SystemDialPlanPolicyGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDialPlanPolicyGetRequest22V2()` The following elements are only
used in AS data mode: overrideResolvedDeviceDigitMap The following elements are only
used in AS data mode and not returned in XS data mode: deviceDigitMap
performInternalTranslationsWithOAC permissiveOACDialing

**Attributes:**

|Name                                            |Type |Description                                   |
|------------------------------------------------|-----|----------------------------------------------|
|requires_access_code_for_public_calls           |bool |requiresAccessCodeForPublicCalls              |
|allow_e164_public_calls                         |bool |allowE164PublicCalls                          |
|prefer_e164_number_format_for_callback_services |bool |preferE164NumberFormatForCallbackServices     |
|public_digit_map                                |str  |publicDigitMap                                |
|private_digit_map                               |str  |privateDigitMap *Optional*                    |
|override_resolved_device_digit_map              |bool |overrideResolvedDeviceDigitMap                |
|device_digit_map                                |str  |deviceDigitMap *Optional*                     |
|perform_internal_translations_with_oac          |bool |performInternalTranslationsWithOAC *Optional* |
|permissive_oac_dialing                          |bool |permissiveOACDialing *Optional*               |
</div>


## `SystemDialableCallerIDCriteriaGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemDialableCallerIDCriteriaGetRequest()`.

The response contains the Dialable Caller ID Criteria information.

**Attributes:**

|Name                           |Type      |Description                            |
|-------------------------------|----------|---------------------------------------|
|description                    |str       |description *Optional*                 |
|prefix_digits                  |str       |prefixDigits *Optional*                |
|match_call_type                |List[str] |matchCallType *Optional*               |
|match_alternate_call_indicator |List[str] |matchAlternateCallIndicator *Optional* |
|match_local_category           |bool      |matchLocalCategory                     |
|match_national_category        |bool      |matchNationalCategory                  |
|match_interlata_category       |bool      |matchInterlataCategory                 |
|match_intralata_category       |bool      |matchIntralataCategory                 |
|match_international_category   |bool      |matchInternationalCategory             |
|match_private_category         |bool      |matchPrivateCategory                   |
|match_emergency_category       |bool      |matchEmergencyCategory                 |
|match_other_category           |bool      |matchOtherCategory                     |
</div>


## `SystemDialableCallerIDGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemDialableCallerIDGetRequest()`.

The criteria table?s column headings are ?Active?, "Name", "Description", ?Prefix
Digits?, and ?Priority?.

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|criteria_table |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `SystemDigitCollectionGetResponse13mp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDigitCollectionGetRequest13mp4()`.


**Attributes:**

|Name              |Type|Description                |
|------------------|----|---------------------------|
|access_code       |str |accessCode *Optional*      |
|public_digit_map  |str |publicDigitMap             |
|private_digit_map |str |privateDigitMap *Optional* |
</div>


## `SystemDnGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDnGetSummaryListRequest()`.

The column headings are "Phone Numbers, "Service Provider Id", "Is Enterprise" and
"Reseller Id". The following columns are only returned in AS data mode: "Reseller Id"

**Attributes:**

|Name             |Type                 |Description                                                   |
|-----------------|---------------------|--------------------------------------------------------------|
|dn_summary_table |List(dnSummaryTable) |dnSummaryTable - *Table* array of dnSummaryTable named tuples |
</div>


## `SystemDnGetUtilizationListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDnUtilizationGetListRequest()`.

The table columns are: "Service Provider Id", "Phone Numbers", "Assigned to Groups",
"Percentage Assigned", "Is Enterprise", "Activated on Groups", "Reseller Id". The
following columns are only returned in AS data mode: "Reseller Id"

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|dn_utilization_table |List(dnUtilizationTable) |dnUtilizationTable - *Table* array of dnUtilizationTable named tuples |
</div>


## `SystemDnGetUtilizationResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDnGetUtilizationRequest()`.

Replaced By: `SystemDnGetUtilizationResponse14sp3()`

**Attributes:**

|Name                     |Type |Description          |
|-------------------------|-----|---------------------|
|service_provider_id      |str  |serviceProviderId    |
|group_id                 |str  |groupId *Optional*   |
|user_id                  |str  |userId *Optional*    |
|user_type                |str  |userType *Optional*  |
|is_group_calling_line_id |bool |isGroupCallingLineId |
</div>


## `SystemDnGetUtilizationResponse14sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDnGetUtilizationRequest14sp3()`.

The isActivated element is only included when the DN is assigned to a user.

**Attributes:**

|Name                     |Type |Description            |
|-------------------------|-----|-----------------------|
|service_provider_id      |str  |serviceProviderId      |
|group_id                 |str  |groupId *Optional*     |
|user_id                  |str  |userId *Optional*      |
|user_type                |str  |userType *Optional*    |
|is_group_calling_line_id |bool |isGroupCallingLineId   |
|is_activated             |bool |isActivated *Optional* |
</div>


## `SystemDomainGetAssignedServiceProviderListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDomainGetAssignedServiceProviderListRequest()`.

The table columns are: "Service Provider Id", "Service Provider Name", "Is Enterprise"
and "Reseller Id". The following columns are only returned in AS data mode: "Reseller
Id"

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|service_provider_table |List(serviceProviderTable) |serviceProviderTable - *Table* array of serviceProviderTable named tuples |
</div>


## `SystemDomainGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains a simple list of all system-level domain names.

The following elements are only used in AS and XS data mode and not returned in
Amplify data mode: systemDefaultDomain Replaced by `SystemDomainGetListResponse22()`
in AS data mode.

**Attributes:**

|Name                  |Type      |Description                    |
|----------------------|----------|-------------------------------|
|system_default_domain |str       |systemDefaultDomain *Optional* |
|domain                |List[str] |domain *Optional*              |
</div>


## `SystemDomainGetListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains a table of all matching system-level domain names and all matching reseller
level domains.

The column headings are: "Domain Name" and "Reseller Id". The following elements are
only used in AS and XS data mode and not returned in Amplify data mode:
systemDefaultDomain Replaced by `SystemDomainGetListResponse22V2()` in AS data mode.

**Attributes:**

|Name                  |Type              |Description                                             |
|----------------------|------------------|--------------------------------------------------------|
|system_default_domain |str               |systemDefaultDomain *Optional*                          |
|domain_table          |List(domainTable) |domainTable - *Table* array of domainTable named tuples |
</div>


## `SystemDomainGetListResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains a table of all matching system-level domain names and all matching reseller
level domains.

The column headings are: "Domain Name" and "Reseller Id". The following elements are
only used in AS and XS data mode and not returned in Amplify data mode:
systemDefaultDomain

**Attributes:**

|Name                  |Type              |Description                                             |
|----------------------|------------------|--------------------------------------------------------|
|system_default_domain |str               |systemDefaultDomain *Optional*                          |
|domain_table          |List(domainTable) |domainTable - *Table* array of domainTable named tuples |
</div>


## `SystemDomainParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDomainParametersGetRequest()`.

Contains the system Domain parameters.  The following elements are only used in AS
data mode: useAliasForDomain, value "false" is returned in XS data mode.  The
following elements are only used in AS and XS data mode and not returned in Amplify
data mode.  defaultDomain

**Attributes:**

|Name                 |Type |Description              |
|---------------------|-----|-------------------------|
|use_alias_for_domain |bool |useAliasForDomain        |
|default_domain       |str  |defaultDomain *Optional* |
</div>


## `SystemEmergencyCallDDoSProtectionGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemEmergencyCallDDoSProtectionGetRequest()`.


**Attributes:**

|Name                    |Type |Description               |
|------------------------|-----|--------------------------|
|enabled                 |bool |enabled                   |
|sample_interval_seconds |int  |sampleIntervalSeconds     |
|protection_rate         |int  |protectionRate *Optional* |
|protection_action       |str  |protectionAction          |
</div>


## `SystemEmergencyCallNotificationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemEmergencyCallNotificationGetResponse()`.


**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|default_from_address |str |defaultFromAddress |
</div>


## `SystemEmergencyZonesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemEmergencyZonesGetRequest()`.


**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|default_from_address |str |defaultFromAddress |
</div>


## `SystemEndpointGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemEndpointGetListRequest()`.

The column headings for the endpointTable are: "Organization Id", "Organization Type",
"Group Id", "Line/Port", "Last Name","First Name", "User Id", "User Type", "Phone
Number", "Extension", "Device Type", "Device Name", "Net Address", "MAC Address",
"Department", "Email Address", "Reseller Id". Possible values for User Type are
"User", "CCBasic", "CCStandard", "CCPremium", "RP", "MOH", "MOHVideo". The following
columns are only returned in AS data mode: "Reseller Id"

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|endpoint_table |List(endpointTable) |endpointTable - *Table* array of endpointTable named tuples |
</div>


## `SystemEnhancedCallLogsActiveSchemaInstanceGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemEnhancedCallLogsSchemaInstanceActualUsageGetListRequest()`.

Contains a table with column headings: "Instance Name", "Active Users".

**Attributes:**

|Name                        |Type                           |Description                                                                       |
|----------------------------|-------------------------------|----------------------------------------------------------------------------------|
|schema_instance_usage_table |List(schemaInstanceUsageTable) |schemaInstanceUsageTable - *Table* array of schemaInstanceUsageTable named tuples |
</div>


## `SystemEnhancedCallLogsGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemEnhancedCallLogsGetRequest()`.


**Attributes:**

|Name                               |Type |Description                     |
|-----------------------------------|-----|--------------------------------|
|is_send_enabled                    |bool |isSendEnabled                   |
|server1_net_address                |str  |server1NetAddress *Optional*    |
|server1_send_port                  |int  |server1SendPort                 |
|server1_retrieve_port              |int  |server1RetrievePort             |
|server2_net_address                |str  |server2NetAddress *Optional*    |
|server2_send_port                  |int  |server2SendPort                 |
|server2_retrieve_port              |int  |server2RetrievePort             |
|shared_secret                      |str  |sharedSecret *Optional*         |
|retransmission_delay_milli_seconds |int  |retransmissionDelayMilliSeconds |
|max_transmissions                  |int  |maxTransmissions                |
|soap_timeout_seconds               |int  |soapTimeoutSeconds              |
</div>


## `SystemEnhancedCallLogsGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemEnhancedCallLogsGetRequest17sp4()`.

The following elements are only used in AS data mode: isSendEnabled server1SendPort
server1RetrievePort server2SendPort server2RetrievePort
retransmissionDelayMilliSeconds maxTransmissions soapTimeoutSeconds useDBS The
following elements are only used in AS data mode and not returned in XS data mode:
server1NetAddress server2NetAddress sharedSecret Replaced
by:`SystemEnhancedCallLogsGetResponse20sp1()` in AS data mode

**Attributes:**

|Name                               |Type |Description                     |
|-----------------------------------|-----|--------------------------------|
|is_send_enabled                    |bool |isSendEnabled                   |
|server1_net_address                |str  |server1NetAddress *Optional*    |
|server1_send_port                  |int  |server1SendPort                 |
|server1_retrieve_port              |int  |server1RetrievePort             |
|server2_net_address                |str  |server2NetAddress *Optional*    |
|server2_send_port                  |int  |server2SendPort                 |
|server2_retrieve_port              |int  |server2RetrievePort             |
|shared_secret                      |str  |sharedSecret *Optional*         |
|retransmission_delay_milli_seconds |int  |retransmissionDelayMilliSeconds |
|max_transmissions                  |int  |maxTransmissions                |
|soap_timeout_seconds               |int  |soapTimeoutSeconds              |
|use_dbs                            |bool |useDBS                          |
|max_non_paged_response_size        |int  |maxNonPagedResponseSize         |
</div>


## `SystemEnhancedCallLogsGetResponse20sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemEnhancedCallLogsGetRequest20sp1()`.

The following elements are only used in AS data mode: isSendEnabled server1NetAddress
server1SendPort server1RetrievePort server2NetAddress server2SendPort
server2RetrievePort sharedSecret retransmissionDelayMilliSeconds maxTransmissions
soapTimeoutSeconds useDBS eclQueryApplicationURL eclQueryDataRepositoryURL

**Attributes:**

|Name                               |Type |Description                          |
|-----------------------------------|-----|-------------------------------------|
|is_send_enabled                    |bool |isSendEnabled                        |
|server1_net_address                |str  |server1NetAddress *Optional*         |
|server1_send_port                  |int  |server1SendPort                      |
|server1_retrieve_port              |int  |server1RetrievePort                  |
|server2_net_address                |str  |server2NetAddress *Optional*         |
|server2_send_port                  |int  |server2SendPort                      |
|server2_retrieve_port              |int  |server2RetrievePort                  |
|shared_secret                      |str  |sharedSecret *Optional*              |
|retransmission_delay_milli_seconds |int  |retransmissionDelayMilliSeconds      |
|max_transmissions                  |int  |maxTransmissions                     |
|soap_timeout_seconds               |int  |soapTimeoutSeconds                   |
|use_dbs                            |bool |useDBS                               |
|max_non_paged_response_size        |int  |maxNonPagedResponseSize              |
|ecl_query_application_url          |str  |eclQueryApplicationURL *Optional*    |
|ecl_query_data_repository_url      |str  |eclQueryDataRepositoryURL *Optional* |
</div>


## `SystemEnhancedCallLogsGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Replaced By `SystemEnhancedCallLogsGetResponse24()`.

Response to `SystemEnhancedCallLogsGetRequest22()`.

**Attributes:**

|Name                          |Type|Description                          |
|------------------------------|----|-------------------------------------|
|max_non_paged_response_size   |int |maxNonPagedResponseSize              |
|ecl_query_application_url     |str |eclQueryApplicationURL *Optional*    |
|ecl_query_data_repository_url |str |eclQueryDataRepositoryURL *Optional* |
</div>


## `SystemEnhancedCallLogsGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemEnhancedCallLogsGetRequest22V2()`.


**Attributes:**

|Name                          |Type|Description                          |
|------------------------------|----|-------------------------------------|
|default_schema                |str |defaultSchema *Optional*             |
|max_non_paged_response_size   |int |maxNonPagedResponseSize              |
|ecl_query_application_url     |str |eclQueryApplicationURL *Optional*    |
|ecl_query_data_repository_url |str |eclQueryDataRepositoryURL *Optional* |
</div>


## `SystemEnhancedCallLogsSchemaInstanceGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemEnhancedCallLogsSchemaInstanceGetListRequest()`.

Contains a table with column headings: "Instance Name", "Actual Users", "Potential
Users".

**Attributes:**

|Name                        |Type                           |Description                                                                       |
|----------------------------|-------------------------------|----------------------------------------------------------------------------------|
|schema_instance_usage_table |List(schemaInstanceUsageTable) |schemaInstanceUsageTable - *Table* array of schemaInstanceUsageTable named tuples |
</div>


## `SystemEnterpriseTrunkGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemEnterpriseTrunkGetRequest()`.


**Attributes:**

|Name                                     |Type |Description                         |
|-----------------------------------------|-----|------------------------------------|
|enable_holdover_of_highwater_call_counts |bool |enableHoldoverOfHighwaterCallCounts |
|holdover_period                          |str  |holdoverPeriod                      |
|time_zone_offset_minutes                 |str  |timeZoneOffsetMinutes               |
</div>


## `SystemExecutiveGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemExecutiveGetRequest()`.


**Attributes:**

|Name                                   |Type |Description                      |
|---------------------------------------|-----|---------------------------------|
|treat_virtual_on_net_calls_as_internal |bool |treatVirtualOnNetCallsAsInternal |
</div>


## `SystemExpensiveCallNotificationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemExpensiveCallNotificationGetRequest()`.


**Attributes:**

|Name                                 |Type |Description                      |
|-------------------------------------|-----|---------------------------------|
|enable_post_announcement_delay_timer |bool |enablePostAnnouncementDelayTimer |
|post_announcement_delay_seconds      |int  |postAnnouncementDelaySeconds     |
</div>


## `SystemExpensiveCallTypeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemExpensiveCallTypeGetListRequest()`.

Replaced by: `SystemExpensiveCallTypeGetListResponse16sp1()`

**Attributes:**

|Name                     |Type      |Description                       |
|-------------------------|----------|----------------------------------|
|alternate_call_indicator |List[str] |alternateCallIndicator *Optional* |
</div>


## `SystemExpensiveCallTypeGetListResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemExpensiveCallTypeGetListRequest16sp1()`.

The column headings are: "Alternate Call Indicator", "Treatment Audio File".

**Attributes:**

|Name                           |Type                              |Description                                                                             |
|-------------------------------|----------------------------------|----------------------------------------------------------------------------------------|
|alternate_call_indicator_table |List(alternateCallIndicatorTable) |alternateCallIndicatorTable - *Table* array of alternateCallIndicatorTable named tuples |
</div>


## `SystemExtensionLengthGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemExtensionLengthGetRequest()`.


**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|min_extension_length |int |minExtensionLength |
|max_extension_length |int |maxExtensionLength |
</div>


## `SystemExternalAuthenticationGetACLListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemExternalAuthenticationGetACLListRequest()`.

The table columns are: "Net Address" and "Description".

**Attributes:**

|Name      |Type           |Description                                       |
|----------|---------------|--------------------------------------------------|
|acl_table |List(aclTable) |aclTable - *Table* array of aclTable named tuples |
</div>


## `SystemExternalEmergencyRoutingParametersGetResponse13mp13`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemExternalEmergencyRoutingParametersGetRequest13mp13()`.

Contains a list of system External Emergency Routing parameters.

**Attributes:**

|Name                       |Type |Description                       |
|---------------------------|-----|----------------------------------|
|service_uri                |str  |serviceURI *Optional*             |
|default_emergency_number   |str  |defaultEmergencyNumber *Optional* |
|is_active                  |bool |isActive                          |
|supports_dnssrv            |bool |supportsDNSSRV                    |
|connection_timeout_seconds |int  |connectionTimeoutSeconds          |
</div>


## `SystemFaxMessagingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemFAXMessagingGetRequest()`.

The following elements are only used in AS data mode: statusDurationHours
statusAuditIntervalHours

**Attributes:**

|Name                              |Type|Description                   |
|----------------------------------|----|------------------------------|
|status_duration_hours             |int |statusDurationHours           |
|status_audit_interval_hours       |int |statusAuditIntervalHours      |
|maximum_concurrent_faxes_per_user |int |maximumConcurrentFaxesPerUser |
</div>


## `SystemFileGetContentResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemFileGetContentRequest()`.

The fileContent length returned is limited to 128KBytes.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|file_content |str |fileContent |
</div>


## `SystemFileRepositoryDeviceGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemFileRepositoryDeviceGetListRequest()`.

Contains a table with column headings : "Name","Protocol", "Root Directory", "Extended
File Capture Support" in a row for each file repository.

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|file_repository_table |List(fileRepositoryTable) |fileRepositoryTable - *Table* array of fileRepositoryTable named tuples |
</div>


## `SystemFileRepositoryDeviceUserGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemFileRepositoryDeviceUserGetListRequest()`.

Contains a table with column headings : "User Name","Allow Get","Allow Delete","Allow
Put" in a row for each file repository user.

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|file_repository_user_table |List(fileRepositoryUserTable) |fileRepositoryUserTable - *Table* array of fileRepositoryUserTable named tuples |
</div>


## `SystemFileRepositoryDeviceUserGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemFileRepositoryDeviceUserGetRequest()`.


**Attributes:**

|Name         |Type |Description |
|-------------|-----|------------|
|allow_put    |bool |allowPut    |
|allow_delete |bool |allowDelete |
|allow_get    |bool |allowGet    |
</div>


## `SystemGETSAvpCodeMapGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGETSAvpCodeMapGetListRequest()`.

The table columns are: "AVP Code" and "Vendor ID".

**Attributes:**

|Name           |Type               |Description                                               |
|---------------|-------------------|----------------------------------------------------------|
|avp_code_table |List(avpCodeTable) |avpCodeTable - *Table* array of avpCodeTable named tuples |
</div>


## `SystemGETSGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGETSGetRequest()`.


**Attributes:**

|Name                             |Type |Description                   |
|---------------------------------|-----|------------------------------|
|enabled                          |bool |enabled                       |
|enable_require_resource_priority |bool |enableRequireResourcePriority |
|send_access_resource_priority    |bool |sendAccessResourcePriority    |
|call_identifier_mode             |str  |callIdentifierMode            |
|default_priority_avp             |int  |defaultPriorityAVP            |
|signaling_dscp                   |int  |signalingDSCP                 |
|default_r_value                  |str  |defaultRValue                 |
|bypass_ro_release                |bool |bypassRoRelease               |
</div>


## `SystemGETSNumberGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGETSNumberGetListRequest()`.

The table columns are: "Number", "Type" and "Description".

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|reserved_number_table |List(reservedNumberTable) |reservedNumberTable - *Table* array of reservedNumberTable named tuples |
</div>


## `SystemGETSReservedFeatureAccessCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGETSReservedFeatureAccessCodeGetListRequest()`.

The table columns are: "Code" and "Description".

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|reserved_code_table |List(reservedCodeTable) |reservedCodeTable - *Table* array of reservedCodeTable named tuples |
</div>


## `SystemGETSResourcePriorityGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGETSResourcePriorityGetListRequest()`.

The table columns are: "Priority Value", "Priority Level" and "Priority Class".

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|resource_priority_table |List(resourcePriorityTable) |resourcePriorityTable - *Table* array of resourcePriorityTable named tuples |
</div>


## `SystemGETSSessionPriorityMapGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGETSSessionPriorityMapGetListRequest()`.

The table columns are: "Priority Level" and "Session Priority Value".

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|session_priority_table |List(sessionPriorityTable) |sessionPriorityTable - *Table* array of sessionPriorityTable named tuples |
</div>


## `SystemGeographicRedundancyPeerSipConnectionMonitoringGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGeographicRedundancyPeerSipConnectionMonitoringGetRequest()`.

Contains a list of Peer SIP Connection Monitoring system parameters.

**Attributes:**

|Name               |Type |Description       |
|-------------------|-----|------------------|
|enabled            |bool |enabled           |
|heartbeat_interval |int  |heartbeatInterval |
|heartbeat_timeout  |int  |heartbeatTimeout  |
</div>


## `SystemGeographicRedundancyProxyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGeographicRedundancyProxyGetRequest()`.

Contains a list of Geographic Redundancy Proxy system parameters.

**Attributes:**

|Name    |Type |Description|
|--------|-----|-----------|
|enabled |bool |enabled    |
</div>


## `SystemGeographicRedundancyUnreachableFromPrimaryGetUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGeographicRedundancyUnreachableFromPrimaryGetUserListRequest()`.

The Unreachable From Primary User table column headings are: "User ID", "Lineport".
Replaced by: `SystemGeographicRedundancyUnreachableFromPrimaryGetUserListResponse22()`
in AS data mode

**Attributes:**

|Name                                |Type                                  |Description                                                                                     |
|------------------------------------|--------------------------------------|------------------------------------------------------------------------------------------------|
|unreachable_from_primary_user_table |List(unreachableFromPrimaryUserTable) |unreachableFromPrimaryUserTable - *Table* array of unreachableFromPrimaryUserTable named tuples |
</div>


## `SystemGeographicRedundancyUnreachableFromPrimaryGetUserListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGeographicRedundancyUnreachableFromPrimaryGetUserListRequest22()`.

The Unreachable From Primary User table column headings are: "User ID", "Lineport".
The optional totalNumberOfUnreachableFromPrimaryUsers is returned only when the
userListSizeLimit is set in the request and if the total number of unreachable from
primary users is greater than the value of userListSizeLimit.

**Attributes:**

|Name                                           |Type                                  |Description                                                                                     |
|-----------------------------------------------|--------------------------------------|------------------------------------------------------------------------------------------------|
|unreachable_from_primary_user_table            |List(unreachableFromPrimaryUserTable) |unreachableFromPrimaryUserTable - *Table* array of unreachableFromPrimaryUserTable named tuples |
|total_number_of_unreachable_from_primary_users |int                                   |totalNumberOfUnreachableFromPrimaryUsers *Optional*                                             |
</div>


## `SystemGetRegistrationContactListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGetRegistrationContactListRequest()`.

The table columns are: "Service Provider Id", "Group Id", "User Id", "Line/Port",
"Endpoint Type", "Order", "URI", "Expiration", "Contact", "Device Level", "Device
Name", "Public Net Address", "Public Port", "Private Net Address", "Private Port",
"User Agent", "Reseller Id". The following columns are only returned in AS data mode:
"Reseller Id"

**Attributes:**

|Name               |Type                    |Description                                                         |
|-------------------|------------------------|--------------------------------------------------------------------|
|registration_table |List(registrationTable) |registrationTable - *Table* array of registrationTable named tuples |
</div>


## `SystemGetRegistrationContactListResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGetRegistrationContactListRequest()`.

The table columns are: "Service Provider Id", "Group Id", "User Id", "Line/Port",
"Endpoint Type", "Order", "URI", "Expiration", "Contact", "Device Level", "Device
Name", "Public Net Address", "Public Port", "Private Net Address", "Private Port",
"User Agent", "Reseller Id", "Path Header". The Endpoint Type column contains one of
the enumerated RegistrationEndpointType21sp1 values.  The value Mobility in Endpoint
Type column is only applicable in AS data mode.  The following columns are only
returned in AS data mode: "Reseller Id"

**Attributes:**

|Name               |Type                    |Description                                                         |
|-------------------|------------------------|--------------------------------------------------------------------|
|registration_table |List(registrationTable) |registrationTable - *Table* array of registrationTable named tuples |
</div>


## `SystemGroupNightForwardingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGroupNightForwardingGetRequest()`.


**Attributes:**

|Name                                              |Type |Description                                 |
|--------------------------------------------------|-----|--------------------------------------------|
|night_forward_inter_group_calls_within_enterprise |bool |nightForwardInterGroupCallsWithinEnterprise |
</div>


## `SystemHPBXAlternateCarrierSelectionGetCarrierListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemHPBXAlternateCarrierSelectionGetCarrierListRequest()`.

Contains a table with column headings: "Carrier Name", "Carrier Prefix", "Carrier
Domain", "Carrier Type" The possible values for Carrier Type are "Local And Distant"
and "Distant".

**Attributes:**

|Name                          |Type                             |Description                                                                           |
|------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|hpbx_alternate_carriers_table |List(HPBXAlternateCarriersTable) |HPBXAlternateCarriersTable - *Table* array of HPBXAlternateCarriersTable named tuples |
</div>


## `SystemHPBXMobileTerminationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemHPBXMobileTerminationGetRequest()`.

Contains the hPBX mobile termination related configuration parameters.

**Attributes:**

|Name           |Type|Description              |
|---------------|----|-------------------------|
|routing_prefix |str |routingPrefix *Optional* |
</div>


## `SystemHolidayScheduleGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemHolidayScheduleGetListRequest()`.

The response contains all the system holiday schedule names.

**Attributes:**

|Name                  |Type      |Description                    |
|----------------------|----------|-------------------------------|
|holiday_schedule_name |List[str] |holidayScheduleName *Optional* |
</div>


## `SystemHomeNetworkGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemHomeNetworkGetListRequest()`.


**Attributes:**

|Name        |Type      |Description           |
|------------|----------|----------------------|
|msc_address |List[str] |mscAddress *Optional* |
</div>


## `SystemHuntGroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemHuntGroupGetRequest()`.

Replaced by: `SystemHuntGroupGetResponse17()`

**Attributes:**

|Name                              |Type |Description                   |
|----------------------------------|-----|------------------------------|
|anonymous_instead_of_private_clid |bool |anonymousInsteadOfPrivateCLID |
|remove_hunt_group_name_from_clid  |bool |removeHuntGroupNameFromCLID   |
</div>


## `SystemHuntGroupGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemHuntGroupGetRequest()`.

Replaced by: `SystemHuntGroupGetResponse21()` in AS data mode

**Attributes:**

|Name                                   |Type |Description                        |
|---------------------------------------|-----|-----------------------------------|
|anonymous_instead_of_private_clid      |bool |anonymousInsteadOfPrivateCLID      |
|remove_hunt_group_name_from_clid       |bool |removeHuntGroupNameFromCLID        |
|uniform_call_distribution_policy_scope |str  |uniformCallDistributionPolicyScope |
</div>


## `SystemHuntGroupGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemHuntGroupGetRequest21()`.


**Attributes:**

|Name                                   |Type |Description                        |
|---------------------------------------|-----|-----------------------------------|
|remove_hunt_group_name_from_clid       |bool |removeHuntGroupNameFromCLID        |
|uniform_call_distribution_policy_scope |str  |uniformCallDistributionPolicyScope |
|allow_agent_device_initiated_forward   |bool |allowAgentDeviceInitiatedForward   |
</div>


## `SystemInCallServiceActivationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemInCallServiceActivationGetRequest()`.

Replaced by: `SystemInCallServiceActivationGetResponse17()`

**Attributes:**

|Name                      |Type|Description             |
|--------------------------|----|------------------------|
|default_activation_digits |str |defaultActivationDigits |
</div>


## `SystemInCallServiceActivationGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemInCallServiceActivationGetRequest17()`.


**Attributes:**

|Name                                    |Type|Description                         |
|----------------------------------------|----|------------------------------------|
|default_flash_activation_digits         |str |defaultFlashActivationDigits        |
|default_call_transfer_activation_digits |str |defaultCallTransferActivationDigits |
</div>


## `SystemIntegratedIMPGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemIntegratedIMPGetRequest()`.

The response contains the system Integrated IMP service attributes.  Replaced by
`SystemIntegratedIMPGetResponse19()`.

**Attributes:**

|Name                                |Type |Description                   |
|------------------------------------|-----|------------------------------|
|service_domain                      |str  |serviceDomain *Optional*      |
|service_port                        |int  |servicePort *Optional*        |
|add_service_provider_in_imp_user_id |bool |addServiceProviderInIMPUserId |
</div>


## `SystemIntegratedIMPGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemIntegratedIMPGetRequest19()`.

The response contains the system Integrated IMP service attributes.  The following
elements are only used in AS data mode and not returned in XS data mode: boshURL
Replaced by: `SystemIntegratedIMPGetResponse21()` in AS data mode

**Attributes:**

|Name                                |Type |Description                   |
|------------------------------------|-----|------------------------------|
|service_domain                      |str  |serviceDomain *Optional*      |
|service_port                        |int  |servicePort *Optional*        |
|add_service_provider_in_imp_user_id |bool |addServiceProviderInIMPUserId |
|bosh_url                            |str  |boshURL *Optional*            |
</div>


## `SystemIntegratedIMPGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemIntegratedIMPGetRequest21()`.

The response contains the system Integrated IMP service attributes.  The following
elements are only used in AS data mode: boshURL

**Attributes:**

|Name                                |Type |Description                   |
|------------------------------------|-----|------------------------------|
|service_domain                      |str  |serviceDomain *Optional*      |
|service_port                        |int  |servicePort *Optional*        |
|add_service_provider_in_imp_user_id |bool |addServiceProviderInIMPUserId |
|bosh_url                            |str  |boshURL *Optional*            |
|allow_imp_password_retrieval        |bool |allowImpPasswordRetrieval     |
</div>


## `SystemInterceptUserGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemInterceptUserGetRequest()`.


**Attributes:**

|Name                           |Type |Description                 |
|-------------------------------|-----|----------------------------|
|emergency_and_repair_intercept |bool |emergencyAndRepairIntercept |
</div>


## `SystemInventoryReportGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemInventoryReportGetRequest()`.


**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|default_from_address |str |defaultFromAddress |
</div>


## `SystemLanguageGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLanguageGetListRequest()`.

The language table column headings are: "Language", "Locale" and "Encoding".

**Attributes:**

|Name             |Type                |Description                                                 |
|-----------------|--------------------|------------------------------------------------------------|
|default_language |str                 |defaultLanguage                                             |
|language_table   |List(languageTable) |languageTable - *Table* array of languageTable named tuples |
</div>


## `SystemLegacyAutomaticCallbackGetLineTypeListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLegacyAutomaticCallbackGetLineTypeListRequest()`.

Returns a 3 column table with column headings: "Line Type", "Match" and "No Match".
The possible values for the "Match" and "No Match" columns are "Accept" and "Deny".

**Attributes:**

|Name            |Type                |Description                                                 |
|----------------|--------------------|------------------------------------------------------------|
|line_type_table |List(lineTypeTable) |lineTypeTable - *Table* array of lineTypeTable named tuples |
</div>


## `SystemLegacyAutomaticCallbackGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLegacyAutomaticCallbackGetRequest()`.


**Attributes:**

|Name                        |Type|Description              |
|----------------------------|----|-------------------------|
|max_monitors_per_originator |int |maxMonitorsPerOriginator |
|max_monitors_per_terminator |int |maxMonitorsPerTerminator |
|t2_minutes                  |int |t2Minutes                |
|t4_seconds                  |int |t4Seconds                |
|t5_seconds                  |int |t5Seconds                |
|t6_minutes                  |int |t6Minutes                |
|t7_minutes                  |int |t7Minutes                |
|t8_seconds                  |int |t8Seconds                |
|t_ring_seconds              |int |tRingSeconds             |
|t10_o_minutes               |int |t10OMinutes              |
|t10_t_minutes               |int |t10TMinutes              |
</div>


## `SystemLicensingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLicensingGetRequest()`.

The license table columns are: "Name", "Licensed", "Used", "Available" and "Expiration
Date".

Replaced By: `SystemLicensingGetResponse14sp3()`

**Attributes:**

|Name               |Type               |Description                                               |
|-------------------|-------------------|----------------------------------------------------------|
|license_strictness |str                |licenseStrictness                                         |
|group_userlimit    |int                |groupUserlimit                                            |
|expiration_date    |str                |expirationDate *Optional*                                 |
|host_id            |List[str]          |hostId *Optional*                                         |
|license_name       |List[str]          |licenseName *Optional*                                    |
|license_table      |List(licenseTable) |licenseTable - *Table* array of licenseTable named tuples |
</div>


## `SystemLicensingGetResponse14sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLicensingGetRequest14sp3()`.

The subscriber license table columns are: "Name", "Licensed", "Used" and "Available".
The group service license table columns are: "Name", "Licensed", "Used" and
"Available". The virtual service license table columns are: "Name", "Licensed", "Used"
and "Available". The user service license table columns are: "Name", "Licensed",
"Used", "Available", "Used By Hosted Users", "Used By Trunk Users", and "Expiration
Date". The system param license table columns are: "Name", "Licensed", "Used",
Available".

**Attributes:**

|Name                          |Type                             |Description                                                                           |
|------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|license_strictness            |str                              |licenseStrictness                                                                     |
|group_userlimit               |int                              |groupUserlimit                                                                        |
|expiration_date               |str                              |expirationDate *Optional*                                                             |
|host_id                       |List[str]                        |hostId *Optional*                                                                     |
|license_name                  |List[str]                        |licenseName *Optional*                                                                |
|number_of_trunk_users         |int                              |numberOfTrunkUsers                                                                    |
|subscriber_license_table      |List(subscriberLicenseTable)     |subscriberLicenseTable - *Table* array of subscriberLicenseTable named tuples         |
|group_service_license_table   |List(groupServiceLicenseTable)   |groupServiceLicenseTable - *Table* array of groupServiceLicenseTable named tuples     |
|virtual_service_license_table |List(virtualServiceLicenseTable) |virtualServiceLicenseTable - *Table* array of virtualServiceLicenseTable named tuples |
|user_service_license_table    |List(userServiceLicenseTable)    |userServiceLicenseTable - *Table* array of userServiceLicenseTable named tuples       |
|system_param_license_table    |List(systemParamLicenseTable)    |systemParamLicenseTable - *Table* array of systemParamLicenseTable named tuples       |
</div>


## `SystemLicensingGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLicensingGetRequest21sp1()`.

The subscriber license table columns are: "Name", "Licensed", "Used" and "Available".
The group service license table columns are: "Name", "Licensed", "Used" and
"Available". The virtual service license table columns are: "Name", "Licensed", "Used"
and "Available". The user service license table columns are: "Name", "Licensed",
"Used", "Available", "Used By Hosted Users", "Used By Trunk Users", and "Expiration
Date". The system param license table columns are: "Name", "Licensed", "Used",
Available".

**Attributes:**

|Name                          |Type                             |Description                                                                           |
|------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|license_strictness            |str                              |licenseStrictness                                                                     |
|group_userlimit               |int                              |groupUserlimit                                                                        |
|expiration_date               |str                              |expirationDate *Optional*                                                             |
|host_id                       |List[str]                        |hostId *Optional*                                                                     |
|license_name                  |List[str]                        |licenseName *Optional*                                                                |
|number_of_trunk_users         |int                              |numberOfTrunkUsers                                                                    |
|system_id                     |str                              |systemId *Optional*                                                                   |
|subscriber_license_table      |List(subscriberLicenseTable)     |subscriberLicenseTable - *Table* array of subscriberLicenseTable named tuples         |
|group_service_license_table   |List(groupServiceLicenseTable)   |groupServiceLicenseTable - *Table* array of groupServiceLicenseTable named tuples     |
|virtual_service_license_table |List(virtualServiceLicenseTable) |virtualServiceLicenseTable - *Table* array of virtualServiceLicenseTable named tuples |
|user_service_license_table    |List(userServiceLicenseTable)    |userServiceLicenseTable - *Table* array of userServiceLicenseTable named tuples       |
|system_param_license_table    |List(systemParamLicenseTable)    |systemParamLicenseTable - *Table* array of systemParamLicenseTable named tuples       |
</div>


## `SystemLicensingGetSystemLicenseListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLicensingGetSystemLicenseListRequest()`.

Replaced by: `SystemLicensingGetSystemLicenseListResponse21()` in AS data mode

**Attributes:**

|Name    |Type      |Description        |
|--------|----------|-------------------|
|license |List[str] |license *Optional* |
</div>


## `SystemLicensingGetSystemLicenseListResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLicensingGetSystemLicenseListRequest19sp1()`.

Replaced by: `SystemLicensingGetSystemLicenseListRequest21sp1()`.

**Attributes:**

|Name    |Type      |Description        |
|--------|----------|-------------------|
|license |List[str] |license *Optional* |
</div>


## `SystemLicensingGetSystemLicenseListResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLicensingGetSystemLicenseListRequest21()`.

Replaced by: `SystemLicensingGetSystemLicenseListRequest21sp1()`.

**Attributes:**

|Name    |Type      |Description        |
|--------|----------|-------------------|
|license |List[str] |license *Optional* |
</div>


## `SystemLicensingGetSystemLicenseListResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLicensingGetSystemLicenseListRequest21sp1()`.

Replaced by: `SystemLicensingGetSystemLicenseListRequest22()`.

**Attributes:**

|Name    |Type      |Description        |
|--------|----------|-------------------|
|license |List[str] |license *Optional* |
</div>


## `SystemLicensingGetSystemLicenseListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLicensingGetSystemLicenseListRequest22()`.

Replaced by: `SystemLicensingGetSystemLicenseListResponse22V2()`.

**Attributes:**

|Name    |Type      |Description        |
|--------|----------|-------------------|
|license |List[str] |license *Optional* |
</div>


## `SystemLicensingGetSystemLicenseListResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLicensingGetSystemLicenseListRequest22V2()`.


**Attributes:**

|Name    |Type      |Description        |
|--------|----------|-------------------|
|license |List[str] |license *Optional* |
</div>


## `SystemLocationBasedCallingRestrictionsGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLocationBasedCallingRestrictionsGetRequest()`.

Replaced by: `SystemLocationBasedCallingRestrictionsGetResponse17sp3()`

**Attributes:**

|Name                            |Type |Description                  |
|--------------------------------|-----|-----------------------------|
|physical_location_indicator     |str  |physicalLocationIndicator    |
|enforce_msc_validation          |bool |enforceMscValidation         |
|enable_office_zone_announcement |bool |enableOfficeZoneAnnouncement |
</div>


## `SystemLocationBasedCallingRestrictionsGetResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemLocationBasedCallingRestrictionsGetRequest17sp3()`.


**Attributes:**

|Name                            |Type |Description                  |
|--------------------------------|-----|-----------------------------|
|physical_location_indicator     |str  |physicalLocationIndicator    |
|enforce_msc_validation          |bool |enforceMscValidation         |
|enable_office_zone_announcement |bool |enableOfficeZoneAnnouncement |
|enhance_office_zone             |bool |enhanceOfficeZone            |
</div>


## `SystemMGCPDeviceTypeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMGCPDeviceTypeGetListRequest()`.

Contains a table of identity/ device profile types configured in the system.  The
column headings are: "Device Type", "Profile", "Is Obsolete".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|device_type_table |List(deviceTypeTable) |deviceTypeTable - *Table* array of deviceTypeTable named tuples |
</div>


## `SystemMailParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMailParametersGetListRequest()`.

Contains a list of system Mail parameters.

**Attributes:**

|Name                                  |Type |Description                          |
|--------------------------------------|-----|-------------------------------------|
|primary_server_net_address            |str  |primaryServerNetAddress *Optional*   |
|secondary_server_net_address          |str  |secondaryServerNetAddress *Optional* |
|default_from_address                  |str  |defaultFromAddress                   |
|default_subject                       |str  |defaultSubject *Optional*            |
|support_dnssrv_for_mail_server_access |bool |supportDNSSRVForMailServerAccess     |
</div>


## `SystemMailParametersGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMailParametersGetListRequest22()`.

Contains a list of system Mail parameters.

**Attributes:**

|Name                                  |Type |Description                          |
|--------------------------------------|-----|-------------------------------------|
|primary_server_net_address            |str  |primaryServerNetAddress *Optional*   |
|secondary_server_net_address          |str  |secondaryServerNetAddress *Optional* |
|default_from_address                  |str  |defaultFromAddress                   |
|default_subject                       |str  |defaultSubject *Optional*            |
|support_dnssrv_for_mail_server_access |bool |supportDNSSRVForMailServerAccess     |
|secure_mode                           |str  |secureMode                           |
|port                                  |int  |port *Optional*                      |
</div>


## `SystemMaliciousCallTraceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemMaliciousCallTraceGetRequest()`.

The response contains the Malicious Call Trace system parameters and the list of users
that use the Malicious Call Trace feature.  The column headings are "Service Provider
Id", "Group Id", "User Id", "Last Name", "First Name", "Phone Number", "Trace Type",
"Status", "Hiragana Last Name" and "Hiragana First Name", "Extension", "Department",
"Email Address".

**Attributes:**

|Name                          |Type            |Description                                         |
|------------------------------|----------------|----------------------------------------------------|
|play_mct_warning_announcement |bool            |playMCTWarningAnnouncement                          |
|user_table                    |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `SystemMaliciousCallTraceGetUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMaliciousCallTraceGetUserListRequest()`.

The column headings are "Service Provider Id", "Group Id", "User Id", "Last Name",
"First Name", "Phone Number", "Trace Type", "Status", "Hiragana Last Name" and
"Hiragana First Name".

Replaced By: `SystemMaliciousCallTraceGetResponse()`

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `SystemMediaGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMediaGetListRequest()`.

The column headings are "Media Name", "Codec", "Media Type", "Bandwidth Enforcement
Type" and "Bandwidth".

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|media_table |List(mediaTable) |mediaTable - *Table* array of mediaTable named tuples |
</div>


## `SystemMediaGroupCodecGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMediaGroupCodecGetListRequest()`.

Contains a table of media assigned to the media group.  The column headings are:
"Codec Name", "Codec Weight".

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|codec_table |List(codecTable) |codecTable - *Table* array of codecTable named tuples |
</div>


## `SystemMediaGroupGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMediaGroupGetListRequest()`.

The response includes an array of media groups defined in the system.

**Attributes:**

|Name |Type      |Description     |
|-----|----------|----------------|
|name |List[str] |name *Optional* |
</div>


## `SystemMediaGroupUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMediaGroupUsageListRequest()`.

Contains a table of SAC groups associated with the media group.  The column headings
are: "SAC Group Name", "Organization Id", "Organization Type", and "Group Id". The
"Group Id" will be empty for enterprise SAC groups.

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|usage_table |List(usageTable) |usageTable - *Table* array of usageTable named tuples |
</div>


## `SystemMediaServerGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMediaServerGetListRequest()`.

The Media Server table column headings are: "Net Address", "Port", "Transport",
"Description".

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|media_server_table |List(mediaServerTable) |mediaServerTable - *Table* array of mediaServerTable named tuples |
</div>


## `SystemMediaServerParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMediaServerParametersGetListRequest()`.

Contains a list of system Media Server parameters.

**Attributes:**

|Name                                            |Type |Description                                |
|------------------------------------------------|-----|-------------------------------------------|
|media_server_response_timer_milliseconds        |int  |mediaServerResponseTimerMilliseconds       |
|media_server_selection_route_timer_milliseconds |int  |mediaServerSelectionRouteTimerMilliseconds |
|use_static_media_server_device                  |bool |useStaticMediaServerDevice                 |
</div>


## `SystemMediaSetGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMediaSetGetRequest()`.


**Attributes:**

|Name           |Type      |Description             |
|---------------|----------|------------------------|
|media_set_name |List[str] |mediaSetName *Optional* |
</div>


## `SystemMediaSetGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMediaSetGetRequest()`.

Returns a list of media names in the set.

**Attributes:**

|Name       |Type      |Description|
|-----------|----------|-----------|
|media_name |List[str] |mediaName  |
</div>


## `SystemMeetMeConferencingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMeetMeConferencingGetRequest()`.

Replaced by: `SystemMeetMeConferencingGetResponse17sp3()`

**Attributes:**

|Name                                         |Type |Description                             |
|---------------------------------------------|-----|----------------------------------------|
|conference_id_length                         |int  |conferenceIdLength                      |
|moderator_pin_length                         |int  |moderatorPinLength                      |
|enable_conference_end_date_restriction       |bool |enableConferenceEndDateRestriction      |
|conference_end_date_restriction_months       |int  |conferenceEndDateRestrictionMonths      |
|delete_expired_conferences_after_hold_period |bool |deleteExpiredConferencesAfterHoldPeriod |
|expired_conference_hold_period_days          |int  |expiredConferenceHoldPeriodDays         |
|recording_web_app_url                        |str  |recordingWebAppURL *Optional*           |
</div>


## `SystemMeetMeConferencingGetResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMeetMeConferencingGetRequest17sp3()`.

Replaced by: `SystemMeetMeConferencingGetResponse18()`

**Attributes:**

|Name                                         |Type |Description                             |
|---------------------------------------------|-----|----------------------------------------|
|conference_id_length                         |int  |conferenceIdLength                      |
|moderator_pin_length                         |int  |moderatorPinLength                      |
|enable_conference_end_date_restriction       |bool |enableConferenceEndDateRestriction      |
|conference_end_date_restriction_months       |int  |conferenceEndDateRestrictionMonths      |
|delete_expired_conferences_after_hold_period |bool |deleteExpiredConferencesAfterHoldPeriod |
|expired_conference_hold_period_days          |int  |expiredConferenceHoldPeriodDays         |
|recording_web_app_url                        |str  |recordingWebAppURL *Optional*           |
|recording_file_format                        |str  |recordingFileFormat                     |
</div>


## `SystemMigratedUsersGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMigratedUsersGetListRequest()`.

Replaced by: `SystemMigratedUsersGetListResponse22()` in AS data mode

**Attributes:**

|Name    |Type      |Description       |
|--------|----------|------------------|
|user_id |List[str] |userId *Optional* |
</div>


## `SystemMigratedUsersGetListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMigratedUsersGetListRequest22()`.

The optional totalNumberOfMigratedUsers is returned only when the userListSizeLimit is
set in the request and if the total number of migrated users is greater than the value
of userListSizeLimit.

**Attributes:**

|Name                           |Type      |Description                           |
|-------------------------------|----------|--------------------------------------|
|user_id                        |List[str] |userId *Optional*                     |
|total_number_of_migrated_users |int       |totalNumberOfMigratedUsers *Optional* |
</div>


## `SystemMultimediaPolicyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMultimediaPolicyGetRequest()`

**Attributes:**

|Name                                 |Type |Description                     |
|-------------------------------------|-----|--------------------------------|
|restrict_non_audio_video_media_types |bool |restrictNonAudioVideoMediaTypes |
</div>


## `SystemMusicOnHoldGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMusicOnHoldGetRequest()`.


**Attributes:**

|Name               |Type|Description       |
|-------------------|----|------------------|
|delay_milliseconds |int |delayMilliseconds |
</div>


## `SystemNetworkClassOfServiceGetAssignedServiceProviderListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemNetworkClassOfServiceGetAssignedServiceProviderListRequest()`.

The response contains a table of all Service Providers that have the given Network
Class of Service assigned.  The column headings are "Service Provider Id", "Service
Provider Name" and "Is Enterprise".

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|service_provider_table |List(serviceProviderTable) |serviceProviderTable - *Table* array of serviceProviderTable named tuples |
</div>


## `SystemNetworkClassOfServiceGetAssignedSystemVoicePortalListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`SystemNetworkClassOfServiceGetAssignedSystemVoicePortalListRequest()`.

The response contains a table of system voice portals that have the given Network
Class of Service assigned.  The column headings are "System Voice Portal Id" and
"Name".

**Attributes:**

|Name                      |Type                         |Description                                                                   |
|--------------------------|-----------------------------|------------------------------------------------------------------------------|
|system_voice_portal_table |List(systemVoicePortalTable) |systemVoicePortalTable - *Table* array of systemVoicePortalTable named tuples |
</div>


## `SystemNetworkClassOfServiceGetCommunicationBarringProfileUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`SystemNetworkClassOfServiceGetCommunicationBarringProfileUsageListRequest()`.

The response contains a table of all Network Classes of Service that contain the
specific Communication Barring Profile.  The column headings are "Name" and
"Description"

**Attributes:**

|Name                           |Type                             |Description                                                                           |
|-------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|network_class_of_service_table |List(networkClassOfServiceTable) |networkClassOfServiceTable - *Table* array of networkClassOfServiceTable named tuples |
</div>


## `SystemNetworkClassOfServiceGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemNetworkClassOfServiceGetListRequest()`.

The response contains a table of all Network Classes of Service in the system.  The
column headings are "Name" and "Description"

**Attributes:**

|Name                           |Type                             |Description                                                                           |
|-------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|network_class_of_service_table |List(networkClassOfServiceTable) |networkClassOfServiceTable - *Table* array of networkClassOfServiceTable named tuples |
</div>


## `SystemNetworkDeviceMonitorParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNetworkDeviceMonitorParametersGetListRequest()`.

Contains a list of system Network Device Polling parameters.

**Attributes:**

|Name                            |Type|Description                  |
|--------------------------------|----|-----------------------------|
|polling_interval_minutes        |int |pollingIntervalMinutes       |
|failed_polling_interval_minutes |int |failedPollingIntervalMinutes |
</div>


## `SystemNetworkProgressionGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNetworkProgressionGetRequest()`.


**Attributes:**

|Name                |Type |Description       |
|--------------------|-----|------------------|
|is_active           |bool |isActive          |
|wait_period_seconds |int  |waitPeriodSeconds |
</div>


## `SystemNetworkRoutingServerGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNetworkRoutingServerGetListRequest()`.

The routing Network Server table column headings are: "Net Address", "Port",
"Transport", "Poll", "OpState", "Description".

**Attributes:**

|Name                         |Type                            |Description                                                                         |
|-----------------------------|--------------------------------|------------------------------------------------------------------------------------|
|network_routing_server_table |List(networkRoutingServerTable) |networkRoutingServerTable - *Table* array of networkRoutingServerTable named tuples |
</div>


## `SystemNetworkServerSyncParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNetworkServerSyncParametersGetListRequest()`.

Contains a list of system Network Server Sync parameters.

**Attributes:**

|Name        |Type |Description|
|------------|-----|-----------|
|enable_sync |bool |enableSync |
</div>


## `SystemNetworkServerSyncParametersGetResponse14sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNetworkServerSyncParametersGetRequest14sp2()`.

Contains a list of system Network Server Sync parameters.

Replaced By: `SystemNetworkServerSyncParametersGetResponse16()`

**Attributes:**

|Name            |Type |Description   |
|----------------|-----|--------------|
|enable_sync     |bool |enableSync    |
|sync_line_ports |bool |syncLinePorts |
</div>


## `SystemNetworkServerSyncParametersGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNetworkServerSyncParametersGetRequest16()`.

Contains a list of system Network Server Sync parameters.

Replaced By: `SystemNetworkServerSyncParametersGetResponse17sp4()`

**Attributes:**

|Name                        |Type |Description              |
|----------------------------|-----|-------------------------|
|enable_sync                 |bool |enableSync               |
|sync_line_ports             |bool |syncLinePorts            |
|sync_device_management_info |bool |syncDeviceManagementInfo |
</div>


## `SystemNetworkServerSyncParametersGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNetworkServerSyncParametersGetRequest17sp4()`.

Contains a list of system Network Server Sync parameters.  The following elements are
only used in AS data mode: syncTrunkGroups Replaced by:
`SystemNetworkServerSyncParametersGetResponse24()`

**Attributes:**

|Name                        |Type |Description              |
|----------------------------|-----|-------------------------|
|enable_sync                 |bool |enableSync               |
|sync_line_ports             |bool |syncLinePorts            |
|sync_device_management_info |bool |syncDeviceManagementInfo |
|sync_trunk_groups           |bool |syncTrunkGroups          |
</div>


## `SystemNetworkServerSyncParametersGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNetworkServerSyncParametersGetRequest22()`.

Contains a list of system Network Server Sync parameters.  The following elements are
only used in AS data mode: syncTrunkGroups Replaced by:
`SystemNetworkServerSyncParametersGetResponse24V2()` in AS data mode.

**Attributes:**

|Name                        |Type |Description              |
|----------------------------|-----|-------------------------|
|enable_sync                 |bool |enableSync               |
|sync_line_ports             |bool |syncLinePorts            |
|sync_device_management_info |bool |syncDeviceManagementInfo |
|sync_trunk_groups           |bool |syncTrunkGroups          |
|sync_enterprise_numbers     |bool |syncEnterpriseNumbers    |
</div>


## `SystemNetworkServerSyncParametersGetResponse24`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNetworkServerSyncParametersGetRequest24()`.

Contains a list of system Network Server Sync parameters.  The following elements are
only used in AS data mode: syncTrunkGroups Replaced by:
`SystemNetworkServerSyncParametersGetResponse24V2()` in AS data mode.

**Attributes:**

|Name                            |Type |Description                             |
|--------------------------------|-----|----------------------------------------|
|enable_sync                     |bool |enableSync                              |
|sync_line_ports                 |bool |syncLinePorts                           |
|sync_device_management_info     |bool |syncDeviceManagementInfo                |
|sync_trunk_groups               |bool |syncTrunkGroups                         |
|sync_connection_timeout_seconds |int  |syncConnectionTimeoutSeconds *Optional* |
</div>


## `SystemNetworkServerSyncParametersGetResponse24V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNetworkServerSyncParametersGetRequest24V2()`.

Contains a list of system Network Server Sync parameters.  The following elements are
only used in AS data mode: syncTrunkGroups

**Attributes:**

|Name                            |Type |Description                             |
|--------------------------------|-----|----------------------------------------|
|enable_sync                     |bool |enableSync                              |
|sync_line_ports                 |bool |syncLinePorts                           |
|sync_device_management_info     |bool |syncDeviceManagementInfo                |
|sync_trunk_groups               |bool |syncTrunkGroups                         |
|sync_connection_timeout_seconds |int  |syncConnectionTimeoutSeconds *Optional* |
|sync_enterprise_numbers         |bool |syncEnterpriseNumbers                   |
</div>


## `SystemNetworkSynchingServerGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNetworkSynchingServerGetListRequest()`.

The Network Server table column headings are: "Net Address", "Port", "Secure",
"Description", "Order". The following columns are only used in XS data mode and not
returned in AS data mode: Order The following elements are only used in AS data mode
and not returned in XS data mode: preferredNetworkServerNetAddress

**Attributes:**

|Name                                 |Type                             |Description                                                                           |
|-------------------------------------|---------------------------------|--------------------------------------------------------------------------------------|
|preferred_network_server_net_address |str                              |preferredNetworkServerNetAddress *Optional*                                           |
|network_synching_server_table        |List(networkSynchingServerTable) |networkSynchingServerTable - *Table* array of networkSynchingServerTable named tuples |
</div>


## `SystemNumberActivationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNumberActivationGetRequest()`.

Contains the system number activation setting.

**Attributes:**

|Name                  |Type |Description         |
|----------------------|-----|--------------------|
|use_number_activation |bool |useNumberActivation |
</div>


## `SystemNumberActivationGetResponse18sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNumberActivationGetRequest18sp1()`.

Contains the system number activation setting.

**Attributes:**

|Name                   |Type|Description          |
|-----------------------|----|---------------------|
|number_activation_mode |str |numberActivationMode |
</div>


## `SystemNumberActivationGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNumberActivationGetRequest21()`.

Contains the system number activation and enterprise trunk number range activation
setting.

**Attributes:**

|Name                                            |Type |Description                                |
|------------------------------------------------|-----|-------------------------------------------|
|number_activation_mode                          |str  |numberActivationMode                       |
|enable_enterprise_trunk_number_range_activation |bool |enableEnterpriseTrunkNumberRangeActivation |
</div>


## `SystemNumberFormattingParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemNumberFormattingParametersGetRequest()`.

Contains the system number formatting parameter.

**Attributes:**

|Name                             |Type |Description                  |
|---------------------------------|-----|-----------------------------|
|apply_formatting_to_e164_numbers |bool |applyFormattingToE164Numbers |
</div>


## `SystemNumberPortabilityQueryDigitPatternGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemNumberPortabilityQueryDigitPatternGetListRequest()`.

Contains a table with column headings: "Digit Pattern", "Status".

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|status_digit_pattern_table |List(statusDigitPatternTable) |statusDigitPatternTable - *Table* array of statusDigitPatternTable named tuples |
</div>


## `SystemNumberPortabilityQueryDigitPatternGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemNumberPortabilityQueryDigitPatternGetRequest()`.


**Attributes:**

|Name   |Type|Description|
|-------|----|-----------|
|status |str |status     |
</div>


## `SystemNumberPortabilityQueryGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemNumberPortabilityQueryGetRequest()`.

Returns system Number Portability Query Parameters.

**Attributes:**

|Name                                                |Type |Description                                    |
|----------------------------------------------------|-----|-----------------------------------------------|
|continue_call_as_dialed_on_timeout_or_error         |bool |continueCallAsDialedOnTimeoutOrError           |
|number_portability_name_lookup_timeout_milliseconds |int  |numberPortabilityNameLookupTimeoutMilliseconds |
</div>


## `SystemNumberPortabilityQueryStatusGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemNumberPortabilityQueryStatusGetListRequest()`.

Contains a table with column headings: "Status and Treatment File Name".

**Attributes:**

|Name         |Type              |Description                                             |
|-------------|------------------|--------------------------------------------------------|
|status_table |List(statusTable) |statusTable - *Table* array of statusTable named tuples |
</div>


## `SystemNumberPortabilityQueryStatusGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemNumberPortabilityQueryStatusGetRequest()`.


**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|treatment_file_name |str |treatmentFileName *Optional* |
</div>


## `SystemOCICallControlApplicationGetACLListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOCICallControlApplicationGetACLListRequest()`.

The table columns are: "Net Address" and "Description".

**Attributes:**

|Name      |Type           |Description                                       |
|----------|---------------|--------------------------------------------------|
|acl_table |List(aclTable) |aclTable - *Table* array of aclTable named tuples |
</div>


## `SystemOCICallControlApplicationGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOCICallControlApplicationGetListRequest()`.

The table columns are: "Application Id", "Enabled System Wide", "Description"
"Notification Timeout Seconds", "Max Event Channels Per Set" and "Channel Set Grace
Period Seconds".

**Attributes:**

|Name      |Type           |Description                                       |
|----------|---------------|--------------------------------------------------|
|app_table |List(appTable) |appTable - *Table* array of appTable named tuples |
</div>


## `SystemOCICallControlGetACLListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOCICallControlGetACLListRequest()`.

The table columns are: "Net Address" and "Description".

**Attributes:**

|Name      |Type           |Description                                       |
|----------|---------------|--------------------------------------------------|
|acl_table |List(aclTable) |aclTable - *Table* array of aclTable named tuples |
</div>


## `SystemOCIGetACLListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOCIGetACLListRequest()`.

Returns a 2 coulmn table with column headings: "Net Address" and "Description".

**Attributes:**

|Name      |Type           |Description                                       |
|----------|---------------|--------------------------------------------------|
|acl_table |List(aclTable) |aclTable - *Table* array of aclTable named tuples |
</div>


## `SystemOCIReportingGetACLListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOCIReportingACLListGetRequest()`.

Contains a table with one row per access control list entry.  The table columns are
"Net Address", "Description" and "Restrict Messages".

**Attributes:**

|Name                    |Type                       |Description                                                               |
|------------------------|---------------------------|--------------------------------------------------------------------------|
|oci_reporting_acl_table |List(ociReportingACLTable) |ociReportingACLTable - *Table* array of ociReportingACLTable named tuples |
</div>


## `SystemOCIReportingGetMessageNameListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOCIReportingGetMessageNameListRequest()`.


**Attributes:**

|Name                     |Type      |Description                      |
|-------------------------|----------|---------------------------------|
|message_name_starts_with |List[str] |messageNameStartsWith *Optional* |
</div>


## `SystemOCIReportingParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOCIReportingParametersGetListRequest()`.

Contains a list of system OCI Reporting parameters.

**Attributes:**

|Name                             |Type |Description                   |
|---------------------------------|-----|------------------------------|
|server_port                      |int  |serverPort                    |
|enable_connection_ping           |bool |enableConnectionPing          |
|connection_ping_interval_seconds |int  |connectionPingIntervalSeconds |
|alter_passwords                  |bool |alterPasswords                |
</div>


## `SystemOCIReportingParametersGetResponse14sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOCIReportingParametersGetRequest14sp1()`.

Contains a list of system OCI Reporting parameters.

**Attributes:**

|Name                             |Type |Description                   |
|---------------------------------|-----|------------------------------|
|server_port                      |int  |serverPort                    |
|enable_connection_ping           |bool |enableConnectionPing          |
|connection_ping_interval_seconds |int  |connectionPingIntervalSeconds |
|alter_passwords                  |bool |alterPasswords                |
|enable_public_identity_reporting |bool |enablePublicIdentityReporting |
</div>


## `SystemOCIReportingParametersGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOCIReportingParametersGetRequest22()`.

Contains a list of system OCI Reporting parameters.

**Attributes:**

|Name                             |Type |Description                   |
|---------------------------------|-----|------------------------------|
|server_port                      |int  |serverPort                    |
|enable_connection_ping           |bool |enableConnectionPing          |
|connection_ping_interval_seconds |int  |connectionPingIntervalSeconds |
|alter_passwords                  |bool |alterPasswords                |
|enable_public_identity_reporting |bool |enablePublicIdentityReporting |
|secure                           |bool |secure                        |
</div>


## `SystemOfficeZoneGetAssignedServiceProviderListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemOfficeZoneGetAssignedServiceProviderListRequest()`.

The response contains a table of all Service Providers that have the given Office Zone
assigned.  The column headings are "Service Provider Id", "Service Provider Name" and
"Is Enterprise".

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|service_provider_table |List(serviceProviderTable) |serviceProviderTable - *Table* array of serviceProviderTable named tuples |
</div>


## `SystemOfficeZoneGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemOfficeZoneGetListRequest()`.

The response contains a table of all Office Zones in the system.  The column headings
are "Name" and "Description"

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|office_zone_table |List(officeZoneTable) |officeZoneTable - *Table* array of officeZoneTable named tuples |
</div>


## `SystemOfficeZoneGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemOfficeZoneGetRequest()`.

The response contains the Office Zone information.

**Attributes:**

|Name              |Type      |Description            |
|------------------|----------|-----------------------|
|description       |str       |description *Optional* |
|zone_name         |List[str] |zoneName               |
|primary_zone_name |str       |primaryZoneName        |
</div>


## `SystemOfficeZoneGetZoneUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemOfficeZoneGetZoneUsageListRequest()`.

The response contains a table of all Office Zones that contain the specific Zone.  The
column headings are "Name" and "Description"

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|office_zone_table |List(officeZoneTable) |officeZoneTable - *Table* array of officeZoneTable named tuples |
</div>


## `SystemOutboundProxyCacheParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOutboundProxyCacheParametersGetRequest()`.

Contains a list of Outbound Proxy Cache system parameters.

**Attributes:**

|Name                         |Type|Description                          |
|-----------------------------|----|-------------------------------------|
|eviction_timeout_minutes     |int |evictionTimeoutMinutes               |
|refresh_timeout_minutes      |int |refreshTimeoutMinutes                |
|audit_interval_minutes       |int |auditIntervalMinutes                 |
|maximum_cache_size           |int |maximumCacheSize                     |
|dns_type_default_value       |str |dnsTypeDefaultValue *Optional*       |
|use_dns_srv_default_value    |str |useDnsSrvDefaultValue *Optional*     |
|srv_prefix_default_value     |str |srvPrefixDefaultValue *Optional*     |
|outbound_proxy_default_value |str |outboundProxyDefaultValue *Optional* |
|transport_type_default_value |str |transportTypeDefaultValue *Optional* |
|secure_rtp_default_value     |str |secureRtpDefaultValue *Optional*     |
</div>


## `SystemOutgoingCallingPlanCallTypeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOutgoingCallingPlanCallTypeGetListRequest()`.


**Attributes:**

|Name      |Type      |Description|
|----------|----------|-----------|
|call_type |List[str] |callType   |
</div>


## `SystemOutgoingCallingPlanCallTypeGetMappingListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOutgoingCallingPlanCallTypeGetMappingListRequest()`.

The table columns are: "Country Code", "Digit Map" and "Call Type".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|call_type_mapping |List(callTypeMapping) |callTypeMapping - *Table* array of callTypeMapping named tuples |
</div>


## `SystemOutgoingCallingPlanGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOutgoingCallingPlanGetRequest()`.


**Attributes:**

|Name                      |Type |Description             |
|--------------------------|-----|------------------------|
|direct_transfer_screening |bool |directTransferScreening |
</div>


## `SystemOutgoingCallingPlanGetResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemOutgoingCallingPlanGetRequest17sp3()`.


**Attributes:**

|Name                             |Type |Description                  |
|---------------------------------|-----|-----------------------------|
|direct_transfer_screening        |bool |directTransferScreening      |
|enable_enhanced_toll_call_typing |bool |enableEnhancedTollCallTyping |
</div>


## `SystemPasswordRulesGetResponse13mp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPasswordRulesGetRequest13mp2()`.

Contains the password rules for System administrator, Provisioning Administrator,
and/or Service Provider Administrator, Group Administrator, Department Administrator,
user.

Replaced By : `SystemPasswordRulesGetResponse16()`

**Attributes:**

|Name                                        |Type |Description                                |
|--------------------------------------------|-----|-------------------------------------------|
|rules_apply_to                              |str  |rulesApplyTo                               |
|allow_web_add_external_authentication_users |bool |allowWebAddExternalAuthenticationUsers     |
|disallow_user_id                            |bool |disallowUserId                             |
|disallow_old_password                       |bool |disallowOldPassword                        |
|disallow_reversed_old_password              |bool |disallowReversedOldPassword                |
|restrict_min_digits                         |bool |restrictMinDigits                          |
|min_digits                                  |int  |minDigits                                  |
|restrict_min_upper_case_letters             |bool |restrictMinUpperCaseLetters                |
|min_upper_case_letters                      |int  |minUpperCaseLetters                        |
|restrict_min_lower_case_letters             |bool |restrictMinLowerCaseLetters                |
|min_lower_case_letters                      |int  |minLowerCaseLetters                        |
|restrict_min_non_alphanumeric_characters    |bool |restrictMinNonAlphanumericCharacters       |
|min_non_alphanumeric_characters             |int  |minNonAlphanumericCharacters               |
|min_length                                  |int  |minLength                                  |
|max_failed_login_attempts                   |int  |maxFailedLoginAttempts                     |
|password_expires_days                       |int  |passwordExpiresDays                        |
|send_login_disabled_notify_email            |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address         |str  |loginDisabledNotifyEmailAddress *Optional* |
|disallow_rules_modification                 |bool |disallowRulesModification                  |
</div>


## `SystemPasswordRulesGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPasswordRulesGetRequest16()`.

Contains the password rules for System administrator, Provisioning Administrator,
and/or Service Provider Administrator, Group Administrator, Department Administrator,
user.  Replaced by: `SystemPasswordRulesGetResponse22()` in AS data mode.

**Attributes:**

|Name                                        |Type |Description                                |
|--------------------------------------------|-----|-------------------------------------------|
|rules_apply_to                              |str  |rulesApplyTo                               |
|allow_web_add_external_authentication_users |bool |allowWebAddExternalAuthenticationUsers     |
|disallow_user_id                            |bool |disallowUserId                             |
|disallow_old_password                       |bool |disallowOldPassword                        |
|disallow_reversed_old_password              |bool |disallowReversedOldPassword                |
|restrict_min_digits                         |bool |restrictMinDigits                          |
|min_digits                                  |int  |minDigits                                  |
|restrict_min_upper_case_letters             |bool |restrictMinUpperCaseLetters                |
|min_upper_case_letters                      |int  |minUpperCaseLetters                        |
|restrict_min_lower_case_letters             |bool |restrictMinLowerCaseLetters                |
|min_lower_case_letters                      |int  |minLowerCaseLetters                        |
|restrict_min_non_alphanumeric_characters    |bool |restrictMinNonAlphanumericCharacters       |
|min_non_alphanumeric_characters             |int  |minNonAlphanumericCharacters               |
|min_length                                  |int  |minLength                                  |
|max_failed_login_attempts                   |int  |maxFailedLoginAttempts                     |
|password_expires_days                       |int  |passwordExpiresDays                        |
|send_login_disabled_notify_email            |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address         |str  |loginDisabledNotifyEmailAddress *Optional* |
|disallow_rules_modification                 |bool |disallowRulesModification                  |
|disallow_previous_passwords                 |bool |disallowPreviousPasswords                  |
|number_of_previous_passwords                |int  |numberOfPreviousPasswords                  |
</div>


## `SystemPasswordRulesGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPasswordRulesGetRequest22()`.

Contains the password rules for System administrator, Provisioning Administrator,
and/or Service Provider Administrator, Group Administrator, Department Administrator,
user.  Replaced by: `SystemPasswordRulesGetResponse23()` in AS data mode.

**Attributes:**

|Name                                        |Type |Description                                |
|--------------------------------------------|-----|-------------------------------------------|
|rules_apply_to                              |str  |rulesApplyTo                               |
|allow_web_add_external_authentication_users |bool |allowWebAddExternalAuthenticationUsers     |
|disallow_user_id                            |bool |disallowUserId                             |
|disallow_old_password                       |bool |disallowOldPassword                        |
|disallow_reversed_old_password              |bool |disallowReversedOldPassword                |
|restrict_min_digits                         |bool |restrictMinDigits                          |
|min_digits                                  |int  |minDigits                                  |
|restrict_min_upper_case_letters             |bool |restrictMinUpperCaseLetters                |
|min_upper_case_letters                      |int  |minUpperCaseLetters                        |
|restrict_min_lower_case_letters             |bool |restrictMinLowerCaseLetters                |
|min_lower_case_letters                      |int  |minLowerCaseLetters                        |
|restrict_min_non_alphanumeric_characters    |bool |restrictMinNonAlphanumericCharacters       |
|min_non_alphanumeric_characters             |int  |minNonAlphanumericCharacters               |
|min_length                                  |int  |minLength                                  |
|max_failed_login_attempts                   |int  |maxFailedLoginAttempts                     |
|password_expires_days                       |int  |passwordExpiresDays                        |
|send_login_disabled_notify_email            |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address         |str  |loginDisabledNotifyEmailAddress *Optional* |
|disallow_rules_modification                 |bool |disallowRulesModification                  |
|disallow_previous_passwords                 |bool |disallowPreviousPasswords                  |
|number_of_previous_passwords                |int  |numberOfPreviousPasswords                  |
|force_password_change_after_reset           |bool |forcePasswordChangeAfterReset              |
</div>


## `SystemPasswordRulesGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPasswordRulesGetRequest23()`.

Contains the password rules for System administrator, Provisioning Administrator,
and/or Service Provider Administrator, Group Administrator, Department Administrator,
user.

**Attributes:**

|Name                                        |Type |Description                                 |
|--------------------------------------------|-----|--------------------------------------------|
|rules_apply_to                              |str  |rulesApplyTo                                |
|allow_web_add_external_authentication_users |bool |allowWebAddExternalAuthenticationUsers      |
|disallow_user_id                            |bool |disallowUserId                              |
|disallow_old_password                       |bool |disallowOldPassword                         |
|disallow_reversed_old_password              |bool |disallowReversedOldPassword                 |
|restrict_min_digits                         |bool |restrictMinDigits                           |
|min_digits                                  |int  |minDigits                                   |
|restrict_min_upper_case_letters             |bool |restrictMinUpperCaseLetters                 |
|min_upper_case_letters                      |int  |minUpperCaseLetters                         |
|restrict_min_lower_case_letters             |bool |restrictMinLowerCaseLetters                 |
|min_lower_case_letters                      |int  |minLowerCaseLetters                         |
|restrict_min_non_alphanumeric_characters    |bool |restrictMinNonAlphanumericCharacters        |
|min_non_alphanumeric_characters             |int  |minNonAlphanumericCharacters                |
|min_length                                  |int  |minLength                                   |
|max_failed_login_attempts                   |int  |maxFailedLoginAttempts                      |
|password_expires_days                       |int  |passwordExpiresDays                         |
|send_login_disabled_notify_email            |bool |sendLoginDisabledNotifyEmail                |
|login_disabled_notify_email_address         |str  |loginDisabledNotifyEmailAddress *Optional*  |
|disallow_rules_modification                 |bool |disallowRulesModification                   |
|disallow_previous_passwords                 |bool |disallowPreviousPasswords                   |
|number_of_previous_passwords                |int  |numberOfPreviousPasswords                   |
|force_password_change_after_reset           |bool |forcePasswordChangeAfterReset               |
|enforce_external_auth_for_route_point       |bool |enforceExternalAuthForRoutePoint *Optional* |
</div>


## `SystemPasswordSecurityParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemPasswordSecurityParametersGetResponse()`.

The response contains the password security parameters for the system.

**Attributes:**

|Name                              |Type |Description                   |
|----------------------------------|-----|------------------------------|
|use_existing_hashing              |bool |useExistingHashing            |
|enforce_password_change_on_expiry |bool |enforcePasswordChangeOnExpiry |
</div>


## `SystemPerformanceMeasurementReportingGetFileServerListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPerformanceMeasurementReportingGetFileServerListRequest()`.

The table columns are: "FTP Host Net Address", "FTP User Id", "Passive FTP".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|file_server_table |List(fileServerTable) |fileServerTable - *Table* array of fileServerTable named tuples |
</div>


## `SystemPerformanceMeasurementReportingGetFileServerListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPerformanceMeasurementReportingGetFileServerListRequest22()`.

The table columns are: "Repository URL", "User Id", "Passive".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|file_server_table |List(fileServerTable) |fileServerTable - *Table* array of fileServerTable named tuples |
</div>


## `SystemPerformanceMeasurementReportingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPerformanceMeasurementReportingGetRequest()`.

Replaced by: `SystemPerformanceMeasurementReportingGetResponse22()`

**Attributes:**

|Name                                 |Type |Description                      |
|-------------------------------------|-----|---------------------------------|
|is_active                            |bool |isActive                         |
|reporting_interval                   |int  |reportingInterval                |
|reset_measurements_after_each_report |bool |resetMeasurementsAfterEachReport |
|report_enterprise                    |bool |reportEnterprise                 |
|report_service_provider              |bool |reportServiceProvider            |
|report_device                        |bool |reportDevice                     |
</div>


## `SystemPerformanceMeasurementReportingGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPerformanceMeasurementReportingGetRequest22()`.

Replaced by: `SystemPerformanceMeasurementReportingGetResponse24()`

**Attributes:**

|Name                                 |Type |Description                      |
|-------------------------------------|-----|---------------------------------|
|is_active                            |bool |isActive                         |
|reporting_interval                   |int  |reportingInterval                |
|reset_measurements_after_each_report |bool |resetMeasurementsAfterEachReport |
|report_enterprise                    |bool |reportEnterprise                 |
|report_service_provider              |bool |reportServiceProvider            |
|report_device                        |bool |reportDevice                     |
|report_table                         |bool |reportTable                      |
</div>


## `SystemPerformanceMeasurementReportingGetResponse24`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPerformanceMeasurementReportingGetRequest24()`.


**Attributes:**

|Name                                 |Type |Description                      |
|-------------------------------------|-----|---------------------------------|
|is_active                            |bool |isActive                         |
|reporting_interval                   |int  |reportingInterval                |
|reset_measurements_after_each_report |bool |resetMeasurementsAfterEachReport |
|report_enterprise                    |bool |reportEnterprise                 |
|report_service_provider              |bool |reportServiceProvider            |
|report_device                        |bool |reportDevice                     |
|report_table                         |bool |reportTable                      |
|report_encoding                      |str  |reportEncoding                   |
</div>


## `SystemPersonalAssistantGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemPersonalAssistantGetRequest()`.

Returns system Personal Assistant Parameters.

**Attributes:**

|Name                            |Type|Description                 |
|--------------------------------|----|----------------------------|
|transfer_to_attendant_key       |str |transferToAttendantKey      |
|transfer_to_voice_messaging_key |str |transferToVoiceMessagingKey |
</div>


## `SystemPhysicalLocationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPhysicalLocationGetRequest()`.

Contains a list of system Physical Location parameters.

**Attributes:**

|Name                         |Type |Description               |
|-----------------------------|-----|--------------------------|
|always_allow_emergency_calls |bool |alwaysAllowEmergencyCalls |
</div>


## `SystemPolicyGetDefaultResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPolicyGetDefaultRequest14()`.

Contains the default policy settings for the system.

**Attributes:**

|Name                                                 |Type|Description                                    |
|-----------------------------------------------------|----|-----------------------------------------------|
|group_calling_plan_access                            |str |groupCallingPlanAccess                         |
|group_extension_access                               |str |groupExtensionAccess                           |
|group_ldap_integration_access                        |str |groupLDAPIntegrationAccess                     |
|group_voice_messaging_access                         |str |groupVoiceMessagingAccess                      |
|group_department_admin_user_access                   |str |groupDepartmentAdminUserAccess                 |
|group_user_authentication_access                     |str |groupUserAuthenticationAccess                  |
|group_user_group_directory_access                    |str |groupUserGroupDirectoryAccess                  |
|group_user_profile_access                            |str |groupUserProfileAccess                         |
|group_admin_profile_access                           |str |groupAdminProfileAccess                        |
|group_admin_user_access                              |str |groupAdminUserAccess                           |
|group_admin_admin_access                             |str |groupAdminAdminAccess                          |
|group_admin_department_access                        |str |groupAdminDepartmentAccess                     |
|group_admin_access_device_access                     |str |groupAdminAccessDeviceAccess                   |
|group_admin_enhanced_service_instance_access         |str |groupAdminEnhancedServiceInstanceAccess        |
|group_admin_feature_access_code_access               |str |groupAdminFeatureAccessCodeAccess              |
|group_admin_phone_number_extension_access            |str |groupAdminPhoneNumberExtensionAccess           |
|group_admin_service_access                           |str |groupAdminServiceAccess                        |
|service_provider_admin_profile_access                |str |serviceProviderAdminProfileAccess              |
|service_provider_admin_group_access                  |str |serviceProviderAdminGroupAccess                |
|service_provider_admin_user_access                   |str |serviceProviderAdminUserAccess                 |
|service_provider_admin_admin_access                  |str |serviceProviderAdminAdminAccess                |
|service_provider_admin_department_access             |str |serviceProviderAdminDepartmentAccess           |
|service_provider_admin_access_device_access          |str |serviceProviderAdminAccessDeviceAccess         |
|service_provider_admin_phone_number_extension_access |str |serviceProviderAdminPhoneNumberExtensionAccess |
|service_provider_admin_service_access                |str |serviceProviderAdminServiceAccess              |
|service_provider_admin_service_pack_access           |str |serviceProviderAdminServicePackAccess          |
|service_provider_admin_web_branding_access           |str |serviceProviderAdminWebBrandingAccess          |
|enterprise_admin_network_policy_access               |str |enterpriseAdminNetworkPolicyAccess             |
</div>


## `SystemPolicyGetDefaultResponse14sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPolicyGetDefaultRequest14sp1()`.

Contains the default policy settings for the system.

**Attributes:**

|Name                                                 |Type|Description                                    |
|-----------------------------------------------------|----|-----------------------------------------------|
|group_calling_plan_access                            |str |groupCallingPlanAccess                         |
|group_extension_access                               |str |groupExtensionAccess                           |
|group_ldap_integration_access                        |str |groupLDAPIntegrationAccess                     |
|group_voice_messaging_access                         |str |groupVoiceMessagingAccess                      |
|group_department_admin_user_access                   |str |groupDepartmentAdminUserAccess                 |
|group_department_admin_trunk_group_access            |str |groupDepartmentAdminTrunkGroupAccess           |
|group_user_authentication_access                     |str |groupUserAuthenticationAccess                  |
|group_user_group_directory_access                    |str |groupUserGroupDirectoryAccess                  |
|group_user_profile_access                            |str |groupUserProfileAccess                         |
|group_admin_profile_access                           |str |groupAdminProfileAccess                        |
|group_admin_user_access                              |str |groupAdminUserAccess                           |
|group_admin_admin_access                             |str |groupAdminAdminAccess                          |
|group_admin_department_access                        |str |groupAdminDepartmentAccess                     |
|group_admin_access_device_access                     |str |groupAdminAccessDeviceAccess                   |
|group_admin_enhanced_service_instance_access         |str |groupAdminEnhancedServiceInstanceAccess        |
|group_admin_feature_access_code_access               |str |groupAdminFeatureAccessCodeAccess              |
|group_admin_phone_number_extension_access            |str |groupAdminPhoneNumberExtensionAccess           |
|group_admin_service_access                           |str |groupAdminServiceAccess                        |
|group_admin_trunk_group_access                       |str |groupAdminTrunkGroupAccess                     |
|service_provider_admin_profile_access                |str |serviceProviderAdminProfileAccess              |
|service_provider_admin_group_access                  |str |serviceProviderAdminGroupAccess                |
|service_provider_admin_user_access                   |str |serviceProviderAdminUserAccess                 |
|service_provider_admin_admin_access                  |str |serviceProviderAdminAdminAccess                |
|service_provider_admin_department_access             |str |serviceProviderAdminDepartmentAccess           |
|service_provider_admin_access_device_access          |str |serviceProviderAdminAccessDeviceAccess         |
|service_provider_admin_phone_number_extension_access |str |serviceProviderAdminPhoneNumberExtensionAccess |
|service_provider_admin_service_access                |str |serviceProviderAdminServiceAccess              |
|service_provider_admin_service_pack_access           |str |serviceProviderAdminServicePackAccess          |
|service_provider_admin_web_branding_access           |str |serviceProviderAdminWebBrandingAccess          |
|enterprise_admin_network_policy_access               |str |enterpriseAdminNetworkPolicyAccess             |
</div>


## `SystemPolicyGetDefaultResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPolicyGetDefaultRequest14sp4()`.

Contains the default policy settings for the system.

**Attributes:**

|Name                                                 |Type|Description                                    |
|-----------------------------------------------------|----|-----------------------------------------------|
|group_calling_plan_access                            |str |groupCallingPlanAccess                         |
|group_extension_access                               |str |groupExtensionAccess                           |
|group_ldap_integration_access                        |str |groupLDAPIntegrationAccess                     |
|group_voice_messaging_access                         |str |groupVoiceMessagingAccess                      |
|group_department_admin_user_access                   |str |groupDepartmentAdminUserAccess                 |
|group_department_admin_trunk_group_access            |str |groupDepartmentAdminTrunkGroupAccess           |
|group_user_authentication_access                     |str |groupUserAuthenticationAccess                  |
|group_user_group_directory_access                    |str |groupUserGroupDirectoryAccess                  |
|group_user_profile_access                            |str |groupUserProfileAccess                         |
|group_user_enhanced_call_logs_access                 |str |groupUserEnhancedCallLogsAccess                |
|group_admin_profile_access                           |str |groupAdminProfileAccess                        |
|group_admin_user_access                              |str |groupAdminUserAccess                           |
|group_admin_admin_access                             |str |groupAdminAdminAccess                          |
|group_admin_department_access                        |str |groupAdminDepartmentAccess                     |
|group_admin_access_device_access                     |str |groupAdminAccessDeviceAccess                   |
|group_admin_enhanced_service_instance_access         |str |groupAdminEnhancedServiceInstanceAccess        |
|group_admin_feature_access_code_access               |str |groupAdminFeatureAccessCodeAccess              |
|group_admin_phone_number_extension_access            |str |groupAdminPhoneNumberExtensionAccess           |
|group_admin_service_access                           |str |groupAdminServiceAccess                        |
|group_admin_trunk_group_access                       |str |groupAdminTrunkGroupAccess                     |
|service_provider_admin_profile_access                |str |serviceProviderAdminProfileAccess              |
|service_provider_admin_group_access                  |str |serviceProviderAdminGroupAccess                |
|service_provider_admin_user_access                   |str |serviceProviderAdminUserAccess                 |
|service_provider_admin_admin_access                  |str |serviceProviderAdminAdminAccess                |
|service_provider_admin_department_access             |str |serviceProviderAdminDepartmentAccess           |
|service_provider_admin_access_device_access          |str |serviceProviderAdminAccessDeviceAccess         |
|service_provider_admin_phone_number_extension_access |str |serviceProviderAdminPhoneNumberExtensionAccess |
|service_provider_admin_service_access                |str |serviceProviderAdminServiceAccess              |
|service_provider_admin_service_pack_access           |str |serviceProviderAdminServicePackAccess          |
|service_provider_admin_web_branding_access           |str |serviceProviderAdminWebBrandingAccess          |
|enterprise_admin_network_policy_access               |str |enterpriseAdminNetworkPolicyAccess             |
</div>


## `SystemPolicyGetDefaultResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPolicyGetDefaultRequest16sp1()`.

Contains the default policy settings for the system.

**Attributes:**

|Name                                                    |Type|Description                                       |
|--------------------------------------------------------|----|--------------------------------------------------|
|group_calling_plan_access                               |str |groupCallingPlanAccess                            |
|group_extension_access                                  |str |groupExtensionAccess                              |
|group_ldap_integration_access                           |str |groupLDAPIntegrationAccess                        |
|group_voice_messaging_access                            |str |groupVoiceMessagingAccess                         |
|group_department_admin_user_access                      |str |groupDepartmentAdminUserAccess                    |
|group_department_admin_trunk_group_access               |str |groupDepartmentAdminTrunkGroupAccess              |
|group_user_authentication_access                        |str |groupUserAuthenticationAccess                     |
|group_user_group_directory_access                       |str |groupUserGroupDirectoryAccess                     |
|group_user_profile_access                               |str |groupUserProfileAccess                            |
|group_user_enhanced_call_logs_access                    |str |groupUserEnhancedCallLogsAccess                   |
|group_admin_profile_access                              |str |groupAdminProfileAccess                           |
|group_admin_user_access                                 |str |groupAdminUserAccess                              |
|group_admin_admin_access                                |str |groupAdminAdminAccess                             |
|group_admin_department_access                           |str |groupAdminDepartmentAccess                        |
|group_admin_access_device_access                        |str |groupAdminAccessDeviceAccess                      |
|group_admin_enhanced_service_instance_access            |str |groupAdminEnhancedServiceInstanceAccess           |
|group_admin_feature_access_code_access                  |str |groupAdminFeatureAccessCodeAccess                 |
|group_admin_phone_number_extension_access               |str |groupAdminPhoneNumberExtensionAccess              |
|group_admin_service_access                              |str |groupAdminServiceAccess                           |
|group_admin_trunk_group_access                          |str |groupAdminTrunkGroupAccess                        |
|group_admin_session_admission_control_access            |str |groupAdminSessionAdmissionControlAccess           |
|service_provider_admin_profile_access                   |str |serviceProviderAdminProfileAccess                 |
|service_provider_admin_group_access                     |str |serviceProviderAdminGroupAccess                   |
|service_provider_admin_user_access                      |str |serviceProviderAdminUserAccess                    |
|service_provider_admin_admin_access                     |str |serviceProviderAdminAdminAccess                   |
|service_provider_admin_department_access                |str |serviceProviderAdminDepartmentAccess              |
|service_provider_admin_access_device_access             |str |serviceProviderAdminAccessDeviceAccess            |
|service_provider_admin_phone_number_extension_access    |str |serviceProviderAdminPhoneNumberExtensionAccess    |
|service_provider_admin_service_access                   |str |serviceProviderAdminServiceAccess                 |
|service_provider_admin_service_pack_access              |str |serviceProviderAdminServicePackAccess             |
|service_provider_admin_session_admission_control_access |str |serviceProviderAdminSessionAdmissionControlAccess |
|service_provider_admin_web_branding_access              |str |serviceProviderAdminWebBrandingAccess             |
|enterprise_admin_network_policy_access                  |str |enterpriseAdminNetworkPolicyAccess                |
</div>


## `SystemPolicyGetDefaultResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPolicyGetDefaultRequest16sp2()`.

Contains the default policy settings for the system.

**Attributes:**

|Name                                                    |Type|Description                                       |
|--------------------------------------------------------|----|--------------------------------------------------|
|group_calling_plan_access                               |str |groupCallingPlanAccess                            |
|group_extension_access                                  |str |groupExtensionAccess                              |
|group_ldap_integration_access                           |str |groupLDAPIntegrationAccess                        |
|group_voice_messaging_access                            |str |groupVoiceMessagingAccess                         |
|group_department_admin_user_access                      |str |groupDepartmentAdminUserAccess                    |
|group_department_admin_trunk_group_access               |str |groupDepartmentAdminTrunkGroupAccess              |
|group_department_admin_phone_number_extension_access    |str |groupDepartmentAdminPhoneNumberExtensionAccess    |
|group_department_admin_calling_line_id_number_access    |str |groupDepartmentAdminCallingLineIdNumberAccess     |
|group_user_authentication_access                        |str |groupUserAuthenticationAccess                     |
|group_user_group_directory_access                       |str |groupUserGroupDirectoryAccess                     |
|group_user_profile_access                               |str |groupUserProfileAccess                            |
|group_user_enhanced_call_logs_access                    |str |groupUserEnhancedCallLogsAccess                   |
|group_admin_profile_access                              |str |groupAdminProfileAccess                           |
|group_admin_user_access                                 |str |groupAdminUserAccess                              |
|group_admin_admin_access                                |str |groupAdminAdminAccess                             |
|group_admin_department_access                           |str |groupAdminDepartmentAccess                        |
|group_admin_access_device_access                        |str |groupAdminAccessDeviceAccess                      |
|group_admin_enhanced_service_instance_access            |str |groupAdminEnhancedServiceInstanceAccess           |
|group_admin_feature_access_code_access                  |str |groupAdminFeatureAccessCodeAccess                 |
|group_admin_phone_number_extension_access               |str |groupAdminPhoneNumberExtensionAccess              |
|group_admin_calling_line_id_number_access               |str |groupAdminCallingLineIdNumberAccess               |
|group_admin_service_access                              |str |groupAdminServiceAccess                           |
|group_admin_trunk_group_access                          |str |groupAdminTrunkGroupAccess                        |
|group_admin_session_admission_control_access            |str |groupAdminSessionAdmissionControlAccess           |
|group_admin_dialable_caller_id_access                   |str |groupAdminDialableCallerIDAccess                  |
|group_admin_office_zone_access                          |str |groupAdminOfficeZoneAccess                        |
|group_admin_number_activation_access                    |str |groupAdminNumberActivationAccess                  |
|service_provider_admin_profile_access                   |str |serviceProviderAdminProfileAccess                 |
|service_provider_admin_group_access                     |str |serviceProviderAdminGroupAccess                   |
|service_provider_admin_user_access                      |str |serviceProviderAdminUserAccess                    |
|service_provider_admin_admin_access                     |str |serviceProviderAdminAdminAccess                   |
|service_provider_admin_department_access                |str |serviceProviderAdminDepartmentAccess              |
|service_provider_admin_access_device_access             |str |serviceProviderAdminAccessDeviceAccess            |
|service_provider_admin_phone_number_extension_access    |str |serviceProviderAdminPhoneNumberExtensionAccess    |
|service_provider_admin_calling_line_id_number_access    |str |serviceProviderAdminCallingLineIdNumberAccess     |
|service_provider_admin_service_access                   |str |serviceProviderAdminServiceAccess                 |
|service_provider_admin_service_pack_access              |str |serviceProviderAdminServicePackAccess             |
|service_provider_admin_session_admission_control_access |str |serviceProviderAdminSessionAdmissionControlAccess |
|service_provider_admin_web_branding_access              |str |serviceProviderAdminWebBrandingAccess             |
|service_provider_admin_office_zone_access               |str |serviceProviderAdminOfficeZoneAccess              |
|enterprise_admin_network_policy_access                  |str |enterpriseAdminNetworkPolicyAccess                |
|service_provider_admin_dialable_caller_id_access        |str |serviceProviderAdminDialableCallerIDAccess        |
|enterprise_admin_number_activation_access               |str |enterpriseAdminNumberActivationAccess             |
</div>


## `SystemPolicyGetDefaultResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPolicyGetDefaultRequest17()`.

Contains the default policy settings for the system.

**Attributes:**

|Name                                                    |Type|Description                                       |
|--------------------------------------------------------|----|--------------------------------------------------|
|group_calling_plan_access                               |str |groupCallingPlanAccess                            |
|group_extension_access                                  |str |groupExtensionAccess                              |
|group_ldap_integration_access                           |str |groupLDAPIntegrationAccess                        |
|group_voice_messaging_access                            |str |groupVoiceMessagingAccess                         |
|group_department_admin_user_access                      |str |groupDepartmentAdminUserAccess                    |
|group_department_admin_trunk_group_access               |str |groupDepartmentAdminTrunkGroupAccess              |
|group_department_admin_phone_number_extension_access    |str |groupDepartmentAdminPhoneNumberExtensionAccess    |
|group_department_admin_calling_line_id_number_access    |str |groupDepartmentAdminCallingLineIdNumberAccess     |
|group_user_authentication_access                        |str |groupUserAuthenticationAccess                     |
|group_user_group_directory_access                       |str |groupUserGroupDirectoryAccess                     |
|group_user_profile_access                               |str |groupUserProfileAccess                            |
|group_user_enhanced_call_logs_access                    |str |groupUserEnhancedCallLogsAccess                   |
|group_admin_profile_access                              |str |groupAdminProfileAccess                           |
|group_admin_user_access                                 |str |groupAdminUserAccess                              |
|group_admin_admin_access                                |str |groupAdminAdminAccess                             |
|group_admin_department_access                           |str |groupAdminDepartmentAccess                        |
|group_admin_access_device_access                        |str |groupAdminAccessDeviceAccess                      |
|group_admin_enhanced_service_instance_access            |str |groupAdminEnhancedServiceInstanceAccess           |
|group_admin_feature_access_code_access                  |str |groupAdminFeatureAccessCodeAccess                 |
|group_admin_phone_number_extension_access               |str |groupAdminPhoneNumberExtensionAccess              |
|group_admin_calling_line_id_number_access               |str |groupAdminCallingLineIdNumberAccess               |
|group_admin_service_access                              |str |groupAdminServiceAccess                           |
|group_admin_trunk_group_access                          |str |groupAdminTrunkGroupAccess                        |
|group_admin_session_admission_control_access            |str |groupAdminSessionAdmissionControlAccess           |
|group_admin_office_zone_access                          |str |groupAdminOfficeZoneAccess                        |
|service_provider_admin_profile_access                   |str |serviceProviderAdminProfileAccess                 |
|service_provider_admin_group_access                     |str |serviceProviderAdminGroupAccess                   |
|service_provider_admin_user_access                      |str |serviceProviderAdminUserAccess                    |
|service_provider_admin_admin_access                     |str |serviceProviderAdminAdminAccess                   |
|service_provider_admin_department_access                |str |serviceProviderAdminDepartmentAccess              |
|service_provider_admin_access_device_access             |str |serviceProviderAdminAccessDeviceAccess            |
|service_provider_admin_phone_number_extension_access    |str |serviceProviderAdminPhoneNumberExtensionAccess    |
|service_provider_admin_calling_line_id_number_access    |str |serviceProviderAdminCallingLineIdNumberAccess     |
|service_provider_admin_service_access                   |str |serviceProviderAdminServiceAccess                 |
|service_provider_admin_service_pack_access              |str |serviceProviderAdminServicePackAccess             |
|service_provider_admin_session_admission_control_access |str |serviceProviderAdminSessionAdmissionControlAccess |
|service_provider_admin_web_branding_access              |str |serviceProviderAdminWebBrandingAccess             |
|service_provider_admin_office_zone_access               |str |serviceProviderAdminOfficeZoneAccess              |
|enterprise_admin_network_policy_access                  |str |enterpriseAdminNetworkPolicyAccess                |
</div>


## `SystemPolicyGetDefaultResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPolicyGetDefaultRequest17sp1()`.

Contains the default policy settings for the system.  The following elements are only
used in XS data mode: serviceProviderAdminCommunicationBarringAccess

**Attributes:**

|Name                                                    |Type|Description                                       |
|--------------------------------------------------------|----|--------------------------------------------------|
|group_calling_plan_access                               |str |groupCallingPlanAccess                            |
|group_extension_access                                  |str |groupExtensionAccess                              |
|group_ldap_integration_access                           |str |groupLDAPIntegrationAccess                        |
|group_voice_messaging_access                            |str |groupVoiceMessagingAccess                         |
|group_department_admin_user_access                      |str |groupDepartmentAdminUserAccess                    |
|group_department_admin_trunk_group_access               |str |groupDepartmentAdminTrunkGroupAccess              |
|group_department_admin_phone_number_extension_access    |str |groupDepartmentAdminPhoneNumberExtensionAccess    |
|group_department_admin_calling_line_id_number_access    |str |groupDepartmentAdminCallingLineIdNumberAccess     |
|group_user_authentication_access                        |str |groupUserAuthenticationAccess                     |
|group_user_group_directory_access                       |str |groupUserGroupDirectoryAccess                     |
|group_user_profile_access                               |str |groupUserProfileAccess                            |
|group_user_enhanced_call_logs_access                    |str |groupUserEnhancedCallLogsAccess                   |
|group_admin_profile_access                              |str |groupAdminProfileAccess                           |
|group_admin_user_access                                 |str |groupAdminUserAccess                              |
|group_admin_admin_access                                |str |groupAdminAdminAccess                             |
|group_admin_department_access                           |str |groupAdminDepartmentAccess                        |
|group_admin_access_device_access                        |str |groupAdminAccessDeviceAccess                      |
|group_admin_enhanced_service_instance_access            |str |groupAdminEnhancedServiceInstanceAccess           |
|group_admin_feature_access_code_access                  |str |groupAdminFeatureAccessCodeAccess                 |
|group_admin_phone_number_extension_access               |str |groupAdminPhoneNumberExtensionAccess              |
|group_admin_calling_line_id_number_access               |str |groupAdminCallingLineIdNumberAccess               |
|group_admin_service_access                              |str |groupAdminServiceAccess                           |
|group_admin_trunk_group_access                          |str |groupAdminTrunkGroupAccess                        |
|group_admin_session_admission_control_access            |str |groupAdminSessionAdmissionControlAccess           |
|group_admin_office_zone_access                          |str |groupAdminOfficeZoneAccess                        |
|service_provider_admin_profile_access                   |str |serviceProviderAdminProfileAccess                 |
|service_provider_admin_group_access                     |str |serviceProviderAdminGroupAccess                   |
|service_provider_admin_user_access                      |str |serviceProviderAdminUserAccess                    |
|service_provider_admin_admin_access                     |str |serviceProviderAdminAdminAccess                   |
|service_provider_admin_department_access                |str |serviceProviderAdminDepartmentAccess              |
|service_provider_admin_access_device_access             |str |serviceProviderAdminAccessDeviceAccess            |
|service_provider_admin_phone_number_extension_access    |str |serviceProviderAdminPhoneNumberExtensionAccess    |
|service_provider_admin_calling_line_id_number_access    |str |serviceProviderAdminCallingLineIdNumberAccess     |
|service_provider_admin_service_access                   |str |serviceProviderAdminServiceAccess                 |
|service_provider_admin_service_pack_access              |str |serviceProviderAdminServicePackAccess             |
|service_provider_admin_session_admission_control_access |str |serviceProviderAdminSessionAdmissionControlAccess |
|service_provider_admin_web_branding_access              |str |serviceProviderAdminWebBrandingAccess             |
|service_provider_admin_office_zone_access               |str |serviceProviderAdminOfficeZoneAccess              |
|service_provider_admin_communication_barring_access     |str |serviceProviderAdminCommunicationBarringAccess    |
|enterprise_admin_network_policy_access                  |str |enterpriseAdminNetworkPolicyAccess                |
</div>


## `SystemPolicyGetDefaultResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPolicyGetDefaultRequest17sp3()`.

Contains the default policy settings for the system.

**Attributes:**

|Name                                                    |Type|Description                                       |
|--------------------------------------------------------|----|--------------------------------------------------|
|group_calling_plan_access                               |str |groupCallingPlanAccess                            |
|group_extension_access                                  |str |groupExtensionAccess                              |
|group_ldap_integration_access                           |str |groupLDAPIntegrationAccess                        |
|group_voice_messaging_access                            |str |groupVoiceMessagingAccess                         |
|group_department_admin_user_access                      |str |groupDepartmentAdminUserAccess                    |
|group_department_admin_trunk_group_access               |str |groupDepartmentAdminTrunkGroupAccess              |
|group_department_admin_phone_number_extension_access    |str |groupDepartmentAdminPhoneNumberExtensionAccess    |
|group_department_admin_calling_line_id_number_access    |str |groupDepartmentAdminCallingLineIdNumberAccess     |
|group_user_authentication_access                        |str |groupUserAuthenticationAccess                     |
|group_user_group_directory_access                       |str |groupUserGroupDirectoryAccess                     |
|group_user_profile_access                               |str |groupUserProfileAccess                            |
|group_user_enhanced_call_logs_access                    |str |groupUserEnhancedCallLogsAccess                   |
|group_admin_profile_access                              |str |groupAdminProfileAccess                           |
|group_admin_user_access                                 |str |groupAdminUserAccess                              |
|group_admin_admin_access                                |str |groupAdminAdminAccess                             |
|group_admin_department_access                           |str |groupAdminDepartmentAccess                        |
|group_admin_access_device_access                        |str |groupAdminAccessDeviceAccess                      |
|group_admin_enhanced_service_instance_access            |str |groupAdminEnhancedServiceInstanceAccess           |
|group_admin_feature_access_code_access                  |str |groupAdminFeatureAccessCodeAccess                 |
|group_admin_phone_number_extension_access               |str |groupAdminPhoneNumberExtensionAccess              |
|group_admin_calling_line_id_number_access               |str |groupAdminCallingLineIdNumberAccess               |
|group_admin_service_access                              |str |groupAdminServiceAccess                           |
|group_admin_trunk_group_access                          |str |groupAdminTrunkGroupAccess                        |
|group_admin_session_admission_control_access            |str |groupAdminSessionAdmissionControlAccess           |
|group_admin_office_zone_access                          |str |groupAdminOfficeZoneAccess                        |
|group_admin_dialable_caller_id_access                   |str |groupAdminDialableCallerIDAccess                  |
|service_provider_admin_profile_access                   |str |serviceProviderAdminProfileAccess                 |
|service_provider_admin_group_access                     |str |serviceProviderAdminGroupAccess                   |
|service_provider_admin_user_access                      |str |serviceProviderAdminUserAccess                    |
|service_provider_admin_admin_access                     |str |serviceProviderAdminAdminAccess                   |
|service_provider_admin_department_access                |str |serviceProviderAdminDepartmentAccess              |
|service_provider_admin_access_device_access             |str |serviceProviderAdminAccessDeviceAccess            |
|service_provider_admin_phone_number_extension_access    |str |serviceProviderAdminPhoneNumberExtensionAccess    |
|service_provider_admin_calling_line_id_number_access    |str |serviceProviderAdminCallingLineIdNumberAccess     |
|service_provider_admin_service_access                   |str |serviceProviderAdminServiceAccess                 |
|service_provider_admin_service_pack_access              |str |serviceProviderAdminServicePackAccess             |
|service_provider_admin_session_admission_control_access |str |serviceProviderAdminSessionAdmissionControlAccess |
|service_provider_admin_web_branding_access              |str |serviceProviderAdminWebBrandingAccess             |
|service_provider_admin_office_zone_access               |str |serviceProviderAdminOfficeZoneAccess              |
|enterprise_admin_network_policy_access                  |str |enterpriseAdminNetworkPolicyAccess                |
|service_provider_admin_dialable_caller_id_access        |str |serviceProviderAdminDialableCallerIDAccess        |
</div>


## `SystemPolicyGetDefaultResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPolicyGetDefaultRequest18()`.

Contains the default policy settings for the system.  The following elements are only
used in AS data mode: GroupAdminDialableCallerIDAccess
ServiceProviderAdminDialableCallerIDAccess The following elements are only used in XS
data mode: serviceProviderAdminCommunicationBarringAccess Replaced by:
`SystemPolicyGetDefaultResponse20()` in AS data mode

**Attributes:**

|Name                                                    |Type|Description                                       |
|--------------------------------------------------------|----|--------------------------------------------------|
|group_calling_plan_access                               |str |groupCallingPlanAccess                            |
|group_extension_access                                  |str |groupExtensionAccess                              |
|group_ldap_integration_access                           |str |groupLDAPIntegrationAccess                        |
|group_voice_messaging_access                            |str |groupVoiceMessagingAccess                         |
|group_department_admin_user_access                      |str |groupDepartmentAdminUserAccess                    |
|group_department_admin_trunk_group_access               |str |groupDepartmentAdminTrunkGroupAccess              |
|group_department_admin_phone_number_extension_access    |str |groupDepartmentAdminPhoneNumberExtensionAccess    |
|group_department_admin_calling_line_id_number_access    |str |groupDepartmentAdminCallingLineIdNumberAccess     |
|group_user_authentication_access                        |str |groupUserAuthenticationAccess                     |
|group_user_group_directory_access                       |str |groupUserGroupDirectoryAccess                     |
|group_user_profile_access                               |str |groupUserProfileAccess                            |
|group_user_enhanced_call_logs_access                    |str |groupUserEnhancedCallLogsAccess                   |
|group_admin_profile_access                              |str |groupAdminProfileAccess                           |
|group_admin_user_access                                 |str |groupAdminUserAccess                              |
|group_admin_admin_access                                |str |groupAdminAdminAccess                             |
|group_admin_department_access                           |str |groupAdminDepartmentAccess                        |
|group_admin_access_device_access                        |str |groupAdminAccessDeviceAccess                      |
|group_admin_enhanced_service_instance_access            |str |groupAdminEnhancedServiceInstanceAccess           |
|group_admin_feature_access_code_access                  |str |groupAdminFeatureAccessCodeAccess                 |
|group_admin_phone_number_extension_access               |str |groupAdminPhoneNumberExtensionAccess              |
|group_admin_calling_line_id_number_access               |str |groupAdminCallingLineIdNumberAccess               |
|group_admin_service_access                              |str |groupAdminServiceAccess                           |
|group_admin_trunk_group_access                          |str |groupAdminTrunkGroupAccess                        |
|group_admin_session_admission_control_access            |str |groupAdminSessionAdmissionControlAccess           |
|group_admin_office_zone_access                          |str |groupAdminOfficeZoneAccess                        |
|group_admin_number_activation_access                    |str |groupAdminNumberActivationAccess                  |
|group_admin_dialable_caller_id_access                   |str |groupAdminDialableCallerIDAccess                  |
|service_provider_admin_profile_access                   |str |serviceProviderAdminProfileAccess                 |
|service_provider_admin_group_access                     |str |serviceProviderAdminGroupAccess                   |
|service_provider_admin_user_access                      |str |serviceProviderAdminUserAccess                    |
|service_provider_admin_admin_access                     |str |serviceProviderAdminAdminAccess                   |
|service_provider_admin_department_access                |str |serviceProviderAdminDepartmentAccess              |
|service_provider_admin_access_device_access             |str |serviceProviderAdminAccessDeviceAccess            |
|service_provider_admin_phone_number_extension_access    |str |serviceProviderAdminPhoneNumberExtensionAccess    |
|service_provider_admin_calling_line_id_number_access    |str |serviceProviderAdminCallingLineIdNumberAccess     |
|service_provider_admin_service_access                   |str |serviceProviderAdminServiceAccess                 |
|service_provider_admin_service_pack_access              |str |serviceProviderAdminServicePackAccess             |
|service_provider_admin_session_admission_control_access |str |serviceProviderAdminSessionAdmissionControlAccess |
|service_provider_admin_web_branding_access              |str |serviceProviderAdminWebBrandingAccess             |
|service_provider_admin_office_zone_access               |str |serviceProviderAdminOfficeZoneAccess              |
|service_provider_admin_communication_barring_access     |str |serviceProviderAdminCommunicationBarringAccess    |
|enterprise_admin_network_policy_access                  |str |enterpriseAdminNetworkPolicyAccess                |
|enterprise_admin_number_activation_access               |str |enterpriseAdminNumberActivationAccess             |
|service_provider_admin_dialable_caller_id_access        |str |serviceProviderAdminDialableCallerIDAccess        |
</div>


## `SystemPolicyGetDefaultResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPolicyGetDefaultRequest19sp1()`.

Contains the default policy settings for the system.  The following elements are only
used in AS data mode: GroupAdminDialableCallerIDAccess
ServiceProviderAdminDialableCallerIDAccess
GroupAdminCommunicationBarringUserProfileAccess (This element is only used for groups
in an Enterprise) The following elements are only used in XS data mode:
serviceProviderAdminCommunicationBarringAccess Replaced by:
`SystemPolicyGetDefaultResponse20()` in AS mode

**Attributes:**

|Name                                                    |Type|Description                                       |
|--------------------------------------------------------|----|--------------------------------------------------|
|group_calling_plan_access                               |str |groupCallingPlanAccess                            |
|group_extension_access                                  |str |groupExtensionAccess                              |
|group_ldap_integration_access                           |str |groupLDAPIntegrationAccess                        |
|group_voice_messaging_access                            |str |groupVoiceMessagingAccess                         |
|group_department_admin_user_access                      |str |groupDepartmentAdminUserAccess                    |
|group_department_admin_trunk_group_access               |str |groupDepartmentAdminTrunkGroupAccess              |
|group_department_admin_phone_number_extension_access    |str |groupDepartmentAdminPhoneNumberExtensionAccess    |
|group_department_admin_calling_line_id_number_access    |str |groupDepartmentAdminCallingLineIdNumberAccess     |
|group_user_authentication_access                        |str |groupUserAuthenticationAccess                     |
|group_user_group_directory_access                       |str |groupUserGroupDirectoryAccess                     |
|group_user_profile_access                               |str |groupUserProfileAccess                            |
|group_user_enhanced_call_logs_access                    |str |groupUserEnhancedCallLogsAccess                   |
|group_admin_profile_access                              |str |groupAdminProfileAccess                           |
|group_admin_user_access                                 |str |groupAdminUserAccess                              |
|group_admin_admin_access                                |str |groupAdminAdminAccess                             |
|group_admin_department_access                           |str |groupAdminDepartmentAccess                        |
|group_admin_access_device_access                        |str |groupAdminAccessDeviceAccess                      |
|group_admin_enhanced_service_instance_access            |str |groupAdminEnhancedServiceInstanceAccess           |
|group_admin_feature_access_code_access                  |str |groupAdminFeatureAccessCodeAccess                 |
|group_admin_phone_number_extension_access               |str |groupAdminPhoneNumberExtensionAccess              |
|group_admin_calling_line_id_number_access               |str |groupAdminCallingLineIdNumberAccess               |
|group_admin_service_access                              |str |groupAdminServiceAccess                           |
|group_admin_trunk_group_access                          |str |groupAdminTrunkGroupAccess                        |
|group_admin_session_admission_control_access            |str |groupAdminSessionAdmissionControlAccess           |
|group_admin_office_zone_access                          |str |groupAdminOfficeZoneAccess                        |
|group_admin_number_activation_access                    |str |groupAdminNumberActivationAccess                  |
|group_admin_dialable_caller_id_access                   |str |groupAdminDialableCallerIDAccess                  |
|group_admin_communication_barring_user_profile_access   |str |groupAdminCommunicationBarringUserProfileAccess   |
|service_provider_admin_profile_access                   |str |serviceProviderAdminProfileAccess                 |
|service_provider_admin_group_access                     |str |serviceProviderAdminGroupAccess                   |
|service_provider_admin_user_access                      |str |serviceProviderAdminUserAccess                    |
|service_provider_admin_admin_access                     |str |serviceProviderAdminAdminAccess                   |
|service_provider_admin_department_access                |str |serviceProviderAdminDepartmentAccess              |
|service_provider_admin_access_device_access             |str |serviceProviderAdminAccessDeviceAccess            |
|service_provider_admin_phone_number_extension_access    |str |serviceProviderAdminPhoneNumberExtensionAccess    |
|service_provider_admin_calling_line_id_number_access    |str |serviceProviderAdminCallingLineIdNumberAccess     |
|service_provider_admin_service_access                   |str |serviceProviderAdminServiceAccess                 |
|service_provider_admin_service_pack_access              |str |serviceProviderAdminServicePackAccess             |
|service_provider_admin_session_admission_control_access |str |serviceProviderAdminSessionAdmissionControlAccess |
|service_provider_admin_web_branding_access              |str |serviceProviderAdminWebBrandingAccess             |
|service_provider_admin_office_zone_access               |str |serviceProviderAdminOfficeZoneAccess              |
|service_provider_admin_communication_barring_access     |str |serviceProviderAdminCommunicationBarringAccess    |
|enterprise_admin_network_policy_access                  |str |enterpriseAdminNetworkPolicyAccess                |
|enterprise_admin_number_activation_access               |str |enterpriseAdminNumberActivationAccess             |
|service_provider_admin_dialable_caller_id_access        |str |serviceProviderAdminDialableCallerIDAccess        |
</div>


## `SystemPolicyGetDefaultResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPolicyGetDefaultRequest20()`.

Contains the default policy settings for the system.  The following elements are only
used in AS data mode: GroupAdminDialableCallerIDAccess
ServiceProviderAdminDialableCallerIDAccess
GroupAdminCommunicationBarringUserProfileAccess (This element is only used for groups
in an Enterprise) GroupAdminVerifyTranslationAndRoutingAccess
ServiceProviderAdminVerifyTranslationAndRoutingAccess The following elements are only
used in XS data mode: serviceProviderAdminCommunicationBarringAccess Replaced by:
`SystemPolicyGetDefaultResponse22()` in AS mode

**Attributes:**

|Name                                                         |Type|Description                                           |
|-------------------------------------------------------------|----|------------------------------------------------------|
|group_calling_plan_access                                    |str |groupCallingPlanAccess                                |
|group_extension_access                                       |str |groupExtensionAccess                                  |
|group_ldap_integration_access                                |str |groupLDAPIntegrationAccess                            |
|group_voice_messaging_access                                 |str |groupVoiceMessagingAccess                             |
|group_department_admin_user_access                           |str |groupDepartmentAdminUserAccess                        |
|group_department_admin_trunk_group_access                    |str |groupDepartmentAdminTrunkGroupAccess                  |
|group_department_admin_phone_number_extension_access         |str |groupDepartmentAdminPhoneNumberExtensionAccess        |
|group_department_admin_calling_line_id_number_access         |str |groupDepartmentAdminCallingLineIdNumberAccess         |
|group_user_authentication_access                             |str |groupUserAuthenticationAccess                         |
|group_user_group_directory_access                            |str |groupUserGroupDirectoryAccess                         |
|group_user_profile_access                                    |str |groupUserProfileAccess                                |
|group_user_enhanced_call_logs_access                         |str |groupUserEnhancedCallLogsAccess                       |
|group_user_auto_attendant_name_dialing_access                |str |groupUserAutoAttendantNameDialingAccess               |
|group_admin_profile_access                                   |str |groupAdminProfileAccess                               |
|group_admin_user_access                                      |str |groupAdminUserAccess                                  |
|group_admin_admin_access                                     |str |groupAdminAdminAccess                                 |
|group_admin_department_access                                |str |groupAdminDepartmentAccess                            |
|group_admin_access_device_access                             |str |groupAdminAccessDeviceAccess                          |
|group_admin_enhanced_service_instance_access                 |str |groupAdminEnhancedServiceInstanceAccess               |
|group_admin_feature_access_code_access                       |str |groupAdminFeatureAccessCodeAccess                     |
|group_admin_phone_number_extension_access                    |str |groupAdminPhoneNumberExtensionAccess                  |
|group_admin_calling_line_id_number_access                    |str |groupAdminCallingLineIdNumberAccess                   |
|group_admin_service_access                                   |str |groupAdminServiceAccess                               |
|group_admin_trunk_group_access                               |str |groupAdminTrunkGroupAccess                            |
|group_admin_verify_translation_and_routing_access            |str |groupAdminVerifyTranslationAndRoutingAccess           |
|group_admin_session_admission_control_access                 |str |groupAdminSessionAdmissionControlAccess               |
|group_admin_office_zone_access                               |str |groupAdminOfficeZoneAccess                            |
|group_admin_number_activation_access                         |str |groupAdminNumberActivationAccess                      |
|group_admin_dialable_caller_id_access                        |str |groupAdminDialableCallerIDAccess                      |
|group_admin_communication_barring_user_profile_access        |str |groupAdminCommunicationBarringUserProfileAccess       |
|service_provider_admin_profile_access                        |str |serviceProviderAdminProfileAccess                     |
|service_provider_admin_group_access                          |str |serviceProviderAdminGroupAccess                       |
|service_provider_admin_user_access                           |str |serviceProviderAdminUserAccess                        |
|service_provider_admin_admin_access                          |str |serviceProviderAdminAdminAccess                       |
|service_provider_admin_department_access                     |str |serviceProviderAdminDepartmentAccess                  |
|service_provider_admin_access_device_access                  |str |serviceProviderAdminAccessDeviceAccess                |
|service_provider_admin_phone_number_extension_access         |str |serviceProviderAdminPhoneNumberExtensionAccess        |
|service_provider_admin_calling_line_id_number_access         |str |serviceProviderAdminCallingLineIdNumberAccess         |
|service_provider_admin_service_access                        |str |serviceProviderAdminServiceAccess                     |
|service_provider_admin_service_pack_access                   |str |serviceProviderAdminServicePackAccess                 |
|service_provider_admin_session_admission_control_access      |str |serviceProviderAdminSessionAdmissionControlAccess     |
|service_provider_admin_verify_translation_and_routing_access |str |serviceProviderAdminVerifyTranslationAndRoutingAccess |
|service_provider_admin_web_branding_access                   |str |serviceProviderAdminWebBrandingAccess                 |
|service_provider_admin_office_zone_access                    |str |serviceProviderAdminOfficeZoneAccess                  |
|service_provider_admin_communication_barring_access          |str |serviceProviderAdminCommunicationBarringAccess        |
|enterprise_admin_network_policy_access                       |str |enterpriseAdminNetworkPolicyAccess                    |
|enterprise_admin_number_activation_access                    |str |enterpriseAdminNumberActivationAccess                 |
|service_provider_admin_dialable_caller_id_access             |str |serviceProviderAdminDialableCallerIDAccess            |
</div>


## `SystemPolicyGetDefaultResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPolicyGetDefaultRequest22()`.

Contains the default policy settings for the system.  The following elements are only
used in AS data mode: GroupAdminDialableCallerIDAccess
ServiceProviderAdminDialableCallerIDAccess
GroupAdminCommunicationBarringUserProfileAccess (This element is only used for groups
in an Enterprise) GroupAdminVerifyTranslationAndRoutingAccess
ServiceProviderAdminVerifyTranslationAndRoutingAccess The following elements are only
used in XS data mode: serviceProviderAdminCommunicationBarringAccess

**Attributes:**

|Name                                                         |Type|Description                                           |
|-------------------------------------------------------------|----|------------------------------------------------------|
|group_calling_plan_access                                    |str |groupCallingPlanAccess                                |
|group_extension_access                                       |str |groupExtensionAccess                                  |
|group_voice_messaging_access                                 |str |groupVoiceMessagingAccess                             |
|group_department_admin_user_access                           |str |groupDepartmentAdminUserAccess                        |
|group_department_admin_trunk_group_access                    |str |groupDepartmentAdminTrunkGroupAccess                  |
|group_department_admin_phone_number_extension_access         |str |groupDepartmentAdminPhoneNumberExtensionAccess        |
|group_department_admin_calling_line_id_number_access         |str |groupDepartmentAdminCallingLineIdNumberAccess         |
|group_user_authentication_access                             |str |groupUserAuthenticationAccess                         |
|group_user_group_directory_access                            |str |groupUserGroupDirectoryAccess                         |
|group_user_profile_access                                    |str |groupUserProfileAccess                                |
|group_user_enhanced_call_logs_access                         |str |groupUserEnhancedCallLogsAccess                       |
|group_user_auto_attendant_name_dialing_access                |str |groupUserAutoAttendantNameDialingAccess               |
|group_admin_profile_access                                   |str |groupAdminProfileAccess                               |
|group_admin_user_access                                      |str |groupAdminUserAccess                                  |
|group_admin_admin_access                                     |str |groupAdminAdminAccess                                 |
|group_admin_department_access                                |str |groupAdminDepartmentAccess                            |
|group_admin_access_device_access                             |str |groupAdminAccessDeviceAccess                          |
|group_admin_enhanced_service_instance_access                 |str |groupAdminEnhancedServiceInstanceAccess               |
|group_admin_feature_access_code_access                       |str |groupAdminFeatureAccessCodeAccess                     |
|group_admin_phone_number_extension_access                    |str |groupAdminPhoneNumberExtensionAccess                  |
|group_admin_calling_line_id_number_access                    |str |groupAdminCallingLineIdNumberAccess                   |
|group_admin_service_access                                   |str |groupAdminServiceAccess                               |
|group_admin_trunk_group_access                               |str |groupAdminTrunkGroupAccess                            |
|group_admin_verify_translation_and_routing_access            |str |groupAdminVerifyTranslationAndRoutingAccess           |
|group_admin_session_admission_control_access                 |str |groupAdminSessionAdmissionControlAccess               |
|group_admin_office_zone_access                               |str |groupAdminOfficeZoneAccess                            |
|group_admin_number_activation_access                         |str |groupAdminNumberActivationAccess                      |
|group_admin_dialable_caller_id_access                        |str |groupAdminDialableCallerIDAccess                      |
|group_admin_communication_barring_user_profile_access        |str |groupAdminCommunicationBarringUserProfileAccess       |
|service_provider_admin_profile_access                        |str |serviceProviderAdminProfileAccess                     |
|service_provider_admin_group_access                          |str |serviceProviderAdminGroupAccess                       |
|service_provider_admin_user_access                           |str |serviceProviderAdminUserAccess                        |
|service_provider_admin_admin_access                          |str |serviceProviderAdminAdminAccess                       |
|service_provider_admin_department_access                     |str |serviceProviderAdminDepartmentAccess                  |
|service_provider_admin_access_device_access                  |str |serviceProviderAdminAccessDeviceAccess                |
|service_provider_admin_phone_number_extension_access         |str |serviceProviderAdminPhoneNumberExtensionAccess        |
|service_provider_admin_calling_line_id_number_access         |str |serviceProviderAdminCallingLineIdNumberAccess         |
|service_provider_admin_service_access                        |str |serviceProviderAdminServiceAccess                     |
|service_provider_admin_service_pack_access                   |str |serviceProviderAdminServicePackAccess                 |
|service_provider_admin_session_admission_control_access      |str |serviceProviderAdminSessionAdmissionControlAccess     |
|service_provider_admin_verify_translation_and_routing_access |str |serviceProviderAdminVerifyTranslationAndRoutingAccess |
|service_provider_admin_web_branding_access                   |str |serviceProviderAdminWebBrandingAccess                 |
|service_provider_admin_office_zone_access                    |str |serviceProviderAdminOfficeZoneAccess                  |
|service_provider_admin_communication_barring_access          |str |serviceProviderAdminCommunicationBarringAccess        |
|enterprise_admin_network_policy_access                       |str |enterpriseAdminNetworkPolicyAccess                    |
|enterprise_admin_number_activation_access                    |str |enterpriseAdminNumberActivationAccess                 |
|service_provider_admin_dialable_caller_id_access             |str |serviceProviderAdminDialableCallerIDAccess            |
</div>


## `SystemPortalPasscodeRulesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPortalPasscodeRulesGetRequest()`.

Contains the system passcode rules setting.  Replaced by:
`SystemPortalPasscodeRulesGetResponse19()`

**Attributes:**

|Name                                          |Type |Description                                |
|----------------------------------------------|-----|-------------------------------------------|
|disallow_repeated_digits                      |bool |disallowRepeatedDigits                     |
|disallow_user_number                          |bool |disallowUserNumber                         |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber                 |
|disallow_old_passcode                         |bool |disallowOldPasscode                        |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode                |
|min_code_length                               |int  |minCodeLength                              |
|max_code_length                               |int  |maxCodeLength                              |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts    |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*          |
|expire_password                               |bool |expirePassword                             |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*             |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional* |
|default_password                              |str  |defaultPassword                            |
</div>


## `SystemPortalPasscodeRulesGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPortalPasscodeRulesGetRequest()`.

Contains the system passcode rules setting.  The following elements are only used in
AS data mode: numberOfRepeatedDigits disallowRepeatedPatterns
disallowContiguousSequences numberOfAscendingDigits numberOfDescendingDigits
numberOfPreviousPasscodes

**Attributes:**

|Name                                          |Type |Description                                |
|----------------------------------------------|-----|-------------------------------------------|
|disallow_repeated_digits                      |bool |disallowRepeatedDigits                     |
|number_of_repeated_digits                     |int  |numberOfRepeatedDigits                     |
|disallow_repeated_patterns                    |bool |disallowRepeatedPatterns                   |
|disallow_contiguous_sequences                 |bool |disallowContiguousSequences                |
|number_of_ascending_digits                    |int  |numberOfAscendingDigits                    |
|number_of_descending_digits                   |int  |numberOfDescendingDigits                   |
|disallow_user_number                          |bool |disallowUserNumber                         |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber                 |
|disallow_old_passcode                         |bool |disallowOldPasscode                        |
|number_of_previous_passcodes                  |int  |numberOfPreviousPasscodes                  |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode                |
|min_code_length                               |int  |minCodeLength                              |
|max_code_length                               |int  |maxCodeLength                              |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts    |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*          |
|expire_password                               |bool |expirePassword                             |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*             |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional* |
|default_password                              |str  |defaultPassword                            |
</div>


## `SystemPreferredCarrierGetGroupListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemPreferredCarrierGetGroupListRequest()`.

Contains a table with one row per group.  The table columns are: "Group Id", "Group
Name", "Organization Id", "Organization Type". The "Organization Id" column is
populated with either a service provider Id or an enterprise Id.  The "Organization
Type" column is populated with one of the enumerated strings defined in the
OrganizationType OCI data type.  Please see OCISchemaDataTypes.xsd for details on
OrganizationType.

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|groups_using_carrier_table |List(groupsUsingCarrierTable) |groupsUsingCarrierTable - *Table* array of groupsUsingCarrierTable named tuples |
</div>


## `SystemPreferredCarrierGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemPreferredCarrierGetListRequest()`.

Contains a table with one row per carrier.  The table columns are: "Carrier", "Country
Code", "CIC", "Is Intra-Lata", "Is Inter-Lata", "Is International". The value in the
"Is Intra-Lata", "Is Inter-Lata", and "Is International" columns is one of "true" or
"false".

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|system_carrier_table |List(systemCarrierTable) |systemCarrierTable - *Table* array of systemCarrierTable named tuples |
</div>


## `SystemPreferredCarrierGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemPreferredCarrierGetRequest()`.

Contains the attributes of a carrier.

**Attributes:**

|Name             |Type |Description     |
|-----------------|-----|----------------|
|cic              |str  |cic             |
|country_code     |str  |countryCode     |
|is_intra_lata    |bool |isIntraLata     |
|is_inter_lata    |bool |isInterLata     |
|is_international |bool |isInternational |
</div>


## `SystemPreferredCarrierGetUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemPreferredCarrierGetUserListRequest()`.

Contains a table with one row per user.  The table columns are: "User Id", "Service
Provider Id", "Group Id", "Last Name", "First Name", "Phone Number", "Email Address",
"Hiragana Last Name", and "Hiragana First Name", "Extension", "Department".

**Attributes:**

|Name                      |Type                         |Description                                                                   |
|--------------------------|-----------------------------|------------------------------------------------------------------------------|
|users_using_carrier_table |List(usersUsingCarrierTable) |usersUsingCarrierTable - *Table* array of usersUsingCarrierTable named tuples |
</div>


## `SystemProvisioningValidationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemProvisioningValidationGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `SystemProvisioningValidationGetResponse14sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemProvisioningValidationGetRequest14sp2()`.


**Attributes:**

|Name                           |Type |Description                |
|-------------------------------|-----|---------------------------|
|is_active                      |bool |isActive                   |
|is_network_server_query_active |bool |isNetworkServerQueryActive |
|timeout_seconds                |int  |timeoutSeconds             |
</div>


## `SystemProvisioningValidationGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemProvisioningValidationGetRequest22()`.


**Attributes:**

|Name                                                   |Type |Description                                      |
|-------------------------------------------------------|-----|-------------------------------------------------|
|is_active                                              |bool |isActive                                         |
|is_network_server_query_active                         |bool |isNetworkServerQueryActive                       |
|timeout_seconds                                        |int  |timeoutSeconds                                   |
|deny_mobility_number_as_redirection_destination        |bool |denyMobilityNumberAsRedirectionDestination       |
|deny_enterprise_number_as_network_location_destination |bool |denyEnterpriseNumberAsNetworkLocationDestination |
</div>


## `SystemPushNotificationAllowedApplicationGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPushNotificationAllowedApplicationGetListRequest()`.

Contains a table with a row for each allowed push notification application with
columns: "Application Id", "Description"

**Attributes:**

|Name              |Type                   |Description                                                       |
|------------------|-----------------------|------------------------------------------------------------------|
|application_table |List(applicationTable) |applicationTable - *Table* array of applicationTable named tuples |
</div>


## `SystemPushNotificationParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemPushNotificationParametersGetRequest()`.

The following elements are only used in AS data mode: subscriptionEventsPerSecond,
value "100" is returned in Amplify data mode.  Contains a list of system push
notification parameters.

**Attributes:**

|Name                             |Type |Description                   |
|---------------------------------|-----|------------------------------|
|enforce_allowed_application_list |bool |enforceAllowedApplicationList |
|maximum_registrations_per_user   |int  |maximumRegistrationsPerUser   |
|maximum_registration_age_days    |int  |maximumRegistrationAgeDays    |
|new_call_timeout                 |int  |newCallTimeout                |
|subscription_events_per_second   |int  |subscriptionEventsPerSecond   |
</div>


## `SystemRedundancyParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Replaced By `SystemRedundancyParametersGetResponse16sp2()` Response to
`SystemRedundancyParametersGetRequest()`.

Contains a list of system Redundancy parameters.

**Attributes:**

|Name                    |Type|Description          |
|------------------------|----|---------------------|
|roll_back_timer_minutes |int |rollBackTimerMinutes |
</div>


## `SystemRedundancyParametersGetResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemRedundancyParametersGetRequest16sp2()`.

Contains a list of system Redundancy parameters.

**Attributes:**

|Name                                   |Type |Description                       |
|---------------------------------------|-----|----------------------------------|
|roll_back_timer_minutes                |int  |rollBackTimerMinutes              |
|send_sip_option_message_upon_migration |bool |sendSipOptionMessageUponMigration |
</div>


## `SystemResourcePriorityGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemResourcePriorityGetRequest()`.

The response contains the system Resource Priority service attributes.

**Attributes:**

|Name                              |Type |Description                   |
|----------------------------------|-----|------------------------------|
|send_resource_priority_to_network |bool |sendResourcePriorityToNetwork |
|resource_priority                 |str  |resourcePriority              |
</div>


## `SystemRoamingNetworkGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemRoamingNetworkGetListRequest()`.

Contains a table with columns: "MSC Address", "Network Translation Index".

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|roaming_network_table |List(roamingNetworkTable) |roamingNetworkTable - *Table* array of roamingNetworkTable named tuples |
</div>


## `SystemRouteListEnterpriseTrunkNumberPrefixGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemRouteListEnterpriseTrunkNumberPrefixGetSummaryListRequest()`.

The column headings are "Number Prefix", "Service Provider Id", "Is Enterprise", "User
Id", "Enterprise Trunk", "Is Active", "Reseller Id" ", “Extension Range Start” and
“Extension Range End”.

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|prefix_summary_table |List(prefixSummaryTable) |prefixSummaryTable - *Table* array of prefixSummaryTable named tuples |
</div>


## `SystemRouteListEnterpriseTrunkNumberRangeGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemRouteListEnterpriseTrunkNumberRangeGetSummaryListRequest()`.

The column headings are "Number Range Start", "Number Range End", "Service Provider
Id", "Is Enterprise", "User Id", "Enterprise Trunk", "Is Active", "Reseller Id" and
"Extension Length".

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|number_range_summary_table |List(numberRangeSummaryTable) |numberRangeSummaryTable - *Table* array of numberRangeSummaryTable named tuples |
</div>


## `SystemRoutePointExternalSystemApplicationControllerGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemRoutePointExternalSystemApplicationControllerGetRequest()`.


**Attributes:**

|Name                   |Type      |Description                      |
|-----------------------|----------|---------------------------------|
|application_controller |List[str] |applicationController *Optional* |
</div>


## `SystemRoutePointExternalSystemGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemRoutePointExternalSystemGetListRequest()`.

Contains a table with column headings: "External System", "Description".

**Attributes:**

|Name                  |Type                      |Description                                                             |
|----------------------|--------------------------|------------------------------------------------------------------------|
|external_system_table |List(externalSystemTable) |externalSystemTable - *Table* array of externalSystemTable named tuples |
</div>


## `SystemRoutePointExternalSystemGetRoutePointListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemRoutePointExternalSystemGetRoutePointListRequest()`.


**Attributes:**

|Name            |Type      |Description              |
|----------------|----------|-------------------------|
|service_user_id |List[str] |serviceUserId *Optional* |
</div>


## `SystemRoutingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemRoutingGetRequest()`.


**Attributes:**

|Name                                  |Type |Description                       |
|--------------------------------------|-----|----------------------------------|
|is_route_round_robin                  |bool |isRouteRoundRobin                 |
|route_timer_seconds                   |int  |routeTimerSeconds                 |
|dns_resolved_address_selection_policy |str  |dnsResolvedAddressSelectionPolicy |
|stateful_expiration_minutes           |int  |statefulExpirationMinutes         |
|max_addresses_per_hostname            |int  |maxAddressesPerHostname           |
|max_addresses_during_setup            |int  |maxAddressesDuringSetup           |
</div>


## `SystemRoutingGetRouteDeviceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemRoutingGetRouteDeviceListRequest()`.

The column headings are "Net Address", "Port", "Transport" and "Description".

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|route_device_table |List(routeDeviceTable) |routeDeviceTable - *Table* array of routeDeviceTable named tuples |
</div>


## `SystemRoutingGetRouteListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemRoutingGetRouteListRequest()`.


**Attributes:**

|Name       |Type      |Description          |
|-----------|----------|---------------------|
|route_name |List[str] |routeName *Optional* |
</div>


## `SystemRoutingGetTranslationListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemRoutingGetTranslationListRequest()`.

The column headings are "Routing Digits" and "Route".

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|routing_table |List(routingTable) |routingTable - *Table* array of routingTable named tuples |
</div>


## `SystemRoutingProfileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemRoutingProfileGetListRequest()`.

Returns a list of routing profiles defined in the system.

**Attributes:**

|Name            |Type      |Description               |
|----------------|----------|--------------------------|
|routing_profile |List[str] |routingProfile *Optional* |
</div>


## `SystemRoutingProfileParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemRoutingProfileParametersGetRequest()`.

Contains a list of Routing Profile parameters.

**Attributes:**

|Name                      |Type |Description             |
|--------------------------|-----|------------------------|
|enable_permissive_routing |bool |enablePermissiveRouting |
</div>


## `SystemRuntimeDataPublicationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemRuntimeDataPublicationGetRequest()`.

The response contains the system call admission control parameters information.  The
following elements are only used in AS data mode: enableRuntimeDataSync, value "false"
is returned in XS data mode.  runtimeDataSyncIntervalInMilliSeconds value "1000" is
returned in XS data mode.

**Attributes:**

|Name                                        |Type |Description                           |
|--------------------------------------------|-----|--------------------------------------|
|enable_runtime_data_sync                    |bool |enableRuntimeDataSync                 |
|runtime_data_sync_interval_in_milli_seconds |int  |runtimeDataSyncIntervalInMilliSeconds |
</div>


## `SystemSIPAuthenticationEndpointLockoutGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPAuthenticationEndpointLockoutGetRequest()`.

The column headings for the lockoutTable are: "Organization Id", "Organization Type",
"Group Id", "Line/Port", "User ID", "First Name", "Last Name", "Lockout Started",
"Lockout Expires", "Lockout Count". Lockout times are shown in the system GMT time.
When a permanent lockout is shown, the "Lockout Expires" column is empty and the
"Lockout Count" column contains the word Permanent.

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|lockout_table |List(lockoutTable) |lockoutTable - *Table* array of lockoutTable named tuples |
</div>


## `SystemSIPAuthenticationPasswordRulesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPAuthenticationPasswordRulesGetRequest()`.

Contains the SIP authentication password rules for the system.

**Attributes:**

|Name                                     |Type |Description                                   |
|-----------------------------------------|-----|----------------------------------------------|
|disallow_authentication_name             |bool |disallowAuthenticationName                    |
|disallow_old_password                    |bool |disallowOldPassword                           |
|disallow_reversed_old_password           |bool |disallowReversedOldPassword                   |
|restrict_min_digits                      |bool |restrictMinDigits                             |
|min_digits                               |int  |minDigits                                     |
|restrict_min_upper_case_letters          |bool |restrictMinUpperCaseLetters                   |
|min_upper_case_letters                   |int  |minUpperCaseLetters                           |
|restrict_min_lower_case_letters          |bool |restrictMinLowerCaseLetters                   |
|min_lower_case_letters                   |int  |minLowerCaseLetters                           |
|restrict_min_non_alphanumeric_characters |bool |restrictMinNonAlphanumericCharacters          |
|min_non_alphanumeric_characters          |int  |minNonAlphanumericCharacters                  |
|min_length                               |int  |minLength                                     |
|send_permanent_lockout_notification      |bool |sendPermanentLockoutNotification              |
|permanent_lockout_notify_email_address   |str  |permanentLockoutNotifyEmailAddress *Optional* |
|endpoint_authentication_lockout_type     |str  |endpointAuthenticationLockoutType             |
|endpoint_temporary_lockout_threshold     |int  |endpointTemporaryLockoutThreshold             |
|endpoint_wait_algorithm                  |str  |endpointWaitAlgorithm                         |
|endpoint_lockout_fixed_minutes           |str  |endpointLockoutFixedMinutes                   |
|endpoint_permanent_lockout_threshold     |int  |endpointPermanentLockoutThreshold             |
|trunk_group_authentication_lockout_type  |str  |trunkGroupAuthenticationLockoutType           |
|trunk_group_temporary_lockout_threshold  |int  |trunkGroupTemporaryLockoutThreshold           |
|trunk_group_wait_algorithm               |str  |trunkGroupWaitAlgorithm                       |
|trunk_group_lockout_fixed_minutes        |str  |trunkGroupLockoutFixedMinutes                 |
|trunk_group_permanent_lockout_threshold  |int  |trunkGroupPermanentLockoutThreshold           |
</div>


## `SystemSIPAuthenticationTrunkGroupLockoutGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPAuthenticationTrunkGroupLockoutGetRequest()`.

The column headings for the lockoutTable are: "Organization Id", "Organization Type",
"Group Id", "Trunk Group Name", "Lockout Started", "Lockout Expires", "Lockout Count".
Lockout times are shown in the system GMT time.  When a permanent lockout is shown,
the "Lockout Expires" column is empty and the "Lockout Count" column contains the word
Permanent.

**Attributes:**

|Name          |Type               |Description                                               |
|--------------|-------------------|----------------------------------------------------------|
|lockout_table |List(lockoutTable) |lockoutTable - *Table* array of lockoutTable named tuples |
</div>


## `SystemSIPDeviceTypeFileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeFileGetListRequest()`.

Contains a table of device files managed by the Device Management System on a per-
device type basis.  The column headings are: "File Type", "File Format", "Is
Authenticated".

Replaced By: `SystemSIPDeviceTypeFileGetListResponse14sp8()`

**Attributes:**

|Name                    |Type                       |Description                                                               |
|------------------------|---------------------------|--------------------------------------------------------------------------|
|device_type_files_table |List(deviceTypeFilesTable) |deviceTypeFilesTable - *Table* array of deviceTypeFilesTable named tuples |
</div>


## `SystemSIPDeviceTypeFileGetListResponse14sp8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeFileGetListRequest14sp8()`.

Contains a table of device files managed by the Device Management System on a per-
device type basis.  The column headings are: "File Format", "Is Authenticated",
"Access URL", "Repository URL", "Template URL".

**Attributes:**

|Name                    |Type                       |Description                                                               |
|------------------------|---------------------------|--------------------------------------------------------------------------|
|device_type_files_table |List(deviceTypeFilesTable) |deviceTypeFilesTable - *Table* array of deviceTypeFilesTable named tuples |
</div>


## `SystemSIPDeviceTypeFileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeFileGetRequest()`.

Replaced By: `SystemSIPDeviceTypeFileGetResponse14sp8()`

**Attributes:**

|Name                                   |Type |Description                         |
|---------------------------------------|-----|------------------------------------|
|file_format                            |str  |fileFormat                          |
|remote_file_format                     |str  |remoteFileFormat                    |
|file_category                          |str  |fileCategory                        |
|allow_file_customization               |bool |allowFileCustomization              |
|file_source                            |str  |fileSource                          |
|configuration_file_name                |str  |configurationFileName *Optional*    |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication         |
|mac_based_file_authentication          |bool |macBasedFileAuthentication          |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication  |
|mac_in_non_request_uri                 |bool |macInNonRequestURI                  |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional* |
</div>


## `SystemSIPDeviceTypeFileGetResponse14sp8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeFileGetRequest14sp8()`.


**Attributes:**

|Name                                   |Type |Description                         |
|---------------------------------------|-----|------------------------------------|
|remote_file_format                     |str  |remoteFileFormat                    |
|file_category                          |str  |fileCategory                        |
|allow_file_customization               |bool |allowFileCustomization              |
|file_source                            |str  |fileSource                          |
|configuration_file_name                |str  |configurationFileName *Optional*    |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication         |
|mac_based_file_authentication          |bool |macBasedFileAuthentication          |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication  |
|mac_in_non_request_uri                 |bool |macInNonRequestURI                  |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional* |
</div>


## `SystemSIPDeviceTypeFileGetResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Replaced By `SystemSIPDeviceTypeFileGetResponse18()`.

Response to `SystemSIPDeviceTypeFileGetRequest16sp1()`.

**Attributes:**

|Name                                   |Type |Description                         |
|---------------------------------------|-----|------------------------------------|
|remote_file_format                     |str  |remoteFileFormat                    |
|file_category                          |str  |fileCategory                        |
|file_customization                     |str  |fileCustomization                   |
|file_source                            |str  |fileSource                          |
|configuration_file_name                |str  |configurationFileName *Optional*    |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication         |
|mac_based_file_authentication          |bool |macBasedFileAuthentication          |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication  |
|mac_in_non_request_uri                 |bool |macInNonRequestURI                  |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional* |
|access_url                             |str  |accessUrl                           |
|repository_url                         |str  |repositoryUrl *Optional*            |
|template_url                           |str  |templateUrl *Optional*              |
</div>


## `SystemSIPDeviceTypeFileGetResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeFileGetRequest18()`.

Take note: 1. accessUrl may have undefined content.  When it is the case, undefined
content is put between []. It may also be set to "Error Access FQDN Not Provisioned"
when the access FQDN is not set, or "Error Access Context Name Not Provisioned" when
the context name is not set.  2. repositoryUrl may be set to
"DEVICE_CONFIGURATION_FILE_REPOSITORY_MISSING", if there is no file repository
defined.

**Attributes:**

|Name                                   |Type |Description                         |
|---------------------------------------|-----|------------------------------------|
|remote_file_format                     |str  |remoteFileFormat                    |
|file_category                          |str  |fileCategory                        |
|file_customization                     |str  |fileCustomization                   |
|file_source                            |str  |fileSource                          |
|configuration_file_name                |str  |configurationFileName *Optional*    |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication         |
|mac_based_file_authentication          |bool |macBasedFileAuthentication          |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication  |
|mac_in_non_request_uri                 |bool |macInNonRequestURI                  |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional* |
|access_url                             |str  |accessUrl                           |
|repository_url                         |str  |repositoryUrl *Optional*            |
|template_url                           |str  |templateUrl *Optional*              |
|allow_http                             |bool |allowHttp                           |
|allow_https                            |bool |allowHttps                          |
|allow_tftp                             |bool |allowTftp                           |
|enable_caching                         |bool |enableCaching                       |
</div>


## `SystemSIPDeviceTypeFileGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeFileGetRequest19()`.

Take note: 1. accessUrl may have undefined content.  When it is the case, undefined
content is put between []. It may also be set to "Error Access FQDN Not Provisioned"
when the access FQDN is not set, or "Error Access Context Name Not Provisioned" when
the context name is not set.  2. repositoryUrl may be set to
"DEVICE_CONFIGURATION_FILE_REPOSITORY_MISSING", if there is no file repository
defined.  Replaced by: `SystemSIPDeviceTypeFileGetResponse20()` in AS data mode

**Attributes:**

|Name                                   |Type |Description                         |
|---------------------------------------|-----|------------------------------------|
|remote_file_format                     |str  |remoteFileFormat                    |
|file_category                          |str  |fileCategory                        |
|file_customization                     |str  |fileCustomization                   |
|file_source                            |str  |fileSource                          |
|configuration_file_name                |str  |configurationFileName *Optional*    |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication         |
|mac_based_file_authentication          |bool |macBasedFileAuthentication          |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication  |
|mac_in_non_request_uri                 |bool |macInNonRequestURI                  |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional* |
|access_url                             |str  |accessUrl                           |
|repository_url                         |str  |repositoryUrl *Optional*            |
|template_url                           |str  |templateUrl *Optional*              |
|allow_http                             |bool |allowHttp                           |
|allow_https                            |bool |allowHttps                          |
|allow_tftp                             |bool |allowTftp                           |
|enable_caching                         |bool |enableCaching                       |
|allow_upload_from_device               |bool |allowUploadFromDevice               |
</div>


## `SystemSIPDeviceTypeFileGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeFileGetRequest20()`.

Take note: 1. accessUrl may have undefined content.  When it is the case, undefined
content is put between []. It may also be set to "Error Access FQDN Not Provisioned"
when the access FQDN is not set, or "Error Access Context Name Not Provisioned" when
the context name is not set.  2. repositoryUrl may be set to
"DEVICE_CONFIGURATION_FILE_REPOSITORY_MISSING", if there is no file repository
defined.  Replaced by: SystemSIPDeviceTypeFileGetResponse20Sp1

**Attributes:**

|Name                                   |Type |Description                               |
|---------------------------------------|-----|------------------------------------------|
|remote_file_format                     |str  |remoteFileFormat                          |
|file_category                          |str  |fileCategory                              |
|file_customization                     |str  |fileCustomization                         |
|file_source                            |str  |fileSource                                |
|configuration_file_name                |str  |configurationFileName *Optional*          |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication               |
|mac_based_file_authentication          |bool |macBasedFileAuthentication                |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication        |
|mac_in_non_request_uri                 |bool |macInNonRequestURI                        |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional*       |
|access_url                             |str  |accessUrl                                 |
|repository_url                         |str  |repositoryUrl *Optional*                  |
|template_url                           |str  |templateUrl *Optional*                    |
|allow_http                             |bool |allowHttp                                 |
|allow_https                            |bool |allowHttps                                |
|allow_tftp                             |bool |allowTftp                                 |
|enable_caching                         |bool |enableCaching                             |
|allow_upload_from_device               |bool |allowUploadFromDevice                     |
|default_extended_file_capture_mode     |bool |defaultExtendedFileCaptureMode *Optional* |
</div>


## `SystemSIPDeviceTypeFileGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeFileGetRequest21sp1()`.

Take note: 1. accessUrl may have undefined content.  When it is the case, undefined
content is put between []. It may also be set to "Error Access FQDN Not Provisioned"
when the access FQDN is not set, or "Error Access Context Name Not Provisioned" when
the context name is not set.  2. repositoryUrl may be set to
"DEVICE_CONFIGURATION_FILE_REPOSITORY_MISSING", if there is no file repository
defined.  Replaced by: `SystemSIPDeviceTypeFileGetResponse22()` in AS data mode.

**Attributes:**

|Name                                   |Type |Description                               |
|---------------------------------------|-----|------------------------------------------|
|remote_file_format                     |str  |remoteFileFormat                          |
|file_category                          |str  |fileCategory                              |
|file_customization                     |str  |fileCustomization                         |
|file_source                            |str  |fileSource                                |
|configuration_file_name                |str  |configurationFileName *Optional*          |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication               |
|mac_based_file_authentication          |bool |macBasedFileAuthentication                |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication        |
|mac_in_cert                            |bool |macInCert                                 |
|mac_in_non_request_uri                 |bool |macInNonRequestURI                        |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional*       |
|access_url                             |str  |accessUrl                                 |
|repository_url                         |str  |repositoryUrl *Optional*                  |
|template_url                           |str  |templateUrl *Optional*                    |
|allow_http                             |bool |allowHttp                                 |
|allow_https                            |bool |allowHttps                                |
|allow_tftp                             |bool |allowTftp                                 |
|enable_caching                         |bool |enableCaching                             |
|allow_upload_from_device               |bool |allowUploadFromDevice                     |
|default_extended_file_capture_mode     |bool |defaultExtendedFileCaptureMode *Optional* |
</div>


## `SystemSIPDeviceTypeFileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeFileGetRequest22()`.

Take note: 1. accessUrl may have undefined content.  When it is the case, undefined
content is put between []. It may also be set to "Error Access FQDN Not Provisioned"
when the access FQDN is not set, or "Error Access Context Name Not Provisioned" when
the context name is not set.  2. repositoryUrl may be set to
"DEVICE_CONFIGURATION_FILE_REPOSITORY_MISSING", if there is no file repository
defined.

**Attributes:**

|Name                                   |Type |Description                               |
|---------------------------------------|-----|------------------------------------------|
|remote_file_format                     |str  |remoteFileFormat                          |
|file_category                          |str  |fileCategory                              |
|file_customization                     |str  |fileCustomization                         |
|file_source                            |str  |fileSource                                |
|configuration_file_name                |str  |configurationFileName *Optional*          |
|use_http_digest_authentication         |bool |useHttpDigestAuthentication               |
|mac_based_file_authentication          |bool |macBasedFileAuthentication                |
|user_name_password_file_authentication |bool |userNamePasswordFileAuthentication        |
|mac_in_cert                            |bool |macInCert                                 |
|mac_in_non_request_uri                 |bool |macInNonRequestURI                        |
|mac_format_in_non_request_uri          |str  |macFormatInNonRequestURI *Optional*       |
|access_url                             |str  |accessUrl *Optional*                      |
|repository_url                         |str  |repositoryUrl *Optional*                  |
|template_url                           |str  |templateUrl *Optional*                    |
|allow_http                             |bool |allowHttp                                 |
|allow_https                            |bool |allowHttps                                |
|allow_tftp                             |bool |allowTftp                                 |
|enable_caching                         |bool |enableCaching                             |
|allow_upload_from_device               |bool |allowUploadFromDevice                     |
|default_extended_file_capture_mode     |bool |defaultExtendedFileCaptureMode *Optional* |
</div>


## `SystemSIPDeviceTypeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetListRequest()`.

Contains a table of identity/ device profile types configured in the system.  The
column headings are: "Device Type", "Profile", "Is Obsolete" and "Reseller Id". The
following columns are only returned in AS data mode: "Reseller Id"

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|device_type_table |List(deviceTypeTable) |deviceTypeTable - *Table* array of deviceTypeTable named tuples |
</div>


## `SystemSIPDeviceTypeLanguageMappingGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeLanguageMappingGetListRequest()`.

Contains a table of device type languages mapped to equivalent BroadWorks languages.
The column headings are: "BroadWorks Language", "Device Language".

**Attributes:**

|Name                        |Type                           |Description                                                                       |
|----------------------------|-------------------------------|----------------------------------------------------------------------------------|
|device_type_languages_table |List(deviceTypeLanguagesTable) |deviceTypeLanguagesTable - *Table* array of deviceTypeLanguagesTable named tuples |
</div>


## `SystemSIPDeviceTypeServiceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeServiceGetRequest()`.

Contains the list of device type services integrated to BroadWorks.

**Attributes:**

|Name                            |Type |Description                  |
|--------------------------------|-----|-----------------------------|
|supports_polycom_phone_services |bool |supportsPolycomPhoneServices |
</div>


## `SystemSIPDiversionReasonGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDiversionReasonGetRequest()`.

Contains a table containing a list of diversion reasons and associated cause values.
The column headings are: "Diversion Reaon", "Cause Value".

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|diversion_reason_table |List(diversionReasonTable) |diversionReasonTable - *Table* array of diversionReasonTable named tuples |
</div>


## `SystemSIPGetACLListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPGetACLListRequest()`.

The table columns are: "Net Address", "Transport" and "Description".

**Attributes:**

|Name      |Type           |Description                                       |
|----------|---------------|--------------------------------------------------|
|acl_table |List(aclTable) |aclTable - *Table* array of aclTable named tuples |
</div>


## `SystemSIPGetContentTypeListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPGetContentTypeListRequest()`.

Returns a 2 column table with column headings: "Content Type" and "Supported
Interface".

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|content_type_table |List(contentTypeTable) |contentTypeTable - *Table* array of contentTypeTable named tuples |
</div>


## `SystemSMDIGetACLListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSMDIGetACLListRequest()`.

The table columns are: "Net Address" and "Description".

**Attributes:**

|Name      |Type           |Description                                       |
|----------|---------------|--------------------------------------------------|
|acl_table |List(aclTable) |aclTable - *Table* array of aclTable named tuples |
</div>


## `SystemSMDIMessageDeskGetServerListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMediaServerGetListRequest()`.

The SMDI Server table column headings are: "Device Name", "Net Address", "Port" and
"Description".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|smdi_server_table |List(smdiServerTable) |smdiServerTable - *Table* array of smdiServerTable named tuples |
</div>


## `SystemSMDIMessageDeskGetServerRouteListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSMDIMessageDeskGetServerRouteListRequest()`.

The SMDI Server route table column headings are: "Destination" and "SMDI Servers".

**Attributes:**

|Name                    |Type                       |Description                                                               |
|------------------------|---------------------------|--------------------------------------------------------------------------|
|smdi_server_route_table |List(smdiServerRouteTable) |smdiServerRouteTable - *Table* array of smdiServerRouteTable named tuples |
</div>


## `SystemSMDIParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSMDIParametersGetListRequest()`.

Contains a list of system SMDI parameters.

**Attributes:**

|Name            |Type |Description    |
|----------------|-----|---------------|
|enable_smdi     |bool |enableSMDI     |
|listening_port  |int  |listeningPort  |
|max_connections |int  |maxConnections |
</div>


## `SystemSMPPGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSMPPGetRequest()`.


**Attributes:**

|Name                              |Type|Description                              |
|----------------------------------|----|-----------------------------------------|
|primary_smpp_server_net_address   |str |primarySMPPServerNetAddress *Optional*   |
|primary_smpp_port                 |int |primarySMPPPort                          |
|secondary_smpp_server_net_address |str |secondarySMPPServerNetAddress *Optional* |
|secondary_smpp_port               |int |secondarySMPPPort                        |
|system_id                         |str |systemId *Optional*                      |
|password                          |str |password *Optional*                      |
|version                           |str |version                                  |
</div>


## `SystemSMPPGetResponse14sp5`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSMPPGetRequest14sp5()`.

Replaced by: `SystemSMPPGetResponse21()` in AS data mode

**Attributes:**

|Name                              |Type|Description                              |
|----------------------------------|----|-----------------------------------------|
|primary_smpp_server_net_address   |str |primarySMPPServerNetAddress *Optional*   |
|primary_smpp_port                 |int |primarySMPPPort                          |
|secondary_smpp_server_net_address |str |secondarySMPPServerNetAddress *Optional* |
|secondary_smpp_port               |int |secondarySMPPPort                        |
|system_id                         |str |systemId *Optional*                      |
|password                          |str |password *Optional*                      |
|version                           |str |version                                  |
|system_type                       |str |systemType *Optional*                    |
</div>


## `SystemSMPPGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSMPPGetRequest21()`.

The following elements are only used in AS data mode: primarySMPPServerNetAddress,
value "" is returned in Amplify data mode primarySMPPPort, value "2775" is returned in
Amplify data mode secondarySMPPServerNetAddress, value "" is returned in Amplify mode
secondarySMPPPort, value "2775" is returned in Amplify data mode systemId, value "" is
returned in Amplify data mode password, value "" is returned in Amplify mode version,
value "" is returned in Amplify data mode systemType, value "VMS" is returned in
Amplify mode useGsmMwiUcs2Encoding, value "true" is returned in Amplify mode

**Attributes:**

|Name                              |Type |Description                              |
|----------------------------------|-----|-----------------------------------------|
|primary_smpp_server_net_address   |str  |primarySMPPServerNetAddress *Optional*   |
|primary_smpp_port                 |int  |primarySMPPPort                          |
|secondary_smpp_server_net_address |str  |secondarySMPPServerNetAddress *Optional* |
|secondary_smpp_port               |int  |secondarySMPPPort                        |
|system_id                         |str  |systemId *Optional*                      |
|password                          |str  |password *Optional*                      |
|version                           |str  |version                                  |
|system_type                       |str  |systemType *Optional*                    |
|enable_mwi_customized_message     |bool |enableMWICustomizedMessage               |
|support_message_payload           |bool |supportMessagePayload                    |
|max_short_message_length          |int  |maxShortMessageLength                    |
|use_gsm_mwi_ucs2_encoding         |bool |useGsmMwiUcs2Encoding                    |
</div>


## `SystemSMPPGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSMPPGetRequest22()`.

The following elements are only used in AS data mode: primarySMPPServerNetAddress,
value "" is returned in Amplify data mode primarySMPPPort, value "2775" is returned in
Amplify data mode secondarySMPPServerNetAddress, value "" is returned in Amplify mode
secondarySMPPPort, value "2775" is returned in Amplify data mode systemId, value "" is
returned in Amplify data mode password, value "" is returned in Amplify mode version,
value "" is returned in Amplify data mode systemType, value "VMS" is returned in
Amplify mode useGsmMwiUcs2Encoding, value "true" is returned in Amplify mode

**Attributes:**

|Name                              |Type |Description                              |
|----------------------------------|-----|-----------------------------------------|
|primary_smpp_server_net_address   |str  |primarySMPPServerNetAddress *Optional*   |
|primary_smpp_port                 |int  |primarySMPPPort                          |
|secondary_smpp_server_net_address |str  |secondarySMPPServerNetAddress *Optional* |
|secondary_smpp_port               |int  |secondarySMPPPort                        |
|system_id                         |str  |systemId *Optional*                      |
|password                          |str  |password *Optional*                      |
|version                           |str  |version                                  |
|system_type                       |str  |systemType *Optional*                    |
|enable_mwi_customized_message     |bool |enableMWICustomizedMessage               |
|support_message_payload           |bool |supportMessagePayload                    |
|max_short_message_length          |int  |maxShortMessageLength                    |
|use_gsm_mwi_ucs2_encoding         |bool |useGsmMwiUcs2Encoding                    |
|include_only_new_message_count    |bool |includeOnlyNewMessageCount               |
</div>


## `SystemScheduleGetEventListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemScheduleGetEventListRequest()`.

The response contains a list of events.

**Attributes:**

|Name       |Type      |Description          |
|-----------|----------|---------------------|
|event_name |List[str] |eventName *Optional* |
</div>


## `SystemScheduleGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemScheduleGetListRequest()`.

The response contains a list of system schedules.

**Attributes:**

|Name          |Type      |Description             |
|--------------|----------|------------------------|
|schedule_name |List[str] |scheduleName *Optional* |
|schedule_type |List[str] |scheduleType *Optional* |
</div>


## `SystemSecurityClassificationGetClassificationResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSecurityClassificationGetClassificationRequest()`.


**Attributes:**

|Name                                |Type|Description                      |
|------------------------------------|----|---------------------------------|
|audio_announcement_file_description |str |audioAnnouncementFileDescription |
|audio_announcement_file_type        |str |audioAnnouncementFileType        |
</div>


## `SystemSecurityClassificationGetClassificationTrunkGroupUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`SystemSecurityClassificationGetClassificationTrunkGroupUsageListRequest()`.

Contains a table with column headings: "Trunk Group Name","Group ID","Organization ID"
and "Organization Type"

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|usage_table |List(usageTable) |usageTable - *Table* array of usageTable named tuples |
</div>


## `SystemSecurityClassificationGetClassificationUserUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSecurityClassificationGetClassificationUserUsageListRequest()`.

Contains a table with column headings: "User ID", "Last Name", "First Name", "Phone
Number", "Extension", "Service Provider Id", "Group Id".

**Attributes:**

|Name        |Type             |Description                                           |
|------------|-----------------|------------------------------------------------------|
|usage_table |List(usageTable) |usageTable - *Table* array of usageTable named tuples |
</div>


## `SystemSecurityClassificationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSecurityClassificationGetRequest()`.

Contains a table with column headings: "Name", "Priority".

**Attributes:**

|Name                          |Type                              |Description                                                                             |
|------------------------------|----------------------------------|----------------------------------------------------------------------------------------|
|meet_me_annc_threshold        |int                               |meetMeAnncThreshold                                                                     |
|security_classification_table |List(SecurityClassificationTable) |SecurityClassificationTable - *Table* array of SecurityClassificationTable named tuples |
</div>


## `SystemSecurityClassificationGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSecurityClassificationGetRequest21()`.

Contains a table with column headings: "Name", "Priority".

**Attributes:**

|Name                                                 |Type                              |Description                                                                             |
|-----------------------------------------------------|----------------------------------|----------------------------------------------------------------------------------------|
|meet_me_annc_threshold                               |int                               |meetMeAnncThreshold                                                                     |
|play_trunk_user_security_classification_announcement |bool                              |playTrunkUserSecurityClassificationAnnouncement                                         |
|security_classification_table                        |List(SecurityClassificationTable) |SecurityClassificationTable - *Table* array of SecurityClassificationTable named tuples |
</div>


## `SystemSelectiveServicesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSelectiveServicesGetRequest()`.


**Attributes:**

|Name                 |Type|Description         |
|---------------------|----|--------------------|
|schedule_combination |str |scheduleCombination |
</div>


## `SystemSelectiveServicesGetResponse18sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSelectiveServicesGetRequest18sp1()`.


**Attributes:**

|Name                  |Type |Description         |
|----------------------|-----|--------------------|
|schedule_combination  |str  |scheduleCombination |
|screen_private_number |bool |screenPrivateNumber |
</div>


## `SystemSelectiveServicesGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSelectiveServicesGetRequest22()`.


**Attributes:**

|Name                                      |Type |Description                         |
|------------------------------------------|-----|------------------------------------|
|schedule_combination                      |str  |scheduleCombination                 |
|screen_private_number                     |bool |screenPrivateNumber                 |
|empty_holiday_schedule_is_out_of_schedule |bool |emptyHolidayScheduleIsOutOfSchedule |
</div>


## `SystemServerAddressesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemServerAddressesGetRequest()`.

Contains a list of system Server Addresses.  See also: `PrimaryInfoGetResponse()`
`PublicClusterGetFullyQualifiedDomainNameResponse()` `ServingInfoGetResponse()`

**Attributes:**

|Name                                              |Type|Description                                             |
|--------------------------------------------------|----|--------------------------------------------------------|
|web_server_cluster_public_fqdn                    |str |webServerClusterPublicFQDN *Optional*                   |
|application_server_cluster_primary_public_fqdn    |str |applicationServerClusterPrimaryPublicFQDN *Optional*    |
|application_server_cluster_secondary_public_fqdn  |str |applicationServerClusterSecondaryPublicFQDN *Optional*  |
|application_server_cluster_primary_private_fqdn   |str |applicationServerClusterPrimaryPrivateFQDN *Optional*   |
|application_server_cluster_secondary_private_fqdn |str |applicationServerClusterSecondaryPrivateFQDN *Optional* |
</div>


## `SystemServiceActivationAccessCodeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemServiceActivationAccessCodeGetRequest()`.

Contains Service Activation Access Code system parameters.

**Attributes:**

|Name                      |Type |Description                      |
|--------------------------|-----|---------------------------------|
|is_active                 |bool |isActive                         |
|terminating_access_code   |str  |terminatingAccessCode *Optional* |
|redirecting_access_code   |str  |redirectingAccessCode *Optional* |
|click_to_dial_access_code |str  |clickToDialAccessCode *Optional* |
</div>


## `SystemServiceCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemServiceCodeGetListRequest()`.

Contains a table of defined service codes The column headings are: "Service Code", and
"Description".

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|service_code_table |List(serviceCodeTable) |serviceCodeTable - *Table* array of serviceCodeTable named tuples |
</div>


## `SystemServicePackMigrationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemServicePackMigrationGetRequest()`.

The response contains the Service Pack Migration system level settings.

**Attributes:**

|Name                             |Type|Description                   |
|---------------------------------|----|------------------------------|
|max_simultaneous_migration_tasks |int |maxSimultaneousMigrationTasks |
</div>


## `SystemServicePhoneNumberLookupResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemServicePhoneNumberLookupRequest()`.

The column headings for the userTable are: "Service Provider Id", "Is Enterprise",
"Group Id", "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Phone Number" and "Extension".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `SystemSessionAdmissionControlGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSessionAdmissionControlGetRequest()`.

The response contains the session admission control settings for the system.  Replaced
by: `SystemSessionAdmissionControlGetResponse21sp1()`.

**Attributes:**

|Name                                   |Type |Description                       |
|---------------------------------------|-----|----------------------------------|
|count_long_connections_to_media_server |bool |countLongConnectionsToMediaServer |
|sac_handling_for_mo_h                  |str  |sacHandlingForMoH                 |
|block_vm_deposit_due_to_sac_limits     |bool |blockVMDepositDueToSACLimits      |
</div>


## `SystemSessionAdmissionControlGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSessionAdmissionControlGetRequest21sp1()`.

The response contains the session admission control settings for the system.  Replaced
by: `SystemSessionAdmissionControlGetResponse22()`.

**Attributes:**

|Name                                   |Type |Description                       |
|---------------------------------------|-----|----------------------------------|
|count_long_connections_to_media_server |bool |countLongConnectionsToMediaServer |
|sac_handling_for_mo_h                  |str  |sacHandlingForMoH                 |
|block_vm_deposit_due_to_sac_limits     |bool |blockVMDepositDueToSACLimits      |
|sac_codec_selection_policy             |str  |sacCodecSelectionPolicy           |
</div>


## `SystemSessionAdmissionControlGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSessionAdmissionControlGetRequest22()`.

The response contains the session admission control settings for the system.

**Attributes:**

|Name                                           |Type |Description                             |
|-----------------------------------------------|-----|----------------------------------------|
|count_long_connections_to_media_server         |bool |countLongConnectionsToMediaServer       |
|sac_handling_for_mo_h                          |str  |sacHandlingForMoH                       |
|block_vm_deposit_due_to_sac_limits             |bool |blockVMDepositDueToSACLimits            |
|sac_codec_selection_policy                     |str  |sacCodecSelectionPolicy                 |
|count_call_to_mobile_number_for_sac_subscriber |bool |countCallToMobileNumberForSACSubscriber |
|count_bw_anywhere_for_sac_subscriber           |bool |countBWAnywhereForSACSubscriber         |
|count_ro_for_sac_subscriber                    |bool |countROForSACSubscriber                 |
|exclude_bw_mobility_for_sac_subscriber         |bool |excludeBWMobilityForSACSubscriber       |
</div>


## `SystemSessionAdmissionControlGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSessionAdmissionControlGetRequest22V2()`.

The response contains the session admission control settings for the system.

**Attributes:**

|Name                                           |Type |Description                             |
|-----------------------------------------------|-----|----------------------------------------|
|count_long_connections_to_media_server         |bool |countLongConnectionsToMediaServer       |
|sac_handling_for_mo_h                          |str  |sacHandlingForMoH                       |
|block_vm_deposit_due_to_sac_limits             |bool |blockVMDepositDueToSACLimits            |
|sac_codec_selection_policy                     |str  |sacCodecSelectionPolicy                 |
|count_call_to_mobile_number_for_sac_subscriber |bool |countCallToMobileNumberForSACSubscriber |
|count_bw_anywhere_for_sac_subscriber           |bool |countBWAnywhereForSACSubscriber         |
|count_ro_for_sac_subscriber                    |bool |countROForSACSubscriber                 |
|exclude_bw_mobility_for_sac_subscriber         |bool |excludeBWMobilityForSACSubscriber       |
|enable_holdover_of_highwater_session_counts    |bool |enableHoldoverOfHighwaterSessionCounts  |
|holdover_period_minutes                        |str  |holdoverPeriodMinutes                   |
|time_zone_offset_minutes                       |str  |timeZoneOffsetMinutes                   |
</div>


## `SystemSessionAuditGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSessionAuditGetRequest()`.

Replaced By: `SystemSessionAuditGetResponse14sp3()`

**Attributes:**

|Name                   |Type |Description          |
|-----------------------|-----|---------------------|
|is_active              |bool |isActive             |
|interval_seconds       |int  |intervalSeconds      |
|timeout_period_seconds |int  |timeoutPeriodSeconds |
</div>


## `SystemSessionAuditGetResponse14sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSessionAuditGetRequest14sp3()`.


**Attributes:**

|Name                                    |Type |Description                        |
|----------------------------------------|-----|-----------------------------------|
|is_audit_active                         |bool |isAuditActive                      |
|audit_interval_seconds                  |int  |auditIntervalSeconds               |
|audit_timeout_seconds                   |int  |auditTimeoutSeconds                |
|release_call_on_audit_failure           |bool |releaseCallOnAuditFailure          |
|is_sip_refresh_allowed_on_audit         |bool |isSIPRefreshAllowedOnAudit         |
|allow_update_for_sip_refresh            |bool |allowUpdateForSIPRefresh           |
|is_sip_session_timer_active             |bool |isSIPSessionTimerActive            |
|sip_session_expires_minimum_seconds     |int  |sipSessionExpiresMinimumSeconds    |
|enforce_sip_session_expires_maximum     |bool |enforceSIPSessionExpiresMaximum    |
|sip_session_expires_maximum_seconds     |int  |sipSessionExpiresMaximumSeconds    |
|sip_session_expires_timer_seconds       |int  |sipSessionExpiresTimerSeconds      |
|always_use_session_timer_when_supported |bool |alwaysUseSessionTimerWhenSupported |
|preferred_session_timer_refresher       |str  |preferredSessionTimerRefresher     |
</div>


## `SystemSessionAuditGetResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSessionAuditGetRequest17sp3()`.

Replaced by: `SystemSessionAuditGetResponse23()` in AS data mode.

**Attributes:**

|Name                                    |Type |Description                        |
|----------------------------------------|-----|-----------------------------------|
|is_audit_active                         |bool |isAuditActive                      |
|audit_interval_seconds                  |int  |auditIntervalSeconds               |
|audit_timeout_seconds                   |int  |auditTimeoutSeconds                |
|release_call_on_audit_failure           |bool |releaseCallOnAuditFailure          |
|is_sip_refresh_allowed_on_audit         |bool |isSIPRefreshAllowedOnAudit         |
|allow_update_for_sip_refresh            |bool |allowUpdateForSIPRefresh           |
|is_sip_session_timer_active             |bool |isSIPSessionTimerActive            |
|sip_session_expires_minimum_seconds     |int  |sipSessionExpiresMinimumSeconds    |
|enforce_sip_session_expires_maximum     |bool |enforceSIPSessionExpiresMaximum    |
|sip_session_expires_maximum_seconds     |int  |sipSessionExpiresMaximumSeconds    |
|sip_session_expires_timer_seconds       |int  |sipSessionExpiresTimerSeconds      |
|always_use_session_timer_when_supported |bool |alwaysUseSessionTimerWhenSupported |
|preferred_session_timer_refresher       |str  |preferredSessionTimerRefresher     |
|enable_emergency_call_alarm_timer       |bool |enableEmergencyCallAlarmTimer      |
|emergency_call_alarm_minutes            |int  |emergencyCallAlarmMinutes          |
|enable_emergency_call_cleanup_timer     |bool |enableEmergencyCallCleanupTimer    |
|emergency_call_cleanup_minutes          |int  |emergencyCallCleanupMinutes        |
</div>


## `SystemSessionAuditGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSessionAuditGetRequest23()`.

The following elements are only used in AS data mode: msAuditIntervalSeconds, value
1200 is returned in XS data mode

**Attributes:**

|Name                                    |Type |Description                        |
|----------------------------------------|-----|-----------------------------------|
|is_audit_active                         |bool |isAuditActive                      |
|audit_interval_seconds                  |int  |auditIntervalSeconds               |
|audit_timeout_seconds                   |int  |auditTimeoutSeconds                |
|release_call_on_audit_failure           |bool |releaseCallOnAuditFailure          |
|is_sip_refresh_allowed_on_audit         |bool |isSIPRefreshAllowedOnAudit         |
|allow_update_for_sip_refresh            |bool |allowUpdateForSIPRefresh           |
|is_sip_session_timer_active             |bool |isSIPSessionTimerActive            |
|sip_session_expires_minimum_seconds     |int  |sipSessionExpiresMinimumSeconds    |
|enforce_sip_session_expires_maximum     |bool |enforceSIPSessionExpiresMaximum    |
|sip_session_expires_maximum_seconds     |int  |sipSessionExpiresMaximumSeconds    |
|sip_session_expires_timer_seconds       |int  |sipSessionExpiresTimerSeconds      |
|always_use_session_timer_when_supported |bool |alwaysUseSessionTimerWhenSupported |
|preferred_session_timer_refresher       |str  |preferredSessionTimerRefresher     |
|enable_emergency_call_alarm_timer       |bool |enableEmergencyCallAlarmTimer      |
|emergency_call_alarm_minutes            |int  |emergencyCallAlarmMinutes          |
|enable_emergency_call_cleanup_timer     |bool |enableEmergencyCallCleanupTimer    |
|emergency_call_cleanup_minutes          |int  |emergencyCallCleanupMinutes        |
|always_allow_refresh_for_ms             |bool |alwaysAllowRefreshForMS            |
|ms_audit_interval_seconds               |int  |msAuditIntervalSeconds             |
</div>


## `SystemShInterfaceParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemShInterfaceParametersGetRequest()`.

Contains the Sh Interface system parameters.  Replaced by:
`SystemShInterfaceParametersGetResponse17()`

**Attributes:**

|Name                                  |Type|Description                       |
|--------------------------------------|----|----------------------------------|
|hss_realm                             |str |hssRealm *Optional*               |
|request_timeout_seconds               |int |requestTimeoutSeconds             |
|public_identity_refresh_delay_seconds |int |publicIdentityRefreshDelaySeconds |
</div>


## `SystemShInterfaceParametersGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemShInterfaceParametersGetRequest()`.

Contains the Sh Interface system parameters.

**Attributes:**

|Name                                  |Type|Description                       |
|--------------------------------------|----|----------------------------------|
|hss_realm                             |str |hssRealm *Optional*               |
|public_identity_refresh_delay_seconds |int |publicIdentityRefreshDelaySeconds |
</div>


## `SystemShInterfaceRefreshTaskGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemShInterfaceRefreshTaskGetRequest()`.

Provides the status of the system refresh task.  If isRunning is false,
numberPublicIdentityRefreshStarted and numberPublicIdentities are omitted.  If
isRunning is true, numberPublicIdentities indicates the total number of public
identities in the system that will be refreshed by the system refresh task;
numberPublicIdentityRefreshesStarted indicates the total number of public identities
for which a refresh has been started.

**Attributes:**

|Name                                     |Type |Description                                     |
|-----------------------------------------|-----|------------------------------------------------|
|is_running                               |bool |isRunning                                       |
|number_public_identity_refreshes_started |int  |numberPublicIdentityRefreshesStarted *Optional* |
|number_public_identities                 |int  |numberPublicIdentities *Optional*               |
</div>


## `SystemSoftwareVersionGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSoftwareVersionGetRequest()`.


**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|version |str |version    |
</div>


## `SystemSpeedDial100GetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSpeedDial100GetRequest()`.

Replaced by: `SystemSpeedDial100GetResponse17sp1()`

**Attributes:**

|Name   |Type|Description|
|-------|----|-----------|
|prefix |str |prefix     |
</div>


## `SystemSpeedDial100GetResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSpeedDial100GetRequest17sp1()`.


**Attributes:**

|Name   |Type|Description       |
|-------|----|------------------|
|prefix |str |prefix *Optional* |
</div>


## `SystemStateOrProvinceGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains a 2 column table with column headings 'Key' and 'Display Name' and a row for
each state or province.


**Attributes:**

|Name                    |Type                       |Description                                                               |
|------------------------|---------------------------|--------------------------------------------------------------------------|
|state_or_province_table |List(stateOrProvinceTable) |stateOrProvinceTable - *Table* array of stateOrProvinceTable named tuples |
</div>


## `SystemStirShakenGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemStirShakenGetRequest()`.


**Attributes:**

|Name                                                   |Type |Description                                      |
|-------------------------------------------------------|-----|-------------------------------------------------|
|signing_policy                                         |str  |signingPolicy                                    |
|tagging_policy                                         |str  |taggingPolicy                                    |
|sign_emergency_calls                                   |bool |signEmergencyCalls                               |
|tag_emergency_calls                                    |bool |tagEmergencyCalls                                |
|signing_service_url                                    |str  |signingServiceURL *Optional*                     |
|tag_from_or_pai                                        |str  |tagFromOrPAI                                     |
|verstat_tag                                            |str  |verstatTag                                       |
|use_os_value_for_orig_id                               |bool |useOSValueForOrigId                              |
|orig_uuid                                              |str  |origUUID *Optional*                              |
|attestation_level                                      |str  |attestationLevel                                 |
|enable_verification                                    |bool |enableVerification                               |
|verification_service_url                               |str  |verificationServiceURL *Optional*                |
|verification_error_handling                            |str  |verificationErrorHandling                        |
|proxy_verstat_to_cnam_subscribe                        |bool |proxyVerstatToCNAMSubscribe                      |
|use_unknown_headers_from_cnam_notify                   |bool |useUnknownHeadersFromCNAMNotify                  |
|use_ts24229_headers                                    |bool |useTS24229Headers                                |
|enable_signing_for_unscreened_trunk_group_originations |bool |enableSigningForUnscreenedTrunkGroupOriginations |
|enable_tagging_for_unscreened_trunk_group_originations |bool |enableTaggingForUnscreenedTrunkGroupOriginations |
|unscreened_trunk_group_origination_attestation_level   |str  |unscreenedTrunkGroupOriginationAttestationLevel  |
|verify_gets_calls                                      |bool |verifyGETSCalls                                  |
</div>


## `SystemSubscriberGetCallProcessingParametersResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSubscriberGetCallProcessingParametersRequest()`.

Replaced By: `SystemSubscriberGetCallProcessingParametersResponse14sp3()`

**Attributes:**

|Name                               |Type |Description                   |
|-----------------------------------|-----|------------------------------|
|user_calling_line_id_selection     |str  |userCallingLineIdSelection    |
|is_extended_calling_line_id_active |bool |isExtendedCallingLineIdActive |
|is_ring_time_out_active            |bool |isRingTimeOutActive           |
|ring_timeout_seconds               |int  |ringTimeoutSeconds            |
</div>


## `SystemSubscriberGetCallProcessingParametersResponse14sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSubscriberGetCallProcessingParametersRequest14sp3()`.


**Attributes:**

|Name                                       |Type |Description                            |
|-------------------------------------------|-----|---------------------------------------|
|user_calling_line_id_selection             |str  |userCallingLineIdSelection             |
|is_extended_calling_line_id_active         |bool |isExtendedCallingLineIdActive          |
|is_ring_time_out_active                    |bool |isRingTimeOutActive                    |
|ring_timeout_seconds                       |int  |ringTimeoutSeconds                     |
|allow_emergency_remote_office_originations |bool |allowEmergencyRemoteOfficeOriginations |
</div>


## `SystemSubscriberGetCallProcessingParametersResponse14sp7`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSubscriberGetCallProcessingParametersRequest14sp7()`.


**Attributes:**

|Name                                       |Type |Description                            |
|-------------------------------------------|-----|---------------------------------------|
|is_extended_calling_line_id_active         |bool |isExtendedCallingLineIdActive          |
|is_ring_time_out_active                    |bool |isRingTimeOutActive                    |
|ring_timeout_seconds                       |int  |ringTimeoutSeconds                     |
|allow_emergency_remote_office_originations |bool |allowEmergencyRemoteOfficeOriginations |
</div>


## `SystemSubscriberGetCallProcessingParametersResponse15`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSubscriberGetCallProcessingParametersRequest15()`.


**Attributes:**

|Name                                       |Type |Description                            |
|-------------------------------------------|-----|---------------------------------------|
|user_calling_line_id_selection             |str  |userCallingLineIdSelection             |
|is_extended_calling_line_id_active         |bool |isExtendedCallingLineIdActive          |
|is_ring_time_out_active                    |bool |isRingTimeOutActive                    |
|ring_timeout_seconds                       |int  |ringTimeoutSeconds                     |
|allow_emergency_remote_office_originations |bool |allowEmergencyRemoteOfficeOriginations |
|max_no_answer_number_of_rings              |int  |maxNoAnswerNumberOfRings               |
</div>


## `SystemSubscriberGetCallProcessingParametersResponse15sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSubscriberGetCallProcessingParametersRequest15sp2()`.

Replaced by: `SystemSubscriberGetCallProcessingParametersResponse17()`

**Attributes:**

|Name                                       |Type |Description                            |
|-------------------------------------------|-----|---------------------------------------|
|is_extended_calling_line_id_active         |bool |isExtendedCallingLineIdActive          |
|is_ring_time_out_active                    |bool |isRingTimeOutActive                    |
|ring_timeout_seconds                       |int  |ringTimeoutSeconds                     |
|allow_emergency_remote_office_originations |bool |allowEmergencyRemoteOfficeOriginations |
|max_no_answer_number_of_rings              |int  |maxNoAnswerNumberOfRings               |
</div>


## `SystemSubscriberGetCallProcessingParametersResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSubscriberGetCallProcessingParametersRequest17()`.


**Attributes:**

|Name                                       |Type |Description                            |
|-------------------------------------------|-----|---------------------------------------|
|is_extended_calling_line_id_active         |bool |isExtendedCallingLineIdActive          |
|is_ring_time_out_active                    |bool |isRingTimeOutActive                    |
|ring_timeout_seconds                       |int  |ringTimeoutSeconds                     |
|allow_emergency_remote_office_originations |bool |allowEmergencyRemoteOfficeOriginations |
|max_no_answer_number_of_rings              |int  |maxNoAnswerNumberOfRings               |
|incoming_call_to_user_alias_mode           |str  |incomingCallToUserAliasMode            |
</div>


## `SystemSubscriberGetCallProcessingParametersResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSubscriberGetCallProcessingParametersRequest17sp3()`.


**Attributes:**

|Name                                       |Type |Description                            |
|-------------------------------------------|-----|---------------------------------------|
|is_extended_calling_line_id_active         |bool |isExtendedCallingLineIdActive          |
|is_ring_time_out_active                    |bool |isRingTimeOutActive                    |
|ring_timeout_seconds                       |int  |ringTimeoutSeconds                     |
|allow_emergency_remote_office_originations |bool |allowEmergencyRemoteOfficeOriginations |
|max_no_answer_number_of_rings              |int  |maxNoAnswerNumberOfRings               |
|incoming_call_to_user_alias_mode           |str  |incomingCallToUserAliasMode            |
|bypass_termination_loop_detection          |bool |bypassTerminationLoopDetection         |
</div>


## `SystemSubscriberGetCallProcessingParametersResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSubscriberGetCallProcessingParametersRequest17sp4()`.


**Attributes:**

|Name                                       |Type |Description                            |
|-------------------------------------------|-----|---------------------------------------|
|is_extended_calling_line_id_active         |bool |isExtendedCallingLineIdActive          |
|is_ring_time_out_active                    |bool |isRingTimeOutActive                    |
|ring_timeout_seconds                       |int  |ringTimeoutSeconds                     |
|allow_emergency_remote_office_originations |bool |allowEmergencyRemoteOfficeOriginations |
|max_no_answer_number_of_rings              |int  |maxNoAnswerNumberOfRings               |
|incoming_call_to_user_alias_mode           |str  |incomingCallToUserAliasMode            |
|bypass_termination_loop_detection          |bool |bypassTerminationLoopDetection         |
|honor_clid_blocking_for_emergency_calls    |bool |honorCLIDBlockingForEmergencyCalls     |
</div>


## `SystemSubscriberGetCallProcessingParametersResponse18sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSubscriberGetCallProcessingParametersRequest18sp1()`.


**Attributes:**

|Name                                       |Type |Description                            |
|-------------------------------------------|-----|---------------------------------------|
|is_extended_calling_line_id_active         |bool |isExtendedCallingLineIdActive          |
|is_ring_time_out_active                    |bool |isRingTimeOutActive                    |
|ring_timeout_seconds                       |int  |ringTimeoutSeconds                     |
|allow_emergency_remote_office_originations |bool |allowEmergencyRemoteOfficeOriginations |
|max_no_answer_number_of_rings              |int  |maxNoAnswerNumberOfRings               |
|incoming_call_to_user_alias_mode           |str  |incomingCallToUserAliasMode            |
|bypass_termination_loop_detection          |bool |bypassTerminationLoopDetection         |
|honor_clid_blocking_for_emergency_calls    |bool |honorCLIDBlockingForEmergencyCalls     |
|use_unicode_identity_name                  |bool |useUnicodeIdentityName                 |
</div>


## `SystemSubscriberGetLoginParametersResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSubscriberGetLoginParametersRequest()`.


**Attributes:**

|Name                      |Type|Description            |
|--------------------------|----|-----------------------|
|max_failed_login_attempts |int |maxFailedLoginAttempts |
|min_login_id_length       |int |minLoginIdLength       |
</div>


## `SystemSubscriberGetProvisioningParametersResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSubscriberGetProvisioningParametersRequest()`.

Replaced by: `SystemSubscriberGetProvisioningParametersResponse24()`

**Attributes:**

|Name                            |Type |Description                   |
|--------------------------------|-----|------------------------------|
|configurable_clid_normalization |bool |configurableCLIDNormalization |
</div>


## `SystemSubscriberGetProvisioningParametersResponse24`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemSubscriberGetProvisioningParametersRequest24()`.


**Attributes:**

|Name                            |Type |Description                   |
|--------------------------------|-----|------------------------------|
|configurable_clid_normalization |bool |configurableCLIDNormalization |
|include_default_domain          |bool |includeDefaultDomain          |
</div>


## `SystemSystemServiceCallProcessingPoliciesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSystemServiceCallProcessingPoliciesGetRequest()`.


**Attributes:**

|Name                                     |Type |Description                        |
|-----------------------------------------|-----|-----------------------------------|
|use_max_simultaneous_calls               |bool |useMaxSimultaneousCalls            |
|max_simultaneous_calls                   |int  |maxSimultaneousCalls               |
|use_max_simultaneous_video_calls         |bool |useMaxSimultaneousVideoCalls       |
|max_simultaneous_video_calls             |int  |maxSimultaneousVideoCalls          |
|use_max_concurrent_redirected_calls      |bool |useMaxConcurrentRedirectedCalls    |
|max_concurrent_redirected_calls          |int  |maxConcurrentRedirectedCalls       |
|use_max_call_time_for_answered_calls     |bool |useMaxCallTimeForAnsweredCalls     |
|max_call_time_for_answered_calls_minutes |int  |maxCallTimeForAnsweredCallsMinutes |
</div>


## `SystemSystemServiceDnGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSystemServiceDnGetAvailableListRequest()`.

Contains a list of available DNs not yet assigned to any instance of system service.

**Attributes:**

|Name         |Type      |Description            |
|-------------|----------|-----------------------|
|available_dn |List[str] |availableDn *Optional* |
</div>


## `SystemSystemServiceDnGetSummaryListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSystemServiceDnGetSummaryListRequest()`.

The column headings are "Phone Numbers" and "Assigned". The possible values for
"Assigned" are true, false.

**Attributes:**

|Name             |Type                 |Description                                                   |
|-----------------|---------------------|--------------------------------------------------------------|
|dn_summary_table |List(dnSummaryTable) |dnSummaryTable - *Table* array of dnSummaryTable named tuples |
</div>


## `SystemSystemServiceDnGetUsageListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSystemServiceDnGetUsageListRequest()`.

The table columns are: "Phone Number", "Id", "Name", and "System Service". The
possible values for "System Service" is "System Voice Portal".

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|dn_utilization_table |List(dnUtilizationTable) |dnUtilizationTable - *Table* array of dnUtilizationTable named tuples |
</div>


## `SystemSystemVoicePortalGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSystemVoicePortalGetListRequest()`.

The column headings are "Default", "System Voice Portal Id", "Name", "Network Voice
Portal Number", "System Voice Portal Number" and "Language". The possible values for
"Default" are true, false.

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|system_voice_portals_table |List(systemVoicePortalsTable) |systemVoicePortalsTable - *Table* array of systemVoicePortalsTable named tuples |
</div>


## `SystemSystemVoicePortalGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSystemVoicePortalGetRequest()`.

Replaced by: `SystemSystemVoicePortalGetResponse21sp1()`.

**Attributes:**

|Name                                                                |Type |Description                                               |
|--------------------------------------------------------------------|-----|----------------------------------------------------------|
|name                                                                |str  |name                                                      |
|calling_line_id_name                                                |str  |callingLineIdName                                         |
|language                                                            |str  |language                                                  |
|time_zone                                                           |str  |timeZone                                                  |
|phone_number                                                        |str  |phoneNumber *Optional*                                    |
|public_user_identity                                                |str  |publicUserIdentity *Optional*                             |
|network_voice_portal_number                                         |str  |networkVoicePortalNumber *Optional*                       |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin |
|use_voice_portal_wizard                                             |bool |useVoicePortalWizard                                      |
|is_default                                                          |bool |isDefault                                                 |
|use_voice_portal_default_greeting                                   |bool |useVoicePortalDefaultGreeting                             |
|voice_portal_greeting_file_description                              |str  |voicePortalGreetingFileDescription *Optional*             |
|voice_portal_greeting_media_file_type                               |str  |voicePortalGreetingMediaFileType *Optional*               |
|use_voice_messaging_default_greeting                                |bool |useVoiceMessagingDefaultGreeting                          |
|voice_messaging_greeting_file_description                           |str  |voiceMessagingGreetingFileDescription *Optional*          |
|voice_messaging_greeting_media_file_type                            |str  |voiceMessagingGreetingMediaFileType *Optional*            |
</div>


## `SystemSystemVoicePortalGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSystemVoicePortalGetRequest21sp1()`.

Replaced by: `SystemSystemVoicePortalGetResponse23()`.

**Attributes:**

|Name                                                                |Type |Description                                               |
|--------------------------------------------------------------------|-----|----------------------------------------------------------|
|name                                                                |str  |name                                                      |
|calling_line_id_name                                                |str  |callingLineIdName                                         |
|language                                                            |str  |language                                                  |
|time_zone                                                           |str  |timeZone                                                  |
|phone_number                                                        |str  |phoneNumber *Optional*                                    |
|public_user_identity                                                |str  |publicUserIdentity *Optional*                             |
|network_voice_portal_number                                         |str  |networkVoicePortalNumber *Optional*                       |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin |
|use_voice_portal_wizard                                             |bool |useVoicePortalWizard                                      |
|is_default                                                          |bool |isDefault                                                 |
|use_voice_portal_default_greeting                                   |bool |useVoicePortalDefaultGreeting                             |
|voice_portal_greeting_file_description                              |str  |voicePortalGreetingFileDescription *Optional*             |
|voice_portal_greeting_media_file_type                               |str  |voicePortalGreetingMediaFileType *Optional*               |
|use_voice_messaging_default_greeting                                |bool |useVoiceMessagingDefaultGreeting                          |
|voice_messaging_greeting_file_description                           |str  |voiceMessagingGreetingFileDescription *Optional*          |
|voice_messaging_greeting_media_file_type                            |str  |voiceMessagingGreetingMediaFileType *Optional*            |
|express_mode                                                        |bool |expressMode                                               |
</div>


## `SystemSystemVoicePortalGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSystemVoicePortalGetRequest23()`.

The following elements are only used in AS data mode and ignored in XS data mode:
networkClassOfService

**Attributes:**

|Name                                                                |Type |Description                                               |
|--------------------------------------------------------------------|-----|----------------------------------------------------------|
|name                                                                |str  |name                                                      |
|calling_line_id_name                                                |str  |callingLineIdName                                         |
|language                                                            |str  |language                                                  |
|time_zone                                                           |str  |timeZone                                                  |
|phone_number                                                        |str  |phoneNumber *Optional*                                    |
|public_user_identity                                                |str  |publicUserIdentity *Optional*                             |
|network_voice_portal_number                                         |str  |networkVoicePortalNumber *Optional*                       |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin |
|use_voice_portal_wizard                                             |bool |useVoicePortalWizard                                      |
|is_default                                                          |bool |isDefault                                                 |
|use_voice_portal_default_greeting                                   |bool |useVoicePortalDefaultGreeting                             |
|voice_portal_greeting_file_description                              |str  |voicePortalGreetingFileDescription *Optional*             |
|voice_portal_greeting_media_file_type                               |str  |voicePortalGreetingMediaFileType *Optional*               |
|use_voice_messaging_default_greeting                                |bool |useVoiceMessagingDefaultGreeting                          |
|voice_messaging_greeting_file_description                           |str  |voiceMessagingGreetingFileDescription *Optional*          |
|voice_messaging_greeting_media_file_type                            |str  |voiceMessagingGreetingMediaFileType *Optional*            |
|express_mode                                                        |bool |expressMode                                               |
|network_class_of_service                                            |str  |networkClassOfService *Optional*                          |
</div>


## `SystemTemplateOnlyDeviceFileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemTemplateOnlyDeviceFileGetListRequest()`.

Contains a list of template files used to support a Visual Device Management device.

**Attributes:**

|Name              |Type      |Description                |
|------------------|----------|---------------------------|
|template_file_url |List[str] |templateFileUrl *Optional* |
</div>


## `SystemThirdPartyEmergencyCallingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemThirdPartyEmergencyCallingGetRequest()`.

The response contains the third-party emergency call service settings for the system.
Replaced by: `SystemThirdPartyEmergencyCallingGetResponse24()`

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|primary_held_server_url     |str |primaryHELDServerURL *Optional*     |
|secondary_held_server_url   |str |secondaryHELDServerURL *Optional*   |
|emergency_route_net_address |str |emergencyRouteNetAddress *Optional* |
|emergency_route_port        |int |emergencyRoutePort *Optional*       |
|emergency_route_transport   |str |emergencyRouteTransport *Optional*  |
</div>


## `SystemThirdPartyEmergencyCallingGetResponse24`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemThirdPartyEmergencyCallingGetRequest24()`.

The response contains the third-party emergency call service settings for the system.

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|primary_held_server_url     |str |primaryHELDServerURL *Optional*     |
|secondary_held_server_url   |str |secondaryHELDServerURL *Optional*   |
|emergency_route_net_address |str |emergencyRouteNetAddress *Optional* |
|emergency_route_port        |int |emergencyRoutePort *Optional*       |
|emergency_route_transport   |str |emergencyRouteTransport *Optional*  |
</div>


## `SystemThirdPartyIMPGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemThirdPartyIMPGetRequest()`.

The response contains the system Third-Party IMP service attributes.  Replaced by
`SystemThirdPartyIMPGetResponse19()`.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_net_address |str |serviceNetAddress *Optional* |
|service_port        |int |servicePort *Optional*       |
</div>


## `SystemThirdPartyIMPGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemThirdPartyIMPGetRequest19()`.

The response contains the system Third-Party IMP service attributes.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_net_address |str |serviceNetAddress *Optional* |
|service_port        |int |servicePort *Optional*       |
|bosh_url            |str |boshURL *Optional*           |
</div>


## `SystemThirdPartyVoiceMailSupportGetDnListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemThirdPartyVoiceMailSupportGetDnListRequest()`.

Contains a table with a row for each ThirdPartyVoiceMailSupport User DN and column
headings: "Phone Number", "Description"

**Attributes:**

|Name                                 |Type                                  |Description                                                                                     |
|-------------------------------------|--------------------------------------|------------------------------------------------------------------------------------------------|
|third_party_voice_mail_support_table |List(thirdPartyVoiceMailSupportTable) |thirdPartyVoiceMailSupportTable - *Table* array of thirdPartyVoiceMailSupportTable named tuples |
</div>


## `SystemThirdPartyVoiceMailSupportGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemThirdPartyVoiceMailSupportGetRequest()`.

Replaced by: `SystemThirdPartyVoiceMailSupportGetResponse17sp4()`

**Attributes:**

|Name                                    |Type |Description                       |
|----------------------------------------|-----|----------------------------------|
|override_alt_caller_id_for_vm_retrieval |bool |overrideAltCallerIdForVMRetrieval |
</div>


## `SystemThirdPartyVoiceMailSupportGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemThirdPartyVoiceMailSupportGetRequest17sp4()`.


**Attributes:**

|Name                                        |Type |Description                            |
|--------------------------------------------|-----|---------------------------------------|
|override_alt_caller_id_for_vm_retrieval     |bool |overrideAltCallerIdForVMRetrieval      |
|strip_diversion_on_vm_destination_retrieval |bool |stripDiversionOnVMDestinationRetrieval |
</div>


## `SystemTimeScheduleGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemTimeScheduleGetListRequest()`.

The response contains all the system time schedule names.

**Attributes:**

|Name          |Type      |Description             |
|--------------|----------|------------------------|
|time_schedule |List[str] |timeSchedule *Optional* |
</div>


## `SystemTimeZoneGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemTimeZoneGetListRequest()`.

Contains a 2 column table with column headings 'Key' and 'Display Name' and a row for
each time zone.  Replaced by: `SystemTimeZoneGetListResponse20()` in AS data mode

**Attributes:**

|Name            |Type                |Description                                                 |
|----------------|--------------------|------------------------------------------------------------|
|time_zone_table |List(timeZoneTable) |timeZoneTable - *Table* array of timeZoneTable named tuples |
</div>


## `SystemTimeZoneGetListResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemTimeZoneGetListRequest20()`.

Contains the configured time zone of the server processing the request and contains a
2 column table with column headings 'Key' and 'Display Name' and a row for each time
zone.

**Attributes:**

|Name             |Type                |Description                                                 |
|-----------------|--------------------|------------------------------------------------------------|
|server_time_zone |str                 |serverTimeZone                                              |
|time_zone_table  |List(timeZoneTable) |timeZoneTable - *Table* array of timeZoneTable named tuples |
</div>


## `SystemTreatmentMappingAccessSIPStatusGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemTreatmentMappingAccessSIPStatusGetListRequest()`.

Contains a table with one row per mapping.  The table columns are: "SIP Status Code",
"Treatment Id".

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|treatment_mapping_table |List(treatmentMappingTable) |treatmentMappingTable - *Table* array of treatmentMappingTable named tuples |
</div>


## `SystemTreatmentMappingCallBlockingServiceGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemTreatmentMappingCallBlockingServiceGetListRequest()`.

Contains a table with one row per mapping.  The table columns are: "Service",
"Treatment Id". Replaced by:
`SystemTreatmentMappingCallBlockingServiceGetListResponse19sp1()` in AS data mode

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|treatment_mapping_table |List(treatmentMappingTable) |treatmentMappingTable - *Table* array of treatmentMappingTable named tuples |
</div>


## `SystemTreatmentMappingCallBlockingServiceGetListResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemTreatmentMappingCallBlockingServiceGetListRequest19sp1()`.

Contains a table with one row per mapping.  The table columns are: "Service",
"Treatment Id". The Service column list the service or policy which is using
corresponding treatment, and can be OCP, EOCP, ICP, ACR, SCR, SCA, AAC, Intercept,
PTT, CommBarring, SAC, IncomingCommBarring, HierCommBarring, IncomHierCommBarring,
BWMobilityDenyOrig, BWMobilityDenyTerm, ETRouteExhaust, CallPark, NumberPortability.
Replaced by: `SystemTreatmentMappingCallBlockingServiceGetListResponse22()`

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|treatment_mapping_table |List(treatmentMappingTable) |treatmentMappingTable - *Table* array of treatmentMappingTable named tuples |
</div>


## `SystemTreatmentMappingCallBlockingServiceGetListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemTreatmentMappingCallBlockingServiceGetListRequest22()`.

Contains a table with one row per mapping.  The table columns are: "Service",
"Treatment Id". The Service column list the service or policy which is using
corresponding treatment, and can be OCP, EOCP, ICP, ACR, SCR, SCA, AAC, Intercept,
PTT, CommBarring, SAC, IncomingCommBarring, HierCommBarring, IncomHierCommBarring,
BWMobilityDenyOrig, BWMobilityDenyTerm, ETRouteExhaust, CallPark, NumberPortability,
ConcTerminatingAlertingPolicy, AutomaticCollectCall.

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|treatment_mapping_table |List(treatmentMappingTable) |treatmentMappingTable - *Table* array of treatmentMappingTable named tuples |
</div>


## `SystemTreatmentMappingCallBlockingServiceGetListResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemTreatmentMappingCallBlockingServiceGetListRequest22V3()`.

Contains a table with one row per mapping.  The table columns are: "Service",
"Treatment Id". The Service column list the service or policy which is using
corresponding treatment, and can be OCP, EOCP, ICP, ACR, SCR, SCA, AAC, Intercept,
PTT, CommBarring, SAC, IncomingCommBarring, HierCommBarring, IncomHierCommBarring,
BWMobilityDenyOrig, BWMobilityDenyTerm, ETRouteExhaust, CallPark, NumberPortability,
ConcTerminatingAlertingPolicy, AutomaticCollectCall, TCUG.

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|treatment_mapping_table |List(treatmentMappingTable) |treatmentMappingTable - *Table* array of treatmentMappingTable named tuples |
</div>


## `SystemTreatmentMappingCallBlockingServiceGetListResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemTreatmentMappingCallBlockingServiceGetListRequest23()`.

Contains a table with one row per mapping.  The table columns are: "Service",
"Treatment Id". The Service column list the service or policy which is using
corresponding treatment, and can be OCP, EOCP, ICP, ACR, SCR, SCA, AAC, Intercept,
PTT, CommBarring, SAC, IncomingCommBarring, HierCommBarring, IncomHierCommBarring,
BWMobilityDenyOrig, BWMobilityDenyTerm, ETRouteExhaust, CallPark, NumberPortability,
ConcTerminatingAlertingPolicy, AutomaticCollectCall, ETRouteExhaustUnreachable.
Replaced by: `SystemTreatmentMappingCallBlockingServiceGetListResponse23V2()` in AS
data mode.

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|treatment_mapping_table |List(treatmentMappingTable) |treatmentMappingTable - *Table* array of treatmentMappingTable named tuples |
</div>


## `SystemTreatmentMappingCallBlockingServiceGetListResponse23V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemTreatmentMappingCallBlockingServiceGetListRequest23V2()`.

Contains a table with one row per mapping.  The table columns are: "Service",
"Treatment Id". The Service column list the service or policy which is using
corresponding treatment, and can be OCP, EOCP, ICP, ACR, SCR, SCA, AAC, Intercept,
PTT, CommBarring, SAC, IncomingCommBarring, HierCommBarring, IncomHierCommBarring,
BWMobilityDenyOrig, BWMobilityDenyTerm, ETRouteExhaust, CallPark, NumberPortability,
ConcTerminatingAlertingPolicy, AutomaticCollectCall, ETRouteExhaustUnreachable, TCUG.

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|treatment_mapping_table |List(treatmentMappingTable) |treatmentMappingTable - *Table* array of treatmentMappingTable named tuples |
</div>


## `SystemTreatmentMappingCallBlockingServiceGetListResponse23V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemTreatmentMappingCallBlockingServiceGetListRequest23V3()`.

Contains a table with one row per mapping.  The table columns are: "Service",
"Treatment Id". The Service column list the service or policy which is using
corresponding treatment, and can be OCP, EOCP, ICP, ACR, SCR, SCA, AAC, Intercept,
PTT, CommBarring, SAC, IncomingCommBarring, HierCommBarring, IncomHierCommBarring,
BWMobilityDenyOrig, BWMobilityDenyTerm, ETRouteExhaust, CallPark, NumberPortability,
ConcTerminatingAlertingPolicy, AutomaticCollectCall, ETRouteExhaustUnreachable, TCUG,
RPAdmission.

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|treatment_mapping_table |List(treatmentMappingTable) |treatmentMappingTable - *Table* array of treatmentMappingTable named tuples |
</div>


## `SystemTreatmentMappingInternalReleaseCauseGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemTreatmentMappingInternalReleaseCauseGetListRequest()`.

Contains a table with one row per mapping.  The table columns are: "Internal Release
Cause", "Treatment Id".

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|treatment_mapping_table |List(treatmentMappingTable) |treatmentMappingTable - *Table* array of treatmentMappingTable named tuples |
</div>


## `SystemTreatmentMappingNetworkSIPStatusGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemTreatmentMappingNetworkSIPStatusGetListRequest()`.

Contains a table with one row per mapping.  The table columns are: "SIP Status Code",
"Treatment Id".

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|treatment_mapping_table |List(treatmentMappingTable) |treatmentMappingTable - *Table* array of treatmentMappingTable named tuples |
</div>


## `SystemTreatmentMappingNetworkServerTreatmentGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemTreatmentMappingNetworkServerTreatmentGetListRequest()`.

Contains a table with one row per mapping.  The table columns are: "NS Treatment",
"Treatment Id".

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|treatment_mapping_table |List(treatmentMappingTable) |treatmentMappingTable - *Table* array of treatmentMappingTable named tuples |
</div>


## `SystemTreatmentMappingQ850CauseGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `SystemTreatmentMappingQ850CauseGetListRequest()`.

Contains a table with one row per mapping.  The table columns are: "Q850 Cause Value",
"Treatment Id".

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|treatment_mapping_table |List(treatmentMappingTable) |treatmentMappingTable - *Table* array of treatmentMappingTable named tuples |
</div>


## `SystemTrunkGroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemTrunkGroupGetRequest()`.

Replaced by: `SystemTrunkGroupGetResponse19sp1()`.

**Attributes:**

|Name                                                     |Type |Description                                        |
|---------------------------------------------------------|-----|---------------------------------------------------|
|enforce_clid_service_assignment_for_pilot_user           |bool |enforceCLIDServiceAssignmentForPilotUser           |
|terminate_unreachable_trigger_detection_on_receipt_of18x |bool |terminateUnreachableTriggerDetectionOnReceiptOf18x |
|pilot_user_calling_line_asserted_identity_policy         |str  |pilotUserCallingLineAssertedIdentityPolicy         |
|enforce_out_of_dialog_pbx_redirection_policies           |bool |enforceOutOfDialogPBXRedirectionPolicies           |
|unscreened_redirection_handling                          |str  |unscreenedRedirectionHandling                      |
|enable_holdover_of_highwater_call_counts                 |bool |enableHoldoverOfHighwaterCallCounts                |
|holdover_period                                          |int  |holdoverPeriod                                     |
|time_zone_offset_minutes                                 |int  |timeZoneOffsetMinutes                              |
</div>


## `SystemTrunkGroupGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemTrunkGroupGetRequest19sp1()`.


**Attributes:**

|Name                                                     |Type |Description                                        |
|---------------------------------------------------------|-----|---------------------------------------------------|
|enforce_clid_service_assignment_for_pilot_user           |bool |enforceCLIDServiceAssignmentForPilotUser           |
|terminate_unreachable_trigger_detection_on_receipt_of18x |bool |terminateUnreachableTriggerDetectionOnReceiptOf18x |
|pilot_user_calling_line_asserted_identity_policy         |str  |pilotUserCallingLineAssertedIdentityPolicy         |
|enforce_out_of_dialog_pbx_redirection_policies           |bool |enforceOutOfDialogPBXRedirectionPolicies           |
|unscreened_redirection_handling                          |str  |unscreenedRedirectionHandling                      |
|enable_holdover_of_highwater_call_counts                 |bool |enableHoldoverOfHighwaterCallCounts                |
|holdover_period                                          |int  |holdoverPeriod                                     |
|time_zone_offset_minutes                                 |int  |timeZoneOffsetMinutes                              |
|clid_source_for_screened_calls_policy                    |str  |clidSourceForScreenedCallsPolicy                   |
|user_lookup_policy                                       |str  |userLookupPolicy                                   |
</div>


## `SystemTrunkGroupGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemTrunkGroupGetRequest21()`.

Following attributes are only used in IMS mode: implicitRegistrationSetSupportPolicy
sipIdentityForPilotAndProxyTrunkModesPolicy Replaced by:
`SystemTrunkGroupGetResponse22()`

**Attributes:**

|Name                                                       |Type |Description                                        |
|-----------------------------------------------------------|-----|---------------------------------------------------|
|enforce_clid_service_assignment_for_pilot_user             |bool |enforceCLIDServiceAssignmentForPilotUser           |
|terminate_unreachable_trigger_detection_on_receipt_of18x   |bool |terminateUnreachableTriggerDetectionOnReceiptOf18x |
|pilot_user_calling_line_asserted_identity_policy           |str  |pilotUserCallingLineAssertedIdentityPolicy         |
|enforce_out_of_dialog_pbx_redirection_policies             |bool |enforceOutOfDialogPBXRedirectionPolicies           |
|unscreened_redirection_handling                            |str  |unscreenedRedirectionHandling                      |
|enable_holdover_of_highwater_call_counts                   |bool |enableHoldoverOfHighwaterCallCounts                |
|holdover_period                                            |int  |holdoverPeriod                                     |
|time_zone_offset_minutes                                   |int  |timeZoneOffsetMinutes                              |
|clid_source_for_screened_calls_policy                      |str  |clidSourceForScreenedCallsPolicy                   |
|user_lookup_policy                                         |str  |userLookupPolicy                                   |
|out_of_dialog_pbx_redirection_clid_mapping                 |str  |outOfDialogPBXRedirectionCLIDMapping               |
|enforce_out_of_dialog_pbx_redirection_trunk_group_capacity |bool |enforceOutOfDialogPBXRedirectionTrunkGroupCapacity |
|implicit_registration_set_support_policy                   |str  |implicitRegistrationSetSupportPolicy               |
|sip_identity_for_pilot_and_proxy_trunk_modes_policy        |str  |sipIdentityForPilotAndProxyTrunkModesPolicy        |
|support_connected_identity_policy                          |str  |supportConnectedIdentityPolicy                     |
</div>


## `SystemTrunkGroupGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemTrunkGroupGetRequest22()`.

Following attributes are only used in IMS mode: implicitRegistrationSetSupportPolicy
sipIdentityForPilotAndProxyTrunkModesPolicy Replaced by:
`SystemTrunkGroupGetResponse23()`

**Attributes:**

|Name                                                       |Type |Description                                        |
|-----------------------------------------------------------|-----|---------------------------------------------------|
|enforce_clid_service_assignment_for_pilot_user             |bool |enforceCLIDServiceAssignmentForPilotUser           |
|terminate_unreachable_trigger_detection_on_receipt_of18x   |bool |terminateUnreachableTriggerDetectionOnReceiptOf18x |
|pilot_user_calling_line_asserted_identity_policy           |str  |pilotUserCallingLineAssertedIdentityPolicy         |
|enforce_out_of_dialog_pbx_redirection_policies             |bool |enforceOutOfDialogPBXRedirectionPolicies           |
|unscreened_redirection_handling                            |str  |unscreenedRedirectionHandling                      |
|enable_holdover_of_highwater_call_counts                   |bool |enableHoldoverOfHighwaterCallCounts                |
|holdover_period                                            |int  |holdoverPeriod                                     |
|time_zone_offset_minutes                                   |int  |timeZoneOffsetMinutes                              |
|clid_source_for_screened_calls_policy                      |str  |clidSourceForScreenedCallsPolicy                   |
|user_lookup_policy                                         |str  |userLookupPolicy                                   |
|out_of_dialog_pbx_redirection_clid_mapping                 |str  |outOfDialogPBXRedirectionCLIDMapping               |
|enforce_out_of_dialog_pbx_redirection_trunk_group_capacity |bool |enforceOutOfDialogPBXRedirectionTrunkGroupCapacity |
|implicit_registration_set_support_policy                   |str  |implicitRegistrationSetSupportPolicy               |
|sip_identity_for_pilot_and_proxy_trunk_modes_policy        |str  |sipIdentityForPilotAndProxyTrunkModesPolicy        |
|support_connected_identity_policy                          |str  |supportConnectedIdentityPolicy                     |
|use_unmapped_sessions_for_trunk_users                      |bool |useUnmappedSessionsForTrunkUsers                   |
</div>


## `SystemTrunkGroupGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemTrunkGroupGetRequest23()`.

Following attributes are only used in IMS mode: implicitRegistrationSetSupportPolicy
sipIdentityForPilotAndProxyTrunkModesPolicy Replaced by:
`SystemTrunkGroupGetResponse24()`

**Attributes:**

|Name                                                       |Type |Description                                        |
|-----------------------------------------------------------|-----|---------------------------------------------------|
|enforce_clid_service_assignment_for_pilot_user             |bool |enforceCLIDServiceAssignmentForPilotUser           |
|terminate_unreachable_trigger_detection_on_receipt_of18x   |bool |terminateUnreachableTriggerDetectionOnReceiptOf18x |
|pilot_user_calling_line_asserted_identity_policy           |str  |pilotUserCallingLineAssertedIdentityPolicy         |
|enforce_out_of_dialog_pbx_redirection_policies             |bool |enforceOutOfDialogPBXRedirectionPolicies           |
|unscreened_redirection_handling                            |str  |unscreenedRedirectionHandling                      |
|enable_holdover_of_highwater_call_counts                   |bool |enableHoldoverOfHighwaterCallCounts                |
|holdover_period                                            |int  |holdoverPeriod                                     |
|time_zone_offset_minutes                                   |int  |timeZoneOffsetMinutes                              |
|clid_source_for_screened_calls_policy                      |str  |clidSourceForScreenedCallsPolicy                   |
|user_lookup_policy                                         |str  |userLookupPolicy                                   |
|out_of_dialog_pbx_redirection_clid_mapping                 |str  |outOfDialogPBXRedirectionCLIDMapping               |
|enforce_out_of_dialog_pbx_redirection_trunk_group_capacity |bool |enforceOutOfDialogPBXRedirectionTrunkGroupCapacity |
|implicit_registration_set_support_policy                   |str  |implicitRegistrationSetSupportPolicy               |
|sip_identity_for_pilot_and_proxy_trunk_modes_policy        |str  |sipIdentityForPilotAndProxyTrunkModesPolicy        |
|support_connected_identity_policy                          |str  |supportConnectedIdentityPolicy                     |
|use_unmapped_sessions_for_trunk_users                      |bool |useUnmappedSessionsForTrunkUsers                   |
|allow_pai_lookup_for_out_of_dialog_pbx_redirection         |bool |allowPAILookupForOutOfDialogPBXRedirection         |
|out_of_dialog_pbx_redirection_originator_lookup_policy     |str  |outOfDialogPBXRedirectionOriginatorLookupPolicy    |
|allow_trunk_identity_for_all_originations                  |bool |allowTrunkIdentityForAllOriginations               |
</div>


## `SystemTrunkGroupGetResponse24`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemTrunkGroupGetRequest24()`.

Following attributes are only used in IMS mode: implicitRegistrationSetSupportPolicy
sipIdentityForPilotAndProxyTrunkModesPolicy useMostRecentEntryOnDeflection

**Attributes:**

|Name                                                       |Type |Description                                        |
|-----------------------------------------------------------|-----|---------------------------------------------------|
|enforce_clid_service_assignment_for_pilot_user             |bool |enforceCLIDServiceAssignmentForPilotUser           |
|terminate_unreachable_trigger_detection_on_receipt_of18x   |bool |terminateUnreachableTriggerDetectionOnReceiptOf18x |
|pilot_user_calling_line_asserted_identity_policy           |str  |pilotUserCallingLineAssertedIdentityPolicy         |
|enforce_out_of_dialog_pbx_redirection_policies             |bool |enforceOutOfDialogPBXRedirectionPolicies           |
|unscreened_redirection_handling                            |str  |unscreenedRedirectionHandling                      |
|enable_holdover_of_highwater_call_counts                   |bool |enableHoldoverOfHighwaterCallCounts                |
|holdover_period                                            |int  |holdoverPeriod                                     |
|time_zone_offset_minutes                                   |int  |timeZoneOffsetMinutes                              |
|clid_source_for_screened_calls_policy                      |str  |clidSourceForScreenedCallsPolicy                   |
|user_lookup_policy                                         |str  |userLookupPolicy                                   |
|out_of_dialog_pbx_redirection_clid_mapping                 |str  |outOfDialogPBXRedirectionCLIDMapping               |
|enforce_out_of_dialog_pbx_redirection_trunk_group_capacity |bool |enforceOutOfDialogPBXRedirectionTrunkGroupCapacity |
|implicit_registration_set_support_policy                   |str  |implicitRegistrationSetSupportPolicy               |
|sip_identity_for_pilot_and_proxy_trunk_modes_policy        |str  |sipIdentityForPilotAndProxyTrunkModesPolicy        |
|support_connected_identity_policy                          |str  |supportConnectedIdentityPolicy                     |
|use_unmapped_sessions_for_trunk_users                      |bool |useUnmappedSessionsForTrunkUsers                   |
|allow_pai_lookup_for_out_of_dialog_pbx_redirection         |bool |allowPAILookupForOutOfDialogPBXRedirection         |
|out_of_dialog_pbx_redirection_originator_lookup_policy     |str  |outOfDialogPBXRedirectionOriginatorLookupPolicy    |
|allow_trunk_identity_for_all_originations                  |bool |allowTrunkIdentityForAllOriginations               |
|use_most_recent_entry_on_deflection                        |bool |useMostRecentEntryOnDeflection                     |
</div>


## `SystemTrunkGroupOptionsMessageResponseStatusCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemTrunkGroupOptionsMessageResponseStatusCodeGetListRequest()`.

The response contains of the list of system level successful SIP OPTIONS message
respoonse status codes.

**Attributes:**

|Name        |Type      |Description           |
|------------|----------|----------------------|
|status_code |List[str] |statusCode *Optional* |
</div>


## `SystemTrunkGroupUserCreationTaskGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemTrunkGroupUserCreationTaskGetListRequest()`.

Contains a table with a row for each user creation task and column headings : "Service
User Id", "Group Id", "Organization Id", "Organization Type", "Name", "Status", "Users
Created", "Total Users To Create", "Error Count". The "Organization Id" column is
populated with either a service provider Id or an enterprise Id.  The "Organization
Type" column is populated with one of the enumerated strings defined in the
OrganizationType OCI data type.  Please see OCISchemaDataTypes.xsd for details on
OrganizationType.

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|task_table |List(taskTable) |taskTable - *Table* array of taskTable named tuples |
</div>


## `SystemTrunkGroupUserCreationTaskGetListResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemTrunkGroupUserCreationTaskGetListRequest14sp4()`.

Contains a table with a row for each user creation task and column headings : "Trunk
Group Name", "Group Id", "Organization Id", "Organization Type", "Name", "Status",
"Users Created", "Total Users To Create", "Error Count". The "Organization Id" column
is populated with either a service provider Id or an enterprise Id.  The "Organization
Type" column is populated with one of the enumerated strings defined in the
OrganizationType OCI data type.  Please see OCISchemaDataTypes.xsd for details on
OrganizationType.

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|task_table |List(taskTable) |taskTable - *Table* array of taskTable named tuples |
</div>


## `SystemTwoStageDialingGetDnListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemTwoStageDialingGetDnListRequest()`.

The Two Stage Dialing DN List table column headings are: "Phone Number",
"Description".

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|phone_number_table |List(phoneNumberTable) |phoneNumberTable - *Table* array of phoneNumberTable named tuples |
</div>


## `SystemVerifyTranslationAndRoutingResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Represents a Verify Translation and Routing Test Call Result.


**Attributes:**

|Name   |Type|Description|
|-------|----|-----------|
|result |str |Result     |
</div>


## `SystemVideoServerGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVideoServerGetListRequest()`.

The Video Server table column headings are: "Net Address", "Port", "Transport",
"Description". Transport types: udp, tcp, unspecified

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|video_server_table |List(videoServerTable) |videoServerTable - *Table* array of videoServerTable named tuples |
</div>


## `SystemVideoServerParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVideoServerParametersGetRequest()`.

Contains a list of system video server parameters.

**Attributes:**

|Name                                            |Type |Description                                |
|------------------------------------------------|-----|-------------------------------------------|
|video_server_response_timer_milliseconds        |int  |videoServerResponseTimerMilliseconds       |
|video_server_selection_route_timer_milliseconds |int  |videoServerSelectionRouteTimerMilliseconds |
|use_static_video_server_device                  |bool |useStaticVideoServerDevice                 |
</div>


## `SystemVirtualOnNetCallTypeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVirtualOnNetCallTypeGetListRequest()`.

Contains a table with column headings: "Virtual On-Net Call Type Name", "Virtual On-
Net Call Type CDR Value" in a row for each Virtual On-Net Call Type.

**Attributes:**

|Name                           |Type                            |Description                                                                         |
|-------------------------------|--------------------------------|------------------------------------------------------------------------------------|
|virtual_on_net_call_type_table |List(virtualOnNetCallTypeTable) |virtualOnNetCallTypeTable - *Table* array of virtualOnNetCallTypeTable named tuples |
</div>


## `SystemVoiceMessageSummaryUpdateGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessageSummaryUpdateGetRequest()`.


**Attributes:**

|Name                                      |Type |Description                         |
|------------------------------------------|-----|------------------------------------|
|send_saved_and_urgent_mwi_on_notification |bool |sendSavedAndUrgentMWIOnNotification |
|send_message_summary_update_on_register   |bool |sendMessageSummaryUpdateOnRegister  |
|min_time_between_mwi_on_register          |int  |minTimeBetweenMWIOnRegister         |
</div>


## `SystemVoiceMessagingGroupGetPasscodeRulesResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetPasscodeRulesRequest14()`.

Contains the system voice portal passcode rules setting.

Replaced By: `SystemPortalPasscodeRulesGetResponse()`

**Attributes:**

|Name                                          |Type |Description                                |
|----------------------------------------------|-----|-------------------------------------------|
|disallow_repeated_digits                      |bool |disallowRepeatedDigits                     |
|disallow_user_number                          |bool |disallowUserNumber                         |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber                 |
|disallow_old_passcode                         |bool |disallowOldPasscode                        |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode                |
|min_code_length                               |int  |minCodeLength                              |
|max_code_length                               |int  |maxCodeLength                              |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts    |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*          |
|expire_password                               |bool |expirePassword                             |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*             |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional* |
|default_password                              |str  |defaultPassword                            |
</div>


## `SystemVoiceMessagingGroupGetResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetRequest14()`.

Replaced by: `SystemVoiceMessagingGroupGetResponse16()`

**Attributes:**

|Name                                      |Type |Description                              |
|------------------------------------------|-----|-----------------------------------------|
|real_delete_for_imap                      |bool |realDeleteForImap                        |
|use_dn_in_mail_body                       |bool |useDnInMailBody                          |
|use_short_subject_line                    |bool |useShortSubjectLine                      |
|max_greeting_length_minutes               |int  |maxGreetingLengthMinutes                 |
|max_message_length_minutes                |int  |maxMessageLengthMinutes                  |
|max_mailbox_length_minutes                |int  |maxMailboxLengthMinutes                  |
|does_message_age                          |bool |doesMessageAge                           |
|hold_period_days                          |int  |holdPeriodDays                           |
|mail_server_net_address                   |str  |mailServerNetAddress *Optional*          |
|mail_server_protocol                      |str  |mailServerProtocol                       |
|default_delivery_from_address             |str  |defaultDeliveryFromAddress               |
|default_notification_from_address         |str  |defaultNotificationFromAddress           |
|default_voice_portal_lockout_from_address |str  |defaultVoicePortalLockoutFromAddress     |
|use_outgoing_mwi_on_smdi                  |bool |useOutgoingMWIOnSMDI                     |
|mwi_delay_in_seconds                      |int  |mwiDelayInSeconds                        |
|voice_portal_scope                        |str  |voicePortalScope                         |
|enterprise_voice_portal_licensed          |bool |enterpriseVoicePortalLicensed            |
|network_wide_messaging                    |bool |networkWideMessaging                     |
|use_external_routing                      |bool |useExternalRouting                       |
|default_external_routing_address          |str  |defaultExternalRoutingAddress *Optional* |
</div>


## `SystemVoiceMessagingGroupGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetRequest16()`.

Replaced by: `SystemVoiceMessagingGroupGetResponse16sp2()`

**Attributes:**

|Name                                      |Type |Description                              |
|------------------------------------------|-----|-----------------------------------------|
|real_delete_for_imap                      |bool |realDeleteForImap                        |
|use_dn_in_mail_body                       |bool |useDnInMailBody                          |
|use_short_subject_line                    |bool |useShortSubjectLine                      |
|max_message_length_minutes                |int  |maxMessageLengthMinutes                  |
|max_mailbox_length_minutes                |int  |maxMailboxLengthMinutes                  |
|does_message_age                          |bool |doesMessageAge                           |
|hold_period_days                          |int  |holdPeriodDays                           |
|mail_server_net_address                   |str  |mailServerNetAddress *Optional*          |
|mail_server_protocol                      |str  |mailServerProtocol                       |
|default_delivery_from_address             |str  |defaultDeliveryFromAddress               |
|default_notification_from_address         |str  |defaultNotificationFromAddress           |
|default_voice_portal_lockout_from_address |str  |defaultVoicePortalLockoutFromAddress     |
|use_outgoing_mwi_on_smdi                  |bool |useOutgoingMWIOnSMDI                     |
|mwi_delay_in_seconds                      |int  |mwiDelayInSeconds                        |
|voice_portal_scope                        |str  |voicePortalScope                         |
|enterprise_voice_portal_licensed          |bool |enterpriseVoicePortalLicensed            |
|network_wide_messaging                    |bool |networkWideMessaging                     |
|use_external_routing                      |bool |useExternalRouting                       |
|default_external_routing_address          |str  |defaultExternalRoutingAddress *Optional* |
</div>


## `SystemVoiceMessagingGroupGetResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetRequest16sp2()`.

The following elements are only used in AS data mode: realDeleteForImap
useDnInMailBody useShortSubjectLine maxMessageLengthMinutes maxMailboxLengthMinutes
doesMessageAge holdPeriodDays mailServerProtocol defaultDeliveryFromAddress
defaultNotificationFromAddress useOutgoingMWIOnSMDI mwiDelayInSeconds voicePortalScope
enterpriseVoicePortalLicensed networkWideMessaging useExternalRouting vmOnlySystem The
following elements are only used in AS data mode and not returned in XS data mode:
mailServerNetAddress defaultExternalRoutingAddress Replaced by:
`SystemVoiceMessagingGroupGetResponse20()` in AS data mode

**Attributes:**

|Name                                      |Type |Description                              |
|------------------------------------------|-----|-----------------------------------------|
|real_delete_for_imap                      |bool |realDeleteForImap                        |
|use_dn_in_mail_body                       |bool |useDnInMailBody                          |
|use_short_subject_line                    |bool |useShortSubjectLine                      |
|max_message_length_minutes                |int  |maxMessageLengthMinutes                  |
|max_mailbox_length_minutes                |int  |maxMailboxLengthMinutes                  |
|does_message_age                          |bool |doesMessageAge                           |
|hold_period_days                          |int  |holdPeriodDays                           |
|mail_server_net_address                   |str  |mailServerNetAddress *Optional*          |
|mail_server_protocol                      |str  |mailServerProtocol                       |
|default_delivery_from_address             |str  |defaultDeliveryFromAddress               |
|default_notification_from_address         |str  |defaultNotificationFromAddress           |
|default_voice_portal_lockout_from_address |str  |defaultVoicePortalLockoutFromAddress     |
|use_outgoing_mwi_on_smdi                  |bool |useOutgoingMWIOnSMDI                     |
|mwi_delay_in_seconds                      |int  |mwiDelayInSeconds                        |
|voice_portal_scope                        |str  |voicePortalScope                         |
|enterprise_voice_portal_licensed          |bool |enterpriseVoicePortalLicensed            |
|network_wide_messaging                    |bool |networkWideMessaging                     |
|use_external_routing                      |bool |useExternalRouting                       |
|default_external_routing_address          |str  |defaultExternalRoutingAddress *Optional* |
|vm_only_system                            |bool |vmOnlySystem                             |
</div>


## `SystemVoiceMessagingGroupGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetRequest20()`.

The following elements are only used in AS data mode: realDeleteForImap
useDnInMailBody useShortSubjectLine maxMessageLengthMinutes maxMailboxLengthMinutes
doesMessageAge holdPeriodDays mailServerProtocol defaultDeliveryFromAddress
defaultNotificationFromAddress useOutgoingMWIOnSMDI mwiDelayInSeconds voicePortalScope
enterpriseVoicePortalLicensed networkWideMessaging useExternalRouting vmOnlySystem
clientInitiatedMailServerSessionTimeoutMinutes The following elements are only used in
AS data mode and not returned in XS data mode mailServerNetAddress
defaultExternalRoutingAddress Replaced by: `SystemVoiceMessagingGroupGetResponse21()`

**Attributes:**

|Name                                                 |Type |Description                                    |
|-----------------------------------------------------|-----|-----------------------------------------------|
|real_delete_for_imap                                 |bool |realDeleteForImap                              |
|use_dn_in_mail_body                                  |bool |useDnInMailBody                                |
|use_short_subject_line                               |bool |useShortSubjectLine                            |
|max_message_length_minutes                           |int  |maxMessageLengthMinutes                        |
|max_mailbox_length_minutes                           |int  |maxMailboxLengthMinutes                        |
|does_message_age                                     |bool |doesMessageAge                                 |
|hold_period_days                                     |int  |holdPeriodDays                                 |
|mail_server_net_address                              |str  |mailServerNetAddress *Optional*                |
|mail_server_protocol                                 |str  |mailServerProtocol                             |
|default_delivery_from_address                        |str  |defaultDeliveryFromAddress                     |
|default_notification_from_address                    |str  |defaultNotificationFromAddress                 |
|default_voice_portal_lockout_from_address            |str  |defaultVoicePortalLockoutFromAddress           |
|use_outgoing_mwi_on_smdi                             |bool |useOutgoingMWIOnSMDI                           |
|mwi_delay_in_seconds                                 |int  |mwiDelayInSeconds                              |
|voice_portal_scope                                   |str  |voicePortalScope                               |
|enterprise_voice_portal_licensed                     |bool |enterpriseVoicePortalLicensed                  |
|network_wide_messaging                               |bool |networkWideMessaging                           |
|use_external_routing                                 |bool |useExternalRouting                             |
|default_external_routing_address                     |str  |defaultExternalRoutingAddress *Optional*       |
|vm_only_system                                       |bool |vmOnlySystem                                   |
|client_initiated_mail_server_session_timeout_minutes |int  |clientInitiatedMailServerSessionTimeoutMinutes |
</div>


## `SystemVoiceMessagingGroupGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetRequest21()`.

The following elements are only used in AS data mode: realDeleteForImap
useDnInMailBody useShortSubjectLine maxMessageLengthMinutes maxMailboxLengthMinutes
doesMessageAge holdPeriodDays mailServerNetAddress mailServerProtocol
defaultDeliveryFromAddress defaultNotificationFromAddress useOutgoingMWIOnSMDI
mwiDelayInSeconds voicePortalScope enterpriseVoicePortalLicensed networkWideMessaging
useExternalRouting defaultExternalRoutingAddress vmOnlySystem
clientInitiatedMailServerSessionTimeoutMinutes recordingAudioFileFormat Replaced by:
`SystemVoiceMessagingGroupGetResponse22()` in AS data mode

**Attributes:**

|Name                                                 |Type |Description                                    |
|-----------------------------------------------------|-----|-----------------------------------------------|
|real_delete_for_imap                                 |bool |realDeleteForImap                              |
|use_dn_in_mail_body                                  |bool |useDnInMailBody                                |
|use_short_subject_line                               |bool |useShortSubjectLine                            |
|max_message_length_minutes                           |int  |maxMessageLengthMinutes                        |
|max_mailbox_length_minutes                           |int  |maxMailboxLengthMinutes                        |
|does_message_age                                     |bool |doesMessageAge                                 |
|hold_period_days                                     |int  |holdPeriodDays                                 |
|mail_server_net_address                              |str  |mailServerNetAddress *Optional*                |
|mail_server_protocol                                 |str  |mailServerProtocol                             |
|default_delivery_from_address                        |str  |defaultDeliveryFromAddress                     |
|default_notification_from_address                    |str  |defaultNotificationFromAddress                 |
|default_voice_portal_lockout_from_address            |str  |defaultVoicePortalLockoutFromAddress           |
|use_outgoing_mwi_on_smdi                             |bool |useOutgoingMWIOnSMDI                           |
|mwi_delay_in_seconds                                 |int  |mwiDelayInSeconds                              |
|voice_portal_scope                                   |str  |voicePortalScope                               |
|enterprise_voice_portal_licensed                     |bool |enterpriseVoicePortalLicensed                  |
|network_wide_messaging                               |bool |networkWideMessaging                           |
|use_external_routing                                 |bool |useExternalRouting                             |
|default_external_routing_address                     |str  |defaultExternalRoutingAddress *Optional*       |
|vm_only_system                                       |bool |vmOnlySystem                                   |
|client_initiated_mail_server_session_timeout_minutes |int  |clientInitiatedMailServerSessionTimeoutMinutes |
|recording_audio_file_format                          |str  |recordingAudioFileFormat                       |
</div>


## `SystemVoiceMessagingGroupGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetResponse22()`.

Replaced by: `SystemVoiceMessagingGroupGetResponse22V2()`.

**Attributes:**

|Name                                                 |Type |Description                                    |
|-----------------------------------------------------|-----|-----------------------------------------------|
|real_delete_for_imap                                 |bool |realDeleteForImap                              |
|use_dn_in_mail_body                                  |bool |useDnInMailBody                                |
|use_short_subject_line                               |bool |useShortSubjectLine                            |
|max_message_length_minutes                           |int  |maxMessageLengthMinutes                        |
|max_mailbox_length_minutes                           |int  |maxMailboxLengthMinutes                        |
|does_message_age                                     |bool |doesMessageAge                                 |
|hold_period_days                                     |int  |holdPeriodDays                                 |
|mail_server_net_address                              |str  |mailServerNetAddress *Optional*                |
|mail_server_protocol                                 |str  |mailServerProtocol                             |
|default_delivery_from_address                        |str  |defaultDeliveryFromAddress                     |
|default_notification_from_address                    |str  |defaultNotificationFromAddress                 |
|default_voice_portal_lockout_from_address            |str  |defaultVoicePortalLockoutFromAddress           |
|use_outgoing_mwi_on_smdi                             |bool |useOutgoingMWIOnSMDI                           |
|mwi_delay_in_seconds                                 |int  |mwiDelayInSeconds                              |
|voice_portal_scope                                   |str  |voicePortalScope                               |
|enterprise_voice_portal_licensed                     |bool |enterpriseVoicePortalLicensed                  |
|network_wide_messaging                               |bool |networkWideMessaging                           |
|use_external_routing                                 |bool |useExternalRouting                             |
|default_external_routing_address                     |str  |defaultExternalRoutingAddress *Optional*       |
|vm_only_system                                       |bool |vmOnlySystem                                   |
|client_initiated_mail_server_session_timeout_minutes |int  |clientInitiatedMailServerSessionTimeoutMinutes |
|recording_audio_file_format                          |str  |recordingAudioFileFormat                       |
|allow_voice_portal_access_from_vm_deposit_menu       |bool |allowVoicePortalAccessFromVMDepositMenu        |
</div>


## `SystemVoiceMessagingGroupGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetRequest22V2()`.

The following elements are only used in AS/Amplify data mode: realDeleteForImap
useDnInMailBody useShortSubjectLine maxMessageLengthMinutes maxMailboxLengthMinutes
doesMessageAge holdPeriodDays mailServerNetAddress mailServerProtocol
defaultDeliveryFromAddress defaultNotificationFromAddress useOutgoingMWIOnSMDI
mwiDelayInSeconds voicePortalScope enterpriseVoicePortalLicensed networkWideMessaging
useExternalRouting defaultExternalRoutingAddress vmOnlySystem, value "false" is
returned in Amplify data mode clientInitiatedMailServerSessionTimeoutMinutes
recordingAudioFileFormat allowVoicePortalAccessFromVMDepositMenu The following
elements are only used in AS mode and not returned in XS data mode: vmBucketName The
following elements are only used in AS data mode: storageSelection, value "Mail
Server" is returned in XS data mode

**Attributes:**

|Name                                                 |Type |Description                                    |
|-----------------------------------------------------|-----|-----------------------------------------------|
|real_delete_for_imap                                 |bool |realDeleteForImap                              |
|use_dn_in_mail_body                                  |bool |useDnInMailBody                                |
|use_short_subject_line                               |bool |useShortSubjectLine                            |
|max_message_length_minutes                           |int  |maxMessageLengthMinutes                        |
|max_mailbox_length_minutes                           |int  |maxMailboxLengthMinutes                        |
|does_message_age                                     |bool |doesMessageAge                                 |
|hold_period_days                                     |int  |holdPeriodDays                                 |
|mail_server_net_address                              |str  |mailServerNetAddress *Optional*                |
|mail_server_protocol                                 |str  |mailServerProtocol                             |
|default_delivery_from_address                        |str  |defaultDeliveryFromAddress                     |
|default_notification_from_address                    |str  |defaultNotificationFromAddress                 |
|default_voice_portal_lockout_from_address            |str  |defaultVoicePortalLockoutFromAddress           |
|use_outgoing_mwi_on_smdi                             |bool |useOutgoingMWIOnSMDI                           |
|mwi_delay_in_seconds                                 |int  |mwiDelayInSeconds                              |
|voice_portal_scope                                   |str  |voicePortalScope                               |
|enterprise_voice_portal_licensed                     |bool |enterpriseVoicePortalLicensed                  |
|network_wide_messaging                               |bool |networkWideMessaging                           |
|use_external_routing                                 |bool |useExternalRouting                             |
|default_external_routing_address                     |str  |defaultExternalRoutingAddress *Optional*       |
|vm_only_system                                       |bool |vmOnlySystem                                   |
|client_initiated_mail_server_session_timeout_minutes |int  |clientInitiatedMailServerSessionTimeoutMinutes |
|recording_audio_file_format                          |str  |recordingAudioFileFormat                       |
|allow_voice_portal_access_from_vm_deposit_menu       |bool |allowVoicePortalAccessFromVMDepositMenu        |
|storage_selection                                    |str  |storageSelection                               |
|vm_bucket_name                                       |str  |vmBucketName *Optional*                        |
</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetVoicePortalMenusRequest14()`.


**Attributes:**

|Name                                                      |Type                                                  |Description                                       |
|----------------------------------------------------------|------------------------------------------------------|--------------------------------------------------|
|use_voice_portal_customization                            |bool                                                  |useVoicePortalCustomization                       |
|voice_portal_main_menu_keys                               |OCI.voicePortalMainMenuKeys                           |voicePortalMainMenuKeys                           |
|voice_messaging_menu_keys                                 |OCI.voiceMessagingMenuKeys                            |voiceMessagingMenuKeys                            |
|change_busy_or_no_answer_greeting_menu_keys               |OCI.changeBusyOrNoAnswerGreetingMenuKeys              |changeBusyOrNoAnswerGreetingMenuKeys              |
|record_new_greeting_or_personalized_name_menu_keys        |OCI.recordNewGreetingOrPersonalizedNameMenuKeys       |recordNewGreetingOrPersonalizedNameMenuKeys       |
|delete_all_messages_menu_keys                             |OCI.deleteAllMessagesMenuKeys                         |deleteAllMessagesMenuKeys                         |
|comm_pilot_express_profile_menu_keys                      |OCI.commPilotExpressProfileMenuKeys                   |commPilotExpressProfileMenuKeys                   |
|personalized_name_menu_keys                               |OCI.personalizedNameMenuKeys                          |personalizedNameMenuKeys                          |
|call_forwarding_options_menu_keys                         |OCI.callForwardingOptionsMenuKeys                     |callForwardingOptionsMenuKeys                     |
|change_call_forwarding_destination_menu_keys              |OCI.changeCallForwardingDestinationMenuKeys           |changeCallForwardingDestinationMenuKeys           |
|voice_portal_calling_menu_keys                            |OCI.voicePortalCallingMenuKeys                        |voicePortalCallingMenuKeys                        |
|hoteling_menu_keys                                        |OCI.hotelingMenuKeys                                  |hotelingMenuKeys                                  |
|passcode_menu_keys                                        |OCI.passcodeMenuKeys                                  |passcodeMenuKeys                                  |
|play_messages_menu_keys                                   |OCI.playMessagesMenuKeys                              |playMessagesMenuKeys                              |
|play_message_menu_keys                                    |OCI.playMessageMenuKeys                               |playMessageMenuKeys                               |
|additional_message_options_menu_keys                      |OCI.additionalMessageOptionsMenuKeys                  |additionalMessageOptionsMenuKeys                  |
|forward_or_compose_message_menu_keys                      |OCI.forwardOrComposeMessageMenuKeys                   |forwardOrComposeMessageMenuKeys                   |
|reply_message_menu_keys                                   |OCI.replyMessageMenuKeys                              |replyMessageMenuKeys                              |
|send_to_distribution_list_menu_keys                       |OCI.sendToDistributionListMenuKeys                    |sendToDistributionListMenuKeys                    |
|select_distribution_list_menu_keys                        |OCI.selectDistributionListMenuKeys                    |selectDistributionListMenuKeys                    |
|review_selected_distribution_list_menu_keys               |OCI.reviewSelectedDistributionListMenuKeys            |reviewSelectedDistributionListMenuKeys            |
|send_message_to_selected_distribution_list_menu_keys      |OCI.sendMessageToSelectedDistributionListMenuKeys     |sendMessageToSelectedDistributionListMenuKeys     |
|send_to_all_group_members_menu_keys                       |OCI.sendToAllGroupMembersMenuKeys                     |sendToAllGroupMembersMenuKeys                     |
|send_to_person_menu_keys                                  |OCI.sendToPersonMenuKeys                              |sendToPersonMenuKeys                              |
|change_current_introduction_or_message_or_reply_menu_keys |OCI.changeCurrentIntroductionOrMessageOrReplyMenuKeys |changeCurrentIntroductionOrMessageOrReplyMenuKeys |
|voice_portal_login_menu_keys                              |OCI.voicePortalLoginMenuKeys                          |voicePortalLoginMenuKeys                          |
|fax_messaging_menu_keys                                   |OCI.faxMessagingMenuKeys                              |faxMessagingMenuKeys                              |
</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetVoicePortalMenusRequest18()`.

Replaced by `SystemVoiceMessagingGroupGetVoicePortalMenusResponse19()`

**Attributes:**

|Name                                                      |Type                                                  |Description                                       |
|----------------------------------------------------------|------------------------------------------------------|--------------------------------------------------|
|use_voice_portal_customization                            |bool                                                  |useVoicePortalCustomization                       |
|voice_portal_main_menu_keys                               |OCI.voicePortalMainMenuKeys                           |voicePortalMainMenuKeys                           |
|voice_messaging_menu_keys                                 |OCI.voiceMessagingMenuKeys                            |voiceMessagingMenuKeys                            |
|play_greeting_menu_keys                                   |OCI.playGreetingMenuKeys                              |playGreetingMenuKeys                              |
|change_busy_or_no_answer_greeting_menu_keys               |OCI.changeBusyOrNoAnswerGreetingMenuKeys              |changeBusyOrNoAnswerGreetingMenuKeys              |
|record_new_greeting_or_personalized_name_menu_keys        |OCI.recordNewGreetingOrPersonalizedNameMenuKeys       |recordNewGreetingOrPersonalizedNameMenuKeys       |
|delete_all_messages_menu_keys                             |OCI.deleteAllMessagesMenuKeys                         |deleteAllMessagesMenuKeys                         |
|comm_pilot_express_profile_menu_keys                      |OCI.commPilotExpressProfileMenuKeys                   |commPilotExpressProfileMenuKeys                   |
|personalized_name_menu_keys                               |OCI.personalizedNameMenuKeys                          |personalizedNameMenuKeys                          |
|call_forwarding_options_menu_keys                         |OCI.callForwardingOptionsMenuKeys                     |callForwardingOptionsMenuKeys                     |
|change_call_forwarding_destination_menu_keys              |OCI.changeCallForwardingDestinationMenuKeys           |changeCallForwardingDestinationMenuKeys           |
|voice_portal_calling_menu_keys                            |OCI.voicePortalCallingMenuKeys                        |voicePortalCallingMenuKeys                        |
|hoteling_menu_keys                                        |OCI.hotelingMenuKeys                                  |hotelingMenuKeys                                  |
|passcode_menu_keys                                        |OCI.passcodeMenuKeys                                  |passcodeMenuKeys                                  |
|play_messages_menu_keys                                   |OCI.playMessagesMenuKeys                              |playMessagesMenuKeys                              |
|play_message_menu_keys                                    |OCI.playMessageMenuKeys                               |playMessageMenuKeys                               |
|additional_message_options_menu_keys                      |OCI.additionalMessageOptionsMenuKeys                  |additionalMessageOptionsMenuKeys                  |
|forward_or_compose_message_menu_keys                      |OCI.forwardOrComposeMessageMenuKeys                   |forwardOrComposeMessageMenuKeys                   |
|reply_message_menu_keys                                   |OCI.replyMessageMenuKeys                              |replyMessageMenuKeys                              |
|send_to_distribution_list_menu_keys                       |OCI.sendToDistributionListMenuKeys                    |sendToDistributionListMenuKeys                    |
|select_distribution_list_menu_keys                        |OCI.selectDistributionListMenuKeys                    |selectDistributionListMenuKeys                    |
|review_selected_distribution_list_menu_keys               |OCI.reviewSelectedDistributionListMenuKeys            |reviewSelectedDistributionListMenuKeys            |
|send_message_to_selected_distribution_list_menu_keys      |OCI.sendMessageToSelectedDistributionListMenuKeys     |sendMessageToSelectedDistributionListMenuKeys     |
|send_to_all_group_members_menu_keys                       |OCI.sendToAllGroupMembersMenuKeys                     |sendToAllGroupMembersMenuKeys                     |
|send_to_person_menu_keys                                  |OCI.sendToPersonMenuKeys                              |sendToPersonMenuKeys                              |
|change_current_introduction_or_message_or_reply_menu_keys |OCI.changeCurrentIntroductionOrMessageOrReplyMenuKeys |changeCurrentIntroductionOrMessageOrReplyMenuKeys |
|voice_portal_login_menu_keys                              |OCI.voicePortalLoginMenuKeys                          |voicePortalLoginMenuKeys                          |
|fax_messaging_menu_keys                                   |OCI.faxMessagingMenuKeys                              |faxMessagingMenuKeys                              |
|message_deposit_menu_keys                                 |OCI.messageDepositMenuKeys                            |messageDepositMenuKeys                            |
|disable_message_deposit_menu_keys                         |OCI.disableMessageDepositMenuKeys                     |disableMessageDepositMenuKeys                     |
|greeting_only_forwarding_destination_menu_keys            |OCI.greetingOnlyForwardingDestinationMenuKeys         |greetingOnlyForwardingDestinationMenuKeys         |
</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusResponse18sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetVoicePortalMenusRequest18sp1()`.

Replaced by `SystemVoiceMessagingGroupGetVoicePortalMenusResponse19sp1()`

**Attributes:**

|Name                                                      |Type                                                  |Description                                       |
|----------------------------------------------------------|------------------------------------------------------|--------------------------------------------------|
|use_voice_portal_customization                            |bool                                                  |useVoicePortalCustomization                       |
|voice_portal_main_menu_keys                               |OCI.voicePortalMainMenuKeys                           |voicePortalMainMenuKeys                           |
|voice_messaging_menu_keys                                 |OCI.voiceMessagingMenuKeys                            |voiceMessagingMenuKeys                            |
|play_greeting_menu_keys                                   |OCI.playGreetingMenuKeys                              |playGreetingMenuKeys                              |
|change_busy_or_no_answer_greeting_menu_keys               |OCI.changeBusyOrNoAnswerGreetingMenuKeys              |changeBusyOrNoAnswerGreetingMenuKeys              |
|change_extended_away_greeting_menu_keys                   |OCI.changeExtendedAwayGreetingMenuKeys                |changeExtendedAwayGreetingMenuKeys                |
|record_new_greeting_or_personalized_name_menu_keys        |OCI.recordNewGreetingOrPersonalizedNameMenuKeys       |recordNewGreetingOrPersonalizedNameMenuKeys       |
|delete_all_messages_menu_keys                             |OCI.deleteAllMessagesMenuKeys                         |deleteAllMessagesMenuKeys                         |
|comm_pilot_express_profile_menu_keys                      |OCI.commPilotExpressProfileMenuKeys                   |commPilotExpressProfileMenuKeys                   |
|personalized_name_menu_keys                               |OCI.personalizedNameMenuKeys                          |personalizedNameMenuKeys                          |
|call_forwarding_options_menu_keys                         |OCI.callForwardingOptionsMenuKeys                     |callForwardingOptionsMenuKeys                     |
|change_call_forwarding_destination_menu_keys              |OCI.changeCallForwardingDestinationMenuKeys           |changeCallForwardingDestinationMenuKeys           |
|voice_portal_calling_menu_keys                            |OCI.voicePortalCallingMenuKeys                        |voicePortalCallingMenuKeys                        |
|hoteling_menu_keys                                        |OCI.hotelingMenuKeys                                  |hotelingMenuKeys                                  |
|passcode_menu_keys                                        |OCI.passcodeMenuKeys                                  |passcodeMenuKeys                                  |
|play_messages_menu_keys                                   |OCI.playMessagesMenuKeys                              |playMessagesMenuKeys                              |
|play_message_menu_keys                                    |OCI.playMessageMenuKeys                               |playMessageMenuKeys                               |
|additional_message_options_menu_keys                      |OCI.additionalMessageOptionsMenuKeys                  |additionalMessageOptionsMenuKeys                  |
|forward_or_compose_message_menu_keys                      |OCI.forwardOrComposeMessageMenuKeys                   |forwardOrComposeMessageMenuKeys                   |
|reply_message_menu_keys                                   |OCI.replyMessageMenuKeys                              |replyMessageMenuKeys                              |
|send_to_distribution_list_menu_keys                       |OCI.sendToDistributionListMenuKeys                    |sendToDistributionListMenuKeys                    |
|select_distribution_list_menu_keys                        |OCI.selectDistributionListMenuKeys                    |selectDistributionListMenuKeys                    |
|review_selected_distribution_list_menu_keys               |OCI.reviewSelectedDistributionListMenuKeys            |reviewSelectedDistributionListMenuKeys            |
|send_message_to_selected_distribution_list_menu_keys      |OCI.sendMessageToSelectedDistributionListMenuKeys     |sendMessageToSelectedDistributionListMenuKeys     |
|send_to_all_group_members_menu_keys                       |OCI.sendToAllGroupMembersMenuKeys                     |sendToAllGroupMembersMenuKeys                     |
|send_to_person_menu_keys                                  |OCI.sendToPersonMenuKeys                              |sendToPersonMenuKeys                              |
|change_current_introduction_or_message_or_reply_menu_keys |OCI.changeCurrentIntroductionOrMessageOrReplyMenuKeys |changeCurrentIntroductionOrMessageOrReplyMenuKeys |
|voice_portal_login_menu_keys                              |OCI.voicePortalLoginMenuKeys                          |voicePortalLoginMenuKeys                          |
|fax_messaging_menu_keys                                   |OCI.faxMessagingMenuKeys                              |faxMessagingMenuKeys                              |
|message_deposit_menu_keys                                 |OCI.messageDepositMenuKeys                            |messageDepositMenuKeys                            |
|disable_message_deposit_menu_keys                         |OCI.disableMessageDepositMenuKeys                     |disableMessageDepositMenuKeys                     |
|greeting_only_forwarding_destination_menu_keys            |OCI.greetingOnlyForwardingDestinationMenuKeys         |greetingOnlyForwardingDestinationMenuKeys         |
</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetVoicePortalMenusRequest19()`.

Replaced by: `SystemVoiceMessagingGroupGetVoicePortalMenusResponse19sp1()`

**Attributes:**

|Name                                                      |Type                                                  |Description                                       |
|----------------------------------------------------------|------------------------------------------------------|--------------------------------------------------|
|use_voice_portal_customization                            |bool                                                  |useVoicePortalCustomization                       |
|voice_portal_main_menu_keys                               |OCI.voicePortalMainMenuKeys                           |voicePortalMainMenuKeys                           |
|greetings_menu_keys                                       |OCI.greetingsMenuKeys                                 |greetingsMenuKeys                                 |
|conference_greeting_menu_keys                             |OCI.conferenceGreetingMenuKeys                        |conferenceGreetingMenuKeys                        |
|voice_messaging_menu_keys                                 |OCI.voiceMessagingMenuKeys                            |voiceMessagingMenuKeys                            |
|play_greeting_menu_keys                                   |OCI.playGreetingMenuKeys                              |playGreetingMenuKeys                              |
|change_busy_or_no_answer_greeting_menu_keys               |OCI.changeBusyOrNoAnswerGreetingMenuKeys              |changeBusyOrNoAnswerGreetingMenuKeys              |
|record_new_greeting_or_personalized_name_menu_keys        |OCI.recordNewGreetingOrPersonalizedNameMenuKeys       |recordNewGreetingOrPersonalizedNameMenuKeys       |
|delete_all_messages_menu_keys                             |OCI.deleteAllMessagesMenuKeys                         |deleteAllMessagesMenuKeys                         |
|comm_pilot_express_profile_menu_keys                      |OCI.commPilotExpressProfileMenuKeys                   |commPilotExpressProfileMenuKeys                   |
|personalized_name_menu_keys                               |OCI.personalizedNameMenuKeys                          |personalizedNameMenuKeys                          |
|call_forwarding_options_menu_keys                         |OCI.callForwardingOptionsMenuKeys                     |callForwardingOptionsMenuKeys                     |
|change_call_forwarding_destination_menu_keys              |OCI.changeCallForwardingDestinationMenuKeys           |changeCallForwardingDestinationMenuKeys           |
|voice_portal_calling_menu_keys                            |OCI.voicePortalCallingMenuKeys                        |voicePortalCallingMenuKeys                        |
|hoteling_menu_keys                                        |OCI.hotelingMenuKeys                                  |hotelingMenuKeys                                  |
|passcode_menu_keys                                        |OCI.passcodeMenuKeys                                  |passcodeMenuKeys                                  |
|play_messages_menu_keys                                   |OCI.playMessagesMenuKeys                              |playMessagesMenuKeys                              |
|play_message_menu_keys                                    |OCI.playMessageMenuKeys                               |playMessageMenuKeys                               |
|additional_message_options_menu_keys                      |OCI.additionalMessageOptionsMenuKeys                  |additionalMessageOptionsMenuKeys                  |
|forward_or_compose_message_menu_keys                      |OCI.forwardOrComposeMessageMenuKeys                   |forwardOrComposeMessageMenuKeys                   |
|reply_message_menu_keys                                   |OCI.replyMessageMenuKeys                              |replyMessageMenuKeys                              |
|send_to_distribution_list_menu_keys                       |OCI.sendToDistributionListMenuKeys                    |sendToDistributionListMenuKeys                    |
|select_distribution_list_menu_keys                        |OCI.selectDistributionListMenuKeys                    |selectDistributionListMenuKeys                    |
|review_selected_distribution_list_menu_keys               |OCI.reviewSelectedDistributionListMenuKeys            |reviewSelectedDistributionListMenuKeys            |
|send_message_to_selected_distribution_list_menu_keys      |OCI.sendMessageToSelectedDistributionListMenuKeys     |sendMessageToSelectedDistributionListMenuKeys     |
|send_to_all_group_members_menu_keys                       |OCI.sendToAllGroupMembersMenuKeys                     |sendToAllGroupMembersMenuKeys                     |
|send_to_person_menu_keys                                  |OCI.sendToPersonMenuKeys                              |sendToPersonMenuKeys                              |
|change_current_introduction_or_message_or_reply_menu_keys |OCI.changeCurrentIntroductionOrMessageOrReplyMenuKeys |changeCurrentIntroductionOrMessageOrReplyMenuKeys |
|voice_portal_login_menu_keys                              |OCI.voicePortalLoginMenuKeys                          |voicePortalLoginMenuKeys                          |
|fax_messaging_menu_keys                                   |OCI.faxMessagingMenuKeys                              |faxMessagingMenuKeys                              |
|message_deposit_menu_keys                                 |OCI.messageDepositMenuKeys                            |messageDepositMenuKeys                            |
|disable_message_deposit_menu_keys                         |OCI.disableMessageDepositMenuKeys                     |disableMessageDepositMenuKeys                     |
|greeting_only_forwarding_destination_menu_keys            |OCI.greetingOnlyForwardingDestinationMenuKeys         |greetingOnlyForwardingDestinationMenuKeys         |
</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetVoicePortalMenusRequest19sp1()`.

Replaced by `SystemVoiceMessagingGroupGetVoicePortalMenusResponse20()`

**Attributes:**

|Name                                                      |Type                                                  |Description                                       |
|----------------------------------------------------------|------------------------------------------------------|--------------------------------------------------|
|use_voice_portal_customization                            |bool                                                  |useVoicePortalCustomization                       |
|voice_portal_main_menu_keys                               |OCI.voicePortalMainMenuKeys                           |voicePortalMainMenuKeys                           |
|greetings_menu_keys                                       |OCI.greetingsMenuKeys                                 |greetingsMenuKeys                                 |
|conference_greeting_menu_keys                             |OCI.conferenceGreetingMenuKeys                        |conferenceGreetingMenuKeys                        |
|voice_messaging_menu_keys                                 |OCI.voiceMessagingMenuKeys                            |voiceMessagingMenuKeys                            |
|play_greeting_menu_keys                                   |OCI.playGreetingMenuKeys                              |playGreetingMenuKeys                              |
|change_busy_or_no_answer_greeting_menu_keys               |OCI.changeBusyOrNoAnswerGreetingMenuKeys              |changeBusyOrNoAnswerGreetingMenuKeys              |
|change_extended_away_greeting_menu_keys                   |OCI.changeExtendedAwayGreetingMenuKeys                |changeExtendedAwayGreetingMenuKeys                |
|record_new_greeting_or_personalized_name_menu_keys        |OCI.recordNewGreetingOrPersonalizedNameMenuKeys       |recordNewGreetingOrPersonalizedNameMenuKeys       |
|delete_all_messages_menu_keys                             |OCI.deleteAllMessagesMenuKeys                         |deleteAllMessagesMenuKeys                         |
|comm_pilot_express_profile_menu_keys                      |OCI.commPilotExpressProfileMenuKeys                   |commPilotExpressProfileMenuKeys                   |
|personalized_name_menu_keys                               |OCI.personalizedNameMenuKeys                          |personalizedNameMenuKeys                          |
|call_forwarding_options_menu_keys                         |OCI.callForwardingOptionsMenuKeys                     |callForwardingOptionsMenuKeys                     |
|change_call_forwarding_destination_menu_keys              |OCI.changeCallForwardingDestinationMenuKeys           |changeCallForwardingDestinationMenuKeys           |
|voice_portal_calling_menu_keys                            |OCI.voicePortalCallingMenuKeys                        |voicePortalCallingMenuKeys                        |
|hoteling_menu_keys                                        |OCI.hotelingMenuKeys                                  |hotelingMenuKeys                                  |
|passcode_menu_keys                                        |OCI.passcodeMenuKeys                                  |passcodeMenuKeys                                  |
|play_messages_menu_keys                                   |OCI.playMessagesMenuKeys                              |playMessagesMenuKeys                              |
|play_message_menu_keys                                    |OCI.playMessageMenuKeys                               |playMessageMenuKeys                               |
|additional_message_options_menu_keys                      |OCI.additionalMessageOptionsMenuKeys                  |additionalMessageOptionsMenuKeys                  |
|forward_or_compose_message_menu_keys                      |OCI.forwardOrComposeMessageMenuKeys                   |forwardOrComposeMessageMenuKeys                   |
|reply_message_menu_keys                                   |OCI.replyMessageMenuKeys                              |replyMessageMenuKeys                              |
|send_to_distribution_list_menu_keys                       |OCI.sendToDistributionListMenuKeys                    |sendToDistributionListMenuKeys                    |
|select_distribution_list_menu_keys                        |OCI.selectDistributionListMenuKeys                    |selectDistributionListMenuKeys                    |
|review_selected_distribution_list_menu_keys               |OCI.reviewSelectedDistributionListMenuKeys            |reviewSelectedDistributionListMenuKeys            |
|send_message_to_selected_distribution_list_menu_keys      |OCI.sendMessageToSelectedDistributionListMenuKeys     |sendMessageToSelectedDistributionListMenuKeys     |
|send_to_all_group_members_menu_keys                       |OCI.sendToAllGroupMembersMenuKeys                     |sendToAllGroupMembersMenuKeys                     |
|send_to_person_menu_keys                                  |OCI.sendToPersonMenuKeys                              |sendToPersonMenuKeys                              |
|change_current_introduction_or_message_or_reply_menu_keys |OCI.changeCurrentIntroductionOrMessageOrReplyMenuKeys |changeCurrentIntroductionOrMessageOrReplyMenuKeys |
|voice_portal_login_menu_keys                              |OCI.voicePortalLoginMenuKeys                          |voicePortalLoginMenuKeys                          |
|fax_messaging_menu_keys                                   |OCI.faxMessagingMenuKeys                              |faxMessagingMenuKeys                              |
|message_deposit_menu_keys                                 |OCI.messageDepositMenuKeys                            |messageDepositMenuKeys                            |
|disable_message_deposit_menu_keys                         |OCI.disableMessageDepositMenuKeys                     |disableMessageDepositMenuKeys                     |
|greeting_only_forwarding_destination_menu_keys            |OCI.greetingOnlyForwardingDestinationMenuKeys         |greetingOnlyForwardingDestinationMenuKeys         |
</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetVoicePortalMenusRequest20()`.


**Attributes:**

|Name                                                      |Type                                                  |Description                                       |
|----------------------------------------------------------|------------------------------------------------------|--------------------------------------------------|
|use_voice_portal_customization                            |bool                                                  |useVoicePortalCustomization                       |
|voice_portal_main_menu_keys                               |OCI.voicePortalMainMenuKeys                           |voicePortalMainMenuKeys                           |
|announcement_menu_keys                                    |OCI.announcementMenuKeys                              |announcementMenuKeys                              |
|announcement_recording_menu_keys                          |OCI.announcementRecordingMenuKeys                     |announcementRecordingMenuKeys                     |
|greetings_menu_keys                                       |OCI.greetingsMenuKeys                                 |greetingsMenuKeys                                 |
|conference_greeting_menu_keys                             |OCI.conferenceGreetingMenuKeys                        |conferenceGreetingMenuKeys                        |
|voice_messaging_menu_keys                                 |OCI.voiceMessagingMenuKeys                            |voiceMessagingMenuKeys                            |
|play_greeting_menu_keys                                   |OCI.playGreetingMenuKeys                              |playGreetingMenuKeys                              |
|change_busy_or_no_answer_greeting_menu_keys               |OCI.changeBusyOrNoAnswerGreetingMenuKeys              |changeBusyOrNoAnswerGreetingMenuKeys              |
|change_extended_away_greeting_menu_keys                   |OCI.changeExtendedAwayGreetingMenuKeys                |changeExtendedAwayGreetingMenuKeys                |
|record_new_greeting_or_personalized_name_menu_keys        |OCI.recordNewGreetingOrPersonalizedNameMenuKeys       |recordNewGreetingOrPersonalizedNameMenuKeys       |
|delete_all_messages_menu_keys                             |OCI.deleteAllMessagesMenuKeys                         |deleteAllMessagesMenuKeys                         |
|comm_pilot_express_profile_menu_keys                      |OCI.commPilotExpressProfileMenuKeys                   |commPilotExpressProfileMenuKeys                   |
|personalized_name_menu_keys                               |OCI.personalizedNameMenuKeys                          |personalizedNameMenuKeys                          |
|call_forwarding_options_menu_keys                         |OCI.callForwardingOptionsMenuKeys                     |callForwardingOptionsMenuKeys                     |
|change_call_forwarding_destination_menu_keys              |OCI.changeCallForwardingDestinationMenuKeys           |changeCallForwardingDestinationMenuKeys           |
|voice_portal_calling_menu_keys                            |OCI.voicePortalCallingMenuKeys                        |voicePortalCallingMenuKeys                        |
|hoteling_menu_keys                                        |OCI.hotelingMenuKeys                                  |hotelingMenuKeys                                  |
|passcode_menu_keys                                        |OCI.passcodeMenuKeys                                  |passcodeMenuKeys                                  |
|play_messages_menu_keys                                   |OCI.playMessagesMenuKeys                              |playMessagesMenuKeys                              |
|play_message_menu_keys                                    |OCI.playMessageMenuKeys                               |playMessageMenuKeys                               |
|additional_message_options_menu_keys                      |OCI.additionalMessageOptionsMenuKeys                  |additionalMessageOptionsMenuKeys                  |
|forward_or_compose_message_menu_keys                      |OCI.forwardOrComposeMessageMenuKeys                   |forwardOrComposeMessageMenuKeys                   |
|reply_message_menu_keys                                   |OCI.replyMessageMenuKeys                              |replyMessageMenuKeys                              |
|send_to_distribution_list_menu_keys                       |OCI.sendToDistributionListMenuKeys                    |sendToDistributionListMenuKeys                    |
|select_distribution_list_menu_keys                        |OCI.selectDistributionListMenuKeys                    |selectDistributionListMenuKeys                    |
|review_selected_distribution_list_menu_keys               |OCI.reviewSelectedDistributionListMenuKeys            |reviewSelectedDistributionListMenuKeys            |
|send_message_to_selected_distribution_list_menu_keys      |OCI.sendMessageToSelectedDistributionListMenuKeys     |sendMessageToSelectedDistributionListMenuKeys     |
|send_to_all_group_members_menu_keys                       |OCI.sendToAllGroupMembersMenuKeys                     |sendToAllGroupMembersMenuKeys                     |
|send_to_person_menu_keys                                  |OCI.sendToPersonMenuKeys                              |sendToPersonMenuKeys                              |
|change_current_introduction_or_message_or_reply_menu_keys |OCI.changeCurrentIntroductionOrMessageOrReplyMenuKeys |changeCurrentIntroductionOrMessageOrReplyMenuKeys |
|voice_portal_login_menu_keys                              |OCI.voicePortalLoginMenuKeys                          |voicePortalLoginMenuKeys                          |
|fax_messaging_menu_keys                                   |OCI.faxMessagingMenuKeys                              |faxMessagingMenuKeys                              |
|message_deposit_menu_keys                                 |OCI.messageDepositMenuKeys                            |messageDepositMenuKeys                            |
|disable_message_deposit_menu_keys                         |OCI.disableMessageDepositMenuKeys                     |disableMessageDepositMenuKeys                     |
|greeting_only_forwarding_destination_menu_keys            |OCI.greetingOnlyForwardingDestinationMenuKeys         |greetingOnlyForwardingDestinationMenuKeys         |
</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetVoicePortalMenusRequest21()`.


**Attributes:**

|Name                                                      |Type                                                  |Description                                       |
|----------------------------------------------------------|------------------------------------------------------|--------------------------------------------------|
|use_voice_portal_customization                            |bool                                                  |useVoicePortalCustomization                       |
|voice_portal_main_menu_keys                               |OCI.voicePortalMainMenuKeys                           |voicePortalMainMenuKeys                           |
|announcement_menu_keys                                    |OCI.announcementMenuKeys                              |announcementMenuKeys                              |
|announcement_recording_menu_keys                          |OCI.announcementRecordingMenuKeys                     |announcementRecordingMenuKeys                     |
|greetings_menu_keys                                       |OCI.greetingsMenuKeys                                 |greetingsMenuKeys                                 |
|conference_greeting_menu_keys                             |OCI.conferenceGreetingMenuKeys                        |conferenceGreetingMenuKeys                        |
|voice_messaging_menu_keys                                 |OCI.voiceMessagingMenuKeys                            |voiceMessagingMenuKeys                            |
|play_greeting_menu_keys                                   |OCI.playGreetingMenuKeys                              |playGreetingMenuKeys                              |
|change_busy_or_no_answer_greeting_menu_keys               |OCI.changeBusyOrNoAnswerGreetingMenuKeys              |changeBusyOrNoAnswerGreetingMenuKeys              |
|change_extended_away_greeting_menu_keys                   |OCI.changeExtendedAwayGreetingMenuKeys                |changeExtendedAwayGreetingMenuKeys                |
|record_new_greeting_or_personalized_name_menu_keys        |OCI.recordNewGreetingOrPersonalizedNameMenuKeys       |recordNewGreetingOrPersonalizedNameMenuKeys       |
|delete_all_messages_menu_keys                             |OCI.deleteAllMessagesMenuKeys                         |deleteAllMessagesMenuKeys                         |
|comm_pilot_express_profile_menu_keys                      |OCI.commPilotExpressProfileMenuKeys                   |commPilotExpressProfileMenuKeys                   |
|personalized_name_menu_keys                               |OCI.personalizedNameMenuKeys                          |personalizedNameMenuKeys                          |
|call_forwarding_options_menu_keys                         |OCI.callForwardingOptionsMenuKeys                     |callForwardingOptionsMenuKeys                     |
|change_call_forwarding_destination_menu_keys              |OCI.changeCallForwardingDestinationMenuKeys           |changeCallForwardingDestinationMenuKeys           |
|voice_portal_calling_menu_keys                            |OCI.voicePortalCallingMenuKeys                        |voicePortalCallingMenuKeys                        |
|hoteling_menu_keys                                        |OCI.hotelingMenuKeys                                  |hotelingMenuKeys                                  |
|passcode_menu_keys                                        |OCI.passcodeMenuKeys                                  |passcodeMenuKeys                                  |
|play_messages_menu_keys                                   |OCI.playMessagesMenuKeys                              |playMessagesMenuKeys                              |
|play_message_menu_keys                                    |OCI.playMessageMenuKeys                               |playMessageMenuKeys                               |
|additional_message_options_menu_keys                      |OCI.additionalMessageOptionsMenuKeys                  |additionalMessageOptionsMenuKeys                  |
|forward_or_compose_message_menu_keys                      |OCI.forwardOrComposeMessageMenuKeys                   |forwardOrComposeMessageMenuKeys                   |
|reply_message_menu_keys                                   |OCI.replyMessageMenuKeys                              |replyMessageMenuKeys                              |
|send_to_distribution_list_menu_keys                       |OCI.sendToDistributionListMenuKeys                    |sendToDistributionListMenuKeys                    |
|select_distribution_list_menu_keys                        |OCI.selectDistributionListMenuKeys                    |selectDistributionListMenuKeys                    |
|review_selected_distribution_list_menu_keys               |OCI.reviewSelectedDistributionListMenuKeys            |reviewSelectedDistributionListMenuKeys            |
|send_message_to_selected_distribution_list_menu_keys      |OCI.sendMessageToSelectedDistributionListMenuKeys     |sendMessageToSelectedDistributionListMenuKeys     |
|send_to_all_group_members_menu_keys                       |OCI.sendToAllGroupMembersMenuKeys                     |sendToAllGroupMembersMenuKeys                     |
|send_to_person_menu_keys                                  |OCI.sendToPersonMenuKeys                              |sendToPersonMenuKeys                              |
|change_current_introduction_or_message_or_reply_menu_keys |OCI.changeCurrentIntroductionOrMessageOrReplyMenuKeys |changeCurrentIntroductionOrMessageOrReplyMenuKeys |
|voice_portal_login_menu_keys                              |OCI.voicePortalLoginMenuKeys                          |voicePortalLoginMenuKeys                          |
|fax_messaging_menu_keys                                   |OCI.faxMessagingMenuKeys                              |faxMessagingMenuKeys                              |
|message_deposit_menu_keys                                 |OCI.messageDepositMenuKeys                            |messageDepositMenuKeys                            |
|disable_message_deposit_menu_keys                         |OCI.disableMessageDepositMenuKeys                     |disableMessageDepositMenuKeys                     |
|greeting_only_forwarding_destination_menu_keys            |OCI.greetingOnlyForwardingDestinationMenuKeys         |greetingOnlyForwardingDestinationMenuKeys         |
|personal_assistant_menu_keys                              |OCI.personalAssistantMenuKeys                         |personalAssistantMenuKeys                         |
</div>


## `SystemXsiApplicationIdGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemXsiApplicationIdGetListRequest()` Contains a table with column
headings: "Xsi Application Id", "Description".


**Attributes:**

|Name                     |Type                        |Description                                                                 |
|-------------------------|----------------------------|----------------------------------------------------------------------------|
|xsi_application_id_table |List(xsiApplicationIdTable) |xsiApplicationIdTable - *Table* array of xsiApplicationIdTable named tuples |
</div>


## `SystemXsiApplicationIdParameterGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemXsiApplictionIdParameterGetRequest()`.

Contains the Xsi application id system parameters.

**Attributes:**

|Name                      |Type |Description            |
|--------------------------|-----|-----------------------|
|screen_xsi_application_id |bool |screenXsiApplicationId |
</div>


## `SystemXsiPolicyProfileGetAssignedServiceProviderListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemXsiPolicyProfileUsageGetListRequest()`.

Contains a table with column headings: "Organization ID", "Organization Name",
"Organization Type" and "Reseller Id".

**Attributes:**

|Name     |Type          |Description                                     |
|---------|--------------|------------------------------------------------|
|sp_table |List(spTable) |spTable - *Table* array of spTable named tuples |
</div>


## `SystemXsiPolicyProfileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemXsiPolicyProfileGetListRequest()` Contains a table with column
headings: "Name", "Level", "Description", "Default".


**Attributes:**

|Name                     |Type                        |Description                                                                 |
|-------------------------|----------------------------|----------------------------------------------------------------------------|
|xsi_policy_profile_table |List(xsiPolicyProfileTable) |xsiPolicyProfileTable - *Table* array of xsiPolicyProfileTable named tuples |
</div>


## `SystemXsiPolicyProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemXsiPolicyProfileGetRequest()`.

The response contains the Xsi policy profile.

**Attributes:**

|Name                    |Type |Description            |
|------------------------|-----|-----------------------|
|description             |str  |description *Optional* |
|max_target_subscription |int  |maxTargetSubscription  |
|default                 |bool |default                |
</div>


## `SystemZoneCallingRestrictionsZoneGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemZoneCallingRestrictionsZoneGetListRequest()`.

Contains a table of all the zones in the system.  The column headings are "Zone Name"
, "Physical Location". Replaced by: `SystemZoneGetListResponse()`

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|zone_table |List(zoneTable) |zoneTable - *Table* array of zoneTable named tuples |
</div>


## `SystemZoneCallingZonePhysicalLocationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemZoneCallingZonePhysicalLocationGetRequest()`.


**Attributes:**

|Name              |Type|Description                 |
|------------------|----|----------------------------|
|physical_location |str |physicalLocation *Optional* |
</div>


## `SystemZoneGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemZoneGetListRequest()`.


**Attributes:**

|Name      |Type      |Description         |
|----------|----------|--------------------|
|zone_name |List[str] |zoneName *Optional* |
</div>


## `SystemZoneLocationBasedPhysicalLocationGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemZoneLocationBasedPhysicalLocationGetListRequest()`.


**Attributes:**

|Name              |Type      |Description                 |
|------------------|----------|----------------------------|
|physical_location |List[str] |physicalLocation *Optional* |
</div>


## `TutorialFlagGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `TutorialFlagGetRequest()`.


**Attributes:**

|Name            |Type |Description    |
|----------------|-----|---------------|
|enable_tutorial |bool |enableTutorial |
</div>


## `UserAccessDeviceDeviceActivationGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAccessDeviceDeviceActivationGetListRequest()`.

Contains a table of devices supporting device activation associated to a user.  The
column headings are: "Device Name", "Device Level", "Device SP", "Device Group",
"Endpoint Type", "Line Port", "Activation Status", "Activation Code", "Expiration
Time" and "MAC Address".

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|access_device_table |List(accessDeviceTable) |accessDeviceTable - *Table* array of accessDeviceTable named tuples |
</div>


## `UserAccessDeviceFileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAccessDeviceFileGetListRequest()`.

Contains a table of user modifiable Device Management files.  The column headings are:
"File Format", "Template URL".

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|device_files_table |List(deviceFilesTable) |deviceFilesTable - *Table* array of deviceFilesTable named tuples |
</div>


## `UserAccessDeviceFileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAccessDeviceFileGetRequest()`.


**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|template_url |str |templateUrl *Optional* |
</div>


## `UserAccessDeviceTagsGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAccessDeviceTagsGetRequest()`.

The response contains a table with columns: "Tag Name", and "Tag Value".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|device_tags_table |List(deviceTagsTable) |deviceTagsTable - *Table* array of deviceTagsTable named tuples |
</div>


## `UserAdviceOfChargeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAdviceOfChargeGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
|aoc_type  |str  |aocType    |
</div>


## `UserAlternateUserIdGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAlternateUserIdGetListRequest()`.

Contains a table of the main user id and the alternate user ids, the column headings
are: "User Id", "Description", "Alternate". The possible values for "Alternate" are
"true" and "false". The "Description" is only present for alternate user Ids.

**Attributes:**

|Name          |Type              |Description                                             |
|--------------|------------------|--------------------------------------------------------|
|user_id_table |List(userIdTable) |userIdTable - *Table* array of userIdTable named tuples |
</div>


## `UserAnnouncementFileGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAnnouncementFileGetAvailableListRequest()`.

The response contains a table with columns: "Name", "Media Type", "File Size",
"Repository Type", and "Announcement File External Id". The "Name" column contains the
name of the announcement file.  The "Media Type" column contains the media type of the
announcement file with the possible values: WMA - Windows Media Audio file WAV - A WAV
file 3GP - A 3GP file MOV - A MOV file using a H.263 or H.264 codec.  The "File Size"
is in Kilobytes.  The "Repository Type" column contains the type of repository for the
announcement file such as "User" or "Group" The "File Size" column contains the file
size in kB of the announcement file.  The "Announcement File External Id" column
contains the External Id of the announcement file.  The following columns are
populated in AS data mode only: "Announcement File External Id"

**Attributes:**

|Name               |Type                    |Description                                                         |
|-------------------|------------------------|--------------------------------------------------------------------|
|announcement_table |List(announcementTable) |announcementTable - *Table* array of announcementTable named tuples |
</div>


## `UserAnnouncementFileGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAnnouncementFileGetListRequest()`.

When requested, the response contains a table with columns: "Name", "Media Type",
"File Size", "Announcement File External Id". The "Name" column contains the name of
the announcement file.  The "Media Type" column contains the media type of the
announcement file with the possible values: WMA - Windows Media Audio file WAV - A WAV
file 3GP - A 3GP file MOV - A MOV file using a H.263 or H.264 codec.  The "File Size"
column contains the file size in kB of the announcement file.  The "Announcement File
External Id" column contains the external ID of the announcement file.  The following
columns are populated in AS data mode only: "Announcement File External Id"

The response also contains the current total file size (KB) for the user across all
media types and the maximum total file size (MB) allowed for the user.

**Attributes:**

|Name               |Type                    |Description                                                                    |
|-------------------|------------------------|-------------------------------------------------------------------------------|
|announcement_table |List(announcementTable) |announcementTable - *Table* array of announcementTable named tuples *Optional* |
|total_file_size    |int                     |totalFileSize                                                                  |
|max_file_size      |int                     |maxFileSize                                                                    |
</div>


## `UserAnnouncementFileGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAnnouncementFileGetPagedSortedListRequest()`.

The response contains a table with columns: "Name", "Media Type", "File Size", and
"Announcement File External Id". The "Name" column contains the name of the
announcement file.  The "Media Type" column contains the media type of the
announcement.  File with the possible values: WMA - Windows Media Audio file WAV - A
WAV file 3GP - A 3GP file MOV - A MOV file using a H.263 or H.264 codec.  The "File
Size" column contains the file size (KB) of the announcement file.

**Attributes:**

|Name               |Type                    |Description                                                                    |
|-------------------|------------------------|-------------------------------------------------------------------------------|
|announcement_table |List(announcementTable) |announcementTable - *Table* array of announcementTable named tuples *Optional* |
</div>


## `UserAnnouncementFileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAnnouncementFileGetRequest()`.

The response contains the file size (KB), uploaded timestamp, description and usage
for an announcement file in the user announcement repository.  The usage table has
columns "Service Name", "Criteria Name" The "Service Name"" values correspond to
string values of the UserService data types.  With the exception of the string "Voice
Portal" which is returned when the announcement is being used by Voice Portal
Personalized Name.  For Call Center and Route Point users the "Instance Name" column
contains the instance id and when the announcement is being used by a DNIS, "Intance
Name" column contans the instance id and the DNIS id.  For Auto Attendants with
submenus and the announcement is used by a submenu the "Instance Name" column will
contain the submenu name Replaced by: `UserAnnouncementFileGetResponse22()`.

**Attributes:**

|Name          |Type             |Description                                           |
|--------------|-----------------|------------------------------------------------------|
|description   |str              |description                                           |
|filesize      |int              |filesize                                              |
|last_uploaded |str              |lastUploaded                                          |
|usage_table   |List(usageTable) |usageTable - *Table* array of usageTable named tuples |
</div>


## `UserAnnouncementRepositoryGetSettingsResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAnnouncementRepositoryGetSettingsRequest()`.

The response contains the current total file size (KB) for the user across all media
types and the maximum total file size (MB) allowed for the user.  It also indicates
the maximum file size for individual audio and video files.

**Attributes:**

|Name                |Type|Description      |
|--------------------|----|-----------------|
|total_file_size     |int |totalFileSize    |
|max_audio_file_size |int |maxAudioFileSize |
|max_video_file_size |int |maxVideoFileSize |
|max_file_size       |int |maxFileSize      |
</div>


## `UserAnonymousCallRejectionGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAnonymousCallRejectionGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserAuthenticationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserAuthenticationGetRequest()`.


**Attributes:**

|Name      |Type|Description         |
|----------|----|--------------------|
|user_name |str |userName *Optional* |
</div>


## `UserAutomaticCallbackGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAutomaticCallbackGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserAutomaticCollectCallGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserAutomaticCollectCallGetRequest()`.

Returns user Automatic Collect Call service settings.

**Attributes:**

|Name                          |Type |Description                |
|------------------------------|-----|---------------------------|
|enable_automatic_collect_call |bool |enableAutomaticCollectCall |
</div>


## `UserAutomaticHoldRetrieveGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAutomaticHoldRetrieveGetRequest()`.


**Attributes:**

|Name                 |Type |Description        |
|---------------------|-----|-------------------|
|is_active            |bool |isActive           |
|recall_timer_seconds |int  |recallTimerSeconds |
</div>


## `UserBargeInExemptGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserBargeInExemptGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserBroadWorksAnywhereGetAvailablePortalListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserBroadWorksAnywhereGetAvailablePortalListRequest()`.

Contains a table with column headings: "Portal ID", "Phone Number", "Extension",
"Language". Replaced by `UserBroadWorksAnywhereGetAvailablePortalListResponse21sp1()`

**Attributes:**

|Name         |Type              |Description                                             |
|-------------|------------------|--------------------------------------------------------|
|portal_table |List(portalTable) |portalTable - *Table* array of portalTable named tuples |
</div>


## `UserBroadWorksAnywhereGetAvailablePortalListResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserBroadWorksAnywhereGetAvailablePortalListRequest21sp1()`.

Contains a table with column headings: "Portal ID", "Portal Name", "Phone Number",
"Extension", "Language".

**Attributes:**

|Name         |Type              |Description                                             |
|-------------|------------------|--------------------------------------------------------|
|portal_table |List(portalTable) |portalTable - *Table* array of portalTable named tuples |
</div>


## `UserBroadWorksAnywhereGetPhoneNumberPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserBroadWorksAnywhereGetPhoneNumberPagedSortedListRequest()`.

The phoneNumberTable contains columns: "Phone Number", "Description", "Activated"

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|phone_number_table |List(phoneNumberTable) |phoneNumberTable - *Table* array of phoneNumberTable named tuples |
</div>


## `UserBroadWorksAnywhereGetPhoneNumberResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserBroadWorksAnywhereGetPhoneNumberRequest()`.

The criteria table's column headings are: "Is Active", "Criteria Name", "Time
Schedule", "Calls From", "Blacklisted", "Holiday Schedule", "Calls To Type", "Calls To
Number" and "Calls To Extension". The following columns are only returned in AS data
mode: "Calls To Type", "Calls To Number" and "Calls To Extension" The possible values
for the "Calls To Type" column are the following or a combination of them separated by
comma: - Primary - Alternate X (where x is a number between 1 and 10) - Mobility The
possible values for the "Calls To Number" column are the following or a combination of
them separated by comma: - The value of the phone number for the corresponding Calls
To Type, when the number is available.  i.e.  Alternate 1 may have extension, but no
number.  - When no number is available a blank space is provided instead.  The
possible values for the "Calls To Extension" column are the following or a
caombination of them separated by comma: - The value of the extension for the
corresponding Calls To Type, when the extension is available.  i.e.  Primary may have
number, but no extension.  - For Mobility Calls To Type, this is always blank.  - When
no exension is available a blank space is provided instead.

**Attributes:**

|Name                         |Type                |Description                                                 |
|-----------------------------|--------------------|------------------------------------------------------------|
|description                  |str                 |description *Optional*                                      |
|outbound_alternate_number    |str                 |outboundAlternateNumber *Optional*                          |
|is_active                    |bool                |isActive                                                    |
|broadworks_call_control      |bool                |broadworksCallControl                                       |
|use_diversion_inhibitor      |bool                |useDiversionInhibitor                                       |
|answer_confirmation_required |bool                |answerConfirmationRequired                                  |
|criteria_table               |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserBroadWorksAnywhereGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserBroadWorksAnywhereGetRequest()`.

The phoneNumberTable contains columns: "Phone Number", "Description" Replaced by:
`UserBroadWorksAnywhereGetResponse16sp2()`

**Attributes:**

|Name                                        |Type                   |Description                                                       |
|--------------------------------------------|-----------------------|------------------------------------------------------------------|
|alert_all_locations_for_click_to_dial_calls |bool                   |alertAllLocationsForClickToDialCalls                              |
|phone_number_table                          |List(phoneNumberTable) |phoneNumberTable - *Table* array of phoneNumberTable named tuples |
</div>


## `UserBroadWorksAnywhereGetResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserBroadWorksAnywhereGetRequest16sp2()`.

The phoneNumberTable contains columns: "Phone Number", "Description"

**Attributes:**

|Name                                        |Type                   |Description                                                       |
|--------------------------------------------|-----------------------|------------------------------------------------------------------|
|alert_all_locations_for_click_to_dial_calls |bool                   |alertAllLocationsForClickToDialCalls                              |
|alert_all_locations_for_group_paging_calls  |bool                   |alertAllLocationsForGroupPagingCalls                              |
|phone_number_table                          |List(phoneNumberTable) |phoneNumberTable - *Table* array of phoneNumberTable named tuples |
</div>


## `UserBroadWorksCommunicatorGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserBroadWorksCommunicatorGetRequest()`.


**Attributes:**

|Name                     |Type|Description                       |
|-------------------------|----|----------------------------------|
|configuration_server_url |str |configurationServerURL *Optional* |
</div>


## `UserBroadWorksMobilityGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `UserBroadWorksMobilityGetRequest()`.


**Attributes:**

|Name                        |Type |Description                  |
|----------------------------|-----|-----------------------------|
|is_active                   |bool |isActive                     |
|phones_to_ring              |str  |phonesToRing                 |
|mobile_phone_number         |str  |mobilePhoneNumber *Optional* |
|alert_click_to_dial_calls   |bool |alertClickToDialCalls        |
|alert_group_paging_calls    |bool |alertGroupPagingCalls        |
|enable_diversion_inhibitor  |bool |enableDiversionInhibitor     |
|require_answer_confirmation |bool |requireAnswerConfirmation    |
|broadworks_call_control     |bool |broadworksCallControl        |
|use_setting_level           |str  |useSettingLevel              |
|deny_call_originations      |bool |denyCallOriginations         |
|deny_call_terminations      |bool |denyCallTerminations         |
</div>


## `UserBroadWorksMobilityGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `UserBroadWorksMobilityGetRequest21sp1()`.

Columns for the profileIdentityMobileNumberAlerted table are as follows: "Mobile
Number", "Country Code", "National Prefix". Columns for the mobileIdentity table are
as follows: "Mobile Number", "Description", "Country Code", "National Prefix", "Is
Primary", "Enable Alerting".

**Attributes:**

|Name                                            |Type                                          |Description                                                                                                     |
|------------------------------------------------|----------------------------------------------|----------------------------------------------------------------------------------------------------------------|
|is_active                                       |bool                                          |isActive                                                                                                        |
|use_mobile_identity_call_anchoring              |bool                                          |useMobileIdentityCallAnchoring                                                                                  |
|prevent_calls_to_own_mobiles                    |bool                                          |preventCallsToOwnMobiles                                                                                        |
|profile_identity_devices_to_ring                |str                                           |profileIdentityDevicesToRing                                                                                    |
|profile_identity_include_shared_call_appearance |bool                                          |profileIdentityIncludeSharedCallAppearance                                                                      |
|profile_identity_include_broadworks_anywhere    |bool                                          |profileIdentityIncludeBroadworksAnywhere                                                                        |
|profile_identity_include_executive_assistant    |bool                                          |profileIdentityIncludeExecutiveAssistant                                                                        |
|profile_identity_mobile_number_alerted_table    |List(profileIdentityMobileNumberAlertedTable) |profileIdentityMobileNumberAlertedTable - *Table* array of profileIdentityMobileNumberAlertedTable named tuples |
|mobile_identity_table                           |List(mobileIdentityTable)                     |mobileIdentityTable - *Table* array of mobileIdentityTable named tuples                                         |
</div>


## `UserBroadWorksReceptionistEnterpriseGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserBroadWorksReceptionistEnterpriseGetAvailableUserListRequest()`.

Returns a 12 column table with column headings: "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name", "Group Id", "Phone Number", "Extension",
"Mobile", "Email Address", "Department", "IMP Id", "Title", "Receptionist Note". The
Receptionist Note column is only populated, if the user sending the request is the
owner of the Receptionist Note and a Note exists.

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserBroadWorksReceptionistEnterpriseGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserBroadWorksReceptionistEnterpriseGetRequest()`.

Returns a 12 column table with column headings: "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name", "Group Id", "Phone Number", "Extension",
"Mobile", "Email Address", "Department", "IMP Id", "Title", "Receptionist Note". The
Receptionist Note column is only populated, if the user sending the request is the
owner of the Receptionist Note and a Note exists.

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|monitored_user_table |List(monitoredUserTable) |monitoredUserTable - *Table* array of monitoredUserTable named tuples |
</div>


## `UserBroadWorksReceptionistEnterpriseNoteGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserBroadWorksReceptionistEnterpriseNoteGetRequest()`.


**Attributes:**

|Name              |Type|Description                 |
|------------------|----|----------------------------|
|receptionist_note |str |receptionistNote *Optional* |
</div>


## `UserBroadWorksReceptionistOfficeGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserBroadWorksReceptionistOfficeGetAvailableUserListRequest()`.

Returns a 12 column table with column headings: "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name", "Group Id", "Phone Number", "Extension",
"Mobile", "Email Address", "Department", "IMP Id", "Title".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserBroadWorksReceptionistOfficeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserBroadWorksReceptionistOfficeGetRequest()`.

Returns a 11 column table with column headings: "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name", "Group Id", "Phone Number", "Extension",
"Mobile", "Email Address", "Department", "IMP Id", "Title".

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|monitored_user_table |List(monitoredUserTable) |monitoredUserTable - *Table* array of monitoredUserTable named tuples |
</div>


## `UserBroadWorksReceptionistSmallBusinessGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`UserBroadWorksReceptionistSmallBusinessGetAvailableUserListRequest()`.

Returns a 11 column table with column headings: "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name", "Group Id", "Phone Number", "Extension",
"Mobile", "Email Address", "Department", "IMP Id", "Title".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserBroadWorksReceptionistSmallBusinessGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserBroadWorksReceptionistSmallBusinessGetRequest()`.

Returns a 12 column table with column headings: "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name", "Group Id", "Phone Number", "Extension",
"Mobile", "Email Address", "Department", "IMP Id", "Title".

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|monitored_user_table |List(monitoredUserTable) |monitoredUserTable - *Table* array of monitoredUserTable named tuples |
</div>


## `UserBusyLampFieldGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `BusyLampFieldGetAvailableUserListRequest()`.

Returns a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address", "IMP Id".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserBusyLampFieldGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Replaced By `UserBusyLampFieldGetResponse16sp2()` Response to
`UserBusyLampFieldGetRequest()`.

The table has column headings: "User Id", "Last Name", "First Name", "Hiragana Last
Name", "Hiragana First Name".

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|list_uri             |str                      |listURI *Optional*                                                    |
|monitored_user_table |List(monitoredUserTable) |monitoredUserTable - *Table* array of monitoredUserTable named tuples |
</div>


## `UserBusyLampFieldGetResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserBusyLampFieldGetRequest16sp2()`.

The table has column headings: "User Id", "Last Name", "First Name", "Hiragana Last
Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address", "IMP Id".

**Attributes:**

|Name                          |Type                     |Description                                                           |
|------------------------------|-------------------------|----------------------------------------------------------------------|
|list_uri                      |str                      |listURI *Optional*                                                    |
|enable_call_park_notification |bool                     |enableCallParkNotification                                            |
|monitored_user_table          |List(monitoredUserTable) |monitoredUserTable - *Table* array of monitoredUserTable named tuples |
</div>


## `UserCallCenterAgentDetailsGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterAgentDetailsGetRequest()`.

Contains the detail information for a Call Center Agent.

**Attributes:**

|Name                             |Type |Description                  |
|---------------------------------|-----|-----------------------------|
|is_call_center_basic_assigned    |bool |isCallCenterBasicAssigned    |
|is_call_center_standard_assigned |bool |isCallCenterStandardAssigned |
|is_call_center_premium_assigned  |bool |isCallCenterPremiumAssigned  |
</div>


## `UserCallCenterAgentSignOutResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterAgentSignOutRequest()`.

It contains a list of call centers for which the agent is the last signed-in agent.
Contains a table with column headings: "Service User Id" and "Call Center Name".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|call_center_table |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `UserCallCenterCallDispositionCodeGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterCallDispositionCodeGetAvailableListRequest()`.

This list may include Group/Enterprise level codes in addition to the Call Center
level codes, depending on the call center disposition codes settings.  Only active
codes are included in the list.  Contains a table with column headings: "Code",
"Description" and "Level". Level column can be any of the values in the data type
CallDispositionCodeLevel.

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|disposition_codes_table |List(dispositionCodesTable) |dispositionCodesTable - *Table* array of dispositionCodesTable named tuples |
</div>


## `UserCallCenterEnhancedReportingReportTemplateParamInfoGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallCenterEnhancedReportingReportTemplateParamInfoGetRequest()`.


**Attributes:**

|Name                                    |Type |Description                                    |
|----------------------------------------|-----|-----------------------------------------------|
|is_realtime_report                      |bool |isRealtimeReport                               |
|require_agent_param                     |bool |requireAgentParam                              |
|require_call_center_param               |bool |requireCallCenterParam                         |
|require_call_center_dnis_param          |bool |requireCallCenterDnisParam                     |
|require_sampling_period_param           |bool |requireSamplingPeriodParam                     |
|call_completion_threshold_param         |str  |callCompletionThresholdParam *Optional*        |
|short_duration_threshold_param          |str  |shortDurationThresholdParam *Optional*         |
|service_level_threshold_param           |str  |serviceLevelThresholdParam *Optional*          |
|service_level_inclusions_param          |str  |serviceLevelInclusionsParam *Optional*         |
|service_level_objective_threshold_param |str  |serviceLevelObjectiveThresholdParam *Optional* |
|abandoned_call_threshold_param          |str  |abandonedCallThresholdParam *Optional*         |
|service_level_threshold_param_number    |int  |serviceLevelThresholdParamNumber *Optional*    |
|abandoned_call_threshold_param_number   |int  |abandonedCallThresholdParamNumber *Optional*   |
</div>


## `UserCallCenterGetAgentSupervisorListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterGetAgentSupervisorListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address", "IMP Id", "Location Code".

**Attributes:**

|Name             |Type                  |Description                                                     |
|-----------------|----------------------|----------------------------------------------------------------|
|supervisor_table |List(supervisorTable) |supervisorTable - *Table* array of supervisorTable named tuples |
</div>


## `UserCallCenterGetAvailableCallCenterListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterGetAvailableCallCenterListRequest()`.

Contains a table with column heading: "Service User Id".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|call_center_table |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `UserCallCenterGetAvailableCallCenterPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterGetAvailableCallCenterPagedSortedListRequest()`.

Contains a table with column heading: "Service User Id".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|call_center_table |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `UserCallCenterGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCentersLoginGetListRequest()`.

Indicates whether the agent is current available (logged in) to each call center in
the list.  Contains a table with column headings: "Service User Id", "Phone Number",
"Extension", "Available", "Logoff Allowed". ***** NOTE: Prior to release 14sp1, the
AppServer had a bug that caused it to emit column heading "Service User ID" with *****
the ID capitalized.  Beginning in release 14sp1, the appserver is compliant with the
schema and emits a ***** the column heading "Service User Id".

Replaced By: `UserCallCenterGetResponse()`

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserCallCenterGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterGetRequest()`.

Contains the user's ACD state Indicates whether the agent is current available (logged
in) to each call center in the list.  Contains a table with column headings: "Service
User Id", "Phone Number", "Extension", "Available", "Logoff Allowed".

**Attributes:**

|Name            |Type            |Description                                                    |
|----------------|----------------|---------------------------------------------------------------|
|agent_acd_state |str             |agentACDState *Optional*                                       |
|user_table      |List(userTable) |userTable - *Table* array of userTable named tuples *Optional* |
</div>


## `UserCallCenterGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterGetRequest16()`.

Contains the user's call center settings.  Indicates whether the agent is current
available (logged in) to each call center in the list.  Contains a table with column
headings: "Service User Id", "Phone Number", "Extension", "Available", "Logoff
Allowed", "Type", and "Priority".

**Attributes:**

|Name                                                        |Type                  |Description                                                     |
|------------------------------------------------------------|----------------------|----------------------------------------------------------------|
|agent_acd_state                                             |str                   |agentACDState *Optional*                                        |
|use_default_guard_timer                                     |bool                  |useDefaultGuardTimer                                            |
|enable_guard_timer                                          |bool                  |enableGuardTimer                                                |
|guard_timer_seconds                                         |int                   |guardTimerSeconds                                               |
|use_system_default_unavailable_settings                     |bool                  |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool                  |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_unavailable_on_personal_calls                         |bool                  |forceUnavailableOnPersonalCalls *Optional*                      |
|force_agent_unavailable_on_bounced_call_limit               |bool                  |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int                   |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|call_center_table                                           |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `UserCallCenterGetSupervisedAgentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterGetSupervisedAgentListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address", "IMP Id", "Location Code".

**Attributes:**

|Name             |Type                 |Description                                                   |
|-----------------|---------------------|--------------------------------------------------------------|
|agent_user_table |List(agentUserTable) |agentUserTable - *Table* array of agentUserTable named tuples |
</div>


## `UserCallCenterGetSupervisorCallCenterListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterGetSupervisorCallCenterListRequest()`.

Contains a table with column headings: "Service User Id", "Phone Number", "Extension",
"Type" and "Priority".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|call_center_table |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `UserCallCenterMonitoringGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallCenterMonitoringGetRequest()`.

Replaced by `UserCallCenterMonitoringGetResponse23()`

**Attributes:**

|Name                                     |Type |Description                        |
|-----------------------------------------|-----|-----------------------------------|
|play_tone_to_agent_for_silent_monitoring |bool |playToneToAgentForSilentMonitoring |
</div>


## `UserCallCenterMonitoringGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallCenterMonitoringGetRequest23()`.


**Attributes:**

|Name                                       |Type |Description                          |
|-------------------------------------------|-----|-------------------------------------|
|play_tone_to_agent_for_silent_monitoring   |bool |playToneToAgentForSilentMonitoring   |
|play_tone_to_agent_for_supervisor_coaching |bool |playToneToAgentForSupervisorCoaching |
</div>


## `UserCallForwardingAlwaysGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallForwardingAlwaysGetRequest()`.


**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|is_active               |bool |isActive                        |
|forward_to_phone_number |str  |forwardToPhoneNumber *Optional* |
|is_ring_splash_active   |bool |isRingSplashActive              |
</div>


## `UserCallForwardingAlwaysSecondaryGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallForwardingAlwaysSecondaryGetRequest()`.


**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|is_active               |bool |isActive                        |
|forward_to_phone_number |str  |forwardToPhoneNumber *Optional* |
|is_ring_splash_active   |bool |isRingSplashActive              |
</div>


## `UserCallForwardingBusyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallForwardingBusyGetRequest()`.


**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|is_active               |bool |isActive                        |
|forward_to_phone_number |str  |forwardToPhoneNumber *Optional* |
</div>


## `UserCallForwardingNoAnswerGetResponse13mp16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallForwardingNoAnswerGetRequest13mp16()`.


**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|is_active               |bool |isActive                        |
|forward_to_phone_number |str  |forwardToPhoneNumber *Optional* |
|number_of_rings         |int  |numberOfRings                   |
</div>


## `UserCallForwardingNotReachableGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallForwardingNotReachableGetRequest()`.


**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|is_active               |bool |isActive                        |
|forward_to_phone_number |str  |forwardToPhoneNumber *Optional* |
</div>


## `UserCallForwardingSelectiveGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallForwardingSelectiveGetRequest()`.

The criteria table's column headings are: "Is Active", "Criteria Name", "Time
Schedule", "Calls From" and "Forward To".

**Attributes:**

|Name                            |Type                |Description                                                 |
|--------------------------------|--------------------|------------------------------------------------------------|
|default_forward_to_phone_number |str                 |defaultForwardToPhoneNumber *Optional*                      |
|play_ring_reminder              |bool                |playRingReminder                                            |
|criteria_table                  |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserCallForwardingSelectiveGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallForwardingSelectiveGetRequest16()`.

The criteria table's column headings are: "Is Active", "Criteria Name", "Time
Schedule", "Calls From", "Forward To", "Blacklisted", "Holiday Schedule", "Calls To
Type", "Calls To Number" and "Calls To Extension". The following columns are only
returned in AS data mode: "Calls To Type", "Calls To Number" and "Calls To Extension"
The possible values for the "Calls To Type" column are the following or a combination
of them separated by comma: - Primary - Alternate X (where x is a number between 1 and
10) - Mobility The possible values for the "Calls To Number" column are the following
or a combination of them separated by comma: - The value of the phone number for the
corresponding Calls To Type, when the number is available.  i.e.  Alternate 1 may have
extension, but no number.  - When no number is available a blank space is provided
instead.  The possible values for the "Calls To Extension" column are the following or
a combination of them separated by comma: - The value of the extension for the
corresponding Calls To Type, when the extension is available.  i.e.  Primary may have
number, but no extension.  - For Mobility Calls To Type, this is always blank.  - When
no extension is available a blank space is provided instead.

**Attributes:**

|Name                            |Type                |Description                                                 |
|--------------------------------|--------------------|------------------------------------------------------------|
|is_active                       |bool                |isActive                                                    |
|default_forward_to_phone_number |str                 |defaultForwardToPhoneNumber *Optional*                      |
|play_ring_reminder              |bool                |playRingReminder                                            |
|criteria_table                  |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserCallMeNowGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallMeNowGetRequest()`.

The criteria table's column headings are: "Is Active", "Criteria Name", "Time
Schedule", "Call To", "Reject Call" and "Holiday Schedule".

**Attributes:**

|Name                |Type                |Description                                                 |
|--------------------|--------------------|------------------------------------------------------------|
|is_active           |bool                |isActive                                                    |
|answer_confirmation |str                 |answerConfirmation                                          |
|criteria_table      |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserCallNotifyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallNotifyGetRequest()`.

The criteria table's column headings are: "Is Active", "Criteria Name", "Time
Schedule", "Calls From", "Blacklisted" ,"Holiday Schedule", "Calls To Type", "Calls To
Number" and "Calls To Extension". The following columns are only returned in AS data
mode: "Calls To Type", "Calls To Number" and "Calls To Extension" The possible values
for the "Calls To Type" column are the following or a combination of them separated by
comma: - Primary - Alternate X (where x is a number between 1 and 10) - Mobility The
possible values for the "Calls To Number" column are the following or a combination of
them separated by comma: - The value of the phone number for the corresponding Calls
To Type, when the number is available.  i.e.  Alternate 1 may have extension, but no
number.  - When no number is available a blank space is provided instead.  The
possible values for the "Calls To Extension" column are the following or a combination
of them separated by comma: - The value of the extension for the corresponding Calls
To Type, when the extension is available.  i.e.  Primary may have number, but no
extension.  - For Mobility Calls To Type, this is always blank.  - When no extension
is available a blank space is provided instead.

**Attributes:**

|Name                      |Type                |Description                                                 |
|--------------------------|--------------------|------------------------------------------------------------|
|call_notify_email_address |str                 |callNotifyEmailAddress *Optional*                           |
|criteria_table            |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserCallParkGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallParkGetRequest()`.

Identifies which Call Park group the user belongs to and the list of users in the
group.  Contains a table with column headings: "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name". The users are in the table in the order
they will try to be parked on.

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|name       |str             |name *Optional*                                     |
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserCallPickupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallPickupGetRequest()`.

Identifies which Call Pickup group the user belongs to and the list of users in the
group.  Contains a table with column headings: "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name", "Department", "Phone Number",
"Extension", "Email Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|name       |str             |name *Optional*                                     |
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserCallPoliciesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallPoliciesGetRequest()`.


**Attributes:**

|Name                          |Type|Description                |
|------------------------------|----|---------------------------|
|redirected_calls_colp_privacy |str |redirectedCallsCOLPPrivacy |
</div>


## `UserCallPoliciesGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallPoliciesGetRequest17()`.

Replaced by: `UserCallPoliciesGetResponse19sp1()` in AS data mode

**Attributes:**

|Name                                    |Type|Description                        |
|----------------------------------------|----|-----------------------------------|
|redirected_calls_colp_privacy           |str |redirectedCallsCOLPPrivacy         |
|call_being_forwarded_response_call_type |str |callBeingForwardedResponseCallType |
</div>


## `UserCallPoliciesGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallPoliciesGetRequest19sp1()`.


**Attributes:**

|Name                                       |Type|Description                           |
|-------------------------------------------|----|--------------------------------------|
|redirected_calls_colp_privacy              |str |redirectedCallsCOLPPrivacy            |
|call_being_forwarded_response_call_type    |str |callBeingForwardedResponseCallType    |
|calling_line_identity_for_redirected_calls |str |callingLineIdentityForRedirectedCalls |
</div>


## `UserCallProcessingGetPolicyResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest14()`.


**Attributes:**

|Name                                       |Type |Description                          |
|-------------------------------------------|-----|-------------------------------------|
|use_user_setting                           |bool |useUserSetting                       |
|use_max_simultaneous_calls                 |bool |useMaxSimultaneousCalls              |
|max_simultaneous_calls                     |int  |maxSimultaneousCalls                 |
|use_max_simultaneous_video_calls           |bool |useMaxSimultaneousVideoCalls         |
|max_simultaneous_video_calls               |int  |maxSimultaneousVideoCalls            |
|use_max_call_time_for_answered_calls       |bool |useMaxCallTimeForAnsweredCalls       |
|max_call_time_for_answered_calls_minutes   |int  |maxCallTimeForAnsweredCallsMinutes   |
|use_max_call_time_for_unanswered_calls     |bool |useMaxCallTimeForUnansweredCalls     |
|max_call_time_for_unanswered_calls_minutes |int  |maxCallTimeForUnansweredCallsMinutes |
|media_policy_selection                     |str  |mediaPolicySelection                 |
|supported_media_set_name                   |str  |supportedMediaSetName *Optional*     |
</div>


## `UserCallProcessingGetPolicyResponse14sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest14sp1()`.

Replaced By: `UserCallProcessingGetPolicyResponse14sp7()`

**Attributes:**

|Name                                             |Type |Description                               |
|-------------------------------------------------|-----|------------------------------------------|
|use_user_setting                                 |bool |useUserSetting                            |
|use_max_simultaneous_calls                       |bool |useMaxSimultaneousCalls                   |
|max_simultaneous_calls                           |int  |maxSimultaneousCalls                      |
|use_max_simultaneous_video_calls                 |bool |useMaxSimultaneousVideoCalls              |
|max_simultaneous_video_calls                     |int  |maxSimultaneousVideoCalls                 |
|use_max_call_time_for_answered_calls             |bool |useMaxCallTimeForAnsweredCalls            |
|max_call_time_for_answered_calls_minutes         |int  |maxCallTimeForAnsweredCallsMinutes        |
|use_max_call_time_for_unanswered_calls           |bool |useMaxCallTimeForUnansweredCalls          |
|max_call_time_for_unanswered_calls_minutes       |int  |maxCallTimeForUnansweredCallsMinutes      |
|media_policy_selection                           |str  |mediaPolicySelection                      |
|supported_media_set_name                         |str  |supportedMediaSetName *Optional*          |
|use_max_concurrent_redirected_calls              |bool |useMaxConcurrentRedirectedCalls           |
|max_concurrent_redirected_calls                  |int  |maxConcurrentRedirectedCalls              |
|use_max_find_me_follow_me_depth                  |bool |useMaxFindMeFollowMeDepth                 |
|max_find_me_follow_me_depth                      |int  |maxFindMeFollowMeDepth                    |
|max_redirection_depth                            |int  |maxRedirectionDepth                       |
|use_max_concurrent_find_me_follow_me_invocations |bool |useMaxConcurrentFindMeFollowMeInvocations |
|max_concurrent_find_me_follow_me_invocations     |int  |maxConcurrentFindMeFollowMeInvocations    |
</div>


## `UserCallProcessingGetPolicyResponse14sp7`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest14sp7()`.

The useUserCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName) The
useUserMediaSetting attribute controls the Media settings (medisPolicySelection,
supportedMediaSetName) The useUserCallLimitsSetting attribute controls the Call Limits
setting (useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations)

**Attributes:**

|Name                                             |Type |Description                                 |
|-------------------------------------------------|-----|--------------------------------------------|
|use_user_clid_setting                            |bool |useUserCLIDSetting                          |
|use_user_media_setting                           |bool |useUserMediaSetting                         |
|use_user_call_limits_setting                     |bool |useUserCallLimitsSetting                    |
|use_max_simultaneous_calls                       |bool |useMaxSimultaneousCalls                     |
|max_simultaneous_calls                           |int  |maxSimultaneousCalls                        |
|use_max_simultaneous_video_calls                 |bool |useMaxSimultaneousVideoCalls                |
|max_simultaneous_video_calls                     |int  |maxSimultaneousVideoCalls                   |
|use_max_call_time_for_answered_calls             |bool |useMaxCallTimeForAnsweredCalls              |
|max_call_time_for_answered_calls_minutes         |int  |maxCallTimeForAnsweredCallsMinutes          |
|use_max_call_time_for_unanswered_calls           |bool |useMaxCallTimeForUnansweredCalls            |
|max_call_time_for_unanswered_calls_minutes       |int  |maxCallTimeForUnansweredCallsMinutes        |
|media_policy_selection                           |str  |mediaPolicySelection                        |
|supported_media_set_name                         |str  |supportedMediaSetName *Optional*            |
|use_max_concurrent_redirected_calls              |bool |useMaxConcurrentRedirectedCalls             |
|max_concurrent_redirected_calls                  |int  |maxConcurrentRedirectedCalls                |
|use_max_find_me_follow_me_depth                  |bool |useMaxFindMeFollowMeDepth                   |
|max_find_me_follow_me_depth                      |int  |maxFindMeFollowMeDepth                      |
|max_redirection_depth                            |int  |maxRedirectionDepth                         |
|use_max_concurrent_find_me_follow_me_invocations |bool |useMaxConcurrentFindMeFollowMeInvocations   |
|max_concurrent_find_me_follow_me_invocations     |int  |maxConcurrentFindMeFollowMeInvocations      |
|clid_policy                                      |str  |clidPolicy                                  |
|emergency_clid_policy                            |str  |emergencyClidPolicy                         |
|allow_alternate_numbers_for_redirecting_identity |bool |allowAlternateNumbersForRedirectingIdentity |
|use_group_name                                   |bool |useGroupName                                |
</div>


## `UserCallProcessingGetPolicyResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest16()`.

The useUserCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName) The
useUserMediaSetting attribute controls the Media settings (medisPolicySelection,
supportedMediaSetName) The useUserCallLimitsSetting attribute controls the Call Limits
setting (useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations)

**Attributes:**

|Name                                             |Type |Description                                 |
|-------------------------------------------------|-----|--------------------------------------------|
|use_user_clid_setting                            |bool |useUserCLIDSetting                          |
|use_user_media_setting                           |bool |useUserMediaSetting                         |
|use_user_call_limits_setting                     |bool |useUserCallLimitsSetting                    |
|use_max_simultaneous_calls                       |bool |useMaxSimultaneousCalls                     |
|max_simultaneous_calls                           |int  |maxSimultaneousCalls                        |
|use_max_simultaneous_video_calls                 |bool |useMaxSimultaneousVideoCalls                |
|max_simultaneous_video_calls                     |int  |maxSimultaneousVideoCalls                   |
|use_max_call_time_for_answered_calls             |bool |useMaxCallTimeForAnsweredCalls              |
|max_call_time_for_answered_calls_minutes         |int  |maxCallTimeForAnsweredCallsMinutes          |
|use_max_call_time_for_unanswered_calls           |bool |useMaxCallTimeForUnansweredCalls            |
|max_call_time_for_unanswered_calls_minutes       |int  |maxCallTimeForUnansweredCallsMinutes        |
|media_policy_selection                           |str  |mediaPolicySelection                        |
|supported_media_set_name                         |str  |supportedMediaSetName *Optional*            |
|use_max_concurrent_redirected_calls              |bool |useMaxConcurrentRedirectedCalls             |
|max_concurrent_redirected_calls                  |int  |maxConcurrentRedirectedCalls                |
|use_max_find_me_follow_me_depth                  |bool |useMaxFindMeFollowMeDepth                   |
|max_find_me_follow_me_depth                      |int  |maxFindMeFollowMeDepth                      |
|max_redirection_depth                            |int  |maxRedirectionDepth                         |
|use_max_concurrent_find_me_follow_me_invocations |bool |useMaxConcurrentFindMeFollowMeInvocations   |
|max_concurrent_find_me_follow_me_invocations     |int  |maxConcurrentFindMeFollowMeInvocations      |
|clid_policy                                      |str  |clidPolicy                                  |
|emergency_clid_policy                            |str  |emergencyClidPolicy                         |
|allow_alternate_numbers_for_redirecting_identity |bool |allowAlternateNumbersForRedirectingIdentity |
|use_group_name                                   |bool |useGroupName                                |
</div>


## `UserCallProcessingGetPolicyResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest16sp2()`.

The useUserCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName) The
useUserMediaSetting attribute controls the Media settings (medisPolicySelection,
supportedMediaSetName) The useUserCallLimitsSetting attribute controls the Call Limits
setting (useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useUserDCLIDSetting controls the Dialable Caller ID settings (enableDialableCallerID)
Replaced by: `UserCallProcessingGetPolicyResponse17sp4()`

**Attributes:**

|Name                                             |Type |Description                                 |
|-------------------------------------------------|-----|--------------------------------------------|
|use_user_clid_setting                            |bool |useUserCLIDSetting                          |
|use_user_media_setting                           |bool |useUserMediaSetting                         |
|use_user_call_limits_setting                     |bool |useUserCallLimitsSetting                    |
|use_user_dclid_setting                           |bool |useUserDCLIDSetting                         |
|use_max_simultaneous_calls                       |bool |useMaxSimultaneousCalls                     |
|max_simultaneous_calls                           |int  |maxSimultaneousCalls                        |
|use_max_simultaneous_video_calls                 |bool |useMaxSimultaneousVideoCalls                |
|max_simultaneous_video_calls                     |int  |maxSimultaneousVideoCalls                   |
|use_max_call_time_for_answered_calls             |bool |useMaxCallTimeForAnsweredCalls              |
|max_call_time_for_answered_calls_minutes         |int  |maxCallTimeForAnsweredCallsMinutes          |
|use_max_call_time_for_unanswered_calls           |bool |useMaxCallTimeForUnansweredCalls            |
|max_call_time_for_unanswered_calls_minutes       |int  |maxCallTimeForUnansweredCallsMinutes        |
|media_policy_selection                           |str  |mediaPolicySelection                        |
|supported_media_set_name                         |str  |supportedMediaSetName *Optional*            |
|use_max_concurrent_redirected_calls              |bool |useMaxConcurrentRedirectedCalls             |
|max_concurrent_redirected_calls                  |int  |maxConcurrentRedirectedCalls                |
|use_max_find_me_follow_me_depth                  |bool |useMaxFindMeFollowMeDepth                   |
|max_find_me_follow_me_depth                      |int  |maxFindMeFollowMeDepth                      |
|max_redirection_depth                            |int  |maxRedirectionDepth                         |
|use_max_concurrent_find_me_follow_me_invocations |bool |useMaxConcurrentFindMeFollowMeInvocations   |
|max_concurrent_find_me_follow_me_invocations     |int  |maxConcurrentFindMeFollowMeInvocations      |
|clid_policy                                      |str  |clidPolicy                                  |
|emergency_clid_policy                            |str  |emergencyClidPolicy                         |
|allow_alternate_numbers_for_redirecting_identity |bool |allowAlternateNumbersForRedirectingIdentity |
|use_group_name                                   |bool |useGroupName                                |
|enable_dialable_caller_id                        |bool |enableDialableCallerID                      |
</div>


## `UserCallProcessingGetPolicyResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest17()`.

The useUserCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName) The
useUserMediaSetting attribute controls the Media settings (medisPolicySelection,
supportedMediaSetName) The useUserCallLimitsSetting attribute controls the Call Limits
setting (useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations)

**Attributes:**

|Name                                             |Type |Description                                 |
|-------------------------------------------------|-----|--------------------------------------------|
|use_user_clid_setting                            |bool |useUserCLIDSetting                          |
|use_user_media_setting                           |bool |useUserMediaSetting                         |
|use_user_call_limits_setting                     |bool |useUserCallLimitsSetting                    |
|use_max_simultaneous_calls                       |bool |useMaxSimultaneousCalls                     |
|max_simultaneous_calls                           |int  |maxSimultaneousCalls                        |
|use_max_simultaneous_video_calls                 |bool |useMaxSimultaneousVideoCalls                |
|max_simultaneous_video_calls                     |int  |maxSimultaneousVideoCalls                   |
|use_max_call_time_for_answered_calls             |bool |useMaxCallTimeForAnsweredCalls              |
|max_call_time_for_answered_calls_minutes         |int  |maxCallTimeForAnsweredCallsMinutes          |
|use_max_call_time_for_unanswered_calls           |bool |useMaxCallTimeForUnansweredCalls            |
|max_call_time_for_unanswered_calls_minutes       |int  |maxCallTimeForUnansweredCallsMinutes        |
|media_policy_selection                           |str  |mediaPolicySelection                        |
|supported_media_set_name                         |str  |supportedMediaSetName *Optional*            |
|use_max_concurrent_redirected_calls              |bool |useMaxConcurrentRedirectedCalls             |
|max_concurrent_redirected_calls                  |int  |maxConcurrentRedirectedCalls                |
|use_max_find_me_follow_me_depth                  |bool |useMaxFindMeFollowMeDepth                   |
|max_find_me_follow_me_depth                      |int  |maxFindMeFollowMeDepth                      |
|max_redirection_depth                            |int  |maxRedirectionDepth                         |
|use_max_concurrent_find_me_follow_me_invocations |bool |useMaxConcurrentFindMeFollowMeInvocations   |
|max_concurrent_find_me_follow_me_invocations     |int  |maxConcurrentFindMeFollowMeInvocations      |
|clid_policy                                      |str  |clidPolicy                                  |
|emergency_clid_policy                            |str  |emergencyClidPolicy                         |
|allow_alternate_numbers_for_redirecting_identity |bool |allowAlternateNumbersForRedirectingIdentity |
|use_group_name                                   |bool |useGroupName                                |
|block_calling_name_for_external_calls            |bool |blockCallingNameForExternalCalls            |
</div>


## `UserCallProcessingGetPolicyResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest17sp3()`.

The useUserCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName) The
useUserMediaSetting attribute controls the Media settings (medisPolicySelection,
supportedMediaSetName) The useUserCallLimitsSetting attribute controls the Call Limits
setting (useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useUserDCLIDSetting controls the Dialable Caller ID settings (enableDialableCallerID)
The following elements are only used in AS data mode: useUserDCLIDSetting
enableDialableCallerID Replaced by: UserCallProcessingGetPolicyResponse17Sp4

**Attributes:**

|Name                                             |Type |Description                                 |
|-------------------------------------------------|-----|--------------------------------------------|
|use_user_clid_setting                            |bool |useUserCLIDSetting                          |
|use_user_media_setting                           |bool |useUserMediaSetting                         |
|use_user_call_limits_setting                     |bool |useUserCallLimitsSetting                    |
|use_user_dclid_setting                           |bool |useUserDCLIDSetting                         |
|use_max_simultaneous_calls                       |bool |useMaxSimultaneousCalls                     |
|max_simultaneous_calls                           |int  |maxSimultaneousCalls                        |
|use_max_simultaneous_video_calls                 |bool |useMaxSimultaneousVideoCalls                |
|max_simultaneous_video_calls                     |int  |maxSimultaneousVideoCalls                   |
|use_max_call_time_for_answered_calls             |bool |useMaxCallTimeForAnsweredCalls              |
|max_call_time_for_answered_calls_minutes         |int  |maxCallTimeForAnsweredCallsMinutes          |
|use_max_call_time_for_unanswered_calls           |bool |useMaxCallTimeForUnansweredCalls            |
|max_call_time_for_unanswered_calls_minutes       |int  |maxCallTimeForUnansweredCallsMinutes        |
|media_policy_selection                           |str  |mediaPolicySelection                        |
|supported_media_set_name                         |str  |supportedMediaSetName *Optional*            |
|use_max_concurrent_redirected_calls              |bool |useMaxConcurrentRedirectedCalls             |
|max_concurrent_redirected_calls                  |int  |maxConcurrentRedirectedCalls                |
|use_max_find_me_follow_me_depth                  |bool |useMaxFindMeFollowMeDepth                   |
|max_find_me_follow_me_depth                      |int  |maxFindMeFollowMeDepth                      |
|max_redirection_depth                            |int  |maxRedirectionDepth                         |
|use_max_concurrent_find_me_follow_me_invocations |bool |useMaxConcurrentFindMeFollowMeInvocations   |
|max_concurrent_find_me_follow_me_invocations     |int  |maxConcurrentFindMeFollowMeInvocations      |
|clid_policy                                      |str  |clidPolicy                                  |
|emergency_clid_policy                            |str  |emergencyClidPolicy                         |
|allow_alternate_numbers_for_redirecting_identity |bool |allowAlternateNumbersForRedirectingIdentity |
|use_group_name                                   |bool |useGroupName                                |
|block_calling_name_for_external_calls            |bool |blockCallingNameForExternalCalls            |
|enable_dialable_caller_id                        |bool |enableDialableCallerID                      |
</div>


## `UserCallProcessingGetPolicyResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest17sp4()`.

The useUserCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowConfigurableCLIDForRedirectingIdentity) The useUserMediaSetting attribute
controls the Media settings (medisPolicySelection, supportedMediaSetName) The
useUserCallLimitsSetting attribute controls the Call Limits setting
(useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useUserDCLIDSetting controls the Dialable Caller ID settings (enableDialableCallerID)
The following elements are only used in AS data mode: useUserDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity Replaced by:
`UserCallProcessingGetPolicyResponse18()`

**Attributes:**

|Name                                             |Type |Description                                 |
|-------------------------------------------------|-----|--------------------------------------------|
|use_user_clid_setting                            |bool |useUserCLIDSetting                          |
|use_user_media_setting                           |bool |useUserMediaSetting                         |
|use_user_call_limits_setting                     |bool |useUserCallLimitsSetting                    |
|use_user_dclid_setting                           |bool |useUserDCLIDSetting                         |
|use_max_simultaneous_calls                       |bool |useMaxSimultaneousCalls                     |
|max_simultaneous_calls                           |int  |maxSimultaneousCalls                        |
|use_max_simultaneous_video_calls                 |bool |useMaxSimultaneousVideoCalls                |
|max_simultaneous_video_calls                     |int  |maxSimultaneousVideoCalls                   |
|use_max_call_time_for_answered_calls             |bool |useMaxCallTimeForAnsweredCalls              |
|max_call_time_for_answered_calls_minutes         |int  |maxCallTimeForAnsweredCallsMinutes          |
|use_max_call_time_for_unanswered_calls           |bool |useMaxCallTimeForUnansweredCalls            |
|max_call_time_for_unanswered_calls_minutes       |int  |maxCallTimeForUnansweredCallsMinutes        |
|media_policy_selection                           |str  |mediaPolicySelection                        |
|supported_media_set_name                         |str  |supportedMediaSetName *Optional*            |
|use_max_concurrent_redirected_calls              |bool |useMaxConcurrentRedirectedCalls             |
|max_concurrent_redirected_calls                  |int  |maxConcurrentRedirectedCalls                |
|use_max_find_me_follow_me_depth                  |bool |useMaxFindMeFollowMeDepth                   |
|max_find_me_follow_me_depth                      |int  |maxFindMeFollowMeDepth                      |
|max_redirection_depth                            |int  |maxRedirectionDepth                         |
|use_max_concurrent_find_me_follow_me_invocations |bool |useMaxConcurrentFindMeFollowMeInvocations   |
|max_concurrent_find_me_follow_me_invocations     |int  |maxConcurrentFindMeFollowMeInvocations      |
|clid_policy                                      |str  |clidPolicy                                  |
|emergency_clid_policy                            |str  |emergencyClidPolicy                         |
|allow_alternate_numbers_for_redirecting_identity |bool |allowAlternateNumbersForRedirectingIdentity |
|use_group_name                                   |bool |useGroupName                                |
|block_calling_name_for_external_calls            |bool |blockCallingNameForExternalCalls            |
|enable_dialable_caller_id                        |bool |enableDialableCallerID                      |
|allow_configurable_clid_for_redirecting_identity |bool |allowConfigurableCLIDForRedirectingIdentity |
</div>


## `UserCallProcessingGetPolicyResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest18()`.

The useUserCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowConfigurableCLIDForRedirectingIdentity, allowDepartmentCLIDNameOverride) The
useUserMediaSetting attribute controls the Media settings (medisPolicySelection,
supportedMediaSetName) The useUserCallLimitsSetting attribute controls the Call Limits
setting (useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
following elements are only used in AS data mode: useUserDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
allowDepartmentCLIDNameOverride Replaced by:
`UserCallProcessingGetPolicyResponse19sp1()`

**Attributes:**

|Name                                             |Type |Description                                 |
|-------------------------------------------------|-----|--------------------------------------------|
|use_user_clid_setting                            |bool |useUserCLIDSetting                          |
|use_user_media_setting                           |bool |useUserMediaSetting                         |
|use_user_call_limits_setting                     |bool |useUserCallLimitsSetting                    |
|use_user_dclid_setting                           |bool |useUserDCLIDSetting                         |
|use_max_simultaneous_calls                       |bool |useMaxSimultaneousCalls                     |
|max_simultaneous_calls                           |int  |maxSimultaneousCalls                        |
|use_max_simultaneous_video_calls                 |bool |useMaxSimultaneousVideoCalls                |
|max_simultaneous_video_calls                     |int  |maxSimultaneousVideoCalls                   |
|use_max_call_time_for_answered_calls             |bool |useMaxCallTimeForAnsweredCalls              |
|max_call_time_for_answered_calls_minutes         |int  |maxCallTimeForAnsweredCallsMinutes          |
|use_max_call_time_for_unanswered_calls           |bool |useMaxCallTimeForUnansweredCalls            |
|max_call_time_for_unanswered_calls_minutes       |int  |maxCallTimeForUnansweredCallsMinutes        |
|media_policy_selection                           |str  |mediaPolicySelection                        |
|supported_media_set_name                         |str  |supportedMediaSetName *Optional*            |
|use_max_concurrent_redirected_calls              |bool |useMaxConcurrentRedirectedCalls             |
|max_concurrent_redirected_calls                  |int  |maxConcurrentRedirectedCalls                |
|use_max_find_me_follow_me_depth                  |bool |useMaxFindMeFollowMeDepth                   |
|max_find_me_follow_me_depth                      |int  |maxFindMeFollowMeDepth                      |
|max_redirection_depth                            |int  |maxRedirectionDepth                         |
|use_max_concurrent_find_me_follow_me_invocations |bool |useMaxConcurrentFindMeFollowMeInvocations   |
|max_concurrent_find_me_follow_me_invocations     |int  |maxConcurrentFindMeFollowMeInvocations      |
|clid_policy                                      |str  |clidPolicy                                  |
|emergency_clid_policy                            |str  |emergencyClidPolicy                         |
|allow_alternate_numbers_for_redirecting_identity |bool |allowAlternateNumbersForRedirectingIdentity |
|use_group_name                                   |bool |useGroupName                                |
|block_calling_name_for_external_calls            |bool |blockCallingNameForExternalCalls            |
|enable_dialable_caller_id                        |bool |enableDialableCallerID                      |
|allow_configurable_clid_for_redirecting_identity |bool |allowConfigurableCLIDForRedirectingIdentity |
|allow_department_clid_name_override              |bool |allowDepartmentCLIDNameOverride             |
</div>


## `UserCallProcessingGetPolicyResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest19sp1()`.

The useUserCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowConfigurableCLIDForRedirectingIdentity, allowDepartmentCLIDNameOverride) The
useUserMediaSetting attribute controls the Media settings (medisPolicySelection,
supportedMediaSetName) The useUserCallLimitsSetting attribute controls the Call Limits
setting (useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
following elements are only used in AS data mode : useUserDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
allowDepartmentCLIDNameOverride Replaced by:
`UserCallProcessingGetPolicyResponse21sp1()`

**Attributes:**

|Name                                             |Type |Description                                 |
|-------------------------------------------------|-----|--------------------------------------------|
|use_user_clid_setting                            |bool |useUserCLIDSetting                          |
|use_user_media_setting                           |bool |useUserMediaSetting                         |
|use_user_call_limits_setting                     |bool |useUserCallLimitsSetting                    |
|use_user_dclid_setting                           |bool |useUserDCLIDSetting                         |
|use_max_simultaneous_calls                       |bool |useMaxSimultaneousCalls                     |
|max_simultaneous_calls                           |int  |maxSimultaneousCalls                        |
|use_max_simultaneous_video_calls                 |bool |useMaxSimultaneousVideoCalls                |
|max_simultaneous_video_calls                     |int  |maxSimultaneousVideoCalls                   |
|use_max_call_time_for_answered_calls             |bool |useMaxCallTimeForAnsweredCalls              |
|max_call_time_for_answered_calls_minutes         |int  |maxCallTimeForAnsweredCallsMinutes          |
|use_max_call_time_for_unanswered_calls           |bool |useMaxCallTimeForUnansweredCalls            |
|max_call_time_for_unanswered_calls_minutes       |int  |maxCallTimeForUnansweredCallsMinutes        |
|media_policy_selection                           |str  |mediaPolicySelection                        |
|supported_media_set_name                         |str  |supportedMediaSetName *Optional*            |
|use_max_concurrent_redirected_calls              |bool |useMaxConcurrentRedirectedCalls             |
|max_concurrent_redirected_calls                  |int  |maxConcurrentRedirectedCalls                |
|use_max_find_me_follow_me_depth                  |bool |useMaxFindMeFollowMeDepth                   |
|max_find_me_follow_me_depth                      |int  |maxFindMeFollowMeDepth                      |
|max_redirection_depth                            |int  |maxRedirectionDepth                         |
|use_max_concurrent_find_me_follow_me_invocations |bool |useMaxConcurrentFindMeFollowMeInvocations   |
|max_concurrent_find_me_follow_me_invocations     |int  |maxConcurrentFindMeFollowMeInvocations      |
|clid_policy                                      |str  |clidPolicy                                  |
|emergency_clid_policy                            |str  |emergencyClidPolicy                         |
|allow_alternate_numbers_for_redirecting_identity |bool |allowAlternateNumbersForRedirectingIdentity |
|use_group_name                                   |bool |useGroupName                                |
|block_calling_name_for_external_calls            |bool |blockCallingNameForExternalCalls            |
|enable_dialable_caller_id                        |bool |enableDialableCallerID                      |
|allow_configurable_clid_for_redirecting_identity |bool |allowConfigurableCLIDForRedirectingIdentity |
|allow_department_clid_name_override              |bool |allowDepartmentCLIDNameOverride             |
</div>


## `UserCallProcessingGetPolicyResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest21sp1()`.

The useUserCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowConfigurableCLIDForRedirectingIdentity, allowDepartmentCLIDNameOverride) The
useUserMediaSetting attribute controls the Media settings (medisPolicySelection,
supportedMediaSetName) The useUserCallLimitsSetting attribute controls the Call Limits
setting (useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useUserDCLIDSetting controls the Dialable Caller ID settings (enableDialableCallerID)
The useUserPhoneListLookupSetting controls whether or not to use the group setting for
the Phone List Lookup policy (enablePhoneListLookup) The following elements are only
used in AS data mode : useUserDCLIDSetting enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity allowDepartmentCLIDNameOverride
useUserPhoneListLookupSetting, value "false" is returned in XS data mode.
enablePhoneListLookup, value "false" is returned in XS data mode.  Replaced by:
`UserCallProcessingGetPolicyResponse21sp2()`

**Attributes:**

|Name                                             |Type |Description                                 |
|-------------------------------------------------|-----|--------------------------------------------|
|use_user_clid_setting                            |bool |useUserCLIDSetting                          |
|use_user_media_setting                           |bool |useUserMediaSetting                         |
|use_user_call_limits_setting                     |bool |useUserCallLimitsSetting                    |
|use_user_dclid_setting                           |bool |useUserDCLIDSetting                         |
|use_max_simultaneous_calls                       |bool |useMaxSimultaneousCalls                     |
|max_simultaneous_calls                           |int  |maxSimultaneousCalls                        |
|use_max_simultaneous_video_calls                 |bool |useMaxSimultaneousVideoCalls                |
|max_simultaneous_video_calls                     |int  |maxSimultaneousVideoCalls                   |
|use_max_call_time_for_answered_calls             |bool |useMaxCallTimeForAnsweredCalls              |
|max_call_time_for_answered_calls_minutes         |int  |maxCallTimeForAnsweredCallsMinutes          |
|use_max_call_time_for_unanswered_calls           |bool |useMaxCallTimeForUnansweredCalls            |
|max_call_time_for_unanswered_calls_minutes       |int  |maxCallTimeForUnansweredCallsMinutes        |
|media_policy_selection                           |str  |mediaPolicySelection                        |
|supported_media_set_name                         |str  |supportedMediaSetName *Optional*            |
|use_max_concurrent_redirected_calls              |bool |useMaxConcurrentRedirectedCalls             |
|max_concurrent_redirected_calls                  |int  |maxConcurrentRedirectedCalls                |
|use_max_find_me_follow_me_depth                  |bool |useMaxFindMeFollowMeDepth                   |
|max_find_me_follow_me_depth                      |int  |maxFindMeFollowMeDepth                      |
|max_redirection_depth                            |int  |maxRedirectionDepth                         |
|use_max_concurrent_find_me_follow_me_invocations |bool |useMaxConcurrentFindMeFollowMeInvocations   |
|max_concurrent_find_me_follow_me_invocations     |int  |maxConcurrentFindMeFollowMeInvocations      |
|clid_policy                                      |str  |clidPolicy                                  |
|emergency_clid_policy                            |str  |emergencyClidPolicy                         |
|allow_alternate_numbers_for_redirecting_identity |bool |allowAlternateNumbersForRedirectingIdentity |
|use_group_name                                   |bool |useGroupName                                |
|block_calling_name_for_external_calls            |bool |blockCallingNameForExternalCalls            |
|enable_dialable_caller_id                        |bool |enableDialableCallerID                      |
|allow_configurable_clid_for_redirecting_identity |bool |allowConfigurableCLIDForRedirectingIdentity |
|allow_department_clid_name_override              |bool |allowDepartmentCLIDNameOverride             |
|use_user_phone_list_lookup_setting               |bool |useUserPhoneListLookupSetting               |
|enable_phone_list_lookup                         |bool |enablePhoneListLookup                       |
</div>


## `UserCallProcessingGetPolicyResponse21sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest21sp2()`.

The useUserCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowConfigurableCLIDForRedirectingIdentity, allowDepartmentCLIDNameOverride) The
useUserMediaSetting attribute controls the Media settings (medisPolicySelection,
supportedMediaSetName) The useUserCallLimitsSetting attribute controls the Call Limits
setting (useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useUserDCLIDSetting controls the Dialable Caller ID settings (enableDialableCallerID)
The useUserPhoneListLookupSetting controls whether or not to use the group setting for
the Phone List Lookup policy (enablePhoneListLookup) The
useUserTranslationRoutingSetting attribute controls the routing and translation
settings (routeOverrideDomain, routeOverridePrefix) The following elements are only
used in AS data mode: useUserDCLIDSetting enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity allowDepartmentCLIDNameOverride
useUserPhoneListLookupSetting, value "false" is returned in XS data mode.
enablePhoneListLookup, value "false" is returned in XS data mode.  The following
elements are only used in XS data mode and ignored in AS data mode:
routeOverrideDomain routeOverridePrefix The following elements are only used in XS
data mode: useUserTranslationRoutingSetting, value "false" is returned in AS data
mode.  Replaced by: `UserCallProcessingGetPolicyResponse22()` in AS data mode

**Attributes:**

|Name                                             |Type |Description                                 |
|-------------------------------------------------|-----|--------------------------------------------|
|use_user_clid_setting                            |bool |useUserCLIDSetting                          |
|use_user_media_setting                           |bool |useUserMediaSetting                         |
|use_user_call_limits_setting                     |bool |useUserCallLimitsSetting                    |
|use_user_dclid_setting                           |bool |useUserDCLIDSetting                         |
|use_user_translation_routing_setting             |bool |useUserTranslationRoutingSetting            |
|use_max_simultaneous_calls                       |bool |useMaxSimultaneousCalls                     |
|max_simultaneous_calls                           |int  |maxSimultaneousCalls                        |
|use_max_simultaneous_video_calls                 |bool |useMaxSimultaneousVideoCalls                |
|max_simultaneous_video_calls                     |int  |maxSimultaneousVideoCalls                   |
|use_max_call_time_for_answered_calls             |bool |useMaxCallTimeForAnsweredCalls              |
|max_call_time_for_answered_calls_minutes         |int  |maxCallTimeForAnsweredCallsMinutes          |
|use_max_call_time_for_unanswered_calls           |bool |useMaxCallTimeForUnansweredCalls            |
|max_call_time_for_unanswered_calls_minutes       |int  |maxCallTimeForUnansweredCallsMinutes        |
|media_policy_selection                           |str  |mediaPolicySelection                        |
|supported_media_set_name                         |str  |supportedMediaSetName *Optional*            |
|use_max_concurrent_redirected_calls              |bool |useMaxConcurrentRedirectedCalls             |
|max_concurrent_redirected_calls                  |int  |maxConcurrentRedirectedCalls                |
|use_max_find_me_follow_me_depth                  |bool |useMaxFindMeFollowMeDepth                   |
|max_find_me_follow_me_depth                      |int  |maxFindMeFollowMeDepth                      |
|max_redirection_depth                            |int  |maxRedirectionDepth                         |
|use_max_concurrent_find_me_follow_me_invocations |bool |useMaxConcurrentFindMeFollowMeInvocations   |
|max_concurrent_find_me_follow_me_invocations     |int  |maxConcurrentFindMeFollowMeInvocations      |
|clid_policy                                      |str  |clidPolicy                                  |
|emergency_clid_policy                            |str  |emergencyClidPolicy                         |
|allow_alternate_numbers_for_redirecting_identity |bool |allowAlternateNumbersForRedirectingIdentity |
|use_group_name                                   |bool |useGroupName                                |
|block_calling_name_for_external_calls            |bool |blockCallingNameForExternalCalls            |
|enable_dialable_caller_id                        |bool |enableDialableCallerID                      |
|allow_configurable_clid_for_redirecting_identity |bool |allowConfigurableCLIDForRedirectingIdentity |
|allow_department_clid_name_override              |bool |allowDepartmentCLIDNameOverride             |
|use_user_phone_list_lookup_setting               |bool |useUserPhoneListLookupSetting               |
|enable_phone_list_lookup                         |bool |enablePhoneListLookup                       |
|route_override_domain                            |str  |routeOverrideDomain *Optional*              |
|route_override_prefix                            |str  |routeOverridePrefix *Optional*              |
</div>


## `UserCallProcessingGetPolicyResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest22()`.

The useUserCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowConfigurableCLIDForRedirectingIdentity, allowDepartmentCLIDNameOverride) The
useUserMediaSetting attribute controls the Media settings (medisPolicySelection,
supportedMediaSetName) The useUserCallLimitsSetting attribute controls the Call Limits
setting (useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations,
useMaxConcurrentTerminatingAlertingRequests, maxConcurrentTerminatingAlertingRequests,
includeRedirectionsInMaximumNumberOfConcurrentCalls) The useUserDCLIDSetting controls
the Dialable Caller ID settings (enableDialableCallerID) The
useUserPhoneListLookupSetting controls whether or not to use the group setting for the
Phone List Lookup policy (enablePhoneListLookup) The useUserTranslationRoutingSetting
attribute controls the routing and translation settings (routeOverrideDomain,
routeOverridePrefix) The following elements are only used in AS data mode:
useUserDCLIDSetting enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
allowDepartmentCLIDNameOverride useUserPhoneListLookupSetting, value "false" is
returned in XS data mode.  enablePhoneListLookup, value "false" is returned in XS data
mode.  useMaxConcurrentTerminatingAlertingRequests, value "false" is returned in XS
data mode.  maxConcurrentTerminatingAlertingRequests, value "10" is returned in XS
data mode.  includeRedirectionsInMaximumNumberOfConcurrentCalls, value "false" is
returned in XS data mode.  The following elements are only used in XS data mode and
ignored in AS data mode: routeOverrideDomain routeOverridePrefix The following
elements are only used in XS data mode: useUserTranslationRoutingSetting, value
"false" is returned in AS data mode.  Replaced by:
`UserCallProcessingGetPolicyResponse22V2()` in AS data mode.

**Attributes:**

|Name                                                       |Type |Description                                         |
|-----------------------------------------------------------|-----|----------------------------------------------------|
|use_user_clid_setting                                      |bool |useUserCLIDSetting                                  |
|use_user_media_setting                                     |bool |useUserMediaSetting                                 |
|use_user_call_limits_setting                               |bool |useUserCallLimitsSetting                            |
|use_user_dclid_setting                                     |bool |useUserDCLIDSetting                                 |
|use_user_translation_routing_setting                       |bool |useUserTranslationRoutingSetting                    |
|use_max_simultaneous_calls                                 |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                     |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                           |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                               |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                       |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                   |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                     |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                 |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                     |str  |mediaPolicySelection                                |
|supported_media_set_name                                   |str  |supportedMediaSetName *Optional*                    |
|use_max_concurrent_redirected_calls                        |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                            |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                            |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                      |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations           |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations               |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                |str  |clidPolicy                                          |
|emergency_clid_policy                                      |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity           |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                             |bool |useGroupName                                        |
|block_calling_name_for_external_calls                      |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                  |bool |enableDialableCallerID                              |
|allow_configurable_clid_for_redirecting_identity           |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                        |bool |allowDepartmentCLIDNameOverride                     |
|use_user_phone_list_lookup_setting                         |bool |useUserPhoneListLookupSetting                       |
|enable_phone_list_lookup                                   |bool |enablePhoneListLookup                               |
|use_max_concurrent_terminating_alerting_requests           |bool |useMaxConcurrentTerminatingAlertingRequests         |
|max_concurrent_terminating_alerting_requests               |int  |maxConcurrentTerminatingAlertingRequests            |
|include_redirections_in_maximum_number_of_concurrent_calls |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls |
|route_override_domain                                      |str  |routeOverrideDomain *Optional*                      |
|route_override_prefix                                      |str  |routeOverridePrefix *Optional*                      |
</div>


## `UserCallProcessingGetPolicyResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallProcessingGetPolicyRequest22V2()`.

The useUserCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowConfigurableCLIDForRedirectingIdentity, allowDepartmentCLIDNameOverride) The
useUserMediaSetting attribute controls the Media settings (medisPolicySelection,
supportedMediaSetName) The useUserCallLimitsSetting attribute controls the Call Limits
setting (useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations,
useMaxConcurrentTerminatingAlertingRequests, maxConcurrentTerminatingAlertingRequests,
includeRedirectionsInMaximumNumberOfConcurrentCalls) The useUserDCLIDSetting controls
the Dialable Caller ID settings (enableDialableCallerID) The
useUserPhoneListLookupSetting controls whether or not to use the group setting for the
Phone List Lookup policy (enablePhoneListLookup) The useUserTranslationRoutingSetting
attribute controls the routing and translation settings (routeOverrideDomain,
routeOverridePrefix) The following elements are only used in AS data mode:
useUserDCLIDSetting enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
allowDepartmentCLIDNameOverride useUserPhoneListLookupSetting, value "false" is
returned in XS data mode.  enablePhoneListLookup, value "false" is returned in XS data
mode.  useMaxConcurrentTerminatingAlertingRequests, value "false" is returned in XS
data mode.  maxConcurrentTerminatingAlertingRequests, value "10" is returned in XS
data mode.  includeRedirectionsInMaximumNumberOfConcurrentCalls, value "false" is
returned in XS data mode.  allowMobileDNForRedirectingIdentity,value "false" is
returned in XS data mode.  The following elements are only used in XS data mode and
ignored in AS data mode: routeOverrideDomain routeOverridePrefix The following
elements are only used in XS data mode: useUserTranslationRoutingSetting, value
"false" is returned in AS data mode.

**Attributes:**

|Name                                                       |Type |Description                                         |
|-----------------------------------------------------------|-----|----------------------------------------------------|
|use_user_clid_setting                                      |bool |useUserCLIDSetting                                  |
|use_user_media_setting                                     |bool |useUserMediaSetting                                 |
|use_user_call_limits_setting                               |bool |useUserCallLimitsSetting                            |
|use_user_dclid_setting                                     |bool |useUserDCLIDSetting                                 |
|use_user_translation_routing_setting                       |bool |useUserTranslationRoutingSetting                    |
|use_max_simultaneous_calls                                 |bool |useMaxSimultaneousCalls                             |
|max_simultaneous_calls                                     |int  |maxSimultaneousCalls                                |
|use_max_simultaneous_video_calls                           |bool |useMaxSimultaneousVideoCalls                        |
|max_simultaneous_video_calls                               |int  |maxSimultaneousVideoCalls                           |
|use_max_call_time_for_answered_calls                       |bool |useMaxCallTimeForAnsweredCalls                      |
|max_call_time_for_answered_calls_minutes                   |int  |maxCallTimeForAnsweredCallsMinutes                  |
|use_max_call_time_for_unanswered_calls                     |bool |useMaxCallTimeForUnansweredCalls                    |
|max_call_time_for_unanswered_calls_minutes                 |int  |maxCallTimeForUnansweredCallsMinutes                |
|media_policy_selection                                     |str  |mediaPolicySelection                                |
|supported_media_set_name                                   |str  |supportedMediaSetName *Optional*                    |
|use_max_concurrent_redirected_calls                        |bool |useMaxConcurrentRedirectedCalls                     |
|max_concurrent_redirected_calls                            |int  |maxConcurrentRedirectedCalls                        |
|use_max_find_me_follow_me_depth                            |bool |useMaxFindMeFollowMeDepth                           |
|max_find_me_follow_me_depth                                |int  |maxFindMeFollowMeDepth                              |
|max_redirection_depth                                      |int  |maxRedirectionDepth                                 |
|use_max_concurrent_find_me_follow_me_invocations           |bool |useMaxConcurrentFindMeFollowMeInvocations           |
|max_concurrent_find_me_follow_me_invocations               |int  |maxConcurrentFindMeFollowMeInvocations              |
|clid_policy                                                |str  |clidPolicy                                          |
|emergency_clid_policy                                      |str  |emergencyClidPolicy                                 |
|allow_alternate_numbers_for_redirecting_identity           |bool |allowAlternateNumbersForRedirectingIdentity         |
|use_group_name                                             |bool |useGroupName                                        |
|block_calling_name_for_external_calls                      |bool |blockCallingNameForExternalCalls                    |
|enable_dialable_caller_id                                  |bool |enableDialableCallerID                              |
|allow_configurable_clid_for_redirecting_identity           |bool |allowConfigurableCLIDForRedirectingIdentity         |
|allow_department_clid_name_override                        |bool |allowDepartmentCLIDNameOverride                     |
|use_user_phone_list_lookup_setting                         |bool |useUserPhoneListLookupSetting                       |
|enable_phone_list_lookup                                   |bool |enablePhoneListLookup                               |
|use_max_concurrent_terminating_alerting_requests           |bool |useMaxConcurrentTerminatingAlertingRequests         |
|max_concurrent_terminating_alerting_requests               |int  |maxConcurrentTerminatingAlertingRequests            |
|include_redirections_in_maximum_number_of_concurrent_calls |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls |
|route_override_domain                                      |str  |routeOverrideDomain *Optional*                      |
|route_override_prefix                                      |str  |routeOverridePrefix *Optional*                      |
|allow_mobile_dn_for_redirecting_identity                   |bool |allowMobileDNForRedirectingIdentity                 |
</div>


## `UserCallRecordingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallRecordingGetRequest()`.

The response contains the user's Call Recording option information.

**Attributes:**

|Name             |Type|Description     |
|-----------------|----|----------------|
|recording_option |str |recordingOption |
</div>


## `UserCallRecordingGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallRecordingGetRequest20()`.

The response contains the user's Call Recording option information.  The following
parameters are not returned for service instance: - pauseResumeNotification -
enableCallRecordingAnnouncement - enableRecordCallRepeatWarningTone -
recordCallRepeatWarningToneTimerSeconds The enableVoiceMailRecording parameter is only
returned if the Voice Messaging User service is assigned to the user.  This applies to
both users and service instances.  The recordingOption and
enableCallRecordingAnnouncement which elements can only be modified by a System or a
Provisioning administrator when restrictCallRecordingProvisioningAccess system param
is set to true.  Both the element values will be ignored when group admin or lower
runs this.  Replaced by: `UserCallRecordingGetResponse23()`.

**Attributes:**

|Name                                          |Type |Description                                        |
|----------------------------------------------|-----|---------------------------------------------------|
|recording_option                              |str  |recordingOption                                    |
|pause_resume_notification                     |str  |pauseResumeNotification *Optional*                 |
|enable_call_recording_announcement            |bool |enableCallRecordingAnnouncement *Optional*         |
|enable_record_call_repeat_warning_tone        |bool |enableRecordCallRepeatWarningTone *Optional*       |
|record_call_repeat_warning_tone_timer_seconds |int  |recordCallRepeatWarningToneTimerSeconds *Optional* |
|enable_voice_mail_recording                   |bool |enableVoiceMailRecording *Optional*                |
</div>


## `UserCallRecordingGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallRecordingGetRequest23()`.

The response contains the user's Call Recording option information.  The following
parameters are not returned for service instance: - pauseResumeNotification -
enableCallRecordingAnnouncement - enableRecordCallRepeatWarningTone -
recordCallRepeatWarningToneTimerSeconds The enableVoiceMailRecording parameter is only
returned if the Voice Messaging User service is assigned to the user.  This applies to
both users and service instances.  The recordingOption and
enableCallRecordingAnnouncement which elements can only be modified by a System or a
Provisioning administrator when restrictCallRecordingProvisioningAccess system param
is set to true.  Both the element values will be ignored when group admin or lower
runs this.  The following elements are only used in AS data mode and not returned in
XS data mode: mediaStream

**Attributes:**

|Name                                          |Type |Description                                        |
|----------------------------------------------|-----|---------------------------------------------------|
|recording_option                              |str  |recordingOption                                    |
|pause_resume_notification                     |str  |pauseResumeNotification *Optional*                 |
|enable_call_recording_announcement            |bool |enableCallRecordingAnnouncement *Optional*         |
|enable_record_call_repeat_warning_tone        |bool |enableRecordCallRepeatWarningTone *Optional*       |
|record_call_repeat_warning_tone_timer_seconds |int  |recordCallRepeatWarningToneTimerSeconds *Optional* |
|enable_voice_mail_recording                   |bool |enableVoiceMailRecording *Optional*                |
|media_stream                                  |str  |mediaStream *Optional*                             |
</div>


## `UserCallTransferGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallTransferGetRequest()`.


**Attributes:**

|Name                                           |Type |Description                               |
|-----------------------------------------------|-----|------------------------------------------|
|is_recall_active                               |bool |isRecallActive                            |
|recall_number_of_rings                         |int  |recallNumberOfRings                       |
|use_diversion_inhibitor_for_blind_transfer     |bool |useDiversionInhibitorForBlindTransfer     |
|use_diversion_inhibitor_for_consultative_calls |bool |useDiversionInhibitorForConsultativeCalls |
</div>


## `UserCallTransferGetResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallTransferGetRequest14sp4()`.


**Attributes:**

|Name                                           |Type |Description                               |
|-----------------------------------------------|-----|------------------------------------------|
|is_recall_active                               |bool |isRecallActive                            |
|recall_number_of_rings                         |int  |recallNumberOfRings                       |
|use_diversion_inhibitor_for_blind_transfer     |bool |useDiversionInhibitorForBlindTransfer     |
|use_diversion_inhibitor_for_consultative_calls |bool |useDiversionInhibitorForConsultativeCalls |
|enable_busy_camp_on                            |bool |enableBusyCampOn                          |
|busy_camp_on_seconds                           |int  |busyCampOnSeconds                         |
</div>


## `UserCallWaitingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallWaitingGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserCallWaitingGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallWaitingGetRequest17sp4()`.

The following elements are only used in AS data mode: disableCallingLineIdDelivery

**Attributes:**

|Name                             |Type |Description                  |
|---------------------------------|-----|-----------------------------|
|is_active                        |bool |isActive                     |
|disable_calling_line_id_delivery |bool |disableCallingLineIdDelivery |
</div>


## `UserCallingLineIDBlockingOverrideGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallingLineIDBlockingOverrideGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserCallingLineIDDeliveryBlockingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallingLineIDDeliveryBlockingGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserCallingNameDeliveryGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallingNameDeliveryGetRequest()`.


**Attributes:**

|Name                         |Type |Description              |
|-----------------------------|-----|-------------------------|
|is_active_for_external_calls |bool |isActiveForExternalCalls |
|is_active_for_internal_calls |bool |isActiveForInternalCalls |
</div>


## `UserCallingNameRetrievalGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallingNameRetrievalGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserCallingNumberDeliveryGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallingNumberDeliveryGetRequest()`.


**Attributes:**

|Name                         |Type |Description              |
|-----------------------------|-----|-------------------------|
|is_active_for_external_calls |bool |isActiveForExternalCalls |
|is_active_for_internal_calls |bool |isActiveForInternalCalls |
</div>


## `UserCallingPartyCategoryGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallingPartyCategoryGetRequest()`.


**Attributes:**

|Name     |Type|Description|
|---------|----|-----------|
|category |str |category   |
</div>


## `UserCallingPartyCategoryGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallingPartyCategoryGetRequest16()`.


**Attributes:**

|Name     |Type|Description|
|---------|----|-----------|
|category |str |category   |
</div>


## `UserChargeNumberGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserChargeNumberGetRequest()`.


**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|phone_number |str |phoneNumber *Optional* |
</div>


## `UserChargeNumberGetResponse14sp9`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserChargeNumberGetRequest14sp9()`.


**Attributes:**

|Name                                        |Type |Description                            |
|--------------------------------------------|-----|---------------------------------------|
|phone_number                                |str  |phoneNumber *Optional*                 |
|use_charge_number_for_enhanced_translations |bool |useChargeNumberForEnhancedTranslations |
|send_charge_number_to_network               |bool |sendChargeNumberToNetwork              |
</div>


## `UserClassmarkGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserClassmarkGetRequest()`.

Contains the Class Mark data

**Attributes:**

|Name      |Type|Description          |
|----------|----|---------------------|
|classmark |str |classmark *Optional* |
</div>


## `UserCollaborateInstantRoomAddResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCollaborateInstantRoomAddRequest()`.


**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|room_id |str |roomId     |
</div>


## `UserCollaborateInstantRoomGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCollaborateInstantRoomGetRequest()`.


**Attributes:**

|Name                    |Type|Description          |
|------------------------|----|---------------------|
|room_name               |str |roomName *Optional*  |
|instant_room_start_time |str |instantRoomStartTime |
|instant_room_end_time   |str |instantRoomEndTime   |
</div>


## `UserCollaborateInstantRoomParametersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCollaborateInstantRoomParametersGetRequest()`.


**Attributes:**

|Name                                       |Type |Description                          |
|-------------------------------------------|-----|-------------------------------------|
|attendee_notification                      |str  |attendeeNotification                 |
|end_collaborate_room_session_on_owner_exit |bool |endCollaborateRoomSessionOnOwnerExit |
|owner_required                             |bool |ownerRequired                        |
</div>


## `UserCollaborateMyRoomGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCollaborateMyRoomGetRequest()`.


**Attributes:**

|Name                                       |Type |Description                          |
|-------------------------------------------|-----|-------------------------------------|
|room_id                                    |str  |roomId                               |
|room_name                                  |str  |roomName                             |
|attendee_notification                      |str  |attendeeNotification                 |
|end_collaborate_room_session_on_owner_exit |bool |endCollaborateRoomSessionOnOwnerExit |
|owner_required                             |bool |ownerRequired                        |
</div>


## `UserCollaborateProjectRoomAddResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCollaborateProjectRoomAddRequest()`.


**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|room_id |str |roomId     |
</div>


## `UserCollaborateRoomIDRegenerateResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCollaborateRoomIDRegenerateRequest()`.


**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|room_id |str |roomId     |
</div>


## `UserCollaborateRoomListGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCollaborateRoomListGetRequest()`.

Contains a table with column headings : "Room Type", "Name", "Room Id", in a row for
each collaborate room instance.  Possible values for Room Type column are MyRoom,
Project Room and Instant Room.

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|room_instance_table |List(roomInstanceTable) |roomInstanceTable - *Table* array of roomInstanceTable named tuples |
</div>


## `UserCommunicationBarringGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCommunicationBarringGetRequest()`.

This command only applies to users in an Enterprise.

**Attributes:**

|Name              |Type |Description            |
|------------------|-----|-----------------------|
|use_group_setting |bool |useGroupSetting        |
|profile_name      |str  |profileName *Optional* |
</div>


## `UserCommunicationBarringUserControlGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCommunicationBarringUserControlGetRequest()`.

Identifies the profiles available to the user and which one if any is active as well
as the lockout status.  Contains a table with column headings: "Name", "Code",
"Activated" and "Primary".

**Attributes:**

|Name           |Type               |Description                                               |
|---------------|-------------------|----------------------------------------------------------|
|lockout_status |bool               |lockoutStatus                                             |
|profile_table  |List(profileTable) |profileTable - *Table* array of profileTable named tuples |
</div>


## `UserConnectedLineIdentificationRestrictionGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserConnectedLineIdentificationRestrictionGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserCustomRingbackUserGetCriteriaListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCustomRingbackUserGetCriteriaListRequest()`.

The criteria table's column headings are: "Is Active", "Criteria Name", "Time
Schedule", "Calls From", "Blacklisted", "Holiday Schedule", "Calls To Type", "Calls To
Number" and "Calls To Extension". The following columns are only returned in AS data
mode: "Calls To Type", "Calls To Number" and "Calls To Extension" The possible values
for the "Calls To Type" column are the following or a combination of them separated by
comma: - Primary - Alternate X (where x is a number between 1 and 10) - Mobility The
possible values for the "Calls To Number" column are the following or a combination of
them separated by comma: - The value of the phone number for the corresponding Calls
To Type, when the number is available.  i.e.  Alternate 1 may have extension, but no
number.  - When no number is available a blank space is provided instead.  The
possible values for the "Calls To Extension" column are the following or a combination
of them separated by comma: - The value of the extension for the corresponding Calls
To Type, when the extension is available.  i.e.  Primary may have number, but no
extension.  - For Mobility Calls To Type, this is always blank.  - When no extension
is available a blank space is provided instead.

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|criteria_table |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserDeviceActivationPolicyInEffectGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserDeviceActivationPolicyInEffectGetRequest()`.


**Attributes:**

|Name                                  |Type |Description                      |
|--------------------------------------|-----|---------------------------------|
|allow_activation_code_request_by_user |bool |allowActivationCodeRequestByUser |
|send_activation_code_in_email         |bool |sendActivationCodeInEmail        |
</div>


## `UserDevicePoliciesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserDevicePoliciesGetRequest()`.

enableDeviceFeatureSynchronization is ignored by the application server in Multiple
User Shared mode.

**Attributes:**

|Name                                  |Type |Description                        |
|--------------------------------------|-----|-----------------------------------|
|line_mode                             |str  |lineMode                           |
|enable_device_feature_synchronization |bool |enableDeviceFeatureSynchronization |
</div>


## `UserDevicePoliciesGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserDevicePoliciesGetRequest19sp1()`.

enableDeviceFeatureSynchronization is ignored by the application server in Multiple
User Shared mode.

**Attributes:**

|Name                                  |Type |Description                        |
|--------------------------------------|-----|-----------------------------------|
|line_mode                             |str  |lineMode                           |
|enable_device_feature_synchronization |bool |enableDeviceFeatureSynchronization |
|enable_dnd                            |bool |enableDnd                          |
|enable_call_forwarding_always         |bool |enableCallForwardingAlways         |
|enable_call_forwarding_busy           |bool |enableCallForwardingBusy           |
|enable_call_forwarding_no_answer      |bool |enableCallForwardingNoAnswer       |
|enable_acd                            |bool |enableAcd                          |
|enable_executive                      |bool |enableExecutive                    |
|enable_executive_assistant            |bool |enableExecutiveAssistant           |
</div>


## `UserDevicePoliciesGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserDevicePoliciesGetRequest201()`.

enableDeviceFeatureSynchronization is ignored by the application server in Multiple
User Shared mode.

**Attributes:**

|Name                                  |Type |Description                        |
|--------------------------------------|-----|-----------------------------------|
|line_mode                             |str  |lineMode                           |
|enable_device_feature_synchronization |bool |enableDeviceFeatureSynchronization |
|enable_dnd                            |bool |enableDnd                          |
|enable_call_forwarding_always         |bool |enableCallForwardingAlways         |
|enable_call_forwarding_busy           |bool |enableCallForwardingBusy           |
|enable_call_forwarding_no_answer      |bool |enableCallForwardingNoAnswer       |
|enable_acd                            |bool |enableAcd                          |
|enable_executive                      |bool |enableExecutive                    |
|enable_executive_assistant            |bool |enableExecutiveAssistant           |
|enable_security_classification        |bool |enableSecurityClassification       |
|enable_call_recording                 |bool |enableCallRecording                |
</div>


## `UserDevicePoliciesGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserDevicePoliciesGetRequest21()`.

enableDeviceFeatureSynchronization and enableCallDecline are ignored by the
application server in Multiple User Shared mode.  The following element is only used
in AS data mode: lineMode, value “Single User Private and Shared” is returned in XS
data mode The following elements are only used in AS data mode:
enableDeviceFeatureSynchronization, value “false” is returned in XS data mode
enableDnd, value “false” is returned in XS data mode enableCallForwardingAlways, value
“false” is returned in XS data mode enableCallForwardingBusy, value “false” is
returned in XS data mode enableCallForwardingNoAnswer, value “false” is returned in XS
data mode enableAcd, value “false” is returned in XS data mode enableExecutive, value
“false” is returned in XS data mode enableExecutiveAssistant, value “false” is
returned in XS data mode enableSecurityClassification, value “false” is returned in XS
data mode enableCallRecording, value “false” is returned in XS data mode

**Attributes:**

|Name                                  |Type |Description                        |
|--------------------------------------|-----|-----------------------------------|
|line_mode                             |str  |lineMode                           |
|enable_device_feature_synchronization |bool |enableDeviceFeatureSynchronization |
|enable_dnd                            |bool |enableDnd                          |
|enable_call_forwarding_always         |bool |enableCallForwardingAlways         |
|enable_call_forwarding_busy           |bool |enableCallForwardingBusy           |
|enable_call_forwarding_no_answer      |bool |enableCallForwardingNoAnswer       |
|enable_acd                            |bool |enableAcd                          |
|enable_executive                      |bool |enableExecutive                    |
|enable_executive_assistant            |bool |enableExecutiveAssistant           |
|enable_security_classification        |bool |enableSecurityClassification       |
|enable_call_recording                 |bool |enableCallRecording                |
|enable_call_decline                   |bool |enableCallDecline                  |
</div>


## `UserDirectedCallPickupWithBargeInGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserDirectedCallPickupWithBargeInGetRequest()`.


**Attributes:**

|Name                         |Type |Description              |
|-----------------------------|-----|-------------------------|
|enable_barge_in_warning_tone |bool |enableBargeInWarningTone |
</div>


## `UserDirectedCallPickupWithBargeInGetResponse14sp7`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserDirectedCallPickupWithBargeInGetRequest14sp7()`.


**Attributes:**

|Name                              |Type |Description                    |
|----------------------------------|-----|-------------------------------|
|enable_barge_in_warning_tone      |bool |enableBargeInWarningTone       |
|enable_automatic_target_selection |bool |enableAutomaticTargetSelection |
</div>


## `UserDnGetActivationListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserDnGetActivationListRequest()`.

The response contains a table with columns: "Phone Number", and "Activated". The
"Phone Number" column contains a single DN. The "Activated" column indicates if the
phone number is activated or not.

**Attributes:**

|Name     |Type          |Description                                     |
|---------|--------------|------------------------------------------------|
|dn_table |List(dnTable) |dnTable - *Table* array of dnTable named tuples |
</div>


## `UserDoNotDisturbGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserDoNotDisturbGetRequest()`.


**Attributes:**

|Name        |Type |Description|
|------------|-----|-----------|
|is_active   |bool |isActive   |
|ring_splash |bool |ringSplash |
</div>


## `UserEnhancedCallLogsGetListResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserEnhancedCallLogsGetListRequest17sp4()`.

Total numbers of rows is: - the total number of retrievable logs of the call log type
that was specified in the `UserEnhancedCallLogsGetListRequest17sp4()`, if a call log
type was specified in the request.  - the total number of retrievable logs, if no call
log type was specified in the request.  A list of MixedCallLogsEntry will be returned
if the call logs are stored on CDS A list of ExtendedMixedCallLogsEntry will be
returned if the call logs are stored on DBS The logs are sorted by date/time of the
call.  Replaced by UserEnhancedCallLogsGetListResponse17sp4V2. Originally deprecated
in release 20.

**Attributes:**

|Name                 |Type              |Description              |
|---------------------|------------------|-------------------------|
|total_number_of_rows |int               |totalNumberOfRows        |
|legacy_entry         |OCI.legacyEntry   |legacyEntry *Optional*   |
|extended_entry       |OCI.extendedEntry |extendedEntry *Optional* |
</div>


## `UserEnhancedCallLogsGetListResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserEnhancedCallLogsGetListRequest20()`.

Total numbers of rows is: - the total number of retrievable logs of the call log type
that was specified in the `UserEnhancedCallLogsGetListRequest20()`, if a call log type
was specified in the request.  - the total number of retrievable logs, if no call log
type was specified in the request.  A list of MixedCallLogsEntry will be returned if
the call logs are stored on CDS A list of ExtendedMixedCallLogsEntry20 will be
returned if the call logs are stored on DBS The logs are sorted by date/time of the
call.

**Attributes:**

|Name                 |Type              |Description              |
|---------------------|------------------|-------------------------|
|total_number_of_rows |int               |totalNumberOfRows        |
|legacy_entry         |OCI.legacyEntry   |legacyEntry *Optional*   |
|extended_entry       |OCI.extendedEntry |extendedEntry *Optional* |
</div>


## `UserEnhancedCallLogsGetListResponse20sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserEnhancedCallLogsGetListRequest20sp1()`.

Total numbers of rows is: - the total number of retrievable logs of the call log type
that was specified in the `UserEnhancedCallLogsGetListRequest20sp1()`, if a call log
type was specified in the request.  - the total number of retrievable logs, if no call
log type was specified in the request.  A list of MixedCallLogsEntry will be returned
if the call logs are stored on CDS A list of ExtendedMixedCallLogsEntry20sp1 will be
returned if the call logs are stored on DBS The logs are sorted by date/time of the
call.

**Attributes:**

|Name                 |Type              |Description              |
|---------------------|------------------|-------------------------|
|total_number_of_rows |int               |totalNumberOfRows        |
|legacy_entry         |OCI.legacyEntry   |legacyEntry *Optional*   |
|extended_entry       |OCI.extendedEntry |extendedEntry *Optional* |
</div>


## `UserEnhancedCallLogsGetListResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserEnhancedCallLogsGetListRequest21()`.

Total numbers of rows is: - the total number of retrievable logs of the call log type
that was specified in the `UserEnhancedCallLogsGetListRequest21()`, if a call log type
was specified in the request.  - the total number of retrievable logs, if no call log
type was specified in the request.  A list of MixedCallLogsEntry will be returned if
the call logs are stored on CDS A list of ExtendedMixedCallLogsEntry21 will be
returned if the call logs are stored on DBS The logs are sorted by date/time of the
call.  Replaced by: UserEnhancedCallLogsGetListResponse21Sp1 in AS data mode

**Attributes:**

|Name                 |Type              |Description              |
|---------------------|------------------|-------------------------|
|total_number_of_rows |int               |totalNumberOfRows        |
|legacy_entry         |OCI.legacyEntry   |legacyEntry *Optional*   |
|extended_entry       |OCI.extendedEntry |extendedEntry *Optional* |
</div>


## `UserEnhancedCallLogsGetListResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserEnhancedCallLogsGetListRequest21sp1()`.

Total numbers of rows is: - the total number of retrievable logs of the call log type
that was specified in the `UserEnhancedCallLogsGetListRequest21sp1()`, if a call log
type was specified in the request.  - the total number of retrievable logs, if no call
log type was specified in the request.  A list of MixedCallLogsEntry will be returned
if the call logs are stored on CDS A list of ExtendedMixedCallLogsEntry21sp1 will be
returned if the call logs are stored on DBS The logs are sorted by date/time of the
call.  Replaced by: UserEnhancedCallLogsGetListResponse21Sp1V2 in AS data mode

**Attributes:**

|Name                 |Type              |Description              |
|---------------------|------------------|-------------------------|
|total_number_of_rows |int               |totalNumberOfRows        |
|legacy_entry         |OCI.legacyEntry   |legacyEntry *Optional*   |
|extended_entry       |OCI.extendedEntry |extendedEntry *Optional* |
</div>


## `UserEnhancedCallLogsGetListResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserEnhancedCallLogsGetListRequest22()`.

Total numbers of rows is: - the total number of retrievable logs of the call log type
that was specified in the `UserEnhancedCallLogsGetListRequest22()`, if a call log type
was specified in the request.  - the total number of retrievable logs, if no call log
type was specified in the request.  A list of MixedCallLogsEntry will be returned if
the call logs are stored on CDS A list of ExtendedMixedCallLogsEntry22 will be
returned if the call logs are stored on DBS or Couchbase The logs are sorted by
date/time of the call.

**Attributes:**

|Name                 |Type              |Description              |
|---------------------|------------------|-------------------------|
|total_number_of_rows |int               |totalNumberOfRows        |
|legacy_entry         |OCI.legacyEntry   |legacyEntry *Optional*   |
|extended_entry       |OCI.extendedEntry |extendedEntry *Optional* |
</div>


## `UserEnhancedCallLogsGetListResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserEnhancedCallLogsGetListRequest23()`.

Total numbers of rows is: - the total number of retrievable logs of the call log type
that was specified in the `UserEnhancedCallLogsGetListRequest22()`, if a call log type
was specified in the request.  - the total number of retrievable logs, if no call log
type was specified in the request.  A list of MixedCallLogsEntry will be returned if
the call logs are stored on CDS A list of ExtendedMixedCallLogsEntry22 will be
returned if the call logs are stored on DBS or Couchbase The logs are sorted by
date/time of the call.

**Attributes:**

|Name                 |Type              |Description              |
|---------------------|------------------|-------------------------|
|total_number_of_rows |int               |totalNumberOfRows        |
|legacy_entry         |OCI.legacyEntry   |legacyEntry *Optional*   |
|extended_entry       |OCI.extendedEntry |extendedEntry *Optional* |
</div>


## `UserEnterpriseCommonPhoneListGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserEnterpriseCommonPhoneListGetPagedSortedListRequest()`.

The response contains the enterprise's common phone list.  The response contains a
table with column headings: "Name" and "Phone Number".

**Attributes:**

|Name                               |Type                                 |Description                                                                                   |
|-----------------------------------|-------------------------------------|----------------------------------------------------------------------------------------------|
|total_number_of_rows               |int                                  |totalNumberOfRows                                                                             |
|enterprise_common_phone_list_table |List(enterpriseCommonPhoneListTable) |enterpriseCommonPhoneListTable - *Table* array of enterpriseCommonPhoneListTable named tuples |
</div>


## `UserExecutiveAssistantGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserExecutiveAssistantGetRequest()`.

Contains the executive assistant setting and a table of executives this assistant has
been assigned to.  The criteria table's column headings are: "User Id", "Last Name",
"First Name", ", "Hiragana Last Name", "Hiragana First Name", "Phone Number",
"Extension", "Department", "Email Address", "Assistant Opt-in Status" and "Executive
Allow Opt-in". The possible values for "Assistant Opt-in Status" and "Executive Allow
Opt-in" columns are "true" and "false".

**Attributes:**

|Name                   |Type                 |Description                                                   |
|-----------------------|---------------------|--------------------------------------------------------------|
|enable_divert          |bool                 |enableDivert                                                  |
|divert_to_phone_number |str                  |divertToPhoneNumber *Optional*                                |
|executive_table        |List(executiveTable) |executiveTable - *Table* array of executiveTable named tuples |
</div>


## `UserExecutiveGetAssistantResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserExecutiveGetAssistantsRequest()`.

Contains the assistant setting and a table of assigned assistants.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Phone Number", "Extension", "Department", "Email Address" and "Opt-in".
The possible values for "Opt-in" column are "true" and "false".

**Attributes:**

|Name                 |Type                     |Description                                                           |
|---------------------|-------------------------|----------------------------------------------------------------------|
|allow_opt_in_out     |bool                     |allowOptInOut                                                         |
|assistant_user_table |List(assistantUserTable) |assistantUserTable - *Table* array of assistantUserTable named tuples |
</div>


## `UserExecutiveGetAvailableAssistantListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserExecutiveGetAvailableAssistantListResponse()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department" and
"Email Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserExecutiveGetFilteringResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserExecutiveGetFilteringRequest()`.

Contains the filtering setting and a table of filtering criteria.  The criteria
table's column headings are: "Is Active", "Criteria Name", "Time Schedule", "Calls
From", "Filter", "Holiday Schedule", "Calls To Type", "Calls To Number" and "Calls To
Extension". The "Filter" column can contain "true" or "false". The possible values for
the "Calls To Type" column are the following or a combination of them separated by
comma: - Primary - Alternate X (where x is a number between 1 and 10) - Mobility The
possible values for the "Calls To Number" column are the following or a combination of
them separated by comma: - The value of the phone number for the corresponding Calls
To Type, when the number is available.  i.e.  Alternate 1 may have extension, but no
number.  - When no number is available a blank space is provided instead.  The
possible values for the "Calls To Extension" column are the following or a combination
of them separated by comma: - The value of the extension for the corresponding Calls
To Type, when the extension is available.  i.e.  Primary may have number, but no
extension.  - For Mobility Calls To Type, this is always blank.  - When no extension
is available a blank space is provided instead.

**Attributes:**

|Name               |Type                |Description                                                 |
|-------------------|--------------------|------------------------------------------------------------|
|enable_filtering   |bool                |enableFiltering                                             |
|filtering_mode     |str                 |filteringMode                                               |
|simple_filter_type |str                 |simpleFilterType                                            |
|criteria_table     |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserExecutiveGetScreeningAlertingResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserExecutiveGetScreeningAlertingRequest()`.

Contains the screening and alerting settings for an executive.

**Attributes:**

|Name                                         |Type |Description                                       |
|---------------------------------------------|-----|--------------------------------------------------|
|enable_screening                             |bool |enableScreening                                   |
|screening_alert_type                         |str  |screeningAlertType                                |
|alert_broad_works_mobility_location          |bool |alertBroadWorksMobilityLocation                   |
|alert_broad_works_anywhere_locations         |bool |alertBroadWorksAnywhereLocations                  |
|alert_shared_call_appearance_locations       |bool |alertSharedCallAppearanceLocations                |
|alerting_mode                                |str  |alertingMode                                      |
|alerting_calling_line_id_name_mode           |str  |alertingCallingLineIdNameMode                     |
|alerting_custom_calling_line_id_name         |str  |alertingCustomCallingLineIdName *Optional*        |
|unicode_alerting_custom_calling_line_id_name |str  |unicodeAlertingCustomCallingLineIdName *Optional* |
|alerting_calling_line_id_phone_number_mode   |str  |alertingCallingLineIdPhoneNumberMode              |
|alerting_custom_calling_line_id_phone_number |str  |alertingCustomCallingLineIdPhoneNumber *Optional* |
|call_push_recall_number_of_rings             |int  |callPushRecallNumberOfRings                       |
|next_assistant_number_of_rings               |int  |nextAssistantNumberOfRings                        |
|enable_rollover                              |bool |enableRollover                                    |
|rollover_wait_time_seconds                   |int  |rolloverWaitTimeSeconds *Optional*                |
|rollover_action                              |str  |rolloverAction                                    |
|rollover_forward_to_phone_number             |str  |rolloverForwardToPhoneNumber *Optional*           |
</div>


## `UserExternalCallingLineIDDeliveryGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserExternalCallingLineIDDeliveryGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserExternalCustomRingbackGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserExternalCustomRingbackGetRequest()`.


**Attributes:**

|Name              |Type |Description              |
|------------------|-----|-------------------------|
|is_active         |bool |isActive                 |
|use_setting_level |str  |useSettingLevel          |
|sip_request_uri   |str  |sipRequestURI *Optional* |
</div>


## `UserFaxMessagingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserFaxMessagingGetRequest()`.


**Attributes:**

|Name         |Type |Description            |
|-------------|-----|-----------------------|
|is_active    |bool |isActive               |
|phone_number |str  |phoneNumber *Optional* |
|extension    |str  |extension *Optional*   |
</div>


## `UserFaxMessagingGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserFaxMessagingGetRequest17()`.


**Attributes:**

|Name         |Type |Description            |
|-------------|-----|-----------------------|
|is_active    |bool |isActive               |
|phone_number |str  |phoneNumber *Optional* |
|extension    |str  |extension *Optional*   |
</div>


## `UserFaxMessagingGetResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserFaxMessagingGetRequest17sp1()`.


**Attributes:**

|Name         |Type      |Description            |
|-------------|----------|-----------------------|
|is_active    |bool      |isActive               |
|phone_number |str       |phoneNumber *Optional* |
|extension    |str       |extension *Optional*   |
|alias        |List[str] |alias *Optional*       |
</div>


## `UserFlexibleSeatingGuestGetAvailableHostListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserFlexibleSeatingGuestGetAvailableHostListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address", "Association Limit Hours", "Enable Association Limit",

**Attributes:**

|Name            |Type                |Description                                                 |
|----------------|--------------------|------------------------------------------------------------|
|host_user_table |List(hostUserTable) |hostUserTable - *Table* array of hostUserTable named tuples |
</div>


## `UserGetListInGroupPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetListInGroupPagedSortedListRequest()`.

Contains a table with column headings : "User Id", "Last Name", "First Name",
"Department", "Department Type", "Parent Department","Parent Department Type", "Phone
Number", "Phone Number Activated", "Email Address", "Hiragana Last Name", "Hiragana
First Name", "In Trunk Group", "Extension", "Country Code", "National Prefix", "User
External Id" in a row for each user.  The "Department Type" and "Parent Department
Type" columns will contain the values "Enterprise" or "Group". The following columns
are only populated in AS data mode: "Country Code", "National Prefix", "User External
Id"

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserGetListInGroupResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetListInGroupRequest()`.

Contains a table with column headings : "User Id", "Last Name", "First Name",
"Department", "Phone Number", "Phone Number Activated", "Email Address", "Hiragana
Last Name", "Hiragana First Name", "In Trunk Group", "Extension", "Country Code",
"National Prefix" in a row for each user.  The following columns are only returned in
AS data mode: "Country Code", "National Prefix

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserGetListInServiceProviderResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetListInServiceProviderRequest()`.

Contains a table with column headings : "User Id", "Group Id", "Last Name", "First
Name", "Department", "Phone Number", "Phone Number Activated", "Email Address",
"Hiragana Last Name", "Hiragana First Name", "In Trunk Group", "Extension", "User
External Id" in a row for each user.  The following columns are populated in AS data
mode only: "User External Id"

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserGetListInSystemResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetListInSystemRequest()`.

Contains a table with column headings : "User Id", "Group Id", "Service Provider Id",
"Last Name", "First Name", "Department", "Phone Number", "Phone Number Activated",
"Email Address", "Hiragana Last Name", "Hiragana First Name", "In Trunk Group",
"Extension", "Reseller Id", "User External Id" in a row for each user.  The following
columns are only returned in AS data mode: "Reseller Id" "User External Id"

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserGetLoginInfoResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetLoginInfoRequest()` If a phoneNumber is returned, it will be the
primary DN of the user

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|last_name             |str  |lastName *Optional*            |
|first_name            |str  |firstName *Optional*           |
|user_id               |str  |userId                         |
|phone_number          |str  |phoneNumber *Optional*         |
</div>


## `UserGetLoginInfoResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetLoginInfoRequest21sp1()` If a phoneNumber is returned, it will be
the primary DN of the user The parameter tokenRevocationTime is represented in the
number of milliseconds since January 1, 1970, 00:00:00 GMT, and it is set to the more
current time between the system level token revocation time and user level token
revocation time.

Replaced by `UserGetLoginInfoResponse22V2()`.

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|last_name             |str  |lastName *Optional*            |
|first_name            |str  |firstName *Optional*           |
|user_id               |str  |userId                         |
|phone_number          |str  |phoneNumber *Optional*         |
|token_revocation_time |int  |tokenRevocationTime *Optional* |
</div>


## `UserGetLoginInfoResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetLoginInfoRequest22()` If a phoneNumber is returned, it will be the
primary DN of the user Replaced by `UserGetLoginInfoResponse22V2()`.


**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|last_name             |str  |lastName *Optional*            |
|first_name            |str  |firstName *Optional*           |
|user_id               |str  |userId                         |
|phone_number          |str  |phoneNumber *Optional*         |
|reseller_id           |str  |resellerId *Optional*          |
</div>


## `UserGetLoginInfoResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetLoginInfoRequest22V2()` The following data elements are only used
in AS data mode: resellerId tokenRevocationTime If a phoneNumber is returned, it will
be the primary DN of the user The parameter tokenRevocationTime is represented in the
number of milliseconds since January 1, 1970, 00:00:00 GMT, and it is set to the more
current time between the system level token revocation time and user level token
revocation time.

Replaced by `UserGetLoginInfoResponse22V3()`.

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|last_name             |str  |lastName *Optional*            |
|first_name            |str  |firstName *Optional*           |
|user_id               |str  |userId                         |
|phone_number          |str  |phoneNumber *Optional*         |
|reseller_id           |str  |resellerId *Optional*          |
|token_revocation_time |int  |tokenRevocationTime *Optional* |
</div>


## `UserGetLoginInfoResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetLoginInfoRequest22V3()` The following data elements are only used
in AS data mode: resellerId If a phoneNumber is returned, it will be the primary DN of
the user The parameter tokenRevocationTime is represented in the number of
milliseconds since January 1, 1970, 00:00:00 GMT, and it is set to the more current
time between the system level token revocation time and user level token revocation
time.


**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|last_name             |str  |lastName *Optional*            |
|first_name            |str  |firstName *Optional*           |
|user_id               |str  |userId                         |
|phone_number          |str  |phoneNumber *Optional*         |
|reseller_id           |str  |resellerId *Optional*          |
|token_revocation_time |int  |tokenRevocationTime *Optional* |
</div>


## `UserGetLoginInfoResponse22V4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetLoginInfoRequest22V4()` The following data elements are only used
in AS data mode: resellerId If a phoneNumber is returned, it will be the primary DN of
the user The parameter tokenRevocationTime is represented in the number of
milliseconds since January 1, 1970, 00:00:00 GMT, and it is set to the more current
time between the system level token revocation time and user level token revocation
time.


**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|login_type            |str  |loginType                      |
|locale                |str  |locale                         |
|encoding              |str  |encoding                       |
|group_id              |str  |groupId *Optional*             |
|service_provider_id   |str  |serviceProviderId *Optional*   |
|is_enterprise         |bool |isEnterprise                   |
|password_expires_days |int  |passwordExpiresDays *Optional* |
|last_name             |str  |lastName *Optional*            |
|first_name            |str  |firstName *Optional*           |
|user_id               |str  |userId                         |
|phone_number          |str  |phoneNumber *Optional*         |
|reseller_id           |str  |resellerId *Optional*          |
|token_revocation_time |int  |tokenRevocationTime *Optional* |
</div>


## `UserGetRegistrationListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRegistrationListRequest()`.

The registrationTable table column headings are: "Device Level", "Device Name",
"Order", "URI", "Expiration", "Line/Port", "Endpoint Type", "Public Net Address",
"Public Port", "Private Net Address", "Private Port", "User Agent", "Lockout Started",
"Lockout Expires", "Lockout Count", "Access Info", "Private Identity", "SIP Instance
ID", "Supports Only CS Media", "Feature Parameters", "Supports Voice Over PS", "Path
Header", "Registration Active" The following columns are only used in AS and Amplify
data modes: "Order", "Public Net Address", "Public Port", "Private Net Address",
"Private Port", "Lockout Started", "Lockout Expires", "Lockout Count", "Path Header".
The following columns are only used in XS data mode: "Private Identity", "SIP Instance
ID", "Supports Only CS Media", "Feature Parameters", "Supports Voice Over PS". The
following columns are only used in AS data mode: "Registration Active". The "Device
Level" column contains one of the AccessDeviceLevel enumerated constants.  The
expiration column will be empty when the registration is static.  In XS data mode, its
value will be 0 when the registration is dynamic regardless of the registration's
actual expiration date.  The Endpoint Type column contains one of the enumerated
EndpointType values.  The Endpoint Type is empty when the registration is against a
TELURI. The table is sorted by: telURI (after SIPURI), Line/Port, static (after
dynamic), order.  Lockout times are shown in GMT offset.  When a permanent lockout is
shown, the "Lockout Expires" column is empty and the "Lockout Count" column contains
the word Permanent.

**Attributes:**

|Name               |Type                    |Description                                                         |
|-------------------|------------------------|--------------------------------------------------------------------|
|registration_table |List(registrationTable) |registrationTable - *Table* array of registrationTable named tuples |
</div>


## `UserGetServiceInstanceListInServiceProviderResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetServiceInstanceListInServiceProviderRequest()`.

Contains a table with column headings : "User Id", "Group Id", "Service Type", "Name",
"Phone Number", "Extension", "Department" in a row for each Service Instance.
Possible values for Service Type column are ServiceType enums.

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|service_instance_table |List(serviceInstanceTable) |serviceInstanceTable - *Table* array of serviceInstanceTable named tuples |
</div>


## `UserGetServiceInstanceListInSystemResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetServiceInstanceListInSystemRequest()`.

Contains a table with column headings : "User Id", "Group Id", "Service Provider Id",
"Service Type", "Name", "Phone Number", "Extension", "Reseller Id" in a row for each
Service Instance.  Possible values for Service Type column are ServiceType enums.  The
following columns are only returned in AS data mode: "Reseller Id"

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|service_instance_table |List(serviceInstanceTable) |serviceInstanceTable - *Table* array of serviceInstanceTable named tuples |
</div>


## `UserGroupCommonPhoneListGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserGroupCommonPhoneListGetPagedSortedListRequest()`.

The response contains the group's common phone list.  The response contains a table
with column headings: "Name" and "Phone Number".

**Attributes:**

|Name                          |Type                            |Description                                                                         |
|------------------------------|--------------------------------|------------------------------------------------------------------------------------|
|total_number_of_rows          |int                             |totalNumberOfRows                                                                   |
|group_common_phone_list_table |List(groupCommonPhoneListTable) |groupCommonPhoneListTable - *Table* array of groupCommonPhoneListTable named tuples |
</div>


## `UserGroupCustomContactDirectoryGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserGroupCustomContactDirectoryGetPagedSortedListRequest()`.

Returns the number of entries that would be returned if the response Was not page size
restricted.

The response contains all the contacts in the group's given custom contact directory.
Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Virtual On-Net Phone Number", "Group Id", "Is
Virtual On-Net User", "Department", "Phone Number", "Extension", "Mobile", "Email
Address", "Yahoo Id", "Title", "IMP Id", "Receptionist Note". If the entry represents
a Virtual On-Net user then "User Id" is blank, the "Virtual On-Net Phone Number"
contains the phone Number of the Virtual On-Net user, the "Group Id" contains the
Virtual On-Net user's group and the "Is Virtual On-Net User" contains true.  If the
entry represents a BroadWorks user then the "User Id" contains his BroadWorks userId,
the "Virtual On-Net Phone Number" and "Group Id" fields are field is blank and the "Is
Virtual On-Net User" contains false.  The Receptionist Note column is only populated,
if the user sending the request is the owner of this Receptionist Note and a Note
exists.

**Attributes:**

|Name                 |Type            |Description                                         |
|---------------------|----------------|----------------------------------------------------|
|total_number_of_rows |int             |totalNumberOfRows                                   |
|user_table           |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserGroupPagingGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserGroupPagingGetListRequest()`.

The groupPagingTable contains columns: "Name", "Phone Number", "Extension" and "Is
Active" The column value for "Is Active" can either be true, or false.

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|paging_group_table |List(pagingGroupTable) |pagingGroupTable - *Table* array of pagingGroupTable named tuples |
</div>


## `UserHolidayScheduleGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserHolidayScheduleGetListRequest()`.

The response contains all the user's personal and user's group holiday schedule names.

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|holiday_schedule_table |List(holidayScheduleTable) |holidayScheduleTable - *Table* array of holidayScheduleTable named tuples |
</div>


## `UserHotelingGuestGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserHotelingGuestGetAvailableUserListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Association Limit Hours", "Enable Association
Limit", "Phone Number", "Extension", "Department", "Email Address".

**Attributes:**

|Name            |Type                |Description                                                 |
|----------------|--------------------|------------------------------------------------------------|
|host_user_table |List(hostUserTable) |hostUserTable - *Table* array of hostUserTable named tuples |
</div>


## `UserHotelingGuestGetResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserHotelingGuestGetRequest14()`.

Replaced By: `UserSharedCallAppearanceAddEndpointRequest14sp2()`

**Attributes:**

|Name                       |Type |Description                        |
|---------------------------|-----|-----------------------------------|
|is_active                  |bool |isActive                           |
|association_limit_hours    |int  |associationLimitHours              |
|host_user_id               |str  |hostUserId *Optional*              |
|host_last_name             |str  |hostLastName *Optional*            |
|host_first_name            |str  |hostFirstName *Optional*           |
|host_association_date_time |str  |hostAssociationDateTime *Optional* |
</div>


## `UserHotelingGuestGetResponse14sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserHotelingGuestGetRequest14()`.

Replaced by: `UserHotelingGuestGetResponse14sp4()`

**Attributes:**

|Name                         |Type |Description                          |
|-----------------------------|-----|-------------------------------------|
|is_active                    |bool |isActive                             |
|association_limit_hours      |int  |associationLimitHours                |
|host_user_id                 |str  |hostUserId *Optional*                |
|host_last_name               |str  |hostLastName *Optional*              |
|host_first_name              |str  |hostFirstName *Optional*             |
|host_association_date_time   |str  |hostAssociationDateTime *Optional*   |
|host_association_limit_hours |int  |hostAssociationLimitHours *Optional* |
</div>


## `UserHotelingGuestGetResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserHotelingGuestGetRequest14sp4()`

**Attributes:**

|Name                            |Type |Description                             |
|--------------------------------|-----|----------------------------------------|
|is_active                       |bool |isActive                                |
|enable_association_limit        |bool |enableAssociationLimit                  |
|association_limit_hours         |int  |associationLimitHours                   |
|host_user_id                    |str  |hostUserId *Optional*                   |
|host_last_name                  |str  |hostLastName *Optional*                 |
|host_first_name                 |str  |hostFirstName *Optional*                |
|host_association_date_time      |str  |hostAssociationDateTime *Optional*      |
|host_enforces_association_limit |bool |hostEnforcesAssociationLimit *Optional* |
|host_association_limit_hours    |int  |hostAssociationLimitHours *Optional*    |
</div>


## `UserHotelingHostGetResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserHotelingHostGetRequest14()`.

Replaced by: `UserHotelingHostGetResponse14sp4()`

**Attributes:**

|Name                        |Type |Description                         |
|----------------------------|-----|------------------------------------|
|is_active                   |bool |isActive                            |
|association_limit_hours     |int  |associationLimitHours               |
|access_level                |str  |accessLevel                         |
|guest_last_name             |str  |guestLastName *Optional*            |
|guest_first_name            |str  |guestFirstName *Optional*           |
|guest_phone_number          |str  |guestPhoneNumber *Optional*         |
|guest_extension             |str  |guestExtension *Optional*           |
|guest_location_dialing_code |str  |guestLocationDialingCode *Optional* |
|guest_association_date_time |str  |guestAssociationDateTime *Optional* |
</div>


## `UserHotelingHostGetResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserHotelingHostGetRequest14sp4()`.


**Attributes:**

|Name                        |Type |Description                         |
|----------------------------|-----|------------------------------------|
|is_active                   |bool |isActive                            |
|enforce_association_limit   |bool |enforceAssociationLimit             |
|association_limit_hours     |int  |associationLimitHours               |
|access_level                |str  |accessLevel                         |
|guest_last_name             |str  |guestLastName *Optional*            |
|guest_first_name            |str  |guestFirstName *Optional*           |
|guest_phone_number          |str  |guestPhoneNumber *Optional*         |
|guest_extension             |str  |guestExtension *Optional*           |
|guest_location_dialing_code |str  |guestLocationDialingCode *Optional* |
|guest_association_date_time |str  |guestAssociationDateTime *Optional* |
</div>


## `UserHotelingHostGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserHotelingHostGetRequest17()`.


**Attributes:**

|Name                        |Type |Description                         |
|----------------------------|-----|------------------------------------|
|is_active                   |bool |isActive                            |
|enforce_association_limit   |bool |enforceAssociationLimit             |
|association_limit_hours     |int  |associationLimitHours               |
|access_level                |str  |accessLevel                         |
|guest_last_name             |str  |guestLastName *Optional*            |
|guest_first_name            |str  |guestFirstName *Optional*           |
|guest_phone_number          |str  |guestPhoneNumber *Optional*         |
|guest_extension             |str  |guestExtension *Optional*           |
|guest_location_dialing_code |str  |guestLocationDialingCode *Optional* |
|guest_association_date_time |str  |guestAssociationDateTime *Optional* |
</div>


## `UserINIntegrationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserINIntegrationGetRequest()`

**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|originating_service_key |int |originatingServiceKey *Optional* |
|terminating_service_key |int |terminatingServiceKey *Optional* |
</div>


## `UserInCallServiceActivationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserInCallServiceActivationGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserIntegratedIMPGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserIntegratedIMPGetRequest()`.

The response contains the Integrated IMP specific service attributes for the user.
Replaced by: `UserIntegratedIMPGetResponse21sp1()`

**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserIntegratedIMPGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserIntegratedIMPGetRequest21sp1()`.

The response contains the Integrated IMP specific service attributes for the user.
The following elements are only used in AS data mode and not returned in XS data mode:
impId isAlternateImpId

**Attributes:**

|Name                |Type |Description                 |
|--------------------|-----|----------------------------|
|is_active           |bool |isActive                    |
|imp_id              |str  |impId *Optional*            |
|is_alternate_imp_id |bool |isAlternateImpId *Optional* |
</div>


## `UserInterceptUserGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserInterceptUserGetRequest()`.

Replaced By: `UserInterceptUserGetResponse16()`

**Attributes:**

|Name                             |Type |Description                     |
|---------------------------------|-----|--------------------------------|
|is_active                        |bool |isActive                        |
|announcement_selection           |str  |announcementSelection           |
|audio_file_description           |str  |audioFileDescription *Optional* |
|video_file_description           |str  |videoFileDescription *Optional* |
|play_new_phone_number            |bool |playNewPhoneNumber              |
|new_phone_number                 |str  |newPhoneNumber *Optional*       |
|transfer_on_zero_to_phone_number |bool |transferOnZeroToPhoneNumber     |
|transfer_phone_number            |str  |transferPhoneNumber *Optional*  |
</div>


## `UserInterceptUserGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserInterceptUserGetRequest16()`.

Replaced By: `UserInterceptUserGetResponse16sp1()`

**Attributes:**

|Name                             |Type |Description                     |
|---------------------------------|-----|--------------------------------|
|is_active                        |bool |isActive                        |
|announcement_selection           |str  |announcementSelection           |
|audio_file_description           |str  |audioFileDescription *Optional* |
|audio_media_type                 |str  |audioMediaType *Optional*       |
|video_file_description           |str  |videoFileDescription *Optional* |
|video_media_type                 |str  |videoMediaType *Optional*       |
|play_new_phone_number            |bool |playNewPhoneNumber              |
|new_phone_number                 |str  |newPhoneNumber *Optional*       |
|transfer_on_zero_to_phone_number |bool |transferOnZeroToPhoneNumber     |
|transfer_phone_number            |str  |transferPhoneNumber *Optional*  |
</div>


## `UserInterceptUserGetResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserInterceptUserGetRequest16sp1()`.

Replaced by: `UserInterceptUserGetResponse21sp1()` in AS data mode

**Attributes:**

|Name                             |Type |Description                           |
|---------------------------------|-----|--------------------------------------|
|is_active                        |bool |isActive                              |
|announcement_selection           |str  |announcementSelection                 |
|audio_file_description           |str  |audioFileDescription *Optional*       |
|audio_media_type                 |str  |audioMediaType *Optional*             |
|video_file_description           |str  |videoFileDescription *Optional*       |
|video_media_type                 |str  |videoMediaType *Optional*             |
|play_new_phone_number            |bool |playNewPhoneNumber                    |
|new_phone_number                 |str  |newPhoneNumber *Optional*             |
|transfer_on_zero_to_phone_number |bool |transferOnZeroToPhoneNumber           |
|transfer_phone_number            |str  |transferPhoneNumber *Optional*        |
|reroute_outbound_calls           |bool |rerouteOutboundCalls                  |
|outbound_reroute_phone_number    |str  |outboundReroutePhoneNumber *Optional* |
|allow_outbound_local_calls       |bool |allowOutboundLocalCalls               |
|inbound_call_mode                |str  |inboundCallMode                       |
|alternate_blocking_announcement  |bool |alternateBlockingAnnouncement         |
|route_to_voice_mail              |bool |routeToVoiceMail                      |
</div>


## `UserInterceptUserGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserInterceptUserGetRequest21sp1()`.

The following elements are only used in AS data mode: exemptInboundMobilityCalls
exemptOutboundMobilityCalls disableParallelRingingToNetworkLocations

**Attributes:**

|Name                                          |Type |Description                              |
|----------------------------------------------|-----|-----------------------------------------|
|is_active                                     |bool |isActive                                 |
|announcement_selection                        |str  |announcementSelection                    |
|audio_file_description                        |str  |audioFileDescription *Optional*          |
|audio_media_type                              |str  |audioMediaType *Optional*                |
|video_file_description                        |str  |videoFileDescription *Optional*          |
|video_media_type                              |str  |videoMediaType *Optional*                |
|inbound_call_mode                             |str  |inboundCallMode                          |
|alternate_blocking_announcement               |bool |alternateBlockingAnnouncement            |
|exempt_inbound_mobility_calls                 |bool |exemptInboundMobilityCalls               |
|disable_parallel_ringing_to_network_locations |bool |disableParallelRingingToNetworkLocations |
|route_to_voice_mail                           |bool |routeToVoiceMail                         |
|play_new_phone_number                         |bool |playNewPhoneNumber                       |
|new_phone_number                              |str  |newPhoneNumber *Optional*                |
|transfer_on_zero_to_phone_number              |bool |transferOnZeroToPhoneNumber              |
|transfer_phone_number                         |str  |transferPhoneNumber *Optional*           |
|outbound_call_mode                            |str  |outboundCallMode                         |
|exempt_outbound_mobility_calls                |bool |exemptOutboundMobilityCalls              |
|reroute_outbound_calls                        |bool |rerouteOutboundCalls                     |
|outbound_reroute_phone_number                 |str  |outboundReroutePhoneNumber *Optional*    |
</div>


## `UserInternalCallingLineIDDeliveryGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserInternalCallingLineIDDeliveryGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserLegacyAutomaticCallbackGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserLegacyAutomaticCallbackGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserLinePortGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserLinePortGetListRequest()`.

Contains a table of line ports configured for a user The column headings are: "Line
Port", "Line Port Type", "In Trunk Group", "Contact", "Contact2", "Contact3",
"Contact4", "Contact5", " Authentication Mode ", and "Auto-Config Soft Client".

**Attributes:**

|Name            |Type                |Description                                                 |
|----------------|--------------------|------------------------------------------------------------|
|line_port_table |List(linePortTable) |linePortTable - *Table* array of linePortTable named tuples |
</div>


## `UserMWIDeliveryToMobileEndpointGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMWIDeliveryToMobileEndpointGetRequest()`.


**Attributes:**

|Name                |Type |Description                  |
|--------------------|-----|-----------------------------|
|is_active           |bool |isActive                     |
|mobile_phone_number |str  |mobilePhoneNumber *Optional* |
</div>


## `UserMeetMeConferencingAddConferenceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMeetMeConferencingAddConferenceRequest()`.


**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|conference_id |str |conferenceId |
|moderator_pin |str |moderatorPin |
</div>


## `UserMeetMeConferencingAddConferenceResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMeetMeConferencingAddConferenceRequest19()`.

Contains the information of a conference.  Replaced by:
`UserMeetMeConferencingAddConferenceResponse23()`

**Attributes:**

|Name          |Type|Description            |
|--------------|----|-----------------------|
|conference_id |str |conferenceId           |
|moderator_pin |str |moderatorPin           |
|security_pin  |str |securityPin *Optional* |
</div>


## `UserMeetMeConferencingAddConferenceResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMeetMeConferencingAddConferenceRequest23()`.

Contains the information of a conference.

**Attributes:**

|Name          |Type|Description            |
|--------------|----|-----------------------|
|conference_id |str |conferenceId           |
|moderator_pin |str |moderatorPin           |
|security_pin  |str |securityPin *Optional* |
</div>


## `UserMeetMeConferencingGetAvailableDelegateListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMeetMeConferencingGetAvailableDelegateListRequest()`.

Contains all hosts assigned on a bridge.  The table has column headings: "User Id",
"Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name", "Phone
Number", "Extension", "Department" and "Email Address".

**Attributes:**

|Name                           |Type                              |Description                                                                             |
|-------------------------------|----------------------------------|----------------------------------------------------------------------------------------|
|conference_delegate_user_table |List(conferenceDelegateUserTable) |conferenceDelegateUserTable - *Table* array of conferenceDelegateUserTable named tuples |
</div>


## `UserMeetMeConferencingGetBridgeListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserMeetMeConferencingGetBridgeListRequest()`.

Contains a table with column headings: "Bridge Id", "Name", "Phone Number",
"Extension", "Ports", and "Is Active" The column values for "Is Active" can either be
true, or false.

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|conference_bridge_table |List(conferenceBridgeTable) |conferenceBridgeTable - *Table* array of conferenceBridgeTable named tuples |
</div>


## `UserMeetMeConferencingGetConferenceDelegateListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMeetMeConferencingGetConferenceDelegateListRequest()`.

Contains a table with table heading:"User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name","Phone Number", "Extension", "Department" and "Email
Address".

**Attributes:**

|Name                           |Type                              |Description                                                                             |
|-------------------------------|----------------------------------|----------------------------------------------------------------------------------------|
|conference_delegate_user_table |List(conferenceDelegateUserTable) |conferenceDelegateUserTable - *Table* array of conferenceDelegateUserTable named tuples |
</div>


## `UserMeetMeConferencingGetConferenceGreetingResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMeetMeConferencingGetConferenceGreetingRequest()`.

Contains the information of a conference custom greeting.

**Attributes:**

|Name                         |Type |Description                          |
|-----------------------------|-----|-------------------------------------|
|play_entrance_greeting       |bool |playEntranceGreeting                 |
|entrance_greeting_audio_file |str  |entranceGreetingAudioFile *Optional* |
|entrance_greeting_media_type |str  |entranceGreetingMediaType *Optional* |
</div>


## `UserMeetMeConferencingGetConferenceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserMeetMeConferencingGetConferenceListRequest()`.

Contains a table with column headings: "Bridge Id", "Conference Id", "Title", "Bridge
Name", "Status", "Type", "Start Time", "Last Name", "First Name" and "Host Id". The
column values for "Status" can be Active, Inactive, or Expired.  The column values for
"Type" can be Reservationless, One Time, Recurring Daily, Recurring Weekly, Recurring
Monthly, or Recurring Yearly.  Start Time is in the format "yyyy-MM-
dd'T'HH:mm:ss:SSSZ". Example: 2010-10-01T09:30:00:000-0400.

**Attributes:**

|Name             |Type                  |Description                                                     |
|-----------------|----------------------|----------------------------------------------------------------|
|conference_table |List(conferenceTable) |conferenceTable - *Table* array of conferenceTable named tuples |
</div>


## `UserMeetMeConferencingGetConferenceRecordingListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserMeetMeConferencingGetConferenceRecordingListRequest()`.

Contains a table with column headings: "Bridge Id", "Conference Id", "Conference
Title", "Bridge Name", "Start Time", "File Size", and "URL". Start Time is in the
format "yyyy-MM-dd'T'HH:mm:ss:SSSZ". Example: 2010-10-01T09:30:00:000-0400.

**Attributes:**

|Name                       |Type                           |Description                                                                       |
|---------------------------|-------------------------------|----------------------------------------------------------------------------------|
|conference_recording_table |List(conferenceRecordingTable) |conferenceRecordingTable - *Table* array of conferenceRecordingTable named tuples |
</div>


## `UserMusicOnHoldGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMusicOnHoldGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserNetworkConferencingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserNetworkConferencingGetRequest()`.


**Attributes:**

|Name                   |Type|Description              |
|-----------------------|----|-------------------------|
|conference_uri         |str |conferenceURI *Optional* |
|max_conference_parties |int |maxConferenceParties     |
</div>


## `UserNumberPortabilityAnnouncementGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserNumberPortabilityAnnouncementGetRequest()`.

The response contains the user Number Portability attributes.

**Attributes:**

|Name   |Type |Description|
|-------|-----|-----------|
|enable |bool |enable     |
</div>


## `UserOCICallControlApplicationGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOCICallControlApplicationGetListRequest()`.


**Attributes:**

|Name           |Type      |Description              |
|---------------|----------|-------------------------|
|application_id |List[str] |applicationId *Optional* |
</div>


## `UserOutgoingCallingPlanAuthorizationCodeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanAuthorizationCodeGetRequest()`.


**Attributes:**

|Name                |Type |Description       |
|--------------------|-----|------------------|
|use_custom_settings |bool |useCustomSettings |
</div>


## `UserOutgoingCallingPlanSustainedAuthorizationCodeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanAuthorizationCodeGetRequest()`.


**Attributes:**

|Name |Type|Description     |
|-----|----|----------------|
|code |str |code *Optional* |
</div>


## `UserPBXIntegrationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPBXIntegrationGetRequest()`.


**Attributes:**

|Name                         |Type |Description              |
|-----------------------------|-----|-------------------------|
|proxy_to_header_from_network |bool |proxyToHeaderFromNetwork |
</div>


## `UserPasswordInfoGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPasswordInfoGetRequest()`.


**Attributes:**

|Name              |Type |Description               |
|------------------|-----|--------------------------|
|is_login_disabled |bool |isLoginDisabled           |
|expiration_days   |int  |expirationDays *Optional* |
|does_not_expire   |bool |doesNotExpire *Optional*  |
</div>


## `UserPersonalAssistantExclusionNumberGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPersonalAssistantExclusionNumberGetListRequest()`.

Contains a table with column headings: "Number", "Description".

**Attributes:**

|Name                   |Type                       |Description                                                               |
|-----------------------|---------------------------|--------------------------------------------------------------------------|
|exclusion_number_table |List(exclusionNumberTable) |exclusionNumberTable - *Table* array of exclusionNumberTable named tuples |
</div>


## `UserPersonalAssistantExclusionNumberGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPersonalAssistantExclusionNumberGetRequest()`

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|description |str |description *Optional* |
</div>


## `UserPersonalAssistantGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPersonalAssistantGetRequest()`.

The response contains the user Personal Assistant information". Replaced by:
`UserPersonalAssistantGetResponse22()`

**Attributes:**

|Name                         |Type |Description                |
|-----------------------------|-----|---------------------------|
|presence                     |str  |presence                   |
|enable_transfer_to_attendant |bool |enableTransferToAttendant  |
|attendant_number             |str  |attendantNumber *Optional* |
|enable_ring_splash           |bool |enableRingSplash           |
|enable_expiration_time       |bool |enableExpirationTime       |
|expiration_time              |str  |expirationTime *Optional*  |
</div>


## `UserPersonalAssistantGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPersonalAssistantGetRequest22()`.

The response contains the user Personal Assistant information".

**Attributes:**

|Name                           |Type |Description                |
|-------------------------------|-----|---------------------------|
|presence                       |str  |presence                   |
|enable_transfer_to_attendant   |bool |enableTransferToAttendant  |
|attendant_number               |str  |attendantNumber *Optional* |
|enable_ring_splash             |bool |enableRingSplash           |
|enable_expiration_time         |bool |enableExpirationTime       |
|expiration_time                |str  |expirationTime *Optional*  |
|alert_me_first                 |bool |alertMeFirst               |
|alert_me_first_number_of_rings |int  |alertMeFirstNumberOfRings  |
</div>


## `UserPersonalPhoneListGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPersonalPhoneListGetPagedSortedListRequest()`.

The response contains a user's personal phone list.  The response contains a table
with column headings: "Name" and "Phone Number".

**Attributes:**

|Name                      |Type                         |Description                                                                   |
|--------------------------|-----------------------------|------------------------------------------------------------------------------|
|total_number_of_rows      |int                          |totalNumberOfRows                                                             |
|personal_phone_list_table |List(personalPhoneListTable) |personalPhoneListTable - *Table* array of personalPhoneListTable named tuples |
</div>


## `UserPhoneDirectoryGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPhoneDirectoryGetListRequest()`.

The "My Room Room Id" and "My Room Bridge Id" are only populated for users assigned
the "Collaborate-Audio" service.  Contains a table with a row for each phone number
and column headings : "Name", "Number", "Extension", "Mobile", "Email Address",
"Department", "First Name", "Last Name", "User Id", "Title", "IMP Id", "My Room Room
Id", "My Room Bridge Id", "Service Name". The Service Name represents the localized
service name for service instances.  The localized values are taken from the
BroadworksLabel.properties file.  Service Name is currently supporting: AutoAttendant,
AutoAttendantStandard, AutoAttendantVideo, CallCenter, CallCenterStandard,
CallCenterPremium HuntGroup, InstantGroupCall, VoiceMessagingGroup, RoutePoint,
BroadWorksAnywhere, GroupPaging, FindmeFollowme, VoiceXML, FlexibleSeatingGuest,
CollaborateAudio, MeetMeConferencing.  For a Regular User or a Virtual On Network
Enterprise Extensions, the Service Name is empty.  The following columns are only
returned in AS data mode: "My Room Room Id", "My Room Bridge Id", "Service Name"

**Attributes:**

|Name            |Type                 |Description                                                   |
|----------------|---------------------|--------------------------------------------------------------|
|directory_table |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `UserPhoneDirectoryGetPagedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPhoneDirectoryGetPagedListRequest()`.

Returns the number of entries that would be returned if the response Was not page size
restricted.  The "My Room Room Id" and "My Room Bridge Id" are only populated for
users assigned the "Collaborate-Audio" service.  Contains a table with a row for each
user and column headings: "User Id", "First Name", "Last Name", "First Name Unicode",
"Last Name Unicode", "Hiragana First Name", "Hiragana Last Name", "Title", "Phone
Number", "Extension", "Mobile", "Pager", "Email Address", "Yahoo Id", "Department",
"Group Id", "Location", "Address Line 1", "Address Line 2", "City", "State", "Zip",
"Country", "IMP Id", "Location Code", "My Room Room Id", "My Room Bridge Id", "Service
Name", and "Receptionist Note". The Service Name represents the localized service name
for service instances.  The localized values are taken from the
BroadworksLabel.properties file.  Service Name is currently supporting: AutoAttendant,
AutoAttendantStandard, AutoAttendantVideo, CallCenter, CallCenterStandard,
CallCenterPremium HuntGroup, InstantGroupCall, VoiceMessagingGroup, RoutePoint,
BroadWorksAnywhere, GroupPaging, FindmeFollowme, VoiceXML, FlexibleSeatingGuest,
CollaborateAudio, MeetMeConferencing.  For a Regular User or a Virtual On Network
Enterprise Extensions, the Service Name is empty.

The response entries are sorted by "Last Name Unicode" first and "First Name unicode"
secondarily.  The following columns are only returned in AS data mode: "Location
Code", "My Room Room Id", "My Room Bridge Id", "Service Name", "Receptionist Note" The
Receptionist Note column is only populated, if the user sending the request is the
owner of the Receptionist Note and a Note exists.

**Attributes:**

|Name                 |Type                 |Description                                                   |
|---------------------|---------------------|--------------------------------------------------------------|
|total_number_of_rows |int                  |totalNumberOfRows                                             |
|directory_table      |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `UserPhoneDirectoryGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPhoneDirectoryGetPagedSortedListRequest()`.

Returns the number of entries that would be returned if the response Was not page size
restricted.  The "My Room Room Id" and "My Room Bridge Id" are only populated for
users assigned the "Collaborate-Audio" service.  Contains a table with a row for each
user and column headings: "User Id", "CLID First Name", "CLID Last Name", "First
Name", "Last Name", "Hiragana First Name", "Hiragana Last Name", "Title", "Phone
Number", "Extension", "Mobile", "Pager", "Email Address", "Yahoo Id", "Department",
"Group Id", "Location", "Address Line 1", "Address Line 2", "City", "State", "Zip",
"Country", "IMP Id", "Location Code", "My Room Room Id", "My Room Bridge Id", "Service
Name", and "Receptionist Note". The Service Name represents the localized service name
for service instances.  The localized values are taken from the
BroadworksLabel.properties file.  Service Name is currently supporting: AutoAttendant,
AutoAttendantStandard, AutoAttendantVideo, CallCenter, CallCenterStandard,
CallCenterPremium, HuntGroup, InstantGroupCall, VoiceMessagingGroup, RoutePoint,
BroadWorksAnywhere, GroupPaging, FindmeFollowme, VoiceXML, FlexibleSeatingGuest,
CollaborateAudio, MeetMeConferencing.  For a Regular User or a Virtual On Network
Enterprise Extensions, the Service Name is empty.  The Receptionist Note column is
only populated, if the user sending the request is the owner of the Receptionist Note
and a Note exists.  The following columns are returned in AS data mode only: "Service
Name", "Receptionist Notes"

**Attributes:**

|Name                 |Type                 |Description                                                   |
|---------------------|---------------------|--------------------------------------------------------------|
|total_number_of_rows |int                  |totalNumberOfRows                                             |
|directory_table      |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `UserPhoneDirectoryGetSearchedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPhoneDirectoryGetSearchedListRequest()`.

The "My Room Room Id" and "My Room Bridge Id" are only populated for users assigned
the "Collaborate-Audio" service.  Contains a table with a row for each phone number
and column headings : "Name", "Number", "Extension", "Mobile", "Email Address",
"Department", "Hiragana Name", "Group Id", "Yahoo Id", "User Id", "IMP Id", "First
Name", "Last Name", "My Room Room Id", "My Room Bridge Id", "Service Name". The
Service Name represents the localized service name for service instances.  The
localized values are taken from the BroadworksLabel.properties file.  Service Name is
currently supporting: AutoAttendant, AutoAttendantStandard, AutoAttendantVideo,
CallCenter, CallCenterStandard, CallCenterPremium HuntGroup, InstantGroupCall,
VoiceMessagingGroup, RoutePoint, BroadWorksAnywhere, GroupPaging, FindmeFollowme,
VoiceXML, FlexibleSeatingGuest, CollaborateAudio, MeetMeConferencing.  For a Regular
User or a Virtual On Network Enterprise Extensions, the Service Name is empty.  The
following columns are only returned in AS data mode: "My Room Room Id", "My Room
Bridge Id", "Service Name"

**Attributes:**

|Name            |Type                 |Description                                                   |
|----------------|---------------------|--------------------------------------------------------------|
|directory_table |List(directoryTable) |directoryTable - *Table* array of directoryTable named tuples |
</div>


## `UserPhysicalLocationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPhysicalLocationGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserPolycomPhoneServicesGetPrimaryEndpointListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPolycomPhoneServicesGetPrimaryEndpointListRequest()`.

The column headings for the deviceUserTable are: "Device Level", "Device Name",
"Line/Port".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|device_user_table |List(deviceUserTable) |deviceUserTable - *Table* array of deviceUserTable named tuples |
</div>


## `UserPolycomPhoneServicesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPolycomPhoneServicesGetRequest()`.


**Attributes:**

|Name                                                |Type |Description                                   |
|----------------------------------------------------|-----|----------------------------------------------|
|integrate_phone_directory_with_broad_works          |bool |integratePhoneDirectoryWithBroadWorks         |
|include_user_personal_phone_list_in_directory       |bool |includeUserPersonalPhoneListInDirectory       |
|include_group_custom_contact_directory_in_directory |bool |includeGroupCustomContactDirectoryInDirectory |
|group_custom_contact_directory                      |str  |groupCustomContactDirectory *Optional*        |
</div>


## `UserPortalPasscodeGetInfoResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPortalPasscodeGetInfoRequest()`.


**Attributes:**

|Name              |Type |Description               |
|------------------|-----|--------------------------|
|is_login_disabled |bool |isLoginDisabled           |
|expiration_days   |int  |expirationDays *Optional* |
|does_not_expire   |bool |doesNotExpire *Optional*  |
|passcode          |str  |passcode                  |
</div>


## `UserPortalPasscodeRulesGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPortalPasscodeRulesGetRequest()`.


**Attributes:**

|Name                                          |Type |Description                                |
|----------------------------------------------|-----|-------------------------------------------|
|disallow_repeated_digits                      |bool |disallowRepeatedDigits                     |
|number_of_repeated_digits                     |int  |numberOfRepeatedDigits                     |
|disallow_repeated_patterns                    |bool |disallowRepeatedPatterns                   |
|disallow_contiguous_sequences                 |bool |disallowContiguousSequences                |
|number_of_ascending_digits                    |int  |numberOfAscendingDigits                    |
|number_of_descending_digits                   |int  |numberOfDescendingDigits                   |
|disallow_user_number                          |bool |disallowUserNumber                         |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber                 |
|disallow_old_passcode                         |bool |disallowOldPasscode                        |
|number_of_previous_passcodes                  |int  |numberOfPreviousPasscodes                  |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode                |
|min_code_length                               |int  |minCodeLength                              |
|max_code_length                               |int  |maxCodeLength                              |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts    |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*          |
|expire_password                               |bool |expirePassword                             |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*             |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail               |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional* |
</div>


## `UserPreAlertingAnnouncementGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `UserPreAlertingAnnouncementGetRequest()`.

The criteria table's column headings are: "Is Active", "Criteria Name", "Blacklisted",
and "Calls From". Replaced by: `UserPreAlertingAnnouncementGetResponse20()` in AS data
mode

**Attributes:**

|Name                   |Type                |Description                                                 |
|-----------------------|--------------------|------------------------------------------------------------|
|is_active              |bool                |isActive                                                    |
|audio_selection        |str                 |audioSelection                                              |
|audio_file_description |str                 |audioFileDescription *Optional*                             |
|audio_media_type       |str                 |audioMediaType *Optional*                                   |
|audio_file_url         |str                 |audioFileUrl *Optional*                                     |
|video_selection        |str                 |videoSelection                                              |
|video_file_description |str                 |videoFileDescription *Optional*                             |
|video_media_type       |str                 |videoMediaType *Optional*                                   |
|video_file_url         |str                 |videoFileUrl *Optional*                                     |
|criteria_table         |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserPrepaidGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPrepaidGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserPrimaryEndpointAdvancedSettingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPrimaryEndpointAdvancedSettingGetRequest()`.


**Attributes:**

|Name              |Type |Description      |
|------------------|-----|-----------------|
|allow_origination |bool |allowOrigination |
|allow_termination |bool |allowTermination |
</div>


## `UserPriorityAlertGetCriteriaListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPriorityAlertGetCriteriaListRequest()`.

The criteria table's column headings are: "Is Active", "Criteria Name", "Time
Schedule", "Calls From", "Blacklisted", "Holiday Schedule", "Calls To Type", "Calls To
Number" and "Calls To Extension". The following columns are only returned in AS data
mode: "Calls To Type", "Calls To Number" and "Calls To Extension" The possible values
for the "Calls To Type" column are the following or a combination of them separated by
comma: - Primary - Alternate X (where x is a number between 1 and 10) - Mobility The
possible values for the "Calls To Number" column are the following or a combination of
them separated by comma: - The value of the phone number for the corresponding Calls
To Type, when the number is available.  i.e.  Alternate 1 may have extension, but no
number.  - When no number is available a blank space is provided instead.  The
possible values for the "Calls To Extension" column are the following or a combination
of them separated by comma: - The value of the extension for the corresponding Calls
To Type, when the extension is available.  i.e.  Primary may have number, but no
extension.  - For Mobility Calls To Type, this is always blank.  - When no extension
is available a blank space is provided instead.

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|criteria_table |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserPrivacyGetAvailableMonitorsUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPrivacyGetAvailableMonitorsUserListRequest()`.

Returns a 10 column table with column headings: "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name", "Phone Number", "Extension",
"Department", "Email Address", "IMP Id".

**Attributes:**

|Name                     |Type                         |Description                                                                   |
|-------------------------|-----------------------------|------------------------------------------------------------------------------|
|available_monitors_table |List(availableMonitorsTable) |availableMonitorsTable - *Table* array of availableMonitorsTable named tuples |
</div>


## `UserPrivacyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPrivacyGetRequest()`.


**Attributes:**

|Name                     |Type |Description            |
|-------------------------|-----|-----------------------|
|enable_directory_privacy |bool |enableDirectoryPrivacy |
</div>


## `UserPrivacyGetResponse13mp17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPrivacyGetRequest13mp17()`.

The permittedMonitorUserIdTable contains the members of the enterprise or group
allowed to monitor the phone status of the user specified in the request.  Members of
this table are allowed to monitor the user even if enablePhoneStatusPrivacy is set to
true.  The table contains column headings: "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name", "Phone Number", "Extension",
"Department", "Email Address", "IMP Id".

**Attributes:**

|Name                                            |Type                              |Description                                                                             |
|------------------------------------------------|----------------------------------|----------------------------------------------------------------------------------------|
|enable_directory_privacy                        |bool                              |enableDirectoryPrivacy                                                                  |
|enable_auto_attendant_extension_dialing_privacy |bool                              |enableAutoAttendantExtensionDialingPrivacy                                              |
|enable_auto_attendant_name_dialing_privacy      |bool                              |enableAutoAttendantNameDialingPrivacy                                                   |
|enable_phone_status_privacy                     |bool                              |enablePhoneStatusPrivacy                                                                |
|permitted_monitor_user_id_table                 |List(permittedMonitorUserIdTable) |permittedMonitorUserIdTable - *Table* array of permittedMonitorUserIdTable named tuples |
</div>


## `UserPushNotificationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPushNotificationGetRequest()`.

Replaced by: `UserPushNotificationResponse24()`

**Attributes:**

|Name                                     |Type |Description                        |
|-----------------------------------------|-----|-----------------------------------|
|send_push_notification_for_click_to_dial |bool |sendPushNotificationForClickToDial |
</div>


## `UserPushNotificationGetResponse24`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPushNotificationGetRequest24()`.


**Attributes:**

|Name                                     |Type |Description                        |
|-----------------------------------------|-----|-----------------------------------|
|send_push_notification_for_click_to_dial |bool |sendPushNotificationForClickToDial |
|send_push_notification_for_group_paging  |bool |sendPushNotificationForGroupPaging |
</div>


## `UserPushNotificationRegistrationGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPushNotificationRegistrationGetListRequest()`.

A registration has more than one row in the response when the registration includes
more than one token.  Registration Date uses the format "yyyy-MM-dd'T'HH:mm:ss.SSSZ"
in the time zone of the requested user.  Example: 2010-10-01T09:30:00:000-0400.
Contains a table with a row for each registration and token with column headings :
"User Id", "Registration Id", "Application Id", "Application Version", "Device Os
Type", "Device Os Version", "Registration Date", "Token", "Events" Replaced by:
`UserPushNotificationRegistrationGetListResponse21sp1()`

**Attributes:**

|Name                |Type                     |Description                                                           |
|--------------------|-------------------------|----------------------------------------------------------------------|
|registrations_table |List(registrationsTable) |registrationsTable - *Table* array of registrationsTable named tuples |
</div>


## `UserPushToTalkGetAvailableUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPushToTalkGetAvailableUserListRequest()`.

Returns a 10 column table with column headings: "User Id", "Last Name", "First Name",
"Hiragana Last Name", "Hiragana First Name", "Phone Number", "Extension",
"Department", "Email Address", "IMP Id".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserPushToTalkGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPushToTalkGetRequest()`.

It returns the service settings and a 9 column selected user table with the following
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Phone Number", "Extension", "Department", "Email Address", "IMP Id".

**Attributes:**

|Name                          |Type                    |Description                                                         |
|------------------------------|------------------------|--------------------------------------------------------------------|
|allow_auto_answer             |bool                    |allowAutoAnswer                                                     |
|outgoing_connection_selection |str                     |outgoingConnectionSelection                                         |
|access_list_selection         |str                     |accessListSelection                                                 |
|selected_user_table           |List(selectedUserTable) |selectedUserTable - *Table* array of selectedUserTable named tuples |
</div>


## `UserRemoteOfficeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserRemoteOfficeGetRequest()`.


**Attributes:**

|Name                       |Type |Description                        |
|---------------------------|-----|-----------------------------------|
|is_active                  |bool |isActive                           |
|remote_office_phone_number |str  |remoteOfficePhoneNumber *Optional* |
</div>


## `UserResourcePriorityGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserResourcePriorityGetRequest()`.

Contains the Resource Priority settings of a user.  If useDefaultResourcePriority is
true, parameter resourcePriority will not be returned.

**Attributes:**

|Name                          |Type |Description                |
|------------------------------|-----|---------------------------|
|use_default_resource_priority |bool |useDefaultResourcePriority |
|default_resource_priority     |str  |defaultResourcePriority    |
|user_resource_priority        |str  |userResourcePriority       |
</div>


## `UserRouteListGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserRouteListGetRequest()`.

Contains the route list setting and a list of assigned number ranges and number
prefixes.  The column headings for assignedNumberRangeTable are "Number Range Start",
"Number Range End" and "Is Active". Replaced by: `UserRouteListGetResponse22()`

**Attributes:**

|Name                                                |Type                           |Description                                                                       |
|----------------------------------------------------|-------------------------------|----------------------------------------------------------------------------------|
|treat_originations_and_pbx_redirections_as_screened |bool                           |treatOriginationsAndPBXRedirectionsAsScreened                                     |
|use_route_list_identity_for_non_emergency_calls     |bool                           |useRouteListIdentityForNonEmergencyCalls                                          |
|use_route_list_identity_for_emergency_calls         |bool                           |useRouteListIdentityForEmergencyCalls                                             |
|assigned_number_range_table                         |List(assignedNumberRangeTable) |assignedNumberRangeTable - *Table* array of assignedNumberRangeTable named tuples |
</div>


## `UserRouteListGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserRouteListGetRequest22()`.

Contains the route list setting and a list of assigned number ranges and number
prefixes.  The column headings for assignedNumberRangeTable are "Number Range Start",
"Number Range End", "Is Active" and “Extension Length”. The column headings for
assignedNumberPrefixTable are "Number Prefix" ","Is Active", “Extension Range Start”
and “Extension Range End”.

**Attributes:**

|Name                                                |Type                            |Description                                                                         |
|----------------------------------------------------|--------------------------------|------------------------------------------------------------------------------------|
|treat_originations_and_pbx_redirections_as_screened |bool                            |treatOriginationsAndPBXRedirectionsAsScreened                                       |
|use_route_list_identity_for_non_emergency_calls     |bool                            |useRouteListIdentityForNonEmergencyCalls                                            |
|use_route_list_identity_for_emergency_calls         |bool                            |useRouteListIdentityForEmergencyCalls                                               |
|assigned_number_range_table                         |List(assignedNumberRangeTable)  |assignedNumberRangeTable - *Table* array of assignedNumberRangeTable named tuples   |
|assigned_number_prefix_table                        |List(assignedNumberPrefixTable) |assignedNumberPrefixTable - *Table* array of assignedNumberPrefixTable named tuples |
</div>


## `UserRoutePointCallDispositionCodeGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserRoutePointCallDispositionCodeGetAvailableListRequest()`.

This list may include Group/Enterprise level codes in addition to the Route Point
level codes, depending on the call center disposition codes settings.  Only active
codes are included in the list.  Contains a table with column headings: "Code",
"Description" and "Level". Level column can be any of the values in the data type
CallDispositionCodeLevel.

**Attributes:**

|Name                    |Type                        |Description                                                                 |
|------------------------|----------------------------|----------------------------------------------------------------------------|
|disposition_codes_table |List(dispositionCodesTable) |dispositionCodesTable - *Table* array of dispositionCodesTable named tuples |
</div>


## `UserRoutePointSupervisorGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserRoutePointSupervisorGetListRequest()`.

Contains a table with column headings: "User Id", "Last Name", "First Name", "Hiragana
Last Name", "Hiragana First Name", "Phone Number", "Extension", "Department", "Email
Address", "Location Code".

**Attributes:**

|Name             |Type                  |Description                                                     |
|-----------------|----------------------|----------------------------------------------------------------|
|supervisor_table |List(supervisorTable) |supervisorTable - *Table* array of supervisorTable named tuples |
</div>


## `UserSMDIMessageDeskGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSMDIMessageDeskGetRequest()`.


**Attributes:**

|Name                |Type |Description                  |
|--------------------|-----|-----------------------------|
|is_active           |bool |isActive                     |
|message_desk_number |str  |messageDeskNumber *Optional* |
</div>


## `UserSMDIMessageDeskGetServerListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSMDIMessageDeskGetServerListRequest()`.

The SMDI Server table column headings are: "Device Name", "Net Address", "Port".

**Attributes:**

|Name              |Type                  |Description                                                     |
|------------------|----------------------|----------------------------------------------------------------|
|smdi_server_table |List(smdiServerTable) |smdiServerTable - *Table* array of smdiServerTable named tuples |
</div>


## `UserScheduleGetEventListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserScheduleGetEventListRequest()`.

The response contains a list of events.

**Attributes:**

|Name       |Type      |Description          |
|-----------|----------|---------------------|
|event_name |List[str] |eventName *Optional* |
</div>


## `UserScheduleGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserScheduleGetListRequest()`.

The response contains a list of system schedules.

**Attributes:**

|Name           |Type      |Description              |
|---------------|----------|-------------------------|
|schedule_name  |List[str] |scheduleName *Optional*  |
|schedule_type  |List[str] |scheduleType *Optional*  |
|schedule_level |List[str] |scheduleLevel *Optional* |
</div>


## `UserScheduleGetPagedSortedListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserScheduleGetPagedSortedListRequest()`.

Contains a 3 column table with column headings: "Name", "Type", "Level" and a row for
each schedule.

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|schedule_table |List(scheduleTable) |scheduleTable - *Table* array of scheduleTable named tuples |
</div>


## `UserSecurityClassificationGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSecurityClassificationGetRequest()`.


**Attributes:**

|Name                    |Type|Description                       |
|------------------------|----|----------------------------------|
|security_classification |str |securityClassification *Optional* |
</div>


## `UserSecurityClassificationGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSecurityClassificationGetRequest22()`.

The following elements are only used in Amplify data mode and not returned in AS and
XS data mode: customizedSecurityClassification

**Attributes:**

|Name                               |Type|Description                                 |
|-----------------------------------|----|--------------------------------------------|
|security_classification            |str |securityClassification *Optional*           |
|customized_security_classification |str |customizedSecurityClassification *Optional* |
</div>


## `UserSelectiveCallAcceptanceGetCriteriaListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSelectiveCallAcceptanceGetCriteriaListRequest()`.

The criteria table's column headings are: "Is Active", "Criteria Name", "Time
Schedule", "Calls From", "Blacklisted", "Holiday Schedule", "Calls To Type", "Calls To
Number" and "Calls To Extension". The following columns are only returned in AS data
mode: "Calls To Type", "Calls To Number" and "Calls To Extension" The possible values
for the "Calls To Type" column are the following or a combination of them separated by
comma: - Primary - Alternate X (where x is a number between 1 and 10) - Mobility The
possible values for the "Calls To Number" column are the following or a combination of
them separated by comma: - The value of the phone number for the corresponding Calls
To Type, when the number is available.  i.e.  Alternate 1 may have extension, but no
number.  - When no number is available a blank space is provided instead.  The
possible values for the "Calls To Extension" column are the following or a combination
of them separated by comma: - The value of the extension for the corresponding Calls
To Type, when the extension is available.  i.e.  Primary may have number, but no
extension.  - For Mobility Calls To Type, this is always blank.  - When no extension
is available a blank space is provided instead.

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|criteria_table |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserSelectiveCallRejectionGetCriteriaListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSelectiveCallRejectionGetCriteriaListRequest()`.

The criteria table's column headings are: "Is Active", "Criteria Name", "Time
Schedule", "Calls From", "Blacklisted", "Holiday Schedule", "Calls To Type", "Calls To
Number" and "Calls To Extension". The following columns are only returned in AS data
mode: "Calls To Type", "Calls To Number" and "Calls To Extension" The possible values
for the "Calls To Type" column are the following or a combination of them separated by
comma: - Primary - Alternate X (where x is a number between 1 and 10) - Mobility The
possible values for the "Calls To Number" column are the following or a combination of
them separated by comma: - The value of the phone number for the corresponding Calls
To Type, when the number is available.  i.e.  Alternate 1 may have extension, but no
number.  - When no number is available a blank space is provided instead.  The
possible values for the "Calls To Extension" column are the following or a combination
of them separated by comma: - The value of the extension for the corresponding Calls
To Type, when the extension is available.  i.e.  Primary may have number, but no
extension.  - For Mobility Calls To Type, this is always blank.  - When no extension
is available a blank space is provided instead.

**Attributes:**

|Name           |Type                |Description                                                 |
|---------------|--------------------|------------------------------------------------------------|
|criteria_table |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserSeriesCompletionGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSeriesCompletionGetRequest()`.

Identifies which Series Completion group the user belongs to and the list of users in
the group.  Contains a table with column headings: "User Id", "Last Name", "First
Name", "Hiragana Last Name", "Hiragana First Name", "Department", "Phone Number",
"Extension", "Email Address".

**Attributes:**

|Name       |Type            |Description                                         |
|-----------|----------------|----------------------------------------------------|
|name       |str             |name *Optional*                                     |
|user_table |List(userTable) |userTable - *Table* array of userTable named tuples |
</div>


## `UserServiceGetAssignmentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserServiceGetAssignmentListRequest()`.

Contains two tables, one for the service packs, and one for the user services.  The
user table has the column headings: "Service Name", "Assigned", The service pack
table's column headings are: "Service Pack Name", "Assigned", "Description". The
"Assigned" column has either a true or false value

**Attributes:**

|Name                           |Type                              |Description                                                                             |
|-------------------------------|----------------------------------|----------------------------------------------------------------------------------------|
|service_packs_assignment_table |List(servicePacksAssignmentTable) |servicePacksAssignmentTable - *Table* array of servicePacksAssignmentTable named tuples |
|user_services_assignment_table |List(userServicesAssignmentTable) |userServicesAssignmentTable - *Table* array of userServicesAssignmentTable named tuples |
</div>


## `UserServiceIsAssignedResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Returns true if the UserService or service pack is assigned, otherwise false.


**Attributes:**

|Name        |Type |Description|
|------------|-----|-----------|
|is_assigned |bool |isAssigned |
</div>


## `UserShInterfaceGetPublicIdDataResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserShInterfaceGetPublicIdDataRequest()`.

The response contains the Sh non-transparent data for the specified Public User
Identity.  The data also includes a userId, userType, and endpointType.  Replaced by:
`UserShInterfaceGetPublicIdDataResponse21sp1()`.

**Attributes:**

|Name           |Type|Description          |
|---------------|----|---------------------|
|user_id        |str |userId               |
|user_type      |str |userType             |
|endpoint_type  |str |endpointType         |
|scscf_name     |str |SCSCFName *Optional* |
|ims_user_state |str |IMSUserState         |
</div>


## `UserShInterfaceGetPublicIdDataResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserShInterfaceGetPublicIdDataRequest21sp1()`.

The response contains the Sh non-transparent data for the specified Public User
Identity.  The data also includes a userId, userType, and endpointType.  The value
Mobility in Endpoint Type is only applicable in AS data mode.

**Attributes:**

|Name           |Type|Description          |
|---------------|----|---------------------|
|user_id        |str |userId               |
|user_type      |str |userType             |
|endpoint_type  |str |endpointType         |
|scscf_name     |str |SCSCFName *Optional* |
|ims_user_state |str |IMSUserState         |
</div>


## `UserSharedCallAppearanceGetEndpointResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSharedCallAppearanceGetEndpointRequest()`.

Replaced by: `UserSharedCallAppearanceGetEndpointResponse21()` in XS data mode

**Attributes:**

|Name              |Type |Description      |
|------------------|-----|-----------------|
|is_active         |bool |isActive         |
|allow_origination |bool |allowOrigination |
|allow_termination |bool |allowTermination |
</div>


## `UserSharedCallAppearanceGetEndpointResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSharedCallAppearanceGetEndpointRequest()`.

The following elements are only used in AS data mode and not returned in XS data mode:
hotlineContact The following elements are only used in AS data mode and a value false
is returned in the XS mode: useHotline

**Attributes:**

|Name              |Type |Description               |
|------------------|-----|--------------------------|
|is_active         |bool |isActive                  |
|allow_origination |bool |allowOrigination          |
|allow_termination |bool |allowTermination          |
|use_hotline       |bool |useHotline                |
|hotline_contact   |str  |hotlineContact *Optional* |
</div>


## `UserSharedCallAppearanceGetResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSharedCallAppearanceGetRequest14()`.

The endpointTable contains columns: "Device Level", "Device Name", "Device Type",
"Line/Port", "SIP Contact". The "Device Level" column contains one of the
AccessDeviceLevel enumerated constants.

Replaced By: `UserSharedCallAppearanceGetResponse14sp2()`

**Attributes:**

|Name                                          |Type                |Description                                                 |
|----------------------------------------------|--------------------|------------------------------------------------------------|
|alert_all_appearances_for_click_to_dial_calls |bool                |alertAllAppearancesForClickToDialCalls                      |
|max_appearances                               |int                 |maxAppearances                                              |
|enable_multiple_call_arrangement              |bool                |enableMultipleCallArrangement                               |
|multiple_call_arrangement_is_active           |bool                |multipleCallArrangementIsActive                             |
|endpoint_table                                |List(endpointTable) |endpointTable - *Table* array of endpointTable named tuples |
|allow_bridging_between_locations              |bool                |allowBridgingBetweenLocations                               |
|bridge_warning_tone                           |str                 |bridgeWarningTone                                           |
</div>


## `UserSharedCallAppearanceGetResponse14sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSharedCallAppearanceGetRequest14sp2()`.

The endpointTable contains columns: "Device Level", "Device Name", "Device Type",
"Line/Port", "SIP Contact". The "Device Level" column contains one of the
AccessDeviceLevel enumerated constants.

**Attributes:**

|Name                                          |Type                |Description                                                 |
|----------------------------------------------|--------------------|------------------------------------------------------------|
|alert_all_appearances_for_click_to_dial_calls |bool                |alertAllAppearancesForClickToDialCalls                      |
|max_appearances                               |int                 |maxAppearances                                              |
|allow_sca_call_retrieve                       |bool                |allowSCACallRetrieve                                        |
|enable_multiple_call_arrangement              |bool                |enableMultipleCallArrangement                               |
|multiple_call_arrangement_is_active           |bool                |multipleCallArrangementIsActive                             |
|endpoint_table                                |List(endpointTable) |endpointTable - *Table* array of endpointTable named tuples |
|allow_bridging_between_locations              |bool                |allowBridgingBetweenLocations                               |
|bridge_warning_tone                           |str                 |bridgeWarningTone                                           |
</div>


## `UserSharedCallAppearanceGetResponse16sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSharedCallAppearanceGetRequest()`.

The endpointTable contains columns: "Device Level", "Device Name", "Device Type",
"Line/Port", "SIP Contact", "Port Number". "Private Identity" . The following columns
are only returned in XS data mode: "Private Identity" The "Device Level" column
contains one of the AccessDeviceLevel enumerated constants.  Port numbers are only
used by devices with static line ordering.  The following elements are only used in AS
data mode: enableCallParkNotification Replaced by:
`UserSharedCallAppearanceGetResponse21sp1()`.

**Attributes:**

|Name                                          |Type                |Description                                                 |
|----------------------------------------------|--------------------|------------------------------------------------------------|
|alert_all_appearances_for_click_to_dial_calls |bool                |alertAllAppearancesForClickToDialCalls                      |
|alert_all_appearances_for_group_paging_calls  |bool                |alertAllAppearancesForGroupPagingCalls                      |
|max_appearances                               |int                 |maxAppearances                                              |
|allow_sca_call_retrieve                       |bool                |allowSCACallRetrieve                                        |
|enable_multiple_call_arrangement              |bool                |enableMultipleCallArrangement                               |
|multiple_call_arrangement_is_active           |bool                |multipleCallArrangementIsActive                             |
|endpoint_table                                |List(endpointTable) |endpointTable - *Table* array of endpointTable named tuples |
|allow_bridging_between_locations              |bool                |allowBridgingBetweenLocations                               |
|bridge_warning_tone                           |str                 |bridgeWarningTone                                           |
|enable_call_park_notification                 |bool                |enableCallParkNotification                                  |
</div>


## `UserSharedCallAppearanceGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSharedCallAppearanceGetRequest21sp1()`.

The endpointTable contains columns: "Device Level", "Device Name", "Device Type",
"Line/Port", "SIP Contact", "Port Number", "Device Support Visual Device Management",
"Is Active", "Allow Origination", "Allow Termination", "Mac Address", "Path Header".
The "Device Level" column contains one of the AccessDeviceLevel enumerated constants.
The "SIP Contact" column does not contain "sip:" in 21sp1. Port numbers are only used
by devices with static line ordering.

**Attributes:**

|Name                                          |Type                |Description                                                 |
|----------------------------------------------|--------------------|------------------------------------------------------------|
|alert_all_appearances_for_click_to_dial_calls |bool                |alertAllAppearancesForClickToDialCalls                      |
|alert_all_appearances_for_group_paging_calls  |bool                |alertAllAppearancesForGroupPagingCalls                      |
|max_appearances                               |int                 |maxAppearances                                              |
|allow_sca_call_retrieve                       |bool                |allowSCACallRetrieve                                        |
|enable_multiple_call_arrangement              |bool                |enableMultipleCallArrangement                               |
|multiple_call_arrangement_is_active           |bool                |multipleCallArrangementIsActive                             |
|endpoint_table                                |List(endpointTable) |endpointTable - *Table* array of endpointTable named tuples |
|allow_bridging_between_locations              |bool                |allowBridgingBetweenLocations                               |
|bridge_warning_tone                           |str                 |bridgeWarningTone                                           |
|enable_call_park_notification                 |bool                |enableCallParkNotification                                  |
</div>


## `UserSilentAlertingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserSilentAlertingGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserSimultaneousRingFamilyGetPhoneNumberResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSimultaneousRingFamilyGetPhoneNumberRequest()`.


**Attributes:**

|Name                         |Type |Description                |
|-----------------------------|-----|---------------------------|
|answer_confirmation_required |bool |answerConfirmationRequired |
</div>


## `UserSimultaneousRingFamilyGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSimultaneousRingFamilyGetRequest()`.

Replaced By: `UserSimultaneousRingFamilyGetResponse14sp4()`

**Attributes:**

|Name                  |Type      |Description                   |
|----------------------|----------|------------------------------|
|is_active             |bool      |isActive                      |
|incoming_calls        |str       |incomingCalls                 |
|sim_ring_phone_number |List[str] |simRingPhoneNumber *Optional* |
</div>


## `UserSimultaneousRingFamilyGetResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSimultaneousRingFamilyGetRequest14sp4()`.

Contains a table with column headings: "Phone Number", "Answer Confirmation Required".

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|is_active          |bool                   |isActive                                                          |
|incoming_calls     |str                    |incomingCalls                                                     |
|phone_number_table |List(phoneNumberTable) |phoneNumberTable - *Table* array of phoneNumberTable named tuples |
</div>


## `UserSimultaneousRingPersonalGetPhoneNumberResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSimultaneousRingPersonalGetPhoneNumberRequest()`.


**Attributes:**

|Name                         |Type |Description                |
|-----------------------------|-----|---------------------------|
|answer_confirmation_required |bool |answerConfirmationRequired |
</div>


## `UserSimultaneousRingPersonalGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSimultaneousRingPersonalGetRequest()`.

Replaced By: `UserSimultaneousRingPersonalGetResponse14sp4()`

**Attributes:**

|Name                  |Type      |Description                   |
|----------------------|----------|------------------------------|
|is_active             |bool      |isActive                      |
|incoming_calls        |str       |incomingCalls                 |
|sim_ring_phone_number |List[str] |simRingPhoneNumber *Optional* |
</div>


## `UserSimultaneousRingPersonalGetResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSimultaneousRingPersonalGetRequest14sp4()`.

Contains a table with column headings: "Phone Number", "Answer Confirmation Required".

**Attributes:**

|Name               |Type                   |Description                                                       |
|-------------------|-----------------------|------------------------------------------------------------------|
|is_active          |bool                   |isActive                                                          |
|incoming_calls     |str                    |incomingCalls                                                     |
|phone_number_table |List(phoneNumberTable) |phoneNumberTable - *Table* array of phoneNumberTable named tuples |
</div>


## `UserSingleSignOnCreateDeviceTokenResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserSingleSignOnCreateDeviceTokenRequest()`.


**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|device_token |str |deviceToken |
</div>


## `UserSpeedDial100GetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSpeedDial100GetRequest()`.


**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|phone_number |str |phoneNumber            |
|description  |str |description *Optional* |
</div>


## `UserTerminatingAlternateTrunkIdentityGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserTerminatingAlternateTrunkIdentityGetRequest()`.


**Attributes:**

|Name                       |Type|Description                         |
|---------------------------|----|------------------------------------|
|terminating_trunk_identity |str |terminatingTrunkIdentity *Optional* |
</div>


## `UserTerminatingClosedUserGroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserTerminatingClosedUserGroupGetRequest()`.

Returns user Terminating CUG service settings.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|user_interlock_code |str |userInterlockCode *Optional* |
</div>


## `UserThirdPartyVoiceMailSupportGetResponse13mp16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserThirdPartyVoiceMailSupportGetRequest13mp16()`.

Replaced by: `UserThirdPartyVoiceMailSupportGetResponse17()`

**Attributes:**

|Name                             |Type |Description                 |
|---------------------------------|-----|----------------------------|
|is_active                        |bool |isActive                    |
|busy_redirect_to_voice_mail      |bool |busyRedirectToVoiceMail     |
|no_answer_redirect_to_voice_mail |bool |noAnswerRedirectToVoiceMail |
|server_selection                 |str  |serverSelection             |
|user_server                      |str  |userServer *Optional*       |
|mailbox_id_type                  |str  |mailboxIdType               |
|mailbox_url                      |str  |mailboxURL *Optional*       |
|no_answer_number_of_rings        |int  |noAnswerNumberOfRings       |
|always_redirect_to_voice_mail    |bool |alwaysRedirectToVoiceMail   |
</div>


## `UserThirdPartyVoiceMailSupportGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserThirdPartyVoiceMailSupportGetRequest17()`.


**Attributes:**

|Name                                       |Type |Description                         |
|-------------------------------------------|-----|------------------------------------|
|is_active                                  |bool |isActive                            |
|busy_redirect_to_voice_mail                |bool |busyRedirectToVoiceMail             |
|no_answer_redirect_to_voice_mail           |bool |noAnswerRedirectToVoiceMail         |
|server_selection                           |str  |serverSelection                     |
|user_server                                |str  |userServer *Optional*               |
|mailbox_id_type                            |str  |mailboxIdType                       |
|mailbox_url                                |str  |mailboxURL *Optional*               |
|no_answer_number_of_rings                  |int  |noAnswerNumberOfRings               |
|always_redirect_to_voice_mail              |bool |alwaysRedirectToVoiceMail           |
|out_of_primary_zone_redirect_to_voice_mail |bool |outOfPrimaryZoneRedirectToVoiceMail |
</div>


## `UserTimeScheduleGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserTimeScheduleGetListRequest()`.

The column headings are "Time Schedule" and "Type".

The response contains user's personal and user's group's schedule names.

**Attributes:**

|Name                |Type                    |Description                                                         |
|--------------------|------------------------|--------------------------------------------------------------------|
|time_schedule_table |List(timeScheduleTable) |timeScheduleTable - *Table* array of timeScheduleTable named tuples |
</div>


## `UserVoiceMessagingUserGetAdvancedVoiceManagementResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserVoiceMessagingUserGetAdvancedVoiceManagementRequest()`.

Replaced By: `UserVoiceMessagingUserGetAdvancedVoiceManagementResponse14sp3()`

**Attributes:**

|Name                                             |Type |Description                                          |
|-------------------------------------------------|-----|-----------------------------------------------------|
|mail_server_selection                            |str  |mailServerSelection                                  |
|group_mail_server_email_address                  |str  |groupMailServerEmailAddress *Optional*               |
|group_mail_server_user_id                        |str  |groupMailServerUserId *Optional*                     |
|group_mail_server_password                       |str  |groupMailServerPassword *Optional*                   |
|use_group_default_mail_server_full_mailbox_limit |bool |useGroupDefaultMailServerFullMailboxLimit *Optional* |
|group_mail_server_full_mailbox_limit             |int  |groupMailServerFullMailboxLimit *Optional*           |
|personal_mail_server_net_address                 |str  |personalMailServerNetAddress *Optional*              |
|personal_mail_server_protocol                    |str  |personalMailServerProtocol                           |
|personal_mail_server_real_delete_for_imap        |bool |personalMailServerRealDeleteForImap                  |
|personal_mail_server_email_address               |str  |personalMailServerEmailAddress *Optional*            |
|personal_mail_server_user_id                     |str  |personalMailServerUserId *Optional*                  |
|personal_mail_server_password                    |str  |personalMailServerPassword *Optional*                |
</div>


## `UserVoiceMessagingUserGetAdvancedVoiceManagementResponse14sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserVoiceMessagingUserGetAdvancedVoiceManagementRequest14sp3()`.


**Attributes:**

|Name                                             |Type |Description                                          |
|-------------------------------------------------|-----|-----------------------------------------------------|
|mail_server_selection                            |str  |mailServerSelection                                  |
|group_mail_server_email_address                  |str  |groupMailServerEmailAddress *Optional*               |
|group_mail_server_user_id                        |str  |groupMailServerUserId *Optional*                     |
|use_group_default_mail_server_full_mailbox_limit |bool |useGroupDefaultMailServerFullMailboxLimit *Optional* |
|group_mail_server_full_mailbox_limit             |int  |groupMailServerFullMailboxLimit *Optional*           |
|personal_mail_server_net_address                 |str  |personalMailServerNetAddress *Optional*              |
|personal_mail_server_protocol                    |str  |personalMailServerProtocol                           |
|personal_mail_server_real_delete_for_imap        |bool |personalMailServerRealDeleteForImap                  |
|personal_mail_server_email_address               |str  |personalMailServerEmailAddress *Optional*            |
|personal_mail_server_user_id                     |str  |personalMailServerUserId *Optional*                  |
</div>


## `UserVoiceMessagingUserGetAliasListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserVoiceMessagingUserGetAliasListRequest()`.


**Attributes:**

|Name         |Type      |Description            |
|-------------|----------|-----------------------|
|phone_number |List[str] |phoneNumber *Optional* |
</div>


## `UserVoiceMessagingUserGetDistributionListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserVoiceMessagingUserGetDistributionListRequest()`.


**Attributes:**

|Name         |Type      |Description            |
|-------------|----------|-----------------------|
|description  |str       |description *Optional* |
|phone_number |List[str] |phoneNumber *Optional* |
</div>


## `UserVoiceMessagingUserGetOutgoingSMDIMWIResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserVoiceMessagingUserGetOutgoingSMDIMWIRequest()`.


**Attributes:**

|Name                          |Type      |Description                           |
|------------------------------|----------|--------------------------------------|
|is_active                     |bool      |isActive                              |
|outgoing_smdimwi_phone_number |List[str] |outgoingSMDIMWIPhoneNumber *Optional* |
</div>


## `UserVoiceMessagingUserGetVoiceManagementResponse13mp8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserVoiceMessagingUserGetVoiceManagementRequest13mp8()`.

Replaced by: `UserVoiceMessagingUserGetVoiceManagementResponse17()`

**Attributes:**

|Name                                    |Type |Description                                   |
|----------------------------------------|-----|----------------------------------------------|
|is_active                               |bool |isActive                                      |
|processing                              |str  |processing                                    |
|voice_message_delivery_email_address    |str  |voiceMessageDeliveryEmailAddress *Optional*   |
|use_phone_message_waiting_indicator     |bool |usePhoneMessageWaitingIndicator               |
|send_voice_message_notify_email         |bool |sendVoiceMessageNotifyEmail                   |
|voice_message_notify_email_address      |str  |voiceMessageNotifyEmailAddress *Optional*     |
|send_carbon_copy_voice_message          |bool |sendCarbonCopyVoiceMessage                    |
|voice_message_carbon_copy_email_address |str  |voiceMessageCarbonCopyEmailAddress *Optional* |
|transfer_on_zero_to_phone_number        |bool |transferOnZeroToPhoneNumber                   |
|transfer_phone_number                   |str  |transferPhoneNumber *Optional*                |
|always_redirect_to_voice_mail           |bool |alwaysRedirectToVoiceMail                     |
|busy_redirect_to_voice_mail             |bool |busyRedirectToVoiceMail                       |
|no_answer_redirect_to_voice_mail        |bool |noAnswerRedirectToVoiceMail                   |
</div>


## `UserVoiceMessagingUserGetVoiceManagementResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserVoiceMessagingUserGetVoiceManagementRequest17()`.


**Attributes:**

|Name                                       |Type |Description                                   |
|-------------------------------------------|-----|----------------------------------------------|
|is_active                                  |bool |isActive                                      |
|processing                                 |str  |processing                                    |
|voice_message_delivery_email_address       |str  |voiceMessageDeliveryEmailAddress *Optional*   |
|use_phone_message_waiting_indicator        |bool |usePhoneMessageWaitingIndicator               |
|send_voice_message_notify_email            |bool |sendVoiceMessageNotifyEmail                   |
|voice_message_notify_email_address         |str  |voiceMessageNotifyEmailAddress *Optional*     |
|send_carbon_copy_voice_message             |bool |sendCarbonCopyVoiceMessage                    |
|voice_message_carbon_copy_email_address    |str  |voiceMessageCarbonCopyEmailAddress *Optional* |
|transfer_on_zero_to_phone_number           |bool |transferOnZeroToPhoneNumber                   |
|transfer_phone_number                      |str  |transferPhoneNumber *Optional*                |
|always_redirect_to_voice_mail              |bool |alwaysRedirectToVoiceMail                     |
|busy_redirect_to_voice_mail                |bool |busyRedirectToVoiceMail                       |
|no_answer_redirect_to_voice_mail           |bool |noAnswerRedirectToVoiceMail                   |
|out_of_primary_zone_redirect_to_voice_mail |bool |outOfPrimaryZoneRedirectToVoiceMail           |
</div>


## `UserVoiceMessagingUserGetVoicePortalPasswordInfoResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserVoiceMessagingUserGetVoicePortalPasswordInfoRequest()`.

Replaced By: `UserPortalPasscodeGetInfoResponse()`

**Attributes:**

|Name              |Type |Description               |
|------------------|-----|--------------------------|
|is_login_disabled |bool |isLoginDisabled           |
|expiration_days   |int  |expirationDays *Optional* |
|does_not_expire   |bool |doesNotExpire *Optional*  |
|password          |str  |password                  |
</div>


## `UserVoiceMessagingUserGetVoicePortalResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserVoiceMessagingUserGetVoicePortalRequest()`.

Replaced By: `UserVoiceMessagingUserGetVoicePortalResponse16()`

**Attributes:**

|Name                                     |Type |Description                                     |
|-----------------------------------------|-----|------------------------------------------------|
|use_personalized_name                    |bool |usePersonalizedName                             |
|voice_portal_auto_login                  |bool |voicePortalAutoLogin                            |
|personalized_name_audio_file_description |str  |personalizedNameAudioFileDescription *Optional* |
</div>


## `UserVoiceMessagingUserGetVoicePortalResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserVoiceMessagingUserGetVoicePortalRequest16()`.


**Attributes:**

|Name                                     |Type |Description                                     |
|-----------------------------------------|-----|------------------------------------------------|
|use_personalized_name                    |bool |usePersonalizedName                             |
|voice_portal_auto_login                  |bool |voicePortalAutoLogin                            |
|personalized_name_audio_file_description |str  |personalizedNameAudioFileDescription *Optional* |
|personalized_name_media_type             |str  |personalizedNameMediaType *Optional*            |
</div>


## `UserVoicePortalCallingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserVoicePortalCallingGetRequest()`.


**Attributes:**

|Name      |Type |Description|
|----------|-----|-----------|
|is_active |bool |isActive   |
</div>


## `UserXsiPolicyProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserXsiPolicyProfileGetRequest()`.


**Attributes:**

|Name               |Type|Description      |
|-------------------|----|-----------------|
|xsi_policy_profile |str |xsiPolicyProfile |
</div>


## `UserZoneCallingRestrictionsGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Gets the home zone for a user Response to a `UserZoneCallingRestrictionsGetRequest()`

**Attributes:**

|Name           |Type|Description             |
|---------------|----|------------------------|
|home_zone_name |str |homeZoneName *Optional* |
</div>


## `EnterpriseCommonPhoneListGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCommonPhoneListGetListRequest()`.

The response contains the enterprise's common phone list.

**Attributes:**

|Name  |Type            |Description      |
|------|----------------|-----------------|
|entry |List[OCI.entry] |entry *Optional* |
</div>


## `EnterpriseCommunicationBarringAuthorizationCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `EnterpriseCommunicationBarringAuthorizationCodeGetListRequest()`.

Contains a list of Communication Barring Authorization Codes assigned to a group.

**Attributes:**

|Name |Type           |Description     |
|-----|---------------|----------------|
|code |List[OCI.code] |code *Optional* |
</div>


## `EnterpriseDepartmentGetAvailableParentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseDepartmentGetAvailableParentListRequest()`.

The response includes two parallel arrays of department keys and department display
names.

**Attributes:**

|Name           |Type                    |Description              |
|---------------|------------------------|-------------------------|
|department_key |List[OCI.departmentKey] |departmentKey *Optional* |
|full_path_name |List[str]               |fullPathName *Optional*  |
</div>


## `EnterpriseDepartmentGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseDepartmentGetListRequest()`.

The response includes two parallel arrays of department keys and department display
names.

**Attributes:**

|Name           |Type                    |Description              |
|---------------|------------------------|-------------------------|
|department_key |List[OCI.departmentKey] |departmentKey *Optional* |
|full_path_name |List[str]               |fullPathName *Optional*  |
</div>


## `EnterpriseEnterpriseTrunkGetAvailableTrunkGroupListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseEnterpriseTrunkGetAvailableTrunkGroupListRequest()`.


**Attributes:**

|Name        |Type                 |Description           |
|------------|---------------------|----------------------|
|trunk_group |List[OCI.trunkGroup] |trunkGroup *Optional* |
</div>


## `EnterpriseVoiceVPNGetDefaultResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseVoiceVPNGetDefaultResponse()`.


**Attributes:**

|Name                         |Type                |Description                |
|-----------------------------|--------------------|---------------------------|
|policy_selection             |List[str]           |policySelection            |
|digit_manipulation_operation |List[str]           |digitManipulationOperation |
|route_group_id               |List[str]           |routeGroupId *Optional*    |
|treatment                    |List[OCI.treatment] |treatment *Optional*       |
</div>


## `EnterpriseVoiceVPNGetPolicyResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseVoiceVPNGetPolicyRequest()`.


**Attributes:**

|Name                 |Type                        |Description                  |
|---------------------|----------------------------|-----------------------------|
|min_extension_length |int                         |minExtensionLength           |
|max_extension_length |int                         |maxExtensionLength           |
|description          |str                         |description *Optional*       |
|route_group_id       |str                         |routeGroupId *Optional*      |
|policy_selection     |str                         |policySelection              |
|digit_manipulation   |List[OCI.digitManipulation] |digitManipulation *Optional* |
|treatment_id         |str                         |treatmentId *Optional*       |
</div>


## `GroupAccessDeviceGetLinkedLeafDeviceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetLinkedLeafDeviceListRequest()`.


**Attributes:**

|Name                |Type                    |Description              |
|--------------------|------------------------|-------------------------|
|tree_device_link_id |str                     |treeDeviceLinkId         |
|leaf_device_key     |List[OCI.leafDeviceKey] |leafDeviceKey *Optional* |
</div>


## `GroupAccessDeviceGetResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetRequest14()`.

Replaced By: `GroupAccessDeviceGetResponse14sp3()`

**Attributes:**

|Name                              |Type              |Description                              |
|----------------------------------|------------------|-----------------------------------------|
|device_type                       |str               |deviceType                               |
|protocol                          |str               |protocol *Optional*                      |
|net_address                       |str               |netAddress *Optional*                    |
|port                              |int               |port *Optional*                          |
|outbound_proxy_server_net_address |str               |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str               |stunServerNetAddress *Optional*          |
|mac_address                       |str               |macAddress *Optional*                    |
|serial_number                     |str               |serialNumber *Optional*                  |
|description                       |str               |description *Optional*                   |
|number_of_ports                   |OCI.numberOfPorts |numberOfPorts                            |
|number_of_assigned_ports          |int               |numberOfAssignedPorts                    |
|status                            |str               |status                                   |
|configuration_mode                |str               |configurationMode *Optional*             |
|configuration_file_name           |str               |configurationFileName *Optional*         |
|physical_location                 |str               |physicalLocation *Optional*              |
|transport_protocol                |str               |transportProtocol *Optional*             |
</div>


## `GroupAccessDeviceGetResponse14sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetRequest14sp3()`.

Replaced By: `GroupAccessDeviceGetResponse14sp6()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol *Optional*                                    |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|configuration_mode                               |str               |configurationMode *Optional*                           |
|configuration_file_name                          |str               |configurationFileName *Optional*                       |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
</div>


## `GroupAccessDeviceGetResponse14sp6`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to: `GroupAccessDeviceGetRequest14sp6()` Replaced by:
`GroupAccessDeviceGetResponse16()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol *Optional*                                    |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|configuration_mode                               |str               |configurationMode *Optional*                           |
|configuration_file_name                          |str               |configurationFileName *Optional*                       |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
</div>


## `GroupAccessDeviceGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetRequest16()`.


**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol *Optional*                                    |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|configuration_mode                               |str               |configurationMode *Optional*                           |
|configuration_file_name                          |str               |configurationFileName *Optional*                       |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
</div>


## `GroupAccessDeviceGetResponse18sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetRequest18sp1()`.

Replaced by: `GroupAccessDeviceGetResponse22()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol *Optional*                                    |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|configuration_mode                               |str               |configurationMode *Optional*                           |
|configuration_file_name                          |str               |configurationFileName *Optional*                       |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
|version                                          |str               |version *Optional*                                     |
</div>


## `GroupAccessDeviceGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetRequest22()`.

Replaced by `GroupAccessDeviceGetResponse24()`. The following elements are only used
in AS data mode: useHotline hotlineContact

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol *Optional*                                    |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|configuration_mode                               |str               |configurationMode *Optional*                           |
|configuration_file_name                          |str               |configurationFileName *Optional*                       |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
|version                                          |str               |version *Optional*                                     |
|use_hotline                                      |bool              |useHotline                                             |
|hotline_contact                                  |str               |hotlineContact *Optional*                              |
</div>


## `GroupAccessDeviceGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetRequest22V2()`.

The following elements are only returned in AS data mode: useHotline hotlineContact
serviceProviderId groupId The following elements are only used in AS data mode and not
returned in XS data mode: deviceName deviceExternalId Replaced by:
`GroupAccessDeviceGetResponse24()` in AS data mode.

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol *Optional*                                    |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|configuration_mode                               |str               |configurationMode *Optional*                           |
|configuration_file_name                          |str               |configurationFileName *Optional*                       |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
|version                                          |str               |version *Optional*                                     |
|use_hotline                                      |bool              |useHotline                                             |
|hotline_contact                                  |str               |hotlineContact *Optional*                              |
|service_provider_id                              |str               |serviceProviderId                                      |
|group_id                                         |str               |groupId                                                |
|device_name                                      |str               |deviceName                                             |
|device_external_id                               |str               |deviceExternalId *Optional*                            |
</div>


## `GroupAccessDeviceGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetRequest22V3()`.

The following elements are only returned in AS data mode: serviceProviderId groupId
The following elements are only used in AS data mode and not returned in XS data mode:
deviceName deviceExternalId Replaced by `GroupAccessDeviceGetResponse24()`.

**Attributes:**

|Name                              |Type              |Description                              |
|----------------------------------|------------------|-----------------------------------------|
|device_type                       |str               |deviceType                               |
|protocol                          |str               |protocol *Optional*                      |
|net_address                       |str               |netAddress *Optional*                    |
|port                              |int               |port *Optional*                          |
|outbound_proxy_server_net_address |str               |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str               |stunServerNetAddress *Optional*          |
|mac_address                       |str               |macAddress *Optional*                    |
|serial_number                     |str               |serialNumber *Optional*                  |
|description                       |str               |description *Optional*                   |
|number_of_ports                   |OCI.numberOfPorts |numberOfPorts                            |
|number_of_assigned_ports          |int               |numberOfAssignedPorts                    |
|status                            |str               |status                                   |
|configuration_mode                |str               |configurationMode *Optional*             |
|configuration_file_name           |str               |configurationFileName *Optional*         |
|physical_location                 |str               |physicalLocation *Optional*              |
|transport_protocol                |str               |transportProtocol *Optional*             |
|use_custom_user_name_password     |bool              |useCustomUserNamePassword *Optional*     |
|user_name                         |str               |userName *Optional*                      |
|version                           |str               |version *Optional*                       |
|service_provider_id               |str               |serviceProviderId                        |
|group_id                          |str               |groupId                                  |
|device_name                       |str               |deviceName                               |
|device_external_id                |str               |deviceExternalId *Optional*              |
</div>


## `GroupAccessDeviceGetResponse24`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetRequest24()`.

The following elements are only used in AS data mode: serviceProviderId groupId
deviceName deviceExternalId

**Attributes:**

|Name                              |Type              |Description                              |
|----------------------------------|------------------|-----------------------------------------|
|device_type                       |str               |deviceType                               |
|protocol                          |str               |protocol *Optional*                      |
|net_address                       |str               |netAddress *Optional*                    |
|port                              |int               |port *Optional*                          |
|outbound_proxy_server_net_address |str               |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str               |stunServerNetAddress *Optional*          |
|mac_address                       |str               |macAddress *Optional*                    |
|serial_number                     |str               |serialNumber *Optional*                  |
|description                       |str               |description *Optional*                   |
|number_of_ports                   |OCI.numberOfPorts |numberOfPorts                            |
|number_of_assigned_ports          |int               |numberOfAssignedPorts                    |
|status                            |str               |status                                   |
|configuration_mode                |str               |configurationMode *Optional*             |
|configuration_file_name           |str               |configurationFileName *Optional*         |
|physical_location                 |str               |physicalLocation *Optional*              |
|transport_protocol                |str               |transportProtocol *Optional*             |
|use_custom_user_name_password     |bool              |useCustomUserNamePassword *Optional*     |
|user_name                         |str               |userName *Optional*                      |
|version                           |str               |version *Optional*                       |
|service_provider_id               |str               |serviceProviderId                        |
|group_id                          |str               |groupId                                  |
|device_name                       |str               |deviceName                               |
|device_external_id                |str               |deviceExternalId *Optional*              |
</div>


## `GroupAccountAuthorizationCodesGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccountAuthorizationCodesGetListRequest()`.


**Attributes:**

|Name       |Type                |Description          |
|-----------|--------------------|---------------------|
|code_entry |List[OCI.codeEntry] |codeEntry *Optional* |
</div>


## `GroupAnnouncementFileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAnnouncementFileGetRequest22()`.

The response contains the file size, uploaded timestamp, description and usage for an
announcement file in the user announcement repository.  The usage table has columns
"Service Name", and "Instance Name". The Service Name values correspond to string
values of the GroupService and UserService data types.  With the exception of the
string "Voice Portal" which is returned when the announcement is being used by Voice
Portal Personalized Name.  The following data elements are only used in AS data mode:
announcementFileExternalId

**Attributes:**

|Name                          |Type                    |Description                                           |
|------------------------------|------------------------|------------------------------------------------------|
|description                   |str                     |description                                           |
|filesize                      |int                     |filesize                                              |
|last_uploaded                 |str                     |lastUploaded                                          |
|service_provider_id           |str                     |serviceProviderId                                     |
|group_id                      |str                     |groupId                                               |
|announcement_file_key         |OCI.announcementFileKey |announcementFileKey                                   |
|announcement_file_external_id |str                     |announcementFileExternalId *Optional*                 |
|usage_table                   |List(usageTable)        |usageTable - *Table* array of usageTable named tuples |
</div>


## `GroupBroadWorksMobilityGetResponse22V4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The response to a `GroupBroadWorksMobilityGetRequest22V4()`.


**Attributes:**

|Name                                           |Type                 |Description                               |
|-----------------------------------------------|---------------------|------------------------------------------|
|use_setting_level                              |str                  |useSettingLevel                           |
|enable_location_services                       |bool                 |enableLocationServices                    |
|enable_msrn_lookup                             |bool                 |enableMSRNLookup                          |
|enable_mobile_state_checking                   |bool                 |enableMobileStateChecking                 |
|deny_call_originations                         |bool                 |denyCallOriginations                      |
|deny_call_terminations                         |bool                 |denyCallTerminations                      |
|enable_announcement_suppression                |bool                 |enableAnnouncementSuppression             |
|enable_internal_clid_delivery                  |bool                 |enableInternalCLIDDelivery                |
|enable_internal_clid_delivery_access_locations |bool                 |enableInternalCLIDDeliveryAccessLocations |
|enable_enhanced_unreachable_state_checking     |bool                 |enableEnhancedUnreachableStateChecking    |
|enable_network_call_barring_status_check       |bool                 |enableNetworkCallBarringStatusCheck       |
|network_translation_index                      |str                  |networkTranslationIndex *Optional*        |
|enable_pbx_route_policy                        |bool                 |enablePBXRoutePolicy                      |
|pbx_route_identity                             |OCI.pbxRouteIdentity |pbxRouteIdentity *Optional*               |
</div>


## `GroupCallCenterComfortMessageBypassGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterComfortMessageBypassGetRequest17()`.

Replaced by: `GroupCallCenterComfortMessageBypassGetResponse20()`

**Attributes:**

|Name                                          |Type                   |Description                              |
|----------------------------------------------|-----------------------|-----------------------------------------|
|is_active                                     |bool                   |isActive                                 |
|call_waiting_age_threshold_seconds            |int                    |callWaitingAgeThresholdSeconds           |
|play_announcement_after_ringing               |bool                   |playAnnouncementAfterRinging             |
|ring_time_before_playing_announcement_seconds |int                    |ringTimeBeforePlayingAnnouncementSeconds |
|audio_message_selection                       |str                    |audioMessageSelection                    |
|audio_url_list                                |OCI.audioUrlList       |audioUrlList *Optional*                  |
|audio_file_list                               |OCI.audioFileList      |audioFileList *Optional*                 |
|audio_media_type_list                         |OCI.audioMediaTypeList |audioMediaTypeList *Optional*            |
|video_message_selection                       |str                    |videoMessageSelection                    |
|video_url_list                                |OCI.videoUrlList       |videoUrlList *Optional*                  |
|video_file_list                               |OCI.videoFileList      |videoFileList *Optional*                 |
|video_media_type_list                         |OCI.videoMediaTypeList |videoMediaTypeList *Optional*            |
</div>


## `GroupCallCenterForcedForwardingGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterForcedForwardingGetRequest17()`.


**Attributes:**

|Name                                |Type                   |Description                      |
|------------------------------------|-----------------------|---------------------------------|
|is_active                           |bool                   |isActive                         |
|forward_to_phone_number             |str                    |forwardToPhoneNumber *Optional*  |
|allow_enable_via_fac                |bool                   |allowEnableViaFAC                |
|play_announcement_before_forwarding |bool                   |playAnnouncementBeforeForwarding |
|audio_message_selection             |str                    |audioMessageSelection            |
|audio_url_list                      |OCI.audioUrlList       |audioUrlList *Optional*          |
|audio_file_list                     |OCI.audioFileList      |audioFileList *Optional*         |
|audio_media_type_list               |OCI.audioMediaTypeList |audioMediaTypeList *Optional*    |
|video_message_selection             |str                    |videoMessageSelection            |
|video_url_list                      |OCI.videoUrlList       |videoUrlList *Optional*          |
|video_file_list                     |OCI.videoFileList      |videoFileList *Optional*         |
|video_media_type_list               |OCI.videoMediaTypeList |videoMediaTypeList *Optional*    |
</div>


## `GroupCallCenterGetAnnouncementResponse14sp6`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAnnouncementRequest14sp6()`.


**Attributes:**

|Name                                            |Type                     |Description                                           |
|------------------------------------------------|-------------------------|------------------------------------------------------|
|entrance_message_selection                      |str                      |entranceMessageSelection                              |
|entrance_message_audio_file_description         |str                      |entranceMessageAudioFileDescription *Optional*        |
|entrance_message_video_file_description         |str                      |entranceMessageVideoFileDescription *Optional*        |
|periodic_comfort_message_selection              |str                      |periodicComfortMessageSelection                       |
|periodic_comfort_message_audio_file_description |str                      |periodicComfortMessageAudioFileDescription *Optional* |
|periodic_comfort_message_video_file_description |str                      |periodicComfortMessageVideoFileDescription *Optional* |
|on_hold_source                                  |OCI.onHoldSource         |onHoldSource                                          |
|on_hold_use_alternate_source_for_internal_calls |bool                     |onHoldUseAlternateSourceForInternalCalls              |
|on_hold_internal_source                         |OCI.onHoldInternalSource |onHoldInternalSource *Optional*                       |
</div>


## `GroupCallCenterHolidayServiceGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterHolidayServiceGetRequest17()`.


**Attributes:**

|Name                            |Type                   |Description                    |
|--------------------------------|-----------------------|-------------------------------|
|action                          |str                    |action                         |
|holiday_schedule                |str                    |holidaySchedule *Optional*     |
|transfer_phone_number           |str                    |transferPhoneNumber *Optional* |
|play_announcement_before_action |bool                   |playAnnouncementBeforeAction   |
|audio_message_selection         |str                    |audioMessageSelection          |
|audio_url_list                  |OCI.audioUrlList       |audioUrlList *Optional*        |
|audio_file_list                 |OCI.audioFileList      |audioFileList *Optional*       |
|audio_media_type_list           |OCI.audioMediaTypeList |audioMediaTypeList *Optional*  |
|video_message_selection         |str                    |videoMessageSelection          |
|video_url_list                  |OCI.videoUrlList       |videoUrlList *Optional*        |
|video_file_list                 |OCI.videoFileList      |videoFileList *Optional*       |
|video_media_type_list           |OCI.videoMediaTypeList |videoMediaTypeList *Optional*  |
</div>


## `GroupCallCenterHolidayServiceGetResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterHolidayServiceGetRequest17sp1()`.


**Attributes:**

|Name                            |Type                   |Description                    |
|--------------------------------|-----------------------|-------------------------------|
|action                          |str                    |action                         |
|holiday_schedule                |OCI.holidaySchedule    |holidaySchedule *Optional*     |
|transfer_phone_number           |str                    |transferPhoneNumber *Optional* |
|play_announcement_before_action |bool                   |playAnnouncementBeforeAction   |
|audio_message_selection         |str                    |audioMessageSelection          |
|audio_url_list                  |OCI.audioUrlList       |audioUrlList *Optional*        |
|audio_file_list                 |OCI.audioFileList      |audioFileList *Optional*       |
|audio_media_type_list           |OCI.audioMediaTypeList |audioMediaTypeList *Optional*  |
|video_message_selection         |str                    |videoMessageSelection          |
|video_url_list                  |OCI.videoUrlList       |videoUrlList *Optional*        |
|video_file_list                 |OCI.videoFileList      |videoFileList *Optional*       |
|video_media_type_list           |OCI.videoMediaTypeList |videoMediaTypeList *Optional*  |
</div>


## `GroupCallCenterNightServiceGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterNightServiceGetRequest17()`.


**Attributes:**

|Name                            |Type                         |Description                         |
|--------------------------------|-----------------------------|------------------------------------|
|action                          |str                          |action                              |
|business_hours                  |str                          |businessHours *Optional*            |
|force_night_service             |bool                         |forceNightService                   |
|allow_manual_override_via_fac   |bool                         |allowManualOverrideViaFAC           |
|transfer_phone_number           |str                          |transferPhoneNumber *Optional*      |
|play_announcement_before_action |bool                         |playAnnouncementBeforeAction        |
|audio_message_selection         |str                          |audioMessageSelection               |
|audio_url_list                  |OCI.audioUrlList             |audioUrlList *Optional*             |
|audio_file_list                 |OCI.audioFileList            |audioFileList *Optional*            |
|audio_media_type_list           |OCI.audioMediaTypeList       |audioMediaTypeList *Optional*       |
|video_message_selection         |str                          |videoMessageSelection               |
|video_url_list                  |OCI.videoUrlList             |videoUrlList *Optional*             |
|video_file_list                 |OCI.videoFileList            |videoFileList *Optional*            |
|video_media_type_list           |OCI.videoMediaTypeList       |videoMediaTypeList *Optional*       |
|manual_announcement_mode        |str                          |manualAnnouncementMode              |
|manual_audio_message_selection  |str                          |manualAudioMessageSelection         |
|manual_audio_url_list           |OCI.manualAudioUrlList       |manualAudioUrlList *Optional*       |
|manual_audio_file_list          |OCI.manualAudioFileList      |manualAudioFileList *Optional*      |
|manual_audio_media_type_list    |OCI.manualAudioMediaTypeList |manualAudioMediaTypeList *Optional* |
|manual_video_message_selection  |str                          |manualVideoMessageSelection         |
|manual_video_url_list           |OCI.manualVideoUrlList       |manualVideoUrlList *Optional*       |
|manual_video_file_list          |OCI.manualVideoFileList      |manualVideoFileList *Optional*      |
|manual_video_media_type_list    |OCI.manualVideoMediaTypeList |manualVideoMediaTypeList *Optional* |
</div>


## `GroupCallCenterNightServiceGetResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterNightServiceGetRequest17sp1()`.


**Attributes:**

|Name                            |Type                         |Description                         |
|--------------------------------|-----------------------------|------------------------------------|
|action                          |str                          |action                              |
|business_hours                  |OCI.businessHours            |businessHours *Optional*            |
|force_night_service             |bool                         |forceNightService                   |
|allow_manual_override_via_fac   |bool                         |allowManualOverrideViaFAC           |
|transfer_phone_number           |str                          |transferPhoneNumber *Optional*      |
|play_announcement_before_action |bool                         |playAnnouncementBeforeAction        |
|audio_message_selection         |str                          |audioMessageSelection               |
|audio_url_list                  |OCI.audioUrlList             |audioUrlList *Optional*             |
|audio_file_list                 |OCI.audioFileList            |audioFileList *Optional*            |
|audio_media_type_list           |OCI.audioMediaTypeList       |audioMediaTypeList *Optional*       |
|video_message_selection         |str                          |videoMessageSelection               |
|video_url_list                  |OCI.videoUrlList             |videoUrlList *Optional*             |
|video_file_list                 |OCI.videoFileList            |videoFileList *Optional*            |
|video_media_type_list           |OCI.videoMediaTypeList       |videoMediaTypeList *Optional*       |
|manual_announcement_mode        |str                          |manualAnnouncementMode              |
|manual_audio_message_selection  |str                          |manualAudioMessageSelection         |
|manual_audio_url_list           |OCI.manualAudioUrlList       |manualAudioUrlList *Optional*       |
|manual_audio_file_list          |OCI.manualAudioFileList      |manualAudioFileList *Optional*      |
|manual_audio_media_type_list    |OCI.manualAudioMediaTypeList |manualAudioMediaTypeList *Optional* |
|manual_video_message_selection  |str                          |manualVideoMessageSelection         |
|manual_video_url_list           |OCI.manualVideoUrlList       |manualVideoUrlList *Optional*       |
|manual_video_file_list          |OCI.manualVideoFileList      |manualVideoFileList *Optional*      |
|manual_video_media_type_list    |OCI.manualVideoMediaTypeList |manualVideoMediaTypeList *Optional* |
</div>


## `GroupCallCenterOverflowGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterOverflowGetRequest17()` .


**Attributes:**

|Name                                         |Type                   |Description                              |
|---------------------------------------------|-----------------------|-----------------------------------------|
|action                                       |str                    |action                                   |
|transfer_phone_number                        |str                    |transferPhoneNumber *Optional*           |
|overflow_after_timeout                       |bool                   |overflowAfterTimeout                     |
|timeout_seconds                              |int                    |timeoutSeconds                           |
|play_announcement_before_overflow_processing |bool                   |playAnnouncementBeforeOverflowProcessing |
|audio_message_selection                      |str                    |audioMessageSelection                    |
|audio_url_list                               |OCI.audioUrlList       |audioUrlList *Optional*                  |
|audio_file_list                              |OCI.audioFileList      |audioFileList *Optional*                 |
|audio_media_type_list                        |OCI.audioMediaTypeList |audioMediaTypeList *Optional*            |
|video_message_selection                      |str                    |videoMessageSelection *Optional*         |
|video_url_list                               |OCI.videoUrlList       |videoUrlList *Optional*                  |
|video_file_list                              |OCI.videoFileList      |videoFileList *Optional*                 |
|video_media_type_list                        |OCI.videoMediaTypeList |videoMediaTypeList *Optional*            |
</div>


## `GroupCallCenterQueueCallDispositionCodeSettingsGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterQueueCallDispositionCodeSettingsGetRequest()`.


**Attributes:**

|Name                                |Type                           |Description                           |
|------------------------------------|-------------------------------|--------------------------------------|
|enable_call_disposition_codes       |bool                           |enableCallDispositionCodes            |
|include_organization_codes          |bool                           |includeOrganizationCodes              |
|force_use_of_call_disposition_codes |bool                           |forceUseOfCallDispositionCodes        |
|default_call_disposition_code       |OCI.defaultCallDispositionCode |defaultCallDispositionCode *Optional* |
</div>


## `GroupCallCenterStrandedCallGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterStrandedCallGetRequest17()`.


**Attributes:**

|Name                    |Type                   |Description                      |
|------------------------|-----------------------|---------------------------------|
|action                  |str                    |action                           |
|transfer_phone_number   |str                    |transferPhoneNumber *Optional*   |
|audio_message_selection |str                    |audioMessageSelection *Optional* |
|audio_url_list          |OCI.audioUrlList       |audioUrlList *Optional*          |
|audio_file_list         |OCI.audioFileList      |audioFileList *Optional*         |
|audio_media_type_list   |OCI.audioMediaTypeList |audioMediaTypeList *Optional*    |
|video_message_selection |str                    |videoMessageSelection *Optional* |
|video_url_list          |OCI.videoUrlList       |videoUrlList *Optional*          |
|video_file_list         |OCI.videoFileList      |videoFileList *Optional*         |
|video_media_type_list   |OCI.videoMediaTypeList |videoMediaTypeList *Optional*    |
</div>


## `GroupCallCenterStrandedCallUnavailableGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterStrandedCallUnavailableGetRequest()`.


**Attributes:**

|Name                                                                 |Type                   |Description                                                 |
|---------------------------------------------------------------------|-----------------------|------------------------------------------------------------|
|condition_policy_on_number_of_agents_with_specified_unavailable_code |bool                   |conditionPolicyOnNumberOfAgentsWithSpecifiedUnavailableCode |
|number_of_agents_with_specified_unavailable_code                     |int                    |numberOfAgentsWithSpecifiedUnavailableCode *Optional*       |
|agents_unavailable_code                                              |str                    |agentsUnavailableCode *Optional*                            |
|action                                                               |str                    |action                                                      |
|transfer_phone_number                                                |str                    |transferPhoneNumber *Optional*                              |
|audio_message_selection                                              |str                    |audioMessageSelection *Optional*                            |
|audio_url_list                                                       |OCI.audioUrlList       |audioUrlList *Optional*                                     |
|audio_file_list                                                      |OCI.audioFileList      |audioFileList *Optional*                                    |
|audio_media_type_list                                                |OCI.audioMediaTypeList |audioMediaTypeList *Optional*                               |
|video_message_selection                                              |str                    |videoMessageSelection *Optional*                            |
|video_url_list                                                       |OCI.videoUrlList       |videoUrlList *Optional*                                     |
|video_file_list                                                      |OCI.videoFileList      |videoFileList *Optional*                                    |
|video_media_type_list                                                |OCI.videoMediaTypeList |videoMediaTypeList *Optional*                               |
</div>


## `GroupCommonPhoneListGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCommonPhoneListGetListRequest()`.

The response contains the group's common phone list.

**Attributes:**

|Name  |Type            |Description      |
|------|----------------|-----------------|
|entry |List[OCI.entry] |entry *Optional* |
</div>


## `GroupCommunicationBarringAuthorizationCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCommunicationBarringAuthorizationCodeGetListRequest()`.

Contains a list of Communication Barring Authorization Codes assigned to the group.
Replaced by: `GroupCommunicationBarringAuthorizationCodeGetListResponse21sp1()` in AS
data mode

**Attributes:**

|Name |Type           |Description     |
|-----|---------------|----------------|
|code |List[OCI.code] |code *Optional* |
</div>


## `GroupCommunicationBarringAuthorizationCodeGetListResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCommunicationBarringAuthorizationCodeGetListRequest21sp1()`.

Contains a list of Communication Barring Authorization Codes assigned to the group.

**Attributes:**

|Name |Type           |Description     |
|-----|---------------|----------------|
|code |List[OCI.code] |code *Optional* |
</div>


## `GroupConsolidatedAddResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupConsolidatedAddRequest22()`.


**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|dn_validation_error |List[OCI.dnValidationError] |dnValidationError *Optional* |
</div>


## `GroupConsolidatedDnAssignListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupConsolidatedDnAssignListRequest()`.


**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|dn_validation_error |List[OCI.dnValidationError] |dnValidationError *Optional* |
</div>


## `GroupCustomRingbackGroupGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCustomRingbackGroupGetRequest20()`.


**Attributes:**

|Name            |Type          |Description             |
|----------------|--------------|------------------------|
|is_active       |bool          |isActive                |
|audio_selection |str           |audioSelection          |
|audio_file      |OCI.audioFile |audioFile *Optional*    |
|audio_file_url  |str           |audioFileUrl *Optional* |
|video_selection |str           |videoSelection          |
|video_file      |OCI.videoFile |videoFile *Optional*    |
|video_file_url  |str           |videoFileUrl *Optional* |
</div>


## `GroupDepartmentAdminGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupDepartmentAdminGetRequest()`.

The response contains the group department administrators profile information.

**Attributes:**

|Name                 |Type              |Description          |
|---------------------|------------------|---------------------|
|department_key       |OCI.departmentKey |departmentKey        |
|department_full_path |str               |departmentFullPath   |
|first_name           |str               |firstName *Optional* |
|last_name            |str               |lastName *Optional*  |
|language             |str               |language             |
</div>


## `GroupDepartmentGetAvailableParentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDepartmentGetAvailableParentListRequest()`.

The response includes two parallel arrays of department keys and department display
names.

**Attributes:**

|Name           |Type                    |Description              |
|---------------|------------------------|-------------------------|
|department_key |List[OCI.departmentKey] |departmentKey *Optional* |
|full_path_name |List[str]               |fullPathName *Optional*  |
</div>


## `GroupDepartmentGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDepartmentGetListRequest()`.

The response includes two parallel arrays of department keys and department display
names.  Replaced by: `GroupDepartmentGetListResponse18()`

**Attributes:**

|Name           |Type                    |Description              |
|---------------|------------------------|-------------------------|
|department_key |List[OCI.departmentKey] |departmentKey *Optional* |
|full_path_name |List[str]               |fullPathName *Optional*  |
</div>


## `GroupDepartmentGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDepartmentGetRequest()`.

The following elements are only used in AS data mode: callingLineIdName
caliingLineIdPhoneNumber

**Attributes:**

|Name                         |Type                    |Description                         |
|-----------------------------|------------------------|------------------------------------|
|parent_department_key        |OCI.parentDepartmentKey |parentDepartmentKey *Optional*      |
|calling_line_id_name         |str                     |callingLineIdName *Optional*        |
|calling_line_id_phone_number |str                     |callingLineIdPhoneNumber *Optional* |
</div>


## `GroupDnGetStatusListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupDnGetStatusListRequest()`.


**Attributes:**

|Name      |Type               |Description         |
|----------|-------------------|--------------------|
|dn_status |List[OCI.dnStatus] |dnStatus *Optional* |
</div>


## `GroupEmergencyZonesGetHomeZoneListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupEmergencyZonesGetHomeZoneListRequest()`.


**Attributes:**

|Name                       |Type                             |Description                       |
|---------------------------|---------------------------------|----------------------------------|
|home_zone_ip_address       |List[str]                        |homeZoneIpAddress *Optional*      |
|home_zone_ip_address_range |List[OCI.homeZoneIpAddressRange] |homeZoneIpAddressRange *Optional* |
</div>


## `GroupFeatureAccessCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupFeatureAccessCodeGetListRequest()`.

Replaced by: `GroupFeatureAccessCodeGetResponse()`

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `GroupFeatureAccessCodeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupFeatureAccessCodeGetRequest()`.

Replaced by: `GroupFeatureAccessCodeGetResponse21()` in AS data mode

**Attributes:**

|Name                          |Type                        |Description                  |
|------------------------------|----------------------------|-----------------------------|
|use_feature_access_code_level |str                         |useFeatureAccessCodeLevel    |
|feature_access_code           |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `GroupFeatureAccessCodeGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupFeatureAccessCodeGetRequest20()`.

In release 20 the "Call Recording" FAC name is changed to "Call Recording - Start".
Replaced by : `GroupFeatureAccessCodeGetResponse21()`

**Attributes:**

|Name                          |Type                        |Description                  |
|------------------------------|----------------------------|-----------------------------|
|use_feature_access_code_level |str                         |useFeatureAccessCodeLevel    |
|feature_access_code           |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `GroupFeatureAccessCodeGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupFeatureAccessCodeGetRequest21()`.

In release 20 the "Call Recording" FAC name is changed to "Call Recording - Start".

**Attributes:**

|Name                          |Type                        |Description                  |
|------------------------------|----------------------------|-----------------------------|
|use_feature_access_code_level |str                         |useFeatureAccessCodeLevel    |
|feature_access_code           |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `GroupFindMeFollowMeGetAlertingGroupSelectiveCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupFindMeFollowMeGetAlertingGroupSelectiveCriteriaRequest()`.

Contains the alerting group selective criteria information.  Replaced by:
`GroupFindMeFollowMeGetAlertingGroupSelectiveCriteriaResponse21()`

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted      |bool                |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
</div>


## `GroupFindMeFollowMeGetAlertingGroupSelectiveCriteriaResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupFindMeFollowMeGetAlertingGroupSelectiveCriteriaRequest21()`.

Contains the alerting group selective criteria information.

**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|blacklisted      |bool                   |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `GroupGetAvailableLeafDeviceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupGetAvailableLeafDeviceListRequest()`.


**Attributes:**

|Name            |Type                    |Description              |
|----------------|------------------------|-------------------------|
|leaf_device_key |List[OCI.leafDeviceKey] |leafDeviceKey *Optional* |
</div>


## `GroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupGetRequest()`.

The response contains the group's profile information.

Replaced By: `GroupGetResponse14sp7()`

**Attributes:**

|Name                   |Type        |Description                    |
|-----------------------|------------|-------------------------------|
|default_domain         |str         |defaultDomain                  |
|user_limit             |int         |userLimit                      |
|user_count             |int         |userCount                      |
|group_name             |str         |groupName *Optional*           |
|calling_line_id_name   |str         |callingLineIdName *Optional*   |
|time_zone              |str         |timeZone                       |
|time_zone_display_name |str         |timeZoneDisplayName            |
|location_dialing_code  |str         |locationDialingCode *Optional* |
|contact                |OCI.contact |contact *Optional*             |
|address                |OCI.address |address *Optional*             |
</div>


## `GroupGetResponse14sp7`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupGetRequest14sp7()`.

The response contains the group's profile information.

**Attributes:**

|Name                                 |Type        |Description                                |
|-------------------------------------|------------|-------------------------------------------|
|default_domain                       |str         |defaultDomain                              |
|user_limit                           |int         |userLimit                                  |
|user_count                           |int         |userCount                                  |
|group_name                           |str         |groupName *Optional*                       |
|calling_line_id_name                 |str         |callingLineIdName *Optional*               |
|calling_line_id_phone_number         |str         |callingLineIdPhoneNumber *Optional*        |
|calling_line_id_display_phone_number |str         |callingLineIdDisplayPhoneNumber *Optional* |
|time_zone                            |str         |timeZone                                   |
|time_zone_display_name               |str         |timeZoneDisplayName                        |
|location_dialing_code                |str         |locationDialingCode *Optional*             |
|contact                              |OCI.contact |contact *Optional*                         |
|address                              |OCI.address |address *Optional*                         |
</div>


## `GroupGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupGetRequest22()`.

The response contains the group's profile information.  The following element is only
used in Amplify data mode and not returned in AS and XS data mode: servicePolicy,
callProcessingSliceId, provisioningSliceId, subscriberPartition, preferredDataCenter.
Replaced by `GroupGetResponse22V2()` in AS data mode.

**Attributes:**

|Name                                 |Type        |Description                                |
|-------------------------------------|------------|-------------------------------------------|
|default_domain                       |str         |defaultDomain                              |
|user_limit                           |int         |userLimit                                  |
|user_count                           |int         |userCount                                  |
|group_name                           |str         |groupName *Optional*                       |
|calling_line_id_name                 |str         |callingLineIdName *Optional*               |
|calling_line_id_phone_number         |str         |callingLineIdPhoneNumber *Optional*        |
|calling_line_id_display_phone_number |str         |callingLineIdDisplayPhoneNumber *Optional* |
|time_zone                            |str         |timeZone                                   |
|time_zone_display_name               |str         |timeZoneDisplayName                        |
|location_dialing_code                |str         |locationDialingCode *Optional*             |
|contact                              |OCI.contact |contact *Optional*                         |
|address                              |OCI.address |address *Optional*                         |
|service_policy                       |str         |servicePolicy *Optional*                   |
|call_processing_slice_id             |str         |callProcessingSliceId *Optional*           |
|provisioning_slice_id                |str         |provisioningSliceId *Optional*             |
|subscriber_partition                 |str         |subscriberPartition *Optional*             |
|preferred_data_center                |str         |preferredDataCenter *Optional*             |
</div>


## `GroupGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupGetRequest22V2()`.

The response contains the group's profile information.  The following element is only
used in Amplify data mode and not returned in AS and XS data mode: servicePolicy,
callProcessingSliceId, provisioningSliceId, subscriberPartition, preferredDataCenter.
The following data elements are only used in AS data mode: resellerId Replaced by:
`GroupGetResponse22V3()`

**Attributes:**

|Name                                 |Type        |Description                                |
|-------------------------------------|------------|-------------------------------------------|
|default_domain                       |str         |defaultDomain                              |
|user_limit                           |int         |userLimit                                  |
|user_count                           |int         |userCount                                  |
|group_name                           |str         |groupName *Optional*                       |
|calling_line_id_name                 |str         |callingLineIdName *Optional*               |
|calling_line_id_phone_number         |str         |callingLineIdPhoneNumber *Optional*        |
|calling_line_id_display_phone_number |str         |callingLineIdDisplayPhoneNumber *Optional* |
|time_zone                            |str         |timeZone                                   |
|time_zone_display_name               |str         |timeZoneDisplayName                        |
|location_dialing_code                |str         |locationDialingCode *Optional*             |
|contact                              |OCI.contact |contact *Optional*                         |
|address                              |OCI.address |address *Optional*                         |
|service_policy                       |str         |servicePolicy *Optional*                   |
|call_processing_slice_id             |str         |callProcessingSliceId *Optional*           |
|provisioning_slice_id                |str         |provisioningSliceId *Optional*             |
|subscriber_partition                 |str         |subscriberPartition *Optional*             |
|preferred_data_center                |str         |preferredDataCenter *Optional*             |
|reseller_id                          |str         |resellerId *Optional*                      |
</div>


## `GroupGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupGetRequest22V3()`.

The response contains the group's profile information.  The following element is only
used in Amplify data mode and not returned in AS and XS data mode: servicePolicy,
callProcessingSliceId, provisioningSliceId, subscriberPartition, preferredDataCenter.
The following elements are only used in Amplify and XS data mode and not returned in
AS data mode: preferredDataCenter.  The following data elements are only used in AS
data mode and not returned in XS data mode: resellerId.  The following elements are
only used in XS data mode and not returned in AS data mode:
defaultUserCallingLineIdPhoneNumber.  Replaced by `GroupGetResponse22V4()`

**Attributes:**

|Name                                      |Type        |Description                                    |
|------------------------------------------|------------|-----------------------------------------------|
|default_domain                            |str         |defaultDomain                                  |
|user_limit                                |int         |userLimit                                      |
|user_count                                |int         |userCount                                      |
|group_name                                |str         |groupName *Optional*                           |
|calling_line_id_name                      |str         |callingLineIdName *Optional*                   |
|calling_line_id_phone_number              |str         |callingLineIdPhoneNumber *Optional*            |
|calling_line_id_display_phone_number      |str         |callingLineIdDisplayPhoneNumber *Optional*     |
|time_zone                                 |str         |timeZone                                       |
|time_zone_display_name                    |str         |timeZoneDisplayName                            |
|location_dialing_code                     |str         |locationDialingCode *Optional*                 |
|contact                                   |OCI.contact |contact *Optional*                             |
|address                                   |OCI.address |address *Optional*                             |
|service_policy                            |str         |servicePolicy *Optional*                       |
|call_processing_slice_id                  |str         |callProcessingSliceId *Optional*               |
|provisioning_slice_id                     |str         |provisioningSliceId *Optional*                 |
|subscriber_partition                      |str         |subscriberPartition *Optional*                 |
|preferred_data_center                     |str         |preferredDataCenter *Optional*                 |
|reseller_id                               |str         |resellerId *Optional*                          |
|default_user_calling_line_id_phone_number |str         |defaultUserCallingLineIdPhoneNumber *Optional* |
</div>


## `GroupGetResponse22V4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupGetRequest22V4()`.

The response contains the group's profile information.  The following element is only
used in Amplify data mode and not returned in AS and XS data mode: servicePolicy,
callProcessingSliceId, provisioningSliceId, subscriberPartition, preferredDataCenter.
The following elements are only used in Amplify and XS data mode and not returned in
AS data mode: preferredDataCenter.  The following data elements are only used in AS
data mode and not returned in XS data mode: resellerId.  The following elements are
only used in XS data mode and not returned in AS data mode:
defaultUserCallingLineIdPhoneNumber.  Replaced by: `GroupGetResponse22V5()` in AS data
mode.

**Attributes:**

|Name                                      |Type        |Description                                    |
|------------------------------------------|------------|-----------------------------------------------|
|default_domain                            |str         |defaultDomain                                  |
|user_limit                                |int         |userLimit                                      |
|user_count                                |int         |userCount                                      |
|group_name                                |str         |groupName *Optional*                           |
|calling_line_id_name                      |str         |callingLineIdName *Optional*                   |
|calling_line_id_phone_number              |str         |callingLineIdPhoneNumber *Optional*            |
|calling_line_id_display_phone_number      |str         |callingLineIdDisplayPhoneNumber *Optional*     |
|time_zone                                 |str         |timeZone                                       |
|time_zone_display_name                    |str         |timeZoneDisplayName                            |
|location_dialing_code                     |str         |locationDialingCode *Optional*                 |
|contact                                   |OCI.contact |contact *Optional*                             |
|address                                   |OCI.address |address *Optional*                             |
|service_policy                            |str         |servicePolicy *Optional*                       |
|call_processing_slice_id                  |str         |callProcessingSliceId *Optional*               |
|provisioning_slice_id                     |str         |provisioningSliceId *Optional*                 |
|subscriber_partition                      |str         |subscriberPartition *Optional*                 |
|preferred_data_center                     |str         |preferredDataCenter *Optional*                 |
|reseller_id                               |str         |resellerId *Optional*                          |
|default_user_calling_line_id_phone_number |str         |defaultUserCallingLineIdPhoneNumber *Optional* |
</div>


## `GroupGetResponse22V5`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupGetRequest22V5()`.

The response contains the group's profile information.  The following element is only
used in Amplify data mode and not returned in AS and XS data mode: servicePolicy,
callProcessingSliceId, provisioningSliceId, subscriberPartition, preferredDataCenter.
The following elements are only used in Amplify and XS data mode and not returned in
AS data mode: preferredDataCenter.  The following data elements are only used in AS
data mode and not returned in XS data mode: resellerId, groupExternalId.  The
following elements are only used in XS data mode and not returned in AS data mode:
defaultUserCallingLineIdPhoneNumber.

**Attributes:**

|Name                                      |Type        |Description                                    |
|------------------------------------------|------------|-----------------------------------------------|
|default_domain                            |str         |defaultDomain                                  |
|user_limit                                |int         |userLimit                                      |
|user_count                                |int         |userCount                                      |
|group_name                                |str         |groupName *Optional*                           |
|calling_line_id_name                      |str         |callingLineIdName *Optional*                   |
|calling_line_id_phone_number              |str         |callingLineIdPhoneNumber *Optional*            |
|calling_line_id_display_phone_number      |str         |callingLineIdDisplayPhoneNumber *Optional*     |
|time_zone                                 |str         |timeZone                                       |
|time_zone_display_name                    |str         |timeZoneDisplayName                            |
|location_dialing_code                     |str         |locationDialingCode *Optional*                 |
|contact                                   |OCI.contact |contact *Optional*                             |
|address                                   |OCI.address |address *Optional*                             |
|service_policy                            |str         |servicePolicy *Optional*                       |
|call_processing_slice_id                  |str         |callProcessingSliceId *Optional*               |
|provisioning_slice_id                     |str         |provisioningSliceId *Optional*                 |
|subscriber_partition                      |str         |subscriberPartition *Optional*                 |
|preferred_data_center                     |str         |preferredDataCenter *Optional*                 |
|reseller_id                               |str         |resellerId *Optional*                          |
|default_user_calling_line_id_phone_number |str         |defaultUserCallingLineIdPhoneNumber *Optional* |
|service_provider_id                       |str         |serviceProviderId                              |
|group_id                                  |str         |groupId                                        |
|group_external_id                         |str         |groupExternalId *Optional*                     |
</div>


## `GroupGroupNightForwardingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupGroupNightForwardingGetRequest()`.


**Attributes:**

|Name                    |Type                |Description                     |
|------------------------|--------------------|--------------------------------|
|night_forwarding        |str                 |nightForwarding                 |
|business_hours          |OCI.businessHours   |businessHours *Optional*        |
|holiday_schedule        |OCI.holidaySchedule |holidaySchedule *Optional*      |
|forward_to_phone_number |str                 |forwardToPhoneNumber *Optional* |
</div>


## `GroupHolidayScheduleGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupHolidayScheduleGetRequest()`.

The response contains the group's holiday schedule information.

**Attributes:**

|Name                  |Type          |Description          |
|----------------------|--------------|---------------------|
|holiday_schedule_name |str           |holidayScheduleName  |
|holiday01             |OCI.holiday01 |holiday01 *Optional* |
|holiday02             |OCI.holiday02 |holiday02 *Optional* |
|holiday03             |OCI.holiday03 |holiday03 *Optional* |
|holiday04             |OCI.holiday04 |holiday04 *Optional* |
|holiday05             |OCI.holiday05 |holiday05 *Optional* |
|holiday06             |OCI.holiday06 |holiday06 *Optional* |
|holiday07             |OCI.holiday07 |holiday07 *Optional* |
|holiday08             |OCI.holiday08 |holiday08 *Optional* |
|holiday09             |OCI.holiday09 |holiday09 *Optional* |
|holiday10             |OCI.holiday10 |holiday10 *Optional* |
|holiday11             |OCI.holiday11 |holiday11 *Optional* |
|holiday12             |OCI.holiday12 |holiday12 *Optional* |
|holiday13             |OCI.holiday13 |holiday13 *Optional* |
|holiday14             |OCI.holiday14 |holiday14 *Optional* |
|holiday15             |OCI.holiday15 |holiday15 *Optional* |
|holiday16             |OCI.holiday16 |holiday16 *Optional* |
|holiday17             |OCI.holiday17 |holiday17 *Optional* |
|holiday18             |OCI.holiday18 |holiday18 *Optional* |
|holiday19             |OCI.holiday19 |holiday19 *Optional* |
|holiday20             |OCI.holiday20 |holiday20 *Optional* |
</div>


## `GroupMeetMeConferencingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupMeetMeConferencingGetRequest()`.


**Attributes:**

|Name            |Type               |Description    |
|----------------|-------------------|---------------|
|available_ports |OCI.availablePorts |availablePorts |
|allocated_ports |OCI.allocatedPorts |allocatedPorts |
</div>


## `GroupMusicOnHoldGetDepartmentListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMusicOnHoldGetDepartmentListRequest()`.


**Attributes:**

|Name                 |Type                 |Description                   |
|---------------------|---------------------|------------------------------|
|has_department       |bool                 |hasDepartment                 |
|department           |List[OCI.department] |department *Optional*         |
|department_full_path |List[str]            |departmentFullPath *Optional* |
</div>


## `GroupMusicOnHoldGetInstanceResponse14sp6`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMusicOnHoldGetInstanceRequest14sp6()`.

Replaced By: `GroupMusicOnHoldGetInstanceResponse16()`

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_user_id                         |str                |serviceUserId                      |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|enable_video                            |bool               |enableVideo                        |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource *Optional*          |
</div>


## `GroupMusicOnHoldGetInstanceResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMusicOnHoldGetInstanceRequest16()`.


**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_user_id                         |str                |serviceUserId                      |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|enable_video                            |bool               |enableVideo                        |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource *Optional*          |
</div>


## `GroupMusicOnHoldGetInstanceResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMusicOnHoldGetInstanceRequest19()`.


**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_user_id                         |str                |serviceUserId                      |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|enable_video                            |bool               |enableVideo                        |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource                     |
</div>


## `GroupMusicOnHoldGetInstanceResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMusicOnHoldGetInstanceRequest20()`.

Replaced by: `GroupMusicOnHoldGetInstanceResponse21()`

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_user_id                         |str                |serviceUserId                      |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|enable_video                            |bool               |enableVideo                        |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource                     |
</div>


## `GroupMusicOnHoldGetInstanceResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMusicOnHoldGetInstanceRequest21()`.

Replaced by `GroupMusicOnHoldGetInstanceResponse22()`.

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_user_id                         |str                |serviceUserId                      |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|enable_video                            |bool               |enableVideo                        |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource                     |
</div>


## `GroupMusicOnHoldGetInstanceResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMusicOnHoldGetInstanceRequest22()`.


**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_user_id                         |str                |serviceUserId                      |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|enable_video                            |bool               |enableVideo                        |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource                     |
</div>


## `GroupMusicOnHoldGetInstanceResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMusicOnHoldGetInstanceRequest22V2()`.

Replaced by: `GroupMusicOnHoldGetInstanceResponse22V2()`

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_user_id                         |str                |serviceUserId                      |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|enable_video                            |bool               |enableVideo                        |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource                     |
</div>


## `GroupMusicOnHoldGetInstanceResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMusicOnHoldGetInstanceRequest22V3()`.

Replaced by: `GroupMusicOnHoldGetInstanceResponse23V2()`

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_user_id                         |str                |serviceUserId                      |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|enable_video                            |bool               |enableVideo                        |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource                     |
</div>


## `GroupMusicOnHoldGetInstanceResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMusicOnHoldGetInstanceRequest23()`.

The following elements are only used in AS data mode: - useDynamicMOHDuringCallHold,
value "false" is returned in XS data mode.

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_user_id                         |str                |serviceUserId                      |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|enable_video                            |bool               |enableVideo                        |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource                     |
|use_dynamic_moh_during_call_hold        |bool               |useDynamicMOHDuringCallHold        |
</div>


## `GroupMusicOnHoldGetInstanceResponse23V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMusicOnHoldGetInstanceRequest23V2()`.

The following elements are only used in AS data mode: - useDynamicMOHDuringCallHold,
value “false” is returned in XS data mode.

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_user_id                         |str                |serviceUserId                      |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|enable_video                            |bool               |enableVideo                        |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource                     |
|use_dynamic_moh_during_call_hold        |bool               |useDynamicMOHDuringCallHold        |
</div>


## `GroupOutgoingCallingPlanDepartmentAuthorizationCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanDepartmentAuthorizationCodeGetListRequest()`.


**Attributes:**

|Name       |Type                |Description          |
|-----------|--------------------|---------------------|
|code_entry |List[OCI.codeEntry] |codeEntry *Optional* |
</div>


## `GroupPreAlertingAnnouncementGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `GroupPreAlertingAnnouncementGetResponse20()`.


**Attributes:**

|Name                        |Type          |Description                          |
|----------------------------|--------------|-------------------------------------|
|announcement_interruption   |str           |announcementInterruption             |
|interruption_digit_sequence |str           |interruptionDigitSequence *Optional* |
|audio_selection             |str           |audioSelection                       |
|audio_file                  |OCI.audioFile |audioFile *Optional*                 |
|audio_file_url              |str           |audioFileUrl *Optional*              |
|video_selection             |str           |videoSelection                       |
|video_file                  |OCI.videoFile |videoFile *Optional*                 |
|video_file_url              |str           |videoFileUrl *Optional*              |
</div>


## `GroupPreferredCarrierGroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `GroupPreferredCarrierGroupGetRequest()`.


**Attributes:**

|Name                  |Type                     |Description          |
|----------------------|-------------------------|---------------------|
|intra_lata_carrier    |OCI.intraLataCarrier     |intraLataCarrier     |
|inter_lata_carrier    |OCI.interLataCarrier     |interLataCarrier     |
|international_carrier |OCI.internationalCarrier |internationalCarrier |
</div>


## `GroupRoutePointForcedForwardingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointForcedForwardingGetRequest()`.


**Attributes:**

|Name                                |Type                   |Description                      |
|------------------------------------|-----------------------|---------------------------------|
|is_active                           |bool                   |isActive                         |
|forward_to_phone_number             |str                    |forwardToPhoneNumber *Optional*  |
|play_announcement_before_forwarding |bool                   |playAnnouncementBeforeForwarding |
|audio_message_selection             |str                    |audioMessageSelection            |
|audio_url_list                      |OCI.audioUrlList       |audioUrlList *Optional*          |
|audio_file_list                     |OCI.audioFileList      |audioFileList *Optional*         |
|audio_media_type_list               |OCI.audioMediaTypeList |audioMediaTypeList *Optional*    |
|video_message_selection             |str                    |videoMessageSelection            |
|video_url_list                      |OCI.videoUrlList       |videoUrlList *Optional*          |
|video_file_list                     |OCI.videoFileList      |videoFileList *Optional*         |
|video_media_type_list               |OCI.videoMediaTypeList |videoMediaTypeList *Optional*    |
</div>


## `GroupRoutePointHolidayServiceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointHolidayServiceGetRequest()`.


**Attributes:**

|Name                            |Type                   |Description                    |
|--------------------------------|-----------------------|-------------------------------|
|action                          |str                    |action                         |
|holiday_schedule                |str                    |holidaySchedule *Optional*     |
|transfer_phone_number           |str                    |transferPhoneNumber *Optional* |
|play_announcement_before_action |bool                   |playAnnouncementBeforeAction   |
|audio_message_selection         |str                    |audioMessageSelection          |
|audio_url_list                  |OCI.audioUrlList       |audioUrlList *Optional*        |
|audio_file_list                 |OCI.audioFileList      |audioFileList *Optional*       |
|audio_media_type_list           |OCI.audioMediaTypeList |audioMediaTypeList *Optional*  |
|video_message_selection         |str                    |videoMessageSelection          |
|video_url_list                  |OCI.videoUrlList       |videoUrlList *Optional*        |
|video_file_list                 |OCI.videoFileList      |videoFileList *Optional*       |
|video_media_type_list           |OCI.videoMediaTypeList |videoMediaTypeList *Optional*  |
</div>


## `GroupRoutePointHolidayServiceGetResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointHolidayServiceGetRequest17sp1()`.


**Attributes:**

|Name                            |Type                   |Description                    |
|--------------------------------|-----------------------|-------------------------------|
|action                          |str                    |action                         |
|holiday_schedule                |OCI.holidaySchedule    |holidaySchedule *Optional*     |
|transfer_phone_number           |str                    |transferPhoneNumber *Optional* |
|play_announcement_before_action |bool                   |playAnnouncementBeforeAction   |
|audio_message_selection         |str                    |audioMessageSelection          |
|audio_url_list                  |OCI.audioUrlList       |audioUrlList *Optional*        |
|audio_file_list                 |OCI.audioFileList      |audioFileList *Optional*       |
|audio_media_type_list           |OCI.audioMediaTypeList |audioMediaTypeList *Optional*  |
|video_message_selection         |str                    |videoMessageSelection          |
|video_url_list                  |OCI.videoUrlList       |videoUrlList *Optional*        |
|video_file_list                 |OCI.videoFileList      |videoFileList *Optional*       |
|video_media_type_list           |OCI.videoMediaTypeList |videoMediaTypeList *Optional*  |
</div>


## `GroupRoutePointNightServiceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointNightServiceGetRequest()`.


**Attributes:**

|Name                            |Type                         |Description                         |
|--------------------------------|-----------------------------|------------------------------------|
|action                          |str                          |action                              |
|business_hours                  |str                          |businessHours *Optional*            |
|force_night_service             |bool                         |forceNightService                   |
|transfer_phone_number           |str                          |transferPhoneNumber *Optional*      |
|play_announcement_before_action |bool                         |playAnnouncementBeforeAction        |
|audio_message_selection         |str                          |audioMessageSelection               |
|audio_url_list                  |OCI.audioUrlList             |audioUrlList *Optional*             |
|audio_file_list                 |OCI.audioFileList            |audioFileList *Optional*            |
|audio_media_type_list           |OCI.audioMediaTypeList       |audioMediaTypeList *Optional*       |
|video_message_selection         |str                          |videoMessageSelection               |
|video_url_list                  |OCI.videoUrlList             |videoUrlList *Optional*             |
|video_file_list                 |OCI.videoFileList            |videoFileList *Optional*            |
|video_media_type_list           |OCI.videoMediaTypeList       |videoMediaTypeList *Optional*       |
|manual_announcement_mode        |str                          |manualAnnouncementMode              |
|manual_audio_message_selection  |str                          |manualAudioMessageSelection         |
|manual_audio_url_list           |OCI.manualAudioUrlList       |manualAudioUrlList *Optional*       |
|manual_audio_file_list          |OCI.manualAudioFileList      |manualAudioFileList *Optional*      |
|manual_audio_media_type_list    |OCI.manualAudioMediaTypeList |manualAudioMediaTypeList *Optional* |
|manual_video_message_selection  |str                          |manualVideoMessageSelection         |
|manual_video_url_list           |OCI.manualVideoUrlList       |manualVideoUrlList *Optional*       |
|manual_video_file_list          |OCI.manualVideoFileList      |manualVideoFileList *Optional*      |
|manual_video_media_type_list    |OCI.manualVideoMediaTypeList |manualVideoMediaTypeList *Optional* |
</div>


## `GroupRoutePointNightServiceGetResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointNightServiceGetRequest17sp1()`.


**Attributes:**

|Name                            |Type                         |Description                         |
|--------------------------------|-----------------------------|------------------------------------|
|action                          |str                          |action                              |
|business_hours                  |OCI.businessHours            |businessHours *Optional*            |
|force_night_service             |bool                         |forceNightService                   |
|transfer_phone_number           |str                          |transferPhoneNumber *Optional*      |
|play_announcement_before_action |bool                         |playAnnouncementBeforeAction        |
|audio_message_selection         |str                          |audioMessageSelection               |
|audio_url_list                  |OCI.audioUrlList             |audioUrlList *Optional*             |
|audio_file_list                 |OCI.audioFileList            |audioFileList *Optional*            |
|audio_media_type_list           |OCI.audioMediaTypeList       |audioMediaTypeList *Optional*       |
|video_message_selection         |str                          |videoMessageSelection               |
|video_url_list                  |OCI.videoUrlList             |videoUrlList *Optional*             |
|video_file_list                 |OCI.videoFileList            |videoFileList *Optional*            |
|video_media_type_list           |OCI.videoMediaTypeList       |videoMediaTypeList *Optional*       |
|manual_announcement_mode        |str                          |manualAnnouncementMode              |
|manual_audio_message_selection  |str                          |manualAudioMessageSelection         |
|manual_audio_url_list           |OCI.manualAudioUrlList       |manualAudioUrlList *Optional*       |
|manual_audio_file_list          |OCI.manualAudioFileList      |manualAudioFileList *Optional*      |
|manual_audio_media_type_list    |OCI.manualAudioMediaTypeList |manualAudioMediaTypeList *Optional* |
|manual_video_message_selection  |str                          |manualVideoMessageSelection         |
|manual_video_url_list           |OCI.manualVideoUrlList       |manualVideoUrlList *Optional*       |
|manual_video_file_list          |OCI.manualVideoFileList      |manualVideoFileList *Optional*      |
|manual_video_media_type_list    |OCI.manualVideoMediaTypeList |manualVideoMediaTypeList *Optional* |
</div>


## `GroupRoutePointOverflowGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointOverflowGetRequest()` .


**Attributes:**

|Name                                         |Type                   |Description                              |
|---------------------------------------------|-----------------------|-----------------------------------------|
|action                                       |str                    |action                                   |
|transfer_phone_number                        |str                    |transferPhoneNumber *Optional*           |
|overflow_after_timeout                       |bool                   |overflowAfterTimeout                     |
|timeout_seconds                              |int                    |timeoutSeconds                           |
|play_announcement_before_overflow_processing |bool                   |playAnnouncementBeforeOverflowProcessing |
|audio_message_selection                      |str                    |audioMessageSelection                    |
|audio_url_list                               |OCI.audioUrlList       |audioUrlList *Optional*                  |
|audio_file_list                              |OCI.audioFileList      |audioFileList *Optional*                 |
|audio_media_type_list                        |OCI.audioMediaTypeList |audioMediaTypeList *Optional*            |
|video_message_selection                      |str                    |videoMessageSelection *Optional*         |
|video_url_list                               |OCI.videoUrlList       |videoUrlList *Optional*                  |
|video_file_list                              |OCI.videoFileList      |videoFileList *Optional*                 |
|video_media_type_list                        |OCI.videoMediaTypeList |videoMediaTypeList *Optional*            |
</div>


## `GroupRoutePointQueueCallDispositionCodeSettingsGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupRoutePointQueueCallDispositionCodeSettingsGetRequest()`.


**Attributes:**

|Name                                |Type                           |Description                           |
|------------------------------------|-------------------------------|--------------------------------------|
|enable_call_disposition_codes       |bool                           |enableCallDispositionCodes            |
|include_organization_codes          |bool                           |includeOrganizationCodes              |
|force_use_of_call_disposition_codes |bool                           |forceUseOfCallDispositionCodes        |
|default_call_disposition_code       |OCI.defaultCallDispositionCode |defaultCallDispositionCode *Optional* |
</div>


## `GroupScheduleGetEventResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupScheduleGetEventRequest()`.

The response contains the event of the group schedule.

**Attributes:**

|Name          |Type           |Description            |
|--------------|---------------|-----------------------|
|start_date    |str            |startDate              |
|all_day_event |bool           |allDayEvent *Optional* |
|start_time    |OCI.startTime  |startTime *Optional*   |
|end_time      |OCI.endTime    |endTime *Optional*     |
|end_date      |str            |endDate                |
|recurrence    |OCI.recurrence |recurrence *Optional*  |
</div>


## `GroupServiceGetAuthorizationResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupServiceGetAuthorizationRequest()`.

If the feature is not authorized, then "authorized" is false and the remaining
elements are not returned.  If the service pack is not available for use or is not
authorized, then "authorized" is false and the remaining elements are not returned.
"authorizedQuantity" can be unlimited or a quantity.  In the case of a service pack,
"authorizedQuantity" is the service pack's quantity.  "authorizable" is applicable for
user services and group services; it is not returned for service packs.

**Attributes:**

|Name                |Type                   |Description                   |
|--------------------|-----------------------|------------------------------|
|authorized          |bool                   |authorized                    |
|authorized_quantity |OCI.authorizedQuantity |authorizedQuantity *Optional* |
|used_quantity       |OCI.usedQuantity       |usedQuantity *Optional*       |
|authorizable        |bool                   |authorizable *Optional*       |
</div>


## `GroupSessionAdmissionControlGetAvailableDeviceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupSessionAdmissionControlGetAvailableDeviceListRequest()`.

Contains a table of devices can be assigned to session admission control group in the
group.

**Attributes:**

|Name          |Type                   |Description             |
|--------------|-----------------------|------------------------|
|access_device |List[OCI.accessDevice] |accessDevice *Optional* |
</div>


## `GroupSessionAdmissionControlGroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupSessionAdmissionControlGroupGetRequest()`.

Returns the profile information for the session admission control group.

**Attributes:**

|Name                               |Type              |Description                                |
|-----------------------------------|------------------|-------------------------------------------|
|max_session                        |int               |maxSession                                 |
|max_user_originating_sessions      |int               |maxUserOriginatingSessions *Optional*      |
|max_user_terminating_sessions      |int               |maxUserTerminatingSessions *Optional*      |
|reserved_session                   |int               |reservedSession                            |
|reserved_user_originating_sessions |int               |reservedUserOriginatingSessions *Optional* |
|reserved_user_terminating_sessions |int               |reservedUserTerminatingSessions *Optional* |
|default_group                      |bool              |defaultGroup                               |
|count_intra_sac_group_sessions     |bool              |countIntraSACGroupSessions                 |
|devices                            |List[OCI.devices] |devices *Optional*                         |
</div>


## `GroupSessionAdmissionControlGroupGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupSessionAdmissionControlGroupGetRequest19sp1()`.

Returns the profile information for the session admission control group.  Replaced by:
`GroupSessionAdmissionControlGroupGetResponse21sp1()`

**Attributes:**

|Name                                               |Type              |Description                                |
|---------------------------------------------------|------------------|-------------------------------------------|
|max_session                                        |int               |maxSession                                 |
|max_user_originating_sessions                      |int               |maxUserOriginatingSessions *Optional*      |
|max_user_terminating_sessions                      |int               |maxUserTerminatingSessions *Optional*      |
|reserved_session                                   |int               |reservedSession                            |
|reserved_user_originating_sessions                 |int               |reservedUserOriginatingSessions *Optional* |
|reserved_user_terminating_sessions                 |int               |reservedUserTerminatingSessions *Optional* |
|default_group                                      |bool              |defaultGroup                               |
|count_intra_sac_group_sessions                     |bool              |countIntraSACGroupSessions                 |
|devices                                            |List[OCI.devices] |devices *Optional*                         |
|block_emergency_and_repair_calls_due_to_sac_limits |bool              |blockEmergencyAndRepairCallsDueToSACLimits |
</div>


## `GroupSessionAdmissionControlGroupGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupSessionAdmissionControlGroupGetRequest21sp1()`.

Returns the profile information for the session admission control group.

**Attributes:**

|Name                                               |Type              |Description                                |
|---------------------------------------------------|------------------|-------------------------------------------|
|max_session                                        |int               |maxSession                                 |
|max_user_originating_sessions                      |int               |maxUserOriginatingSessions *Optional*      |
|max_user_terminating_sessions                      |int               |maxUserTerminatingSessions *Optional*      |
|reserved_session                                   |int               |reservedSession                            |
|reserved_user_originating_sessions                 |int               |reservedUserOriginatingSessions *Optional* |
|reserved_user_terminating_sessions                 |int               |reservedUserTerminatingSessions *Optional* |
|default_group                                      |bool              |defaultGroup                               |
|count_intra_sac_group_sessions                     |bool              |countIntraSACGroupSessions                 |
|devices                                            |List[OCI.devices] |devices *Optional*                         |
|block_emergency_and_repair_calls_due_to_sac_limits |bool              |blockEmergencyAndRepairCallsDueToSACLimits |
|media_group_name                                   |str               |mediaGroupName *Optional*                  |
</div>


## `GroupTimeScheduleGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupTimeScheduleGetRequest()`.

The response contains the group's time schedule information.

**Attributes:**

|Name               |Type               |Description               |
|-------------------|-------------------|--------------------------|
|time_schedule_name |str                |timeScheduleName          |
|time_interval01    |OCI.timeInterval01 |timeInterval01 *Optional* |
|time_interval02    |OCI.timeInterval02 |timeInterval02 *Optional* |
|time_interval03    |OCI.timeInterval03 |timeInterval03 *Optional* |
|time_interval04    |OCI.timeInterval04 |timeInterval04 *Optional* |
|time_interval05    |OCI.timeInterval05 |timeInterval05 *Optional* |
|time_interval06    |OCI.timeInterval06 |timeInterval06 *Optional* |
|time_interval07    |OCI.timeInterval07 |timeInterval07 *Optional* |
|time_interval08    |OCI.timeInterval08 |timeInterval08 *Optional* |
|time_interval09    |OCI.timeInterval09 |timeInterval09 *Optional* |
|time_interval10    |OCI.timeInterval10 |timeInterval10 *Optional* |
|time_interval11    |OCI.timeInterval11 |timeInterval11 *Optional* |
|time_interval12    |OCI.timeInterval12 |timeInterval12 *Optional* |
|time_interval13    |OCI.timeInterval13 |timeInterval13 *Optional* |
|time_interval14    |OCI.timeInterval14 |timeInterval14 *Optional* |
|time_interval15    |OCI.timeInterval15 |timeInterval15 *Optional* |
|time_interval16    |OCI.timeInterval16 |timeInterval16 *Optional* |
|time_interval17    |OCI.timeInterval17 |timeInterval17 *Optional* |
|time_interval18    |OCI.timeInterval18 |timeInterval18 *Optional* |
|time_interval19    |OCI.timeInterval19 |timeInterval19 *Optional* |
|time_interval20    |OCI.timeInterval20 |timeInterval20 *Optional* |
</div>


## `GroupTrunkGroupGetInstanceResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest14sp4()`.

Returns the profile information for the Trunk Group.

**Attributes:**

|Name                                            |Type                                           |Description                                           |
|------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|pilot_user_id                                   |str                                            |pilotUserId *Optional*                                |
|department                                      |OCI.department                                 |department *Optional*                                 |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                |int                                            |maxActiveCalls                                        |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                 |bool                                           |enableBursting                                        |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls                      |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls                       |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|unreachable_destination_trap_initial_calls      |int                                            |unreachableDestinationTrapInitialCalls                |
|unreachable_destination_trap_offset_calls       |int                                            |unreachableDestinationTrapOffsetCalls                 |
|invitation_timeout                              |int                                            |invitationTimeout                                     |
|require_authentication                          |bool                                           |requireAuthentication                                 |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                  |
</div>


## `GroupTrunkGroupGetInstanceResponse14sp5`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest14sp5()`.

Returns the profile information for the Trunk Group.  Contains a hosted user table
with column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name".

**Attributes:**

|Name                                            |Type                                           |Description                                                                |
|------------------------------------------------|-----------------------------------------------|---------------------------------------------------------------------------|
|pilot_user_id                                   |str                                            |pilotUserId *Optional*                                                     |
|department                                      |OCI.department                                 |department *Optional*                                                      |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                                                    |
|max_active_calls                                |int                                            |maxActiveCalls                                                             |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                                                |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                                                |
|enable_bursting                                 |bool                                           |enableBursting                                                             |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                                          |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                                        |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                                        |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                                          |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*                                  |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                            |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls                                           |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls                                            |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*                                    |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*                            |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*                      |
|unreachable_destination_trap_initial_calls      |int                                            |unreachableDestinationTrapInitialCalls                                     |
|unreachable_destination_trap_offset_calls       |int                                            |unreachableDestinationTrapOffsetCalls                                      |
|invitation_timeout                              |int                                            |invitationTimeout                                                          |
|require_authentication                          |bool                                           |requireAuthentication                                                      |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                                       |
|hosted_user_table                               |List(hostedUserTable)                          |hostedUserTable - *Table* array of hostedUserTable named tuples *Optional* |
</div>


## `GroupTrunkGroupGetInstanceResponse14sp9`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest14sp9()`.

Returns the profile information for the Trunk Group.  Contains a hosted user table
with column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name".

**Attributes:**

|Name                                            |Type                                           |Description                                                                |
|------------------------------------------------|-----------------------------------------------|---------------------------------------------------------------------------|
|pilot_user_id                                   |str                                            |pilotUserId *Optional*                                                     |
|department                                      |OCI.department                                 |department *Optional*                                                      |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                                                    |
|max_active_calls                                |int                                            |maxActiveCalls                                                             |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                                                |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                                                |
|enable_bursting                                 |bool                                           |enableBursting                                                             |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                                          |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                                        |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                                        |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                                          |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*                                  |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                            |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls                                           |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls                                            |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*                                    |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*                            |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*                      |
|unreachable_destination_trap_initial_calls      |int                                            |unreachableDestinationTrapInitialCalls                                     |
|unreachable_destination_trap_offset_calls       |int                                            |unreachableDestinationTrapOffsetCalls                                      |
|invitation_timeout                              |int                                            |invitationTimeout                                                          |
|require_authentication                          |bool                                           |requireAuthentication                                                      |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                                       |
|hosted_user_table                               |List(hostedUserTable)                          |hostedUserTable - *Table* array of hostedUserTable named tuples *Optional* |
|trunk_group_identity                            |str                                            |trunkGroupIdentity *Optional*                                              |
|otg_dtg_identity                                |str                                            |otgDtgIdentity *Optional*                                                  |
|include_trunk_group_identity                    |bool                                           |includeTrunkGroupIdentity                                                  |
|include_dtg_identity                            |bool                                           |includeDtgIdentity                                                         |
|enable_network_address_identity                 |bool                                           |enableNetworkAddressIdentity                                               |
|allow_unscreened_calls                          |bool                                           |allowUnscreenedCalls                                                       |
|allow_unscreened_emergency_calls                |bool                                           |allowUnscreenedEmergencyCalls                                              |
|use_pilot_user_calling_line_identity            |bool                                           |usePilotUserCallingLineIdentity                                            |
|use_pilot_user_charge_number                    |bool                                           |usePilotUserChargeNumber                                                   |
|call_forwarding_always_action                   |str                                            |callForwardingAlwaysAction *Optional*                                      |
|call_forwarding_always_forward_address          |str                                            |callForwardingAlwaysForwardAddress *Optional*                              |
|call_forwarding_always_reroute_trunk_group_key  |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*                        |
</div>


## `GroupTrunkGroupGetInstanceResponse15`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest15()`.

Returns the profile information for the Trunk Group.  Contains a hosted user table
with column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name".

**Attributes:**

|Name                                            |Type                                           |Description                                                                |
|------------------------------------------------|-----------------------------------------------|---------------------------------------------------------------------------|
|pilot_user_id                                   |str                                            |pilotUserId *Optional*                                                     |
|department                                      |OCI.department                                 |department *Optional*                                                      |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                                                    |
|max_active_calls                                |int                                            |maxActiveCalls                                                             |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                                                |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                                                |
|enable_bursting                                 |bool                                           |enableBursting                                                             |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                                          |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                                        |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                                        |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                                          |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*                                  |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                            |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls                                           |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls                                            |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*                                    |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*                            |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*                      |
|invitation_timeout                              |int                                            |invitationTimeout                                                          |
|require_authentication                          |bool                                           |requireAuthentication                                                      |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                                       |
|hosted_user_table                               |List(hostedUserTable)                          |hostedUserTable - *Table* array of hostedUserTable named tuples *Optional* |
</div>


## `GroupTrunkGroupGetInstanceResponse15sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest15sp2()`.

Returns the profile information for the Trunk Group.  Contains a hosted user table
with column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name".

**Attributes:**

|Name                                            |Type                                           |Description                                                                |
|------------------------------------------------|-----------------------------------------------|---------------------------------------------------------------------------|
|pilot_user_id                                   |str                                            |pilotUserId *Optional*                                                     |
|department                                      |OCI.department                                 |department *Optional*                                                      |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                                                    |
|max_active_calls                                |int                                            |maxActiveCalls                                                             |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                                                |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                                                |
|enable_bursting                                 |bool                                           |enableBursting                                                             |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                                          |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                                        |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                                        |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                                          |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*                                  |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                            |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls                                           |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls                                            |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*                                    |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*                            |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*                      |
|invitation_timeout                              |int                                            |invitationTimeout                                                          |
|require_authentication                          |bool                                           |requireAuthentication                                                      |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                                       |
|hosted_user_table                               |List(hostedUserTable)                          |hostedUserTable - *Table* array of hostedUserTable named tuples *Optional* |
|trunk_group_identity                            |str                                            |trunkGroupIdentity *Optional*                                              |
|otg_dtg_identity                                |str                                            |otgDtgIdentity *Optional*                                                  |
|include_trunk_group_identity                    |bool                                           |includeTrunkGroupIdentity                                                  |
|include_dtg_identity                            |bool                                           |includeDtgIdentity                                                         |
|enable_network_address_identity                 |bool                                           |enableNetworkAddressIdentity                                               |
|allow_unscreened_calls                          |bool                                           |allowUnscreenedCalls                                                       |
|allow_unscreened_emergency_calls                |bool                                           |allowUnscreenedEmergencyCalls                                              |
|pilot_user_calling_line_identity_policy         |str                                            |pilotUserCallingLineIdentityPolicy                                         |
|pilot_user_charge_number_policy                 |str                                            |pilotUserChargeNumberPolicy                                                |
|call_forwarding_always_action                   |str                                            |callForwardingAlwaysAction *Optional*                                      |
|call_forwarding_always_forward_address          |str                                            |callForwardingAlwaysForwardAddress *Optional*                              |
|call_forwarding_always_reroute_trunk_group_key  |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*                        |
</div>


## `GroupTrunkGroupGetInstanceResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest17()`.

Returns the profile information for the Trunk Group.  Contains a hosted user table
with column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name".

**Attributes:**

|Name                                            |Type                                           |Description                                                                |
|------------------------------------------------|-----------------------------------------------|---------------------------------------------------------------------------|
|pilot_user_id                                   |str                                            |pilotUserId *Optional*                                                     |
|department                                      |OCI.department                                 |department *Optional*                                                      |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                                                    |
|max_active_calls                                |int                                            |maxActiveCalls                                                             |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                                                |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                                                |
|enable_bursting                                 |bool                                           |enableBursting                                                             |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                                          |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                                        |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                                        |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                                          |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*                                  |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                            |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls                                           |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls                                            |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*                                    |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*                            |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*                      |
|invitation_timeout                              |int                                            |invitationTimeout                                                          |
|require_authentication                          |bool                                           |requireAuthentication                                                      |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                                       |
|hosted_user_table                               |List(hostedUserTable)                          |hostedUserTable - *Table* array of hostedUserTable named tuples *Optional* |
|trunk_group_identity                            |str                                            |trunkGroupIdentity *Optional*                                              |
|otg_dtg_identity                                |str                                            |otgDtgIdentity *Optional*                                                  |
|include_trunk_group_identity                    |bool                                           |includeTrunkGroupIdentity                                                  |
|include_dtg_identity                            |bool                                           |includeDtgIdentity                                                         |
|enable_network_address_identity                 |bool                                           |enableNetworkAddressIdentity                                               |
|allow_unscreened_calls                          |bool                                           |allowUnscreenedCalls                                                       |
|allow_unscreened_emergency_calls                |bool                                           |allowUnscreenedEmergencyCalls                                              |
|pilot_user_calling_line_identity_policy         |str                                            |pilotUserCallingLineIdentityPolicy                                         |
|pilot_user_charge_number_policy                 |str                                            |pilotUserChargeNumberPolicy                                                |
|call_forwarding_always_action                   |str                                            |callForwardingAlwaysAction *Optional*                                      |
|call_forwarding_always_forward_address          |str                                            |callForwardingAlwaysForwardAddress *Optional*                              |
|call_forwarding_always_reroute_trunk_group_key  |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*                        |
|peering_domain                                  |str                                            |peeringDomain *Optional*                                                   |
|route_to_peering_domain                         |bool                                           |routeToPeeringDomain                                                       |
</div>


## `GroupTrunkGroupGetInstanceResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest17sp3()`.

Returns the profile information for the Trunk Group.  Contains a hosted user table
with column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name".

**Attributes:**

|Name                                            |Type                                           |Description                                                                |
|------------------------------------------------|-----------------------------------------------|---------------------------------------------------------------------------|
|pilot_user_id                                   |str                                            |pilotUserId *Optional*                                                     |
|department                                      |OCI.department                                 |department *Optional*                                                      |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                                                    |
|max_active_calls                                |int                                            |maxActiveCalls                                                             |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                                                |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                                                |
|enable_bursting                                 |bool                                           |enableBursting                                                             |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                                          |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                                        |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                                        |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                                          |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*                                  |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                            |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls                                           |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls                                            |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*                                    |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*                            |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*                      |
|invitation_timeout                              |int                                            |invitationTimeout                                                          |
|require_authentication                          |bool                                           |requireAuthentication                                                      |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                                       |
|hosted_user_table                               |List(hostedUserTable)                          |hostedUserTable - *Table* array of hostedUserTable named tuples *Optional* |
|trunk_group_identity                            |str                                            |trunkGroupIdentity *Optional*                                              |
|otg_dtg_identity                                |str                                            |otgDtgIdentity *Optional*                                                  |
|include_trunk_group_identity                    |bool                                           |includeTrunkGroupIdentity                                                  |
|include_dtg_identity                            |bool                                           |includeDtgIdentity                                                         |
|enable_network_address_identity                 |bool                                           |enableNetworkAddressIdentity                                               |
|allow_unscreened_calls                          |bool                                           |allowUnscreenedCalls                                                       |
|allow_unscreened_emergency_calls                |bool                                           |allowUnscreenedEmergencyCalls                                              |
|pilot_user_calling_line_identity_policy         |str                                            |pilotUserCallingLineIdentityPolicy                                         |
|pilot_user_charge_number_policy                 |str                                            |pilotUserChargeNumberPolicy                                                |
|call_forwarding_always_action                   |str                                            |callForwardingAlwaysAction *Optional*                                      |
|call_forwarding_always_forward_address          |str                                            |callForwardingAlwaysForwardAddress *Optional*                              |
|call_forwarding_always_reroute_trunk_group_key  |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*                        |
|peering_domain                                  |str                                            |peeringDomain *Optional*                                                   |
|route_to_peering_domain                         |bool                                           |routeToPeeringDomain                                                       |
|prefix_enabled                                  |bool                                           |prefixEnabled                                                              |
|prefix                                          |str                                            |prefix *Optional*                                                          |
|stateful_rerouting_enabled                      |bool                                           |statefulReroutingEnabled                                                   |
|send_continuous_options_message                 |bool                                           |sendContinuousOptionsMessage                                               |
|continuous_options_sending_interval_seconds     |int                                            |continuousOptionsSendingIntervalSeconds                                    |
|failure_options_sending_interval_seconds        |int                                            |failureOptionsSendingIntervalSeconds                                       |
|failure_threshold_counter                       |int                                            |failureThresholdCounter                                                    |
|success_threshold_counter                       |int                                            |successThresholdCounter                                                    |
|invite_failure_threshold_counter                |int                                            |inviteFailureThresholdCounter                                              |
|invite_failure_threshold_window_seconds         |int                                            |inviteFailureThresholdWindowSeconds                                        |
|trunk_group_state                               |str                                            |trunkGroupState                                                            |
</div>


## `GroupTrunkGroupGetInstanceResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest17sp4()`.

Returns the profile information for the Trunk Group.  Contains a hosted user table
with column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name", "Phone Number", "Extension", "Department", "Email Address".

**Attributes:**

|Name                                             |Type                                           |Description                                                                |
|-------------------------------------------------|-----------------------------------------------|---------------------------------------------------------------------------|
|pilot_user_id                                    |str                                            |pilotUserId *Optional*                                                     |
|department                                       |OCI.department                                 |department *Optional*                                                      |
|access_device                                    |OCI.accessDevice                               |accessDevice *Optional*                                                    |
|max_active_calls                                 |int                                            |maxActiveCalls                                                             |
|max_incoming_calls                               |int                                            |maxIncomingCalls *Optional*                                                |
|max_outgoing_calls                               |int                                            |maxOutgoingCalls *Optional*                                                |
|enable_bursting                                  |bool                                           |enableBursting                                                             |
|bursting_max_active_calls                        |int                                            |burstingMaxActiveCalls *Optional*                                          |
|bursting_max_incoming_calls                      |int                                            |burstingMaxIncomingCalls *Optional*                                        |
|bursting_max_outgoing_calls                      |int                                            |burstingMaxOutgoingCalls *Optional*                                        |
|capacity_exceeded_action                         |str                                            |capacityExceededAction *Optional*                                          |
|capacity_exceeded_forward_address                |str                                            |capacityExceededForwardAddress *Optional*                                  |
|capacity_exceeded_reroute_trunk_group_key        |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                            |
|capacity_exceeded_trap_initial_calls             |int                                            |capacityExceededTrapInitialCalls                                           |
|capacity_exceeded_trap_offset_calls              |int                                            |capacityExceededTrapOffsetCalls                                            |
|unreachable_destination_action                   |str                                            |unreachableDestinationAction *Optional*                                    |
|unreachable_destination_forward_address          |str                                            |unreachableDestinationForwardAddress *Optional*                            |
|unreachable_destination_reroute_trunk_group_key  |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*                      |
|invitation_timeout                               |int                                            |invitationTimeout                                                          |
|require_authentication                           |bool                                           |requireAuthentication                                                      |
|sip_authentication_user_name                     |str                                            |sipAuthenticationUserName *Optional*                                       |
|hosted_user_table                                |List(hostedUserTable)                          |hostedUserTable - *Table* array of hostedUserTable named tuples *Optional* |
|trunk_group_identity                             |str                                            |trunkGroupIdentity *Optional*                                              |
|otg_dtg_identity                                 |str                                            |otgDtgIdentity *Optional*                                                  |
|allow_termination_to_trunk_group_identity        |bool                                           |allowTerminationToTrunkGroupIdentity                                       |
|allow_termination_to_dtg_identity                |bool                                           |allowTerminationToDtgIdentity                                              |
|include_trunk_group_identity                     |bool                                           |includeTrunkGroupIdentity                                                  |
|include_dtg_identity                             |bool                                           |includeDtgIdentity                                                         |
|include_trunk_group_identity_for_network_calls   |bool                                           |includeTrunkGroupIdentityForNetworkCalls                                   |
|include_otg_identity_for_network_calls           |bool                                           |includeOtgIdentityForNetworkCalls                                          |
|enable_network_address_identity                  |bool                                           |enableNetworkAddressIdentity                                               |
|allow_unscreened_calls                           |bool                                           |allowUnscreenedCalls                                                       |
|allow_unscreened_emergency_calls                 |bool                                           |allowUnscreenedEmergencyCalls                                              |
|pilot_user_calling_line_identity_policy          |str                                            |pilotUserCallingLineIdentityPolicy                                         |
|pilot_user_charge_number_policy                  |str                                            |pilotUserChargeNumberPolicy                                                |
|call_forwarding_always_action                    |str                                            |callForwardingAlwaysAction *Optional*                                      |
|call_forwarding_always_forward_address           |str                                            |callForwardingAlwaysForwardAddress *Optional*                              |
|call_forwarding_always_reroute_trunk_group_key   |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*                        |
|peering_domain                                   |str                                            |peeringDomain *Optional*                                                   |
|route_to_peering_domain                          |bool                                           |routeToPeeringDomain                                                       |
|prefix_enabled                                   |bool                                           |prefixEnabled                                                              |
|prefix                                           |str                                            |prefix *Optional*                                                          |
|stateful_rerouting_enabled                       |bool                                           |statefulReroutingEnabled                                                   |
|send_continuous_options_message                  |bool                                           |sendContinuousOptionsMessage                                               |
|continuous_options_sending_interval_seconds      |int                                            |continuousOptionsSendingIntervalSeconds                                    |
|failure_options_sending_interval_seconds         |int                                            |failureOptionsSendingIntervalSeconds                                       |
|failure_threshold_counter                        |int                                            |failureThresholdCounter                                                    |
|success_threshold_counter                        |int                                            |successThresholdCounter                                                    |
|invite_failure_threshold_counter                 |int                                            |inviteFailureThresholdCounter                                              |
|invite_failure_threshold_window_seconds          |int                                            |inviteFailureThresholdWindowSeconds                                        |
|trunk_group_state                                |str                                            |trunkGroupState                                                            |
|pilot_user_calling_line_asserted_identity_policy |str                                            |pilotUserCallingLineAssertedIdentityPolicy                                 |
|use_system_calling_line_asserted_identity_policy |bool                                           |useSystemCallingLineAssertedIdentityPolicy                                 |
</div>


## `GroupTrunkGroupGetInstanceResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest19()`.

Returns the profile information for the Trunk Group.  Contains a hosted user table
with column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name", "Phone Number", "Extension", "Department", "Email Address".
Replaced by `GroupTrunkGroupGetInstanceResponse19sp1()`.

**Attributes:**

|Name                                             |Type                                           |Description                                                                |
|-------------------------------------------------|-----------------------------------------------|---------------------------------------------------------------------------|
|pilot_user_id                                    |str                                            |pilotUserId *Optional*                                                     |
|department                                       |OCI.department                                 |department *Optional*                                                      |
|access_device                                    |OCI.accessDevice                               |accessDevice *Optional*                                                    |
|max_active_calls                                 |int                                            |maxActiveCalls                                                             |
|max_incoming_calls                               |int                                            |maxIncomingCalls *Optional*                                                |
|max_outgoing_calls                               |int                                            |maxOutgoingCalls *Optional*                                                |
|enable_bursting                                  |bool                                           |enableBursting                                                             |
|bursting_max_active_calls                        |int                                            |burstingMaxActiveCalls *Optional*                                          |
|bursting_max_incoming_calls                      |int                                            |burstingMaxIncomingCalls *Optional*                                        |
|bursting_max_outgoing_calls                      |int                                            |burstingMaxOutgoingCalls *Optional*                                        |
|capacity_exceeded_action                         |str                                            |capacityExceededAction *Optional*                                          |
|capacity_exceeded_forward_address                |str                                            |capacityExceededForwardAddress *Optional*                                  |
|capacity_exceeded_reroute_trunk_group_key        |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                            |
|capacity_exceeded_trap_initial_calls             |int                                            |capacityExceededTrapInitialCalls                                           |
|capacity_exceeded_trap_offset_calls              |int                                            |capacityExceededTrapOffsetCalls                                            |
|unreachable_destination_action                   |str                                            |unreachableDestinationAction *Optional*                                    |
|unreachable_destination_forward_address          |str                                            |unreachableDestinationForwardAddress *Optional*                            |
|unreachable_destination_reroute_trunk_group_key  |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*                      |
|invitation_timeout                               |int                                            |invitationTimeout                                                          |
|require_authentication                           |bool                                           |requireAuthentication                                                      |
|sip_authentication_user_name                     |str                                            |sipAuthenticationUserName *Optional*                                       |
|hosted_user_table                                |List(hostedUserTable)                          |hostedUserTable - *Table* array of hostedUserTable named tuples *Optional* |
|trunk_group_identity                             |str                                            |trunkGroupIdentity *Optional*                                              |
|otg_dtg_identity                                 |str                                            |otgDtgIdentity *Optional*                                                  |
|allow_termination_to_trunk_group_identity        |bool                                           |allowTerminationToTrunkGroupIdentity                                       |
|allow_termination_to_dtg_identity                |bool                                           |allowTerminationToDtgIdentity                                              |
|include_trunk_group_identity                     |bool                                           |includeTrunkGroupIdentity                                                  |
|include_dtg_identity                             |bool                                           |includeDtgIdentity                                                         |
|include_trunk_group_identity_for_network_calls   |bool                                           |includeTrunkGroupIdentityForNetworkCalls                                   |
|include_otg_identity_for_network_calls           |bool                                           |includeOtgIdentityForNetworkCalls                                          |
|enable_network_address_identity                  |bool                                           |enableNetworkAddressIdentity                                               |
|allow_unscreened_calls                           |bool                                           |allowUnscreenedCalls                                                       |
|allow_unscreened_emergency_calls                 |bool                                           |allowUnscreenedEmergencyCalls                                              |
|pilot_user_calling_line_identity_policy          |str                                            |pilotUserCallingLineIdentityPolicy                                         |
|pilot_user_charge_number_policy                  |str                                            |pilotUserChargeNumberPolicy                                                |
|call_forwarding_always_action                    |str                                            |callForwardingAlwaysAction *Optional*                                      |
|call_forwarding_always_forward_address           |str                                            |callForwardingAlwaysForwardAddress *Optional*                              |
|call_forwarding_always_reroute_trunk_group_key   |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*                        |
|peering_domain                                   |str                                            |peeringDomain *Optional*                                                   |
|route_to_peering_domain                          |bool                                           |routeToPeeringDomain                                                       |
|prefix_enabled                                   |bool                                           |prefixEnabled                                                              |
|prefix                                           |str                                            |prefix *Optional*                                                          |
|stateful_rerouting_enabled                       |bool                                           |statefulReroutingEnabled                                                   |
|send_continuous_options_message                  |bool                                           |sendContinuousOptionsMessage                                               |
|continuous_options_sending_interval_seconds      |int                                            |continuousOptionsSendingIntervalSeconds                                    |
|failure_options_sending_interval_seconds         |int                                            |failureOptionsSendingIntervalSeconds                                       |
|failure_threshold_counter                        |int                                            |failureThresholdCounter                                                    |
|success_threshold_counter                        |int                                            |successThresholdCounter                                                    |
|invite_failure_threshold_counter                 |int                                            |inviteFailureThresholdCounter                                              |
|invite_failure_threshold_window_seconds          |int                                            |inviteFailureThresholdWindowSeconds                                        |
|trunk_group_state                                |str                                            |trunkGroupState                                                            |
|pilot_user_calling_line_asserted_identity_policy |str                                            |pilotUserCallingLineAssertedIdentityPolicy                                 |
|use_system_calling_line_asserted_identity_policy |bool                                           |useSystemCallingLineAssertedIdentityPolicy                                 |
|total_active_incoming_calls                      |int                                            |totalActiveIncomingCalls                                                   |
|total_active_outgoing_calls                      |int                                            |totalActiveOutgoingCalls                                                   |
|pilot_user_call_optimization_policy              |str                                            |pilotUserCallOptimizationPolicy                                            |
</div>


## `GroupTrunkGroupGetInstanceResponse19V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest19V2()`.

Returns the profile information for the Trunk Group.  Contains a hosted user table
with column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name", "Phone Number", "Extension", "Department", "Email Address".
Replaced by GroupTrunkGroupGetInstanceResponse19sp1V2.

**Attributes:**

|Name                                             |Type                                           |Description                                                                |
|-------------------------------------------------|-----------------------------------------------|---------------------------------------------------------------------------|
|pilot_user_id                                    |str                                            |pilotUserId *Optional*                                                     |
|department                                       |OCI.department                                 |department *Optional*                                                      |
|access_device                                    |OCI.accessDevice                               |accessDevice *Optional*                                                    |
|max_active_calls                                 |int                                            |maxActiveCalls                                                             |
|max_incoming_calls                               |int                                            |maxIncomingCalls *Optional*                                                |
|max_outgoing_calls                               |int                                            |maxOutgoingCalls *Optional*                                                |
|enable_bursting                                  |bool                                           |enableBursting                                                             |
|bursting_max_active_calls                        |int                                            |burstingMaxActiveCalls *Optional*                                          |
|bursting_max_incoming_calls                      |int                                            |burstingMaxIncomingCalls *Optional*                                        |
|bursting_max_outgoing_calls                      |int                                            |burstingMaxOutgoingCalls *Optional*                                        |
|capacity_exceeded_action                         |str                                            |capacityExceededAction *Optional*                                          |
|capacity_exceeded_forward_address                |str                                            |capacityExceededForwardAddress *Optional*                                  |
|capacity_exceeded_reroute_trunk_group_key        |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                            |
|capacity_exceeded_trap_initial_calls             |int                                            |capacityExceededTrapInitialCalls                                           |
|capacity_exceeded_trap_offset_calls              |int                                            |capacityExceededTrapOffsetCalls                                            |
|unreachable_destination_action                   |str                                            |unreachableDestinationAction *Optional*                                    |
|unreachable_destination_forward_address          |str                                            |unreachableDestinationForwardAddress *Optional*                            |
|unreachable_destination_reroute_trunk_group_key  |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*                      |
|invitation_timeout                               |int                                            |invitationTimeout                                                          |
|require_authentication                           |bool                                           |requireAuthentication                                                      |
|sip_authentication_user_name                     |str                                            |sipAuthenticationUserName *Optional*                                       |
|hosted_user_table                                |List(hostedUserTable)                          |hostedUserTable - *Table* array of hostedUserTable named tuples *Optional* |
|trunk_group_identity                             |str                                            |trunkGroupIdentity *Optional*                                              |
|otg_dtg_identity                                 |str                                            |otgDtgIdentity *Optional*                                                  |
|allow_termination_to_trunk_group_identity        |bool                                           |allowTerminationToTrunkGroupIdentity                                       |
|allow_termination_to_dtg_identity                |bool                                           |allowTerminationToDtgIdentity                                              |
|include_trunk_group_identity                     |bool                                           |includeTrunkGroupIdentity                                                  |
|include_dtg_identity                             |bool                                           |includeDtgIdentity                                                         |
|include_trunk_group_identity_for_network_calls   |bool                                           |includeTrunkGroupIdentityForNetworkCalls                                   |
|include_otg_identity_for_network_calls           |bool                                           |includeOtgIdentityForNetworkCalls                                          |
|enable_network_address_identity                  |bool                                           |enableNetworkAddressIdentity                                               |
|allow_unscreened_calls                           |bool                                           |allowUnscreenedCalls                                                       |
|allow_unscreened_emergency_calls                 |bool                                           |allowUnscreenedEmergencyCalls                                              |
|pilot_user_calling_line_identity_policy          |str                                            |pilotUserCallingLineIdentityPolicy                                         |
|pilot_user_charge_number_policy                  |str                                            |pilotUserChargeNumberPolicy                                                |
|call_forwarding_always_action                    |str                                            |callForwardingAlwaysAction *Optional*                                      |
|call_forwarding_always_forward_address           |str                                            |callForwardingAlwaysForwardAddress *Optional*                              |
|call_forwarding_always_reroute_trunk_group_key   |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*                        |
|peering_domain                                   |str                                            |peeringDomain *Optional*                                                   |
|route_to_peering_domain                          |bool                                           |routeToPeeringDomain                                                       |
|prefix_enabled                                   |bool                                           |prefixEnabled                                                              |
|prefix                                           |str                                            |prefix *Optional*                                                          |
|stateful_rerouting_enabled                       |bool                                           |statefulReroutingEnabled                                                   |
|send_continuous_options_message                  |bool                                           |sendContinuousOptionsMessage                                               |
|continuous_options_sending_interval_seconds      |int                                            |continuousOptionsSendingIntervalSeconds                                    |
|failure_options_sending_interval_seconds         |int                                            |failureOptionsSendingIntervalSeconds                                       |
|failure_threshold_counter                        |int                                            |failureThresholdCounter                                                    |
|success_threshold_counter                        |int                                            |successThresholdCounter                                                    |
|invite_failure_threshold_counter                 |int                                            |inviteFailureThresholdCounter                                              |
|invite_failure_threshold_window_seconds          |int                                            |inviteFailureThresholdWindowSeconds                                        |
|trunk_group_state                                |str                                            |trunkGroupState                                                            |
|pilot_user_calling_line_asserted_identity_policy |str                                            |pilotUserCallingLineAssertedIdentityPolicy                                 |
|use_system_calling_line_asserted_identity_policy |bool                                           |useSystemCallingLineAssertedIdentityPolicy                                 |
|total_active_incoming_calls                      |int                                            |totalActiveIncomingCalls                                                   |
|total_active_outgoing_calls                      |int                                            |totalActiveOutgoingCalls                                                   |
|pilot_user_call_optimization_policy              |str                                            |pilotUserCallOptimizationPolicy                                            |
</div>


## `GroupTrunkGroupGetInstanceResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest19sp1()`.

Returns the profile information for the Trunk Group.  Contains a hosted user table
with column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name", "Phone Number", "Extension", "Department", "Email Address".
Replaced by GroupTrunkGroupGetInstanceResponse19sp1V2.

**Attributes:**

|Name                                                        |Type                                           |Description                                                                |
|------------------------------------------------------------|-----------------------------------------------|---------------------------------------------------------------------------|
|pilot_user_id                                               |str                                            |pilotUserId *Optional*                                                     |
|department                                                  |OCI.department                                 |department *Optional*                                                      |
|access_device                                               |OCI.accessDevice                               |accessDevice *Optional*                                                    |
|max_active_calls                                            |int                                            |maxActiveCalls                                                             |
|max_incoming_calls                                          |int                                            |maxIncomingCalls *Optional*                                                |
|max_outgoing_calls                                          |int                                            |maxOutgoingCalls *Optional*                                                |
|enable_bursting                                             |bool                                           |enableBursting                                                             |
|bursting_max_active_calls                                   |int                                            |burstingMaxActiveCalls *Optional*                                          |
|bursting_max_incoming_calls                                 |int                                            |burstingMaxIncomingCalls *Optional*                                        |
|bursting_max_outgoing_calls                                 |int                                            |burstingMaxOutgoingCalls *Optional*                                        |
|capacity_exceeded_action                                    |str                                            |capacityExceededAction *Optional*                                          |
|capacity_exceeded_forward_address                           |str                                            |capacityExceededForwardAddress *Optional*                                  |
|capacity_exceeded_reroute_trunk_group_key                   |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                            |
|capacity_exceeded_trap_initial_calls                        |int                                            |capacityExceededTrapInitialCalls                                           |
|capacity_exceeded_trap_offset_calls                         |int                                            |capacityExceededTrapOffsetCalls                                            |
|unreachable_destination_action                              |str                                            |unreachableDestinationAction *Optional*                                    |
|unreachable_destination_forward_address                     |str                                            |unreachableDestinationForwardAddress *Optional*                            |
|unreachable_destination_reroute_trunk_group_key             |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*                      |
|invitation_timeout                                          |int                                            |invitationTimeout                                                          |
|require_authentication                                      |bool                                           |requireAuthentication                                                      |
|sip_authentication_user_name                                |str                                            |sipAuthenticationUserName *Optional*                                       |
|hosted_user_table                                           |List(hostedUserTable)                          |hostedUserTable - *Table* array of hostedUserTable named tuples *Optional* |
|trunk_group_identity                                        |str                                            |trunkGroupIdentity *Optional*                                              |
|otg_dtg_identity                                            |str                                            |otgDtgIdentity *Optional*                                                  |
|allow_termination_to_trunk_group_identity                   |bool                                           |allowTerminationToTrunkGroupIdentity                                       |
|allow_termination_to_dtg_identity                           |bool                                           |allowTerminationToDtgIdentity                                              |
|include_trunk_group_identity                                |bool                                           |includeTrunkGroupIdentity                                                  |
|include_dtg_identity                                        |bool                                           |includeDtgIdentity                                                         |
|include_trunk_group_identity_for_network_calls              |bool                                           |includeTrunkGroupIdentityForNetworkCalls                                   |
|include_otg_identity_for_network_calls                      |bool                                           |includeOtgIdentityForNetworkCalls                                          |
|enable_network_address_identity                             |bool                                           |enableNetworkAddressIdentity                                               |
|allow_unscreened_calls                                      |bool                                           |allowUnscreenedCalls                                                       |
|allow_unscreened_emergency_calls                            |bool                                           |allowUnscreenedEmergencyCalls                                              |
|pilot_user_calling_line_identity_for_external_calls_policy  |str                                            |pilotUserCallingLineIdentityForExternalCallsPolicy                         |
|pilot_user_charge_number_policy                             |str                                            |pilotUserChargeNumberPolicy                                                |
|call_forwarding_always_action                               |str                                            |callForwardingAlwaysAction *Optional*                                      |
|call_forwarding_always_forward_address                      |str                                            |callForwardingAlwaysForwardAddress *Optional*                              |
|call_forwarding_always_reroute_trunk_group_key              |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*                        |
|peering_domain                                              |str                                            |peeringDomain *Optional*                                                   |
|route_to_peering_domain                                     |bool                                           |routeToPeeringDomain                                                       |
|prefix_enabled                                              |bool                                           |prefixEnabled                                                              |
|prefix                                                      |str                                            |prefix *Optional*                                                          |
|stateful_rerouting_enabled                                  |bool                                           |statefulReroutingEnabled                                                   |
|send_continuous_options_message                             |bool                                           |sendContinuousOptionsMessage                                               |
|continuous_options_sending_interval_seconds                 |int                                            |continuousOptionsSendingIntervalSeconds                                    |
|failure_options_sending_interval_seconds                    |int                                            |failureOptionsSendingIntervalSeconds                                       |
|failure_threshold_counter                                   |int                                            |failureThresholdCounter                                                    |
|success_threshold_counter                                   |int                                            |successThresholdCounter                                                    |
|invite_failure_threshold_counter                            |int                                            |inviteFailureThresholdCounter                                              |
|invite_failure_threshold_window_seconds                     |int                                            |inviteFailureThresholdWindowSeconds                                        |
|trunk_group_state                                           |str                                            |trunkGroupState                                                            |
|pilot_user_calling_line_asserted_identity_policy            |str                                            |pilotUserCallingLineAssertedIdentityPolicy                                 |
|use_system_calling_line_asserted_identity_policy            |bool                                           |useSystemCallingLineAssertedIdentityPolicy                                 |
|total_active_incoming_calls                                 |int                                            |totalActiveIncomingCalls                                                   |
|total_active_outgoing_calls                                 |int                                            |totalActiveOutgoingCalls                                                   |
|pilot_user_call_optimization_policy                         |str                                            |pilotUserCallOptimizationPolicy                                            |
|clid_source_for_screened_calls_policy                       |str                                            |clidSourceForScreenedCallsPolicy                                           |
|use_system_clid_source_for_screened_calls_policy            |bool                                           |useSystemCLIDSourceForScreenedCallsPolicy                                  |
|user_lookup_policy                                          |str                                            |userLookupPolicy                                                           |
|use_system_user_lookup_policy                               |bool                                           |useSystemUserLookupPolicy                                                  |
|pilot_user_calling_line_identity_for_emergency_calls_policy |str                                            |pilotUserCallingLineIdentityForEmergencyCallsPolicy                        |
</div>


## `GroupTrunkGroupGetInstanceResponse20sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest20sp1()`.

Returns the profile information for the Trunk Group.  Contains a hosted user table
with column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name", "Phone Number", "Extension", "Department", "Email Address".
Replaced by: `GroupTrunkGroupGetInstanceResponse21()`

**Attributes:**

|Name                                                        |Type                                           |Description                                                                |
|------------------------------------------------------------|-----------------------------------------------|---------------------------------------------------------------------------|
|pilot_user_id                                               |str                                            |pilotUserId *Optional*                                                     |
|department                                                  |OCI.department                                 |department *Optional*                                                      |
|access_device                                               |OCI.accessDevice                               |accessDevice *Optional*                                                    |
|max_active_calls                                            |int                                            |maxActiveCalls                                                             |
|max_incoming_calls                                          |int                                            |maxIncomingCalls *Optional*                                                |
|max_outgoing_calls                                          |int                                            |maxOutgoingCalls *Optional*                                                |
|enable_bursting                                             |bool                                           |enableBursting                                                             |
|bursting_max_active_calls                                   |int                                            |burstingMaxActiveCalls *Optional*                                          |
|bursting_max_incoming_calls                                 |int                                            |burstingMaxIncomingCalls *Optional*                                        |
|bursting_max_outgoing_calls                                 |int                                            |burstingMaxOutgoingCalls *Optional*                                        |
|capacity_exceeded_action                                    |str                                            |capacityExceededAction *Optional*                                          |
|capacity_exceeded_forward_address                           |str                                            |capacityExceededForwardAddress *Optional*                                  |
|capacity_exceeded_reroute_trunk_group_key                   |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                            |
|capacity_exceeded_trap_initial_calls                        |int                                            |capacityExceededTrapInitialCalls                                           |
|capacity_exceeded_trap_offset_calls                         |int                                            |capacityExceededTrapOffsetCalls                                            |
|unreachable_destination_action                              |str                                            |unreachableDestinationAction *Optional*                                    |
|unreachable_destination_forward_address                     |str                                            |unreachableDestinationForwardAddress *Optional*                            |
|unreachable_destination_reroute_trunk_group_key             |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*                      |
|invitation_timeout                                          |int                                            |invitationTimeout                                                          |
|require_authentication                                      |bool                                           |requireAuthentication                                                      |
|sip_authentication_user_name                                |str                                            |sipAuthenticationUserName *Optional*                                       |
|hosted_user_table                                           |List(hostedUserTable)                          |hostedUserTable - *Table* array of hostedUserTable named tuples *Optional* |
|trunk_group_identity                                        |str                                            |trunkGroupIdentity *Optional*                                              |
|otg_dtg_identity                                            |str                                            |otgDtgIdentity *Optional*                                                  |
|allow_termination_to_trunk_group_identity                   |bool                                           |allowTerminationToTrunkGroupIdentity                                       |
|allow_termination_to_dtg_identity                           |bool                                           |allowTerminationToDtgIdentity                                              |
|include_trunk_group_identity                                |bool                                           |includeTrunkGroupIdentity                                                  |
|include_dtg_identity                                        |bool                                           |includeDtgIdentity                                                         |
|include_trunk_group_identity_for_network_calls              |bool                                           |includeTrunkGroupIdentityForNetworkCalls                                   |
|include_otg_identity_for_network_calls                      |bool                                           |includeOtgIdentityForNetworkCalls                                          |
|enable_network_address_identity                             |bool                                           |enableNetworkAddressIdentity                                               |
|allow_unscreened_calls                                      |bool                                           |allowUnscreenedCalls                                                       |
|allow_unscreened_emergency_calls                            |bool                                           |allowUnscreenedEmergencyCalls                                              |
|pilot_user_calling_line_identity_for_external_calls_policy  |str                                            |pilotUserCallingLineIdentityForExternalCallsPolicy                         |
|pilot_user_charge_number_policy                             |str                                            |pilotUserChargeNumberPolicy                                                |
|call_forwarding_always_action                               |str                                            |callForwardingAlwaysAction *Optional*                                      |
|call_forwarding_always_forward_address                      |str                                            |callForwardingAlwaysForwardAddress *Optional*                              |
|call_forwarding_always_reroute_trunk_group_key              |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*                        |
|peering_domain                                              |str                                            |peeringDomain *Optional*                                                   |
|route_to_peering_domain                                     |bool                                           |routeToPeeringDomain                                                       |
|prefix_enabled                                              |bool                                           |prefixEnabled                                                              |
|prefix                                                      |str                                            |prefix *Optional*                                                          |
|stateful_rerouting_enabled                                  |bool                                           |statefulReroutingEnabled                                                   |
|send_continuous_options_message                             |bool                                           |sendContinuousOptionsMessage                                               |
|continuous_options_sending_interval_seconds                 |int                                            |continuousOptionsSendingIntervalSeconds                                    |
|failure_options_sending_interval_seconds                    |int                                            |failureOptionsSendingIntervalSeconds                                       |
|failure_threshold_counter                                   |int                                            |failureThresholdCounter                                                    |
|success_threshold_counter                                   |int                                            |successThresholdCounter                                                    |
|invite_failure_threshold_counter                            |int                                            |inviteFailureThresholdCounter                                              |
|invite_failure_threshold_window_seconds                     |int                                            |inviteFailureThresholdWindowSeconds                                        |
|trunk_group_state                                           |str                                            |trunkGroupState                                                            |
|pilot_user_calling_line_asserted_identity_policy            |str                                            |pilotUserCallingLineAssertedIdentityPolicy                                 |
|use_system_calling_line_asserted_identity_policy            |bool                                           |useSystemCallingLineAssertedIdentityPolicy                                 |
|total_active_incoming_calls                                 |int                                            |totalActiveIncomingCalls                                                   |
|total_active_outgoing_calls                                 |int                                            |totalActiveOutgoingCalls                                                   |
|pilot_user_call_optimization_policy                         |str                                            |pilotUserCallOptimizationPolicy                                            |
|clid_source_for_screened_calls_policy                       |str                                            |clidSourceForScreenedCallsPolicy                                           |
|use_system_clid_source_for_screened_calls_policy            |bool                                           |useSystemCLIDSourceForScreenedCallsPolicy                                  |
|user_lookup_policy                                          |str                                            |userLookupPolicy                                                           |
|use_system_user_lookup_policy                               |bool                                           |useSystemUserLookupPolicy                                                  |
|pilot_user_calling_line_identity_for_emergency_calls_policy |str                                            |pilotUserCallingLineIdentityForEmergencyCallsPolicy                        |
</div>


## `GroupTrunkGroupGetInstanceResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest21()`.

Returns the profile information for the Trunk Group.  Contains a hosted user table
with column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name", "Phone Number", "Extension", "Department", "Email Address".
Following attributes are only used in IMS mode: implicitRegistrationSetSupportPolicy
useSystemImplicitRegistrationSetSupportPolicy
sipIdentityForPilotAndProxyTrunkModesPolicy
useSystemSIPIdentityForPilotAndProxyTrunkModesPolicy Replaced by:
`GroupTrunkGroupGetInstanceResponse23()`

**Attributes:**

|Name                                                           |Type                                           |Description                                                                |
|---------------------------------------------------------------|-----------------------------------------------|---------------------------------------------------------------------------|
|pilot_user_id                                                  |str                                            |pilotUserId *Optional*                                                     |
|department                                                     |OCI.department                                 |department *Optional*                                                      |
|access_device                                                  |OCI.accessDevice                               |accessDevice *Optional*                                                    |
|max_active_calls                                               |int                                            |maxActiveCalls                                                             |
|max_incoming_calls                                             |int                                            |maxIncomingCalls *Optional*                                                |
|max_outgoing_calls                                             |int                                            |maxOutgoingCalls *Optional*                                                |
|enable_bursting                                                |bool                                           |enableBursting                                                             |
|bursting_max_active_calls                                      |int                                            |burstingMaxActiveCalls *Optional*                                          |
|bursting_max_incoming_calls                                    |int                                            |burstingMaxIncomingCalls *Optional*                                        |
|bursting_max_outgoing_calls                                    |int                                            |burstingMaxOutgoingCalls *Optional*                                        |
|capacity_exceeded_action                                       |str                                            |capacityExceededAction *Optional*                                          |
|capacity_exceeded_forward_address                              |str                                            |capacityExceededForwardAddress *Optional*                                  |
|capacity_exceeded_reroute_trunk_group_key                      |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                            |
|capacity_exceeded_trap_initial_calls                           |int                                            |capacityExceededTrapInitialCalls                                           |
|capacity_exceeded_trap_offset_calls                            |int                                            |capacityExceededTrapOffsetCalls                                            |
|unreachable_destination_action                                 |str                                            |unreachableDestinationAction *Optional*                                    |
|unreachable_destination_forward_address                        |str                                            |unreachableDestinationForwardAddress *Optional*                            |
|unreachable_destination_reroute_trunk_group_key                |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*                      |
|invitation_timeout                                             |int                                            |invitationTimeout                                                          |
|require_authentication                                         |bool                                           |requireAuthentication                                                      |
|sip_authentication_user_name                                   |str                                            |sipAuthenticationUserName *Optional*                                       |
|hosted_user_table                                              |List(hostedUserTable)                          |hostedUserTable - *Table* array of hostedUserTable named tuples *Optional* |
|trunk_group_identity                                           |str                                            |trunkGroupIdentity *Optional*                                              |
|otg_dtg_identity                                               |str                                            |otgDtgIdentity *Optional*                                                  |
|allow_termination_to_trunk_group_identity                      |bool                                           |allowTerminationToTrunkGroupIdentity                                       |
|allow_termination_to_dtg_identity                              |bool                                           |allowTerminationToDtgIdentity                                              |
|include_trunk_group_identity                                   |bool                                           |includeTrunkGroupIdentity                                                  |
|include_dtg_identity                                           |bool                                           |includeDtgIdentity                                                         |
|include_trunk_group_identity_for_network_calls                 |bool                                           |includeTrunkGroupIdentityForNetworkCalls                                   |
|include_otg_identity_for_network_calls                         |bool                                           |includeOtgIdentityForNetworkCalls                                          |
|enable_network_address_identity                                |bool                                           |enableNetworkAddressIdentity                                               |
|allow_unscreened_calls                                         |bool                                           |allowUnscreenedCalls                                                       |
|allow_unscreened_emergency_calls                               |bool                                           |allowUnscreenedEmergencyCalls                                              |
|pilot_user_calling_line_identity_for_external_calls_policy     |str                                            |pilotUserCallingLineIdentityForExternalCallsPolicy                         |
|pilot_user_charge_number_policy                                |str                                            |pilotUserChargeNumberPolicy                                                |
|call_forwarding_always_action                                  |str                                            |callForwardingAlwaysAction *Optional*                                      |
|call_forwarding_always_forward_address                         |str                                            |callForwardingAlwaysForwardAddress *Optional*                              |
|call_forwarding_always_reroute_trunk_group_key                 |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*                        |
|peering_domain                                                 |str                                            |peeringDomain *Optional*                                                   |
|route_to_peering_domain                                        |bool                                           |routeToPeeringDomain                                                       |
|prefix_enabled                                                 |bool                                           |prefixEnabled                                                              |
|prefix                                                         |str                                            |prefix *Optional*                                                          |
|stateful_rerouting_enabled                                     |bool                                           |statefulReroutingEnabled                                                   |
|send_continuous_options_message                                |bool                                           |sendContinuousOptionsMessage                                               |
|continuous_options_sending_interval_seconds                    |int                                            |continuousOptionsSendingIntervalSeconds                                    |
|failure_options_sending_interval_seconds                       |int                                            |failureOptionsSendingIntervalSeconds                                       |
|failure_threshold_counter                                      |int                                            |failureThresholdCounter                                                    |
|success_threshold_counter                                      |int                                            |successThresholdCounter                                                    |
|invite_failure_threshold_counter                               |int                                            |inviteFailureThresholdCounter                                              |
|invite_failure_threshold_window_seconds                        |int                                            |inviteFailureThresholdWindowSeconds                                        |
|trunk_group_state                                              |str                                            |trunkGroupState                                                            |
|pilot_user_calling_line_asserted_identity_policy               |str                                            |pilotUserCallingLineAssertedIdentityPolicy                                 |
|use_system_calling_line_asserted_identity_policy               |bool                                           |useSystemCallingLineAssertedIdentityPolicy                                 |
|total_active_incoming_calls                                    |int                                            |totalActiveIncomingCalls                                                   |
|total_active_outgoing_calls                                    |int                                            |totalActiveOutgoingCalls                                                   |
|pilot_user_call_optimization_policy                            |str                                            |pilotUserCallOptimizationPolicy                                            |
|clid_source_for_screened_calls_policy                          |str                                            |clidSourceForScreenedCallsPolicy                                           |
|use_system_clid_source_for_screened_calls_policy               |bool                                           |useSystemCLIDSourceForScreenedCallsPolicy                                  |
|user_lookup_policy                                             |str                                            |userLookupPolicy                                                           |
|use_system_user_lookup_policy                                  |bool                                           |useSystemUserLookupPolicy                                                  |
|pilot_user_calling_line_identity_for_emergency_calls_policy    |str                                            |pilotUserCallingLineIdentityForEmergencyCallsPolicy                        |
|implicit_registration_set_support_policy                       |str                                            |implicitRegistrationSetSupportPolicy                                       |
|use_system_implicit_registration_set_support_policy            |bool                                           |useSystemImplicitRegistrationSetSupportPolicy                              |
|sip_identity_for_pilot_and_proxy_trunk_modes_policy            |str                                            |sipIdentityForPilotAndProxyTrunkModesPolicy                                |
|use_system_sip_identity_for_pilot_and_proxy_trunk_modes_policy |bool                                           |useSystemSIPIdentityForPilotAndProxyTrunkModesPolicy                       |
|use_system_support_connected_identity_policy                   |bool                                           |useSystemSupportConnectedIdentityPolicy                                    |
|support_connected_identity_policy                              |str                                            |supportConnectedIdentityPolicy                                             |
|use_system_options_message_response_status_codes               |bool                                           |useSystemOptionsMessageResponseStatusCodes                                 |
|options_message_response_status_code                           |List[str]                                      |optionsMessageResponseStatusCode *Optional*                                |
</div>


## `GroupTrunkGroupGetInstanceResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest23()`.

Returns the profile information for the Trunk Group.  Contains a hosted user table
with column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name",
"Hiragana First Name", "Phone Number", "Extension", "Department", "Email Address".
Following attributes are only used in IMS mode: implicitRegistrationSetSupportPolicy
useSystemImplicitRegistrationSetSupportPolicy
sipIdentityForPilotAndProxyTrunkModesPolicy
useSystemSIPIdentityForPilotAndProxyTrunkModesPolicy

**Attributes:**

|Name                                                           |Type                                           |Description                                                                |
|---------------------------------------------------------------|-----------------------------------------------|---------------------------------------------------------------------------|
|pilot_user_id                                                  |str                                            |pilotUserId *Optional*                                                     |
|department                                                     |OCI.department                                 |department *Optional*                                                      |
|access_device                                                  |OCI.accessDevice                               |accessDevice *Optional*                                                    |
|max_active_calls                                               |int                                            |maxActiveCalls                                                             |
|max_incoming_calls                                             |int                                            |maxIncomingCalls *Optional*                                                |
|max_outgoing_calls                                             |int                                            |maxOutgoingCalls *Optional*                                                |
|enable_bursting                                                |bool                                           |enableBursting                                                             |
|bursting_max_active_calls                                      |int                                            |burstingMaxActiveCalls *Optional*                                          |
|bursting_max_incoming_calls                                    |int                                            |burstingMaxIncomingCalls *Optional*                                        |
|bursting_max_outgoing_calls                                    |int                                            |burstingMaxOutgoingCalls *Optional*                                        |
|capacity_exceeded_action                                       |str                                            |capacityExceededAction *Optional*                                          |
|capacity_exceeded_forward_address                              |str                                            |capacityExceededForwardAddress *Optional*                                  |
|capacity_exceeded_reroute_trunk_group_key                      |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                            |
|capacity_exceeded_trap_initial_calls                           |int                                            |capacityExceededTrapInitialCalls                                           |
|capacity_exceeded_trap_offset_calls                            |int                                            |capacityExceededTrapOffsetCalls                                            |
|unreachable_destination_action                                 |str                                            |unreachableDestinationAction *Optional*                                    |
|unreachable_destination_forward_address                        |str                                            |unreachableDestinationForwardAddress *Optional*                            |
|unreachable_destination_reroute_trunk_group_key                |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*                      |
|invitation_timeout                                             |int                                            |invitationTimeout                                                          |
|require_authentication                                         |bool                                           |requireAuthentication                                                      |
|sip_authentication_user_name                                   |str                                            |sipAuthenticationUserName *Optional*                                       |
|hosted_user_table                                              |List(hostedUserTable)                          |hostedUserTable - *Table* array of hostedUserTable named tuples *Optional* |
|trunk_group_identity                                           |str                                            |trunkGroupIdentity *Optional*                                              |
|otg_dtg_identity                                               |str                                            |otgDtgIdentity *Optional*                                                  |
|allow_termination_to_trunk_group_identity                      |bool                                           |allowTerminationToTrunkGroupIdentity                                       |
|allow_termination_to_dtg_identity                              |bool                                           |allowTerminationToDtgIdentity                                              |
|include_trunk_group_identity                                   |bool                                           |includeTrunkGroupIdentity                                                  |
|include_dtg_identity                                           |bool                                           |includeDtgIdentity                                                         |
|include_trunk_group_identity_for_network_calls                 |bool                                           |includeTrunkGroupIdentityForNetworkCalls                                   |
|include_otg_identity_for_network_calls                         |bool                                           |includeOtgIdentityForNetworkCalls                                          |
|enable_network_address_identity                                |bool                                           |enableNetworkAddressIdentity                                               |
|allow_unscreened_calls                                         |bool                                           |allowUnscreenedCalls                                                       |
|allow_unscreened_emergency_calls                               |bool                                           |allowUnscreenedEmergencyCalls                                              |
|pilot_user_calling_line_identity_for_external_calls_policy     |str                                            |pilotUserCallingLineIdentityForExternalCallsPolicy                         |
|pilot_user_charge_number_policy                                |str                                            |pilotUserChargeNumberPolicy                                                |
|call_forwarding_always_action                                  |str                                            |callForwardingAlwaysAction *Optional*                                      |
|call_forwarding_always_forward_address                         |str                                            |callForwardingAlwaysForwardAddress *Optional*                              |
|call_forwarding_always_reroute_trunk_group_key                 |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*                        |
|peering_domain                                                 |str                                            |peeringDomain *Optional*                                                   |
|route_to_peering_domain                                        |bool                                           |routeToPeeringDomain                                                       |
|prefix_enabled                                                 |bool                                           |prefixEnabled                                                              |
|prefix                                                         |str                                            |prefix *Optional*                                                          |
|stateful_rerouting_enabled                                     |bool                                           |statefulReroutingEnabled                                                   |
|send_continuous_options_message                                |bool                                           |sendContinuousOptionsMessage                                               |
|continuous_options_sending_interval_seconds                    |int                                            |continuousOptionsSendingIntervalSeconds                                    |
|failure_options_sending_interval_seconds                       |int                                            |failureOptionsSendingIntervalSeconds                                       |
|failure_threshold_counter                                      |int                                            |failureThresholdCounter                                                    |
|success_threshold_counter                                      |int                                            |successThresholdCounter                                                    |
|invite_failure_threshold_counter                               |int                                            |inviteFailureThresholdCounter                                              |
|invite_failure_threshold_window_seconds                        |int                                            |inviteFailureThresholdWindowSeconds                                        |
|trunk_group_state                                              |str                                            |trunkGroupState                                                            |
|pilot_user_calling_line_asserted_identity_policy               |str                                            |pilotUserCallingLineAssertedIdentityPolicy                                 |
|use_system_calling_line_asserted_identity_policy               |bool                                           |useSystemCallingLineAssertedIdentityPolicy                                 |
|total_active_incoming_calls                                    |int                                            |totalActiveIncomingCalls                                                   |
|total_active_outgoing_calls                                    |int                                            |totalActiveOutgoingCalls                                                   |
|pilot_user_call_optimization_policy                            |str                                            |pilotUserCallOptimizationPolicy                                            |
|clid_source_for_screened_calls_policy                          |str                                            |clidSourceForScreenedCallsPolicy                                           |
|use_system_clid_source_for_screened_calls_policy               |bool                                           |useSystemCLIDSourceForScreenedCallsPolicy                                  |
|user_lookup_policy                                             |str                                            |userLookupPolicy                                                           |
|use_system_user_lookup_policy                                  |bool                                           |useSystemUserLookupPolicy                                                  |
|pilot_user_calling_line_identity_for_emergency_calls_policy    |str                                            |pilotUserCallingLineIdentityForEmergencyCallsPolicy                        |
|implicit_registration_set_support_policy                       |str                                            |implicitRegistrationSetSupportPolicy                                       |
|use_system_implicit_registration_set_support_policy            |bool                                           |useSystemImplicitRegistrationSetSupportPolicy                              |
|sip_identity_for_pilot_and_proxy_trunk_modes_policy            |str                                            |sipIdentityForPilotAndProxyTrunkModesPolicy                                |
|use_system_sip_identity_for_pilot_and_proxy_trunk_modes_policy |bool                                           |useSystemSIPIdentityForPilotAndProxyTrunkModesPolicy                       |
|use_system_support_connected_identity_policy                   |bool                                           |useSystemSupportConnectedIdentityPolicy                                    |
|support_connected_identity_policy                              |str                                            |supportConnectedIdentityPolicy                                             |
|use_system_options_message_response_status_codes               |bool                                           |useSystemOptionsMessageResponseStatusCodes                                 |
|options_message_response_status_code                           |List[str]                                      |optionsMessageResponseStatusCode *Optional*                                |
</div>


## `GroupTrunkGroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupTrunkGroupGetRequest()`.

The response contains the maximum permissible active trunk group calls for the group.

**Attributes:**

|Name                       |Type                        |Description             |
|---------------------------|----------------------------|------------------------|
|max_active_calls           |OCI.maxActiveCalls          |maxActiveCalls          |
|max_available_active_calls |OCI.maxAvailableActiveCalls |maxAvailableActiveCalls |
</div>


## `GroupTrunkGroupGetResponse14sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupTrunkGroupGetRequest14sp1()`.

The response contains the maximum and bursting maximum permissible active trunk group
calls for the group.

**Attributes:**

|Name                                |Type                                |Description                     |
|------------------------------------|------------------------------------|--------------------------------|
|max_active_calls                    |OCI.maxActiveCalls                  |maxActiveCalls                  |
|max_available_active_calls          |OCI.maxAvailableActiveCalls         |maxAvailableActiveCalls         |
|bursting_max_active_calls           |OCI.burstingMaxActiveCalls          |burstingMaxActiveCalls          |
|bursting_max_available_active_calls |OCI.burstingMaxAvailableActiveCalls |burstingMaxAvailableActiveCalls |
</div>


## `GroupTrunkGroupGetResponse14sp9`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupTrunkGroupGetRequest14sp9()`.

The response contains the maximum and bursting maximum permissible active trunk group
calls for the group.  Deprecated by `GroupTrunkGroupGetResponse23()`

**Attributes:**

|Name                                |Type                                |Description                     |
|------------------------------------|------------------------------------|--------------------------------|
|max_active_calls                    |int                                 |maxActiveCalls                  |
|max_available_active_calls          |OCI.maxAvailableActiveCalls         |maxAvailableActiveCalls         |
|bursting_max_active_calls           |OCI.burstingMaxActiveCalls          |burstingMaxActiveCalls          |
|bursting_max_available_active_calls |OCI.burstingMaxAvailableActiveCalls |burstingMaxAvailableActiveCalls |
</div>


## `GroupTrunkGroupGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupTrunkGroupGetRequest23()`.

The response contains the maximum and bursting maximum permissible active trunk group
calls for the group.

**Attributes:**

|Name                                    |Type                                  |Description                       |
|----------------------------------------|--------------------------------------|----------------------------------|
|max_active_calls                        |int                                   |maxActiveCalls                    |
|max_available_active_calls              |OCI.maxAvailableActiveCalls           |maxAvailableActiveCalls           |
|bursting_max_active_calls               |OCI.burstingMaxActiveCalls            |burstingMaxActiveCalls            |
|bursting_max_available_active_calls     |OCI.burstingMaxAvailableActiveCalls   |burstingMaxAvailableActiveCalls   |
|max_available_number_of_bursting_btl_us |OCI.maxAvailableNumberOfBurstingBTLUs |maxAvailableNumberOfBurstingBTLUs |
|number_of_bursting_btl_us               |int                                   |numberOfBurstingBTLUs *Optional*  |
</div>


## `GroupVisualDeviceManagementGetDeviceInfoResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupVisualDeviceManagementGetDeviceInfoRequest()`.


**Attributes:**

|Name                             |Type            |Description                   |
|---------------------------------|----------------|------------------------------|
|device_type                      |str             |deviceType                    |
|support_visual_device_management |bool            |supportVisualDeviceManagement |
|mac_address                      |str             |macAddress *Optional*         |
|primary_user                     |OCI.primaryUser |primaryUser *Optional*        |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalBrandingResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupVoiceMessagingGroupGetVoicePortalBrandingRequest20()`.


**Attributes:**

|Name                               |Type                           |Description                           |
|-----------------------------------|-------------------------------|--------------------------------------|
|voice_portal_greeting_selection    |str                            |voicePortalGreetingSelection          |
|voice_portal_greeting_file         |OCI.voicePortalGreetingFile    |voicePortalGreetingFile *Optional*    |
|voice_messaging_greeting_selection |str                            |voiceMessagingGreetingSelection       |
|voice_messaging_greeting_file      |OCI.voiceMessagingGreetingFile |voiceMessagingGreetingFile *Optional* |
</div>


## `ServiceProviderAccessDeviceGetLinkedLeafDeviceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetLinkedLeafDeviceListRequest()`.


**Attributes:**

|Name                |Type                    |Description              |
|--------------------|------------------------|-------------------------|
|tree_device_link_id |str                     |treeDeviceLinkId         |
|leaf_device_key     |List[OCI.leafDeviceKey] |leafDeviceKey *Optional* |
</div>


## `ServiceProviderAccessDeviceGetResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetRequest14()`.

Replaced By: `ServiceProviderAccessDeviceGetResponse14sp3()`

**Attributes:**

|Name                              |Type              |Description                              |
|----------------------------------|------------------|-----------------------------------------|
|device_type                       |str               |deviceType                               |
|protocol                          |str               |protocol                                 |
|net_address                       |str               |netAddress *Optional*                    |
|port                              |int               |port *Optional*                          |
|outbound_proxy_server_net_address |str               |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str               |stunServerNetAddress *Optional*          |
|mac_address                       |str               |macAddress *Optional*                    |
|serial_number                     |str               |serialNumber *Optional*                  |
|description                       |str               |description *Optional*                   |
|number_of_ports                   |OCI.numberOfPorts |numberOfPorts                            |
|number_of_assigned_ports          |int               |numberOfAssignedPorts                    |
|status                            |str               |status                                   |
|physical_location                 |str               |physicalLocation *Optional*              |
|transport_protocol                |str               |transportProtocol *Optional*             |
</div>


## `ServiceProviderAccessDeviceGetResponse14sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetRequest14sp3()`.

Replaced By: `ServiceProviderAccessDeviceGetRequest14sp6()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol                                               |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
</div>


## `ServiceProviderAccessDeviceGetResponse14sp6`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to: `ServiceProviderAccessDeviceGetRequest14sp6()` Replaced by:
`ServiceProviderAccessDeviceGetRequest16()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol                                               |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
</div>


## `ServiceProviderAccessDeviceGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetRequest16()`.


**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol                                               |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
</div>


## `ServiceProviderAccessDeviceGetResponse18sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetRequest18sp1()`.

Replaced by: `ServiceProviderAccessDeviceGetResponse22()`.

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol                                               |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
|version                                          |str               |version *Optional*                                     |
</div>


## `ServiceProviderAccessDeviceGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetRequest22()`.

The following elements are only used in AS data mode: useHotline hotlineContact
Replaced by: `ServiceProviderAccessDeviceGetResponse24()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol                                               |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
|version                                          |str               |version *Optional*                                     |
|use_hotline                                      |bool              |useHotline                                             |
|hotline_contact                                  |str               |hotlineContact *Optional*                              |
</div>


## `ServiceProviderAccessDeviceGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetRequest22V2()`.

The following elements are only used in AS data mode: useHotline hotlineContact
serviceProviderId The following elements are only used in AS data mode and not
returned in XS data mode: deviceName deviceExternalId

Replaced By: `ServiceProviderAccessDeviceGetResponse24()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol                                               |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
|version                                          |str               |version *Optional*                                     |
|use_hotline                                      |bool              |useHotline                                             |
|hotline_contact                                  |str               |hotlineContact *Optional*                              |
|service_provider_id                              |str               |serviceProviderId                                      |
|device_name                                      |str               |deviceName                                             |
|device_external_id                               |str               |deviceExternalId *Optional*                            |
</div>


## `ServiceProviderAccessDeviceGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetRequest22V3()`.

The following elements are only used in AS data mode: serviceProviderId The following
elements are only used in AS data mode and not returned in XS data mode: deviceName
deviceExternalId Replaced by: `ServiceProviderAccessDeviceGetResponse24()`

**Attributes:**

|Name                              |Type              |Description                              |
|----------------------------------|------------------|-----------------------------------------|
|device_type                       |str               |deviceType                               |
|protocol                          |str               |protocol                                 |
|net_address                       |str               |netAddress *Optional*                    |
|port                              |int               |port *Optional*                          |
|outbound_proxy_server_net_address |str               |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str               |stunServerNetAddress *Optional*          |
|mac_address                       |str               |macAddress *Optional*                    |
|serial_number                     |str               |serialNumber *Optional*                  |
|description                       |str               |description *Optional*                   |
|number_of_ports                   |OCI.numberOfPorts |numberOfPorts                            |
|number_of_assigned_ports          |int               |numberOfAssignedPorts                    |
|status                            |str               |status                                   |
|physical_location                 |str               |physicalLocation *Optional*              |
|transport_protocol                |str               |transportProtocol *Optional*             |
|use_custom_user_name_password     |bool              |useCustomUserNamePassword *Optional*     |
|user_name                         |str               |userName *Optional*                      |
|version                           |str               |version *Optional*                       |
|service_provider_id               |str               |serviceProviderId                        |
|device_name                       |str               |deviceName                               |
|device_external_id                |str               |deviceExternalId *Optional*              |
</div>


## `ServiceProviderAccessDeviceGetResponse24`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetRequest24()`.

The following elements are only used in AS data mode: useHotline hotlineContact
serviceProviderId deviceName deviceExternalId

**Attributes:**

|Name                              |Type              |Description                              |
|----------------------------------|------------------|-----------------------------------------|
|device_type                       |str               |deviceType                               |
|protocol                          |str               |protocol                                 |
|net_address                       |str               |netAddress *Optional*                    |
|port                              |int               |port *Optional*                          |
|outbound_proxy_server_net_address |str               |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str               |stunServerNetAddress *Optional*          |
|mac_address                       |str               |macAddress *Optional*                    |
|serial_number                     |str               |serialNumber *Optional*                  |
|description                       |str               |description *Optional*                   |
|number_of_ports                   |OCI.numberOfPorts |numberOfPorts                            |
|number_of_assigned_ports          |int               |numberOfAssignedPorts                    |
|status                            |str               |status                                   |
|physical_location                 |str               |physicalLocation *Optional*              |
|transport_protocol                |str               |transportProtocol *Optional*             |
|use_custom_user_name_password     |bool              |useCustomUserNamePassword *Optional*     |
|user_name                         |str               |userName *Optional*                      |
|version                           |str               |version *Optional*                       |
|service_provider_id               |str               |serviceProviderId                        |
|device_name                       |str               |deviceName                               |
|device_external_id                |str               |deviceExternalId *Optional*              |
</div>


## `ServiceProviderCommunicationBarringProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderCommunicationBarringProfileGetRequest()`.

The response contains the Communication Barring Profile information.  The incoming,
originating and redirecting rules are returned in ascending priority order.

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
|incoming_default_action             |str                       |incomingDefaultAction                       |
|incoming_default_call_timeout       |int                       |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |List[OCI.incomingRule]    |incomingRule *Optional*                     |
|is_default                          |bool                      |isDefault                                   |
</div>


## `ServiceProviderCommunicationBarringProfileGetResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderCommunicationBarringProfileGetRequest17sp3()`.

The response contains the Communication Barring Profile information.  The incoming,
originating, redirecting and call me now rules are returned in ascending priority
order.  The following elements are only used in AS data mode: callMeNowDefaultAction,
value "Blocked" is returned in XS data mode The following elements are only used in AS
data mode and not returned in XS data mode: callMeNowDefaultCallTimeout callMeNowRule

Replaced By : ServiceProviderCommunicationBarringProfileGetResponse19sp1V2 in AS data
mode

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
|call_me_now_default_action          |str                       |callMeNowDefaultAction                      |
|call_me_now_default_call_timeout    |int                       |callMeNowDefaultCallTimeout *Optional*      |
|call_me_now_rule                    |List[OCI.callMeNowRule]   |callMeNowRule *Optional*                    |
|incoming_default_action             |str                       |incomingDefaultAction                       |
|incoming_default_call_timeout       |int                       |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |List[OCI.incomingRule]    |incomingRule *Optional*                     |
|is_default                          |bool                      |isDefault                                   |
</div>


## `ServiceProviderCommunicationBarringProfileGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderCommunicationBarringProfileGetRequest19sp1()`.

The response contains the Communication Barring Profile information.  The incoming,
originating, redirecting and call me now rules are returned in ascending priority
order.  The following elements are only used in AS data mode: callMeNowDefaultAction
applyToAttendedCallTransfers The following elements are only used in AS data mode and
not returned in XS data mode callMeNowDefaultCallTimeout callMeNowRule

Replaced By : ServiceProviderCommunicationBarringProfileGetResponse19sp1V2 in AS data
mode

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
|call_me_now_default_action          |str                       |callMeNowDefaultAction                      |
|call_me_now_default_call_timeout    |int                       |callMeNowDefaultCallTimeout *Optional*      |
|call_me_now_rule                    |List[OCI.callMeNowRule]   |callMeNowRule *Optional*                    |
|incoming_default_action             |str                       |incomingDefaultAction                       |
|incoming_default_call_timeout       |int                       |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |List[OCI.incomingRule]    |incomingRule *Optional*                     |
|is_default                          |bool                      |isDefault                                   |
|apply_to_attended_call_transfers    |bool                      |applyToAttendedCallTransfers                |
</div>


## `ServiceProviderDnGetStatusListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderDnGetStatusListRequest()`.


**Attributes:**

|Name      |Type               |Description         |
|----------|-------------------|--------------------|
|dn_status |List[OCI.dnStatus] |dnStatus *Optional* |
</div>


## `ServiceProviderFeatureAccessCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderFeatureAccessCodeGetListRequest()`.

Replaced By : `ServiceProviderFeatureAccessCodeGetListResponse20()` in AS data mode

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `ServiceProviderFeatureAccessCodeGetListResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderFeatureAccessCodeGetListRequest20()`.

In release 20 the "Call Recording" FAC name is changed to "Call Recording - Start".
Replaced by: `ServiceProviderFeatureAccessCodeGetListResponse21()`

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `ServiceProviderFeatureAccessCodeGetListResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderFeatureAccessCodeGetListRequest21()`.

In release 20 the "Call Recording" FAC name is changed to "Call Recording - Start".

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `ServiceProviderGetAvailableLeafDeviceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderGetAvailableLeafDeviceListRequest()`.


**Attributes:**

|Name            |Type                    |Description              |
|----------------|------------------------|-------------------------|
|leaf_device_key |List[OCI.leafDeviceKey] |leafDeviceKey *Optional* |
</div>


## `ServiceProviderGetResponse13mp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderGetRequest13mp2()`.

The response contains the service provider or enterprise's profile information.
Replaced by: `ServiceProviderGetResponse17sp1()`

**Attributes:**

|Name                       |Type        |Description                        |
|---------------------------|------------|-----------------------------------|
|is_enterprise              |bool        |isEnterprise *Optional*            |
|use_custom_routing_profile |bool        |useCustomRoutingProfile *Optional* |
|default_domain             |str         |defaultDomain                      |
|service_provider_name      |str         |serviceProviderName *Optional*     |
|support_email              |str         |supportEmail *Optional*            |
|contact                    |OCI.contact |contact *Optional*                 |
|address                    |OCI.address |address *Optional*                 |
</div>


## `ServiceProviderGetResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderGetRequest17sp1()`.

The response contains the service provider or enterprise's profile information.
Replaced by: `ServiceProviderGetResponse22()`.

**Attributes:**

|Name                           |Type        |Description                        |
|-------------------------------|------------|-----------------------------------|
|is_enterprise                  |bool        |isEnterprise *Optional*            |
|use_custom_routing_profile     |bool        |useCustomRoutingProfile *Optional* |
|default_domain                 |str         |defaultDomain                      |
|service_provider_name          |str         |serviceProviderName *Optional*     |
|support_email                  |str         |supportEmail *Optional*            |
|contact                        |OCI.contact |contact *Optional*                 |
|address                        |OCI.address |address *Optional*                 |
|use_service_provider_languages |bool        |useServiceProviderLanguages        |
</div>


## `ServiceProviderGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderGetRequest22()`.

The response contains the service provider or enterprise's profile information.  The
following element is only used in Amplify data mode and not returned in AS and XS data
mode: servicePolicy, callProcessingSliceId, provisioningSliceId, subscriberPartition,
preferredDataCenter.  Replaced by `ServiceProviderGetResponse22V2()`.

**Attributes:**

|Name                           |Type        |Description                        |
|-------------------------------|------------|-----------------------------------|
|is_enterprise                  |bool        |isEnterprise *Optional*            |
|use_custom_routing_profile     |bool        |useCustomRoutingProfile *Optional* |
|default_domain                 |str         |defaultDomain                      |
|service_provider_name          |str         |serviceProviderName *Optional*     |
|support_email                  |str         |supportEmail *Optional*            |
|contact                        |OCI.contact |contact *Optional*                 |
|address                        |OCI.address |address *Optional*                 |
|use_service_provider_languages |bool        |useServiceProviderLanguages        |
|service_policy                 |str         |servicePolicy *Optional*           |
|call_processing_slice_id       |str         |callProcessingSliceId *Optional*   |
|provisioning_slice_id          |str         |provisioningSliceId *Optional*     |
|subscriber_partition           |str         |subscriberPartition *Optional*     |
|preferred_data_center          |str         |preferredDataCenter *Optional*     |
</div>


## `ServiceProviderGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderGetRequest22V2()`.

The response contains the service provider or enterprise's profile information.  The
following elements isare only used in Amplify data mode and not returned in AS and XS
data mode: servicePolicy, callProcessingSliceId, provisioningSliceId,
subscriberPartition, preferredDataCenter.  The following elements are only used in
Amplify and XS data mode and not returned in AS data mode: preferredDataCenter.  The
following data elements are only used in AS data mode and not returned in XS data
mode: resellerId.  Replaced by `ServiceProviderGetResponse22V3()`.

**Attributes:**

|Name                           |Type        |Description                        |
|-------------------------------|------------|-----------------------------------|
|is_enterprise                  |bool        |isEnterprise *Optional*            |
|use_custom_routing_profile     |bool        |useCustomRoutingProfile *Optional* |
|default_domain                 |str         |defaultDomain                      |
|service_provider_name          |str         |serviceProviderName *Optional*     |
|support_email                  |str         |supportEmail *Optional*            |
|contact                        |OCI.contact |contact *Optional*                 |
|address                        |OCI.address |address *Optional*                 |
|use_service_provider_languages |bool        |useServiceProviderLanguages        |
|service_policy                 |str         |servicePolicy *Optional*           |
|call_processing_slice_id       |str         |callProcessingSliceId *Optional*   |
|provisioning_slice_id          |str         |provisioningSliceId *Optional*     |
|subscriber_partition           |str         |subscriberPartition *Optional*     |
|preferred_data_center          |str         |preferredDataCenter *Optional*     |
|reseller_id                    |str         |resellerId *Optional*              |
</div>


## `ServiceProviderGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderGetRequest22V3()`.

The response contains the service provider or enterprise's profile information.  The
following elements isare only used in Amplify data mode and not returned in AS and XS
data mode: servicePolicy, callProcessingSliceId, provisioningSliceId,
subscriberPartition, preferredDataCenter.  The following elements are only used in
Amplify and XS data mode and not returned in AS data mode: preferredDataCenter.  The
following data elements are only used in AS data mode and not returned in XS data
mode: resellerId.  Replaced by: `ServiceProviderGetResponse22V4()` in AS data mode.

**Attributes:**

|Name                           |Type        |Description                        |
|-------------------------------|------------|-----------------------------------|
|is_enterprise                  |bool        |isEnterprise *Optional*            |
|use_custom_routing_profile     |bool        |useCustomRoutingProfile *Optional* |
|default_domain                 |str         |defaultDomain                      |
|service_provider_name          |str         |serviceProviderName *Optional*     |
|support_email                  |str         |supportEmail *Optional*            |
|contact                        |OCI.contact |contact *Optional*                 |
|address                        |OCI.address |address *Optional*                 |
|use_service_provider_languages |bool        |useServiceProviderLanguages        |
|service_policy                 |str         |servicePolicy *Optional*           |
|call_processing_slice_id       |str         |callProcessingSliceId *Optional*   |
|provisioning_slice_id          |str         |provisioningSliceId *Optional*     |
|subscriber_partition           |str         |subscriberPartition *Optional*     |
|preferred_data_center          |str         |preferredDataCenter *Optional*     |
|reseller_id                    |str         |resellerId *Optional*              |
</div>


## `ServiceProviderGetResponse22V4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderGetRequest22V4()`.

The response contains the service provider or enterprise's profile information.  The
following elements are only used in Amplify data mode and not returned in AS and XS
data mode: servicePolicy, callProcessingSliceId, provisioningSliceId,
subscriberPartition, preferredDataCenter.  The following elements are only used in
Amplify and XS data mode and not returned in AS data mode: preferredDataCenter.  The
following data elements are only used in AS data mode and not returned in XS data
mode: resellerId, serviceProviderExternalId.

**Attributes:**

|Name                           |Type        |Description                          |
|-------------------------------|------------|-------------------------------------|
|is_enterprise                  |bool        |isEnterprise *Optional*              |
|use_custom_routing_profile     |bool        |useCustomRoutingProfile *Optional*   |
|default_domain                 |str         |defaultDomain                        |
|service_provider_name          |str         |serviceProviderName *Optional*       |
|support_email                  |str         |supportEmail *Optional*              |
|contact                        |OCI.contact |contact *Optional*                   |
|address                        |OCI.address |address *Optional*                   |
|use_service_provider_languages |bool        |useServiceProviderLanguages          |
|service_policy                 |str         |servicePolicy *Optional*             |
|call_processing_slice_id       |str         |callProcessingSliceId *Optional*     |
|provisioning_slice_id          |str         |provisioningSliceId *Optional*       |
|subscriber_partition           |str         |subscriberPartition *Optional*       |
|preferred_data_center          |str         |preferredDataCenter *Optional*       |
|reseller_id                    |str         |resellerId *Optional*                |
|service_provider_id            |str         |serviceProviderId                    |
|service_provider_external_id   |str         |serviceProviderExternalId *Optional* |
</div>


## `ServiceProviderMeetMeConferencingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderMeetMeConferencingGetRequest()`.


**Attributes:**

|Name            |Type               |Description    |
|----------------|-------------------|---------------|
|allocated_ports |OCI.allocatedPorts |allocatedPorts |
</div>


## `ServiceProviderScheduleGetEventResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderScheduleGetEventRequest()`.

The response contains the event of the service provider schedule.

**Attributes:**

|Name          |Type           |Description            |
|--------------|---------------|-----------------------|
|start_date    |str            |startDate              |
|all_day_event |bool           |allDayEvent *Optional* |
|start_time    |OCI.startTime  |startTime *Optional*   |
|end_time      |OCI.endTime    |endTime *Optional*     |
|end_date      |str            |endDate                |
|recurrence    |OCI.recurrence |recurrence *Optional*  |
</div>


## `ServiceProviderScheduleGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderScheduleGetListRequest()`.

The response contains a list of service provider schedules.

**Attributes:**

|Name         |Type                  |Description            |
|-------------|----------------------|-----------------------|
|schedule_key |List[OCI.scheduleKey] |scheduleKey *Optional* |
</div>


## `ServiceProviderServiceGetAuthorizationResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderServiceGetAuthorizationRequest()`.

If the feature was never licensed, then "authorized" is false and the remaining
elements are not returned.  If the service pack is available for use, "authorized" is
true.  "authorizedQuantity" can be unlimited or a quantity.  In the case of a service
pack, "authorizedQuantity" is the service pack's quantity.  "authorizable" is
applicable for user services and group services; it is not returned for service packs.

**Attributes:**

|Name                |Type                   |Description                   |
|--------------------|-----------------------|------------------------------|
|authorized          |bool                   |authorized                    |
|authorized_quantity |OCI.authorizedQuantity |authorizedQuantity *Optional* |
|used_quantity       |OCI.usedQuantity       |usedQuantity *Optional*       |
|authorizable        |bool                   |authorizable *Optional*       |
</div>


## `ServiceProviderServicePackGetDetailListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderServicePackGetDetailListRequest()`.

It contains the service pack details and the list of services in a table format.  The
column headings are "Service", "Authorized" "Allocated" and "Available".

**Attributes:**

|Name                     |Type                    |Description                                                       |
|-------------------------|------------------------|------------------------------------------------------------------|
|service_pack_name        |str                     |servicePackName                                                   |
|service_pack_description |str                     |servicePackDescription *Optional*                                 |
|is_available_for_use     |bool                    |isAvailableForUse                                                 |
|service_pack_quantity    |OCI.servicePackQuantity |servicePackQuantity                                               |
|assigned_quantity        |OCI.assignedQuantity    |assignedQuantity                                                  |
|allowed_quantity         |OCI.allowedQuantity     |allowedQuantity                                                   |
|user_service_table       |List(userServiceTable)  |userServiceTable - *Table* array of userServiceTable named tuples |
</div>


## `ServiceProviderTrunkGroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderTrunkGroupGetRequest()`.

The response contains the maximum permissible active trunk group calls for the service
provider.

**Attributes:**

|Name             |Type               |Description    |
|-----------------|-------------------|---------------|
|max_active_calls |OCI.maxActiveCalls |maxActiveCalls |
</div>


## `ServiceProviderTrunkGroupGetResponse14sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderTrunkGroupGetRequest14sp1()`.

The response contains the maximum and bursting maximum permissible active trunk group
calls for the service provider.

**Attributes:**

|Name                      |Type                       |Description            |
|--------------------------|---------------------------|-----------------------|
|max_active_calls          |OCI.maxActiveCalls         |maxActiveCalls         |
|bursting_max_active_calls |OCI.burstingMaxActiveCalls |burstingMaxActiveCalls |
</div>


## `ServiceProviderTrunkGroupGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `ServiceProviderTrunkGroupGetRequest23()`.

The response contains the maximum and bursting maximum permissible active trunk group
calls for the service provider.

**Attributes:**

|Name                      |Type                       |Description            |
|--------------------------|---------------------------|-----------------------|
|max_active_calls          |OCI.maxActiveCalls         |maxActiveCalls         |
|bursting_max_active_calls |OCI.burstingMaxActiveCalls |burstingMaxActiveCalls |
|number_of_bursting_btl_us |OCI.numberOfBurstingBTLUs  |numberOfBurstingBTLUs  |
</div>


## `ServiceProviderVisualDeviceManagementGetDeviceInfoResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderVisualDeviceManagementGetDeviceInfoRequest()`.


**Attributes:**

|Name                             |Type            |Description                   |
|---------------------------------|----------------|------------------------------|
|device_type                      |str             |deviceType                    |
|support_visual_device_management |bool            |supportVisualDeviceManagement |
|mac_address                      |str             |macAddress *Optional*         |
|primary_user                     |OCI.primaryUser |primaryUser *Optional*        |
</div>


## `SystemAccessDeviceGetLinkedLeafDeviceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetLinkedLeafDeviceListRequest()`.


**Attributes:**

|Name                |Type                    |Description              |
|--------------------|------------------------|-------------------------|
|tree_device_link_id |str                     |treeDeviceLinkId         |
|leaf_device_key     |List[OCI.leafDeviceKey] |leafDeviceKey *Optional* |
</div>


## `SystemAccessDeviceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetRequest()`.

Replaced By: `SystemAccessDeviceGetResponse14sp3()`

**Attributes:**

|Name                              |Type              |Description                              |
|----------------------------------|------------------|-----------------------------------------|
|device_type                       |str               |deviceType                               |
|protocol                          |str               |protocol                                 |
|net_address                       |str               |netAddress *Optional*                    |
|port                              |int               |port *Optional*                          |
|outbound_proxy_server_net_address |str               |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str               |stunServerNetAddress *Optional*          |
|mac_address                       |str               |macAddress *Optional*                    |
|serial_number                     |str               |serialNumber *Optional*                  |
|description                       |str               |description *Optional*                   |
|number_of_ports                   |OCI.numberOfPorts |numberOfPorts                            |
|number_of_assigned_ports          |int               |numberOfAssignedPorts                    |
|status                            |str               |status                                   |
|physical_location                 |str               |physicalLocation *Optional*              |
|transport_protocol                |str               |transportProtocol *Optional*             |
</div>


## `SystemAccessDeviceGetResponse14sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetRequest14sp3()`

Replaced By: `SystemAccessDeviceGetResponse14sp6()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol                                               |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
</div>


## `SystemAccessDeviceGetResponse14sp6`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to: `SystemAccessDeviceGetRequest14sp6()` Replaced by:
`SystemAccessDeviceGetRequest16()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol                                               |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
</div>


## `SystemAccessDeviceGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetRequest16()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol                                               |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
</div>


## `SystemAccessDeviceGetResponse18sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetRequest18sp1()` The following elements are only used
in AS data mode: version Replaced by: `SystemAccessDeviceGetResponse22()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol                                               |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
|version                                          |str               |version *Optional*                                     |
</div>


## `SystemAccessDeviceGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetRequest22()` The following elements are only used in
AS data mode: version useHotline hotlineContact Replaced by:
`SystemAccessDeviceGetResponse24()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol                                               |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
|version                                          |str               |version *Optional*                                     |
|use_hotline                                      |bool              |useHotline                                             |
|hotline_contact                                  |str               |hotlineContact *Optional*                              |
</div>


## `SystemAccessDeviceGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetRequest22V2()` The following elements are only
returned in AS data mode: version useHotline hotlineContact The following elements are
only used in AS data mode and not returned in XS data mode: deviceName
deviceExternalId

Replaced By: `SystemAccessDeviceGetResponse24()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol                                               |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
|version                                          |str               |version *Optional*                                     |
|use_hotline                                      |bool              |useHotline                                             |
|hotline_contact                                  |str               |hotlineContact *Optional*                              |
|device_name                                      |str               |deviceName                                             |
|device_external_id                               |str               |deviceExternalId *Optional*                            |
</div>


## `SystemAccessDeviceGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetRequest22V3()` The following elements are only used
in AS data mode: version useHotline hotlineContact The following elements are only
used in AS data mode and not returned in XS data mode: isWebexTeamsDevice
defaultPathHeader deviceExternalId

Replaced By: `SystemAccessDeviceGetResponse24()`

**Attributes:**

|Name                                             |Type              |Description                                            |
|-------------------------------------------------|------------------|-------------------------------------------------------|
|device_type                                      |str               |deviceType                                             |
|protocol                                         |str               |protocol                                               |
|net_address                                      |str               |netAddress *Optional*                                  |
|port                                             |int               |port *Optional*                                        |
|outbound_proxy_server_net_address                |str               |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str               |stunServerNetAddress *Optional*                        |
|mac_address                                      |str               |macAddress *Optional*                                  |
|serial_number                                    |str               |serialNumber *Optional*                                |
|description                                      |str               |description *Optional*                                 |
|number_of_ports                                  |OCI.numberOfPorts |numberOfPorts                                          |
|number_of_assigned_ports                         |int               |numberOfAssignedPorts                                  |
|status                                           |str               |status                                                 |
|physical_location                                |str               |physicalLocation *Optional*                            |
|transport_protocol                               |str               |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str               |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str               |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_default_originating_service_key |int               |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int               |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool              |useCustomUserNamePassword *Optional*                   |
|user_name                                        |str               |userName *Optional*                                    |
|version                                          |str               |version *Optional*                                     |
|use_hotline                                      |bool              |useHotline                                             |
|hotline_contact                                  |str               |hotlineContact *Optional*                              |
|device_name                                      |str               |deviceName                                             |
|device_external_id                               |str               |deviceExternalId *Optional*                            |
|is_webex_teams_device                            |bool              |isWebexTeamsDevice *Optional*                          |
|default_path_header                              |str               |defaultPathHeader *Optional*                           |
</div>


## `SystemAccessDeviceGetResponse22V4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetRequest22V4()` The following elements are only used
in AS data mode: version The following elements are only used in AS data mode and not
returned in XS data mode: isWebexTeamsDevice defaultPathHeader deviceExternalId
Replaced by: `SystemAccessDeviceGetResponse24()`

**Attributes:**

|Name                              |Type              |Description                              |
|----------------------------------|------------------|-----------------------------------------|
|device_type                       |str               |deviceType                               |
|protocol                          |str               |protocol                                 |
|net_address                       |str               |netAddress *Optional*                    |
|port                              |int               |port *Optional*                          |
|outbound_proxy_server_net_address |str               |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str               |stunServerNetAddress *Optional*          |
|mac_address                       |str               |macAddress *Optional*                    |
|serial_number                     |str               |serialNumber *Optional*                  |
|description                       |str               |description *Optional*                   |
|number_of_ports                   |OCI.numberOfPorts |numberOfPorts                            |
|number_of_assigned_ports          |int               |numberOfAssignedPorts                    |
|status                            |str               |status                                   |
|physical_location                 |str               |physicalLocation *Optional*              |
|transport_protocol                |str               |transportProtocol *Optional*             |
|use_custom_user_name_password     |bool              |useCustomUserNamePassword *Optional*     |
|user_name                         |str               |userName *Optional*                      |
|version                           |str               |version *Optional*                       |
|device_name                       |str               |deviceName                               |
|device_external_id                |str               |deviceExternalId *Optional*              |
|is_webex_teams_device             |bool              |isWebexTeamsDevice *Optional*            |
|default_path_header               |str               |defaultPathHeader *Optional*             |
</div>


## `SystemAccessDeviceGetResponse24`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetRequest24()` The following elements are only used in
AS data mode: version deviceName deviceExternalId The following elements are only used
in AS data mode and not returned in XS data mode: isWebexTeamsDevice defaultPathHeader

**Attributes:**

|Name                              |Type              |Description                              |
|----------------------------------|------------------|-----------------------------------------|
|device_type                       |str               |deviceType                               |
|protocol                          |str               |protocol                                 |
|net_address                       |str               |netAddress *Optional*                    |
|port                              |int               |port *Optional*                          |
|outbound_proxy_server_net_address |str               |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str               |stunServerNetAddress *Optional*          |
|mac_address                       |str               |macAddress *Optional*                    |
|serial_number                     |str               |serialNumber *Optional*                  |
|description                       |str               |description *Optional*                   |
|number_of_ports                   |OCI.numberOfPorts |numberOfPorts                            |
|number_of_assigned_ports          |int               |numberOfAssignedPorts                    |
|status                            |str               |status                                   |
|physical_location                 |str               |physicalLocation *Optional*              |
|transport_protocol                |str               |transportProtocol *Optional*             |
|use_custom_user_name_password     |bool              |useCustomUserNamePassword *Optional*     |
|user_name                         |str               |userName *Optional*                      |
|version                           |str               |version *Optional*                       |
|is_webex_teams_device             |bool              |isWebexTeamsDevice *Optional*            |
|default_path_header               |str               |defaultPathHeader *Optional*             |
|device_name                       |str               |deviceName                               |
|device_external_id                |str               |deviceExternalId *Optional*              |
</div>


## `SystemCallCenterEnhancedReportingDataTemplateGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCallCenterEnhancedReportingDataTemplateGetListRequest()`.


**Attributes:**

|Name |Type           |Description     |
|-----|---------------|----------------|
|info |List[OCI.info] |info *Optional* |
</div>


## `SystemCollaborateGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCollaborateGetRequest()`.

Replaced by: `SystemCollaborateGetResponse20sp1()`

**Attributes:**

|Name                                               |Type                       |Description                                   |
|---------------------------------------------------|---------------------------|----------------------------------------------|
|collaborate_room_id_length                         |int                        |collaborateRoomIdLength                       |
|instant_room_idle_timeout_seconds                  |int                        |instantRoomIdleTimeoutSeconds                 |
|collaborate_room_maximum_duration_minutes          |int                        |collaborateRoomMaximumDurationMinutes         |
|support_outdial                                    |bool                       |supportOutdial                                |
|max_collaborate_room_participants                  |int                        |maxCollaborateRoomParticipants                |
|collaborate_active_talker_refresh_interval_seconds |int                        |collaborateActiveTalkerRefreshIntervalSeconds |
|terminate_collaborate_after_grace_period           |bool                       |terminateCollaborateAfterGracePeriod          |
|collaborate_grace_period                           |OCI.collaborateGracePeriod |collaborateGracePeriod                        |
|enable_active_collaborate_notification             |bool                       |enableActiveCollaborateNotification           |
|collaborate_from_address                           |str                        |collaborateFromAddress *Optional*             |
</div>


## `SystemCollaborateGetResponse20sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemCollaborateGetRequest20sp1()`.

Replaced by: SystemCollaborateGetResponse20sp1V2

**Attributes:**

|Name                                               |Type                       |Description                                   |
|---------------------------------------------------|---------------------------|----------------------------------------------|
|collaborate_room_id_length                         |int                        |collaborateRoomIdLength                       |
|instant_room_idle_timeout_seconds                  |int                        |instantRoomIdleTimeoutSeconds                 |
|collaborate_room_maximum_duration_minutes          |int                        |collaborateRoomMaximumDurationMinutes         |
|support_outdial                                    |bool                       |supportOutdial                                |
|max_collaborate_room_participants                  |int                        |maxCollaborateRoomParticipants                |
|collaborate_active_talker_refresh_interval_seconds |int                        |collaborateActiveTalkerRefreshIntervalSeconds |
|terminate_collaborate_after_grace_period           |bool                       |terminateCollaborateAfterGracePeriod          |
|collaborate_grace_period                           |OCI.collaborateGracePeriod |collaborateGracePeriod                        |
|enable_active_collaborate_notification             |bool                       |enableActiveCollaborateNotification           |
|collaborate_from_address                           |str                        |collaborateFromAddress *Optional*             |
</div>


## `SystemCommunicationBarringProfileGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringProfileGetRequest()`.

The response contains the Communication Barring Profile information.  Replaced by:
`SystemCommunicationBarringProfileGetResponse16()`

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
</div>


## `SystemCommunicationBarringProfileGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringProfileGetRequest16()`.

The response contains the Communication Barring Profile information.

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
</div>


## `SystemCommunicationBarringProfileGetResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringProfileGetRequest17sp1()`.

The response contains the Communication Barring Profile information.  The incoming
rules are returned in ascending priority order.  The following elements are only used
in XS data mode: incomingDefaultAction incomingDefaultCallTimeout incomingRule

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
|incoming_default_action             |str                       |incomingDefaultAction                       |
|incoming_default_call_timeout       |int                       |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |List[OCI.incomingRule]    |incomingRule *Optional*                     |
</div>


## `SystemCommunicationBarringProfileGetResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringProfileGetRequest17sp3()`.

The response contains the Communication Barring Profile information.  The incoming
rules are returned in ascending priority order.  The following elements are only used
in AS data mode: callMeNowDefaultAction, value "Block" is returned in XS data mode The
following elements are only used in AS data mode and not returned in XS data mode:
callMeNowDefaultCallTimeout callMeNowRule Replaced by:
`SystemCommunicationBarringProfileGetResponse19sp1()` in AS data mode

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
|incoming_default_action             |str                       |incomingDefaultAction                       |
|incoming_default_call_timeout       |int                       |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |List[OCI.incomingRule]    |incomingRule *Optional*                     |
|call_me_now_default_action          |str                       |callMeNowDefaultAction                      |
|call_me_now_default_call_timeout    |int                       |callMeNowDefaultCallTimeout *Optional*      |
|call_me_now_rule                    |List[OCI.callMeNowRule]   |callMeNowRule *Optional*                    |
</div>


## `SystemCommunicationBarringProfileGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemCommunicationBarringProfileGetRequest19sp1()`.

The response contains the Communication Barring Profile information.  The incoming
rules are returned in ascending priority order.  The following elements are only used
in AS data mode: callMeNowDefaultAction, value "Block" is returned in XS data mode
applyToAttendedCallTransfers, The following elements are only used in AS data mode and
not returned in XS data mode: callMeNowDefaultCallTimeout callMeNowRule Replaced by:
SystemCommunicationBarringProfileGetResponse19sp1V2 in AS data mode

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
|incoming_default_action             |str                       |incomingDefaultAction                       |
|incoming_default_call_timeout       |int                       |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |List[OCI.incomingRule]    |incomingRule *Optional*                     |
|call_me_now_default_action          |str                       |callMeNowDefaultAction                      |
|call_me_now_default_call_timeout    |int                       |callMeNowDefaultCallTimeout *Optional*      |
|call_me_now_rule                    |List[OCI.callMeNowRule]   |callMeNowRule *Optional*                    |
|apply_to_attended_call_transfers    |bool                      |applyToAttendedCallTransfers                |
</div>


## `SystemDeviceTypeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetRequest()`.

Replaced By: `SystemDeviceTypeGetResponse14sp3()`

**Attributes:**

|Name                        |Type                 |Description                  |
|----------------------------|---------------------|-----------------------------|
|is_obsolete                 |bool                 |isObsolete                   |
|profile                     |str                  |profile                      |
|web_based_config_url        |str                  |webBasedConfigURL *Optional* |
|static_registration_capable |bool                 |staticRegistrationCapable    |
|cpe_device_options          |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*  |
|protocol_choice             |List[str]            |protocolChoice               |
|is_ip_address_optional      |bool                 |isIpAddressOptional          |
|use_domain                  |bool                 |useDomain                    |
</div>


## `SystemDeviceTypeGetResponse14sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetRequest14sp3()`.

Replaced By: `SystemDeviceTypeGetResponse14sp6()`

**Attributes:**

|Name                        |Type                 |Description                  |
|----------------------------|---------------------|-----------------------------|
|is_obsolete                 |bool                 |isObsolete                   |
|profile                     |str                  |profile                      |
|web_based_config_url        |str                  |webBasedConfigURL *Optional* |
|static_registration_capable |bool                 |staticRegistrationCapable    |
|cpe_device_options          |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*  |
|protocol_choice             |List[str]            |protocolChoice               |
|is_ip_address_optional      |bool                 |isIpAddressOptional          |
|use_domain                  |bool                 |useDomain                    |
|is_mobility_manager_device  |bool                 |isMobilityManagerDevice      |
</div>


## `SystemFeatureAccessCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemFeatureAccessCodeGetListRequest()`.

Replaced by: `SystemFeatureAccessCodeGetListResponse21()` in AS data mode

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `SystemFeatureAccessCodeGetListResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemFeatureAccessCodeGetListRequest20()`.

In release 20 the "Call Recording" FAC name is changed to "Call Recording - Start".
Replaced by: `SystemFeatureAccessCodeGetListResponse21()`

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `SystemFeatureAccessCodeGetListResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemFeatureAccessCodeGetListRequest21()`.

In release 20 the "Call Recording" FAC name is changed to "Call Recording - Start".

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `SystemFileRepositoryDeviceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemFileRepositoryDeviceGetRequest()`.


**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|root_directory   |str                |rootDirectory *Optional*  |
|port             |int                |port *Optional*           |
|protocol_web_dav |OCI.protocolWebDAV |protocolWebDAV *Optional* |
|protocol_ftp     |OCI.protocolFTP    |protocolFTP *Optional*    |
</div>


## `SystemFileRepositoryDeviceGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemFileRepositoryDeviceGetRequest16()`.

Replaced by: `SystemFileRepositoryDeviceGetResponse20()` in AS data mode

**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|root_directory   |str                |rootDirectory *Optional*  |
|port             |int                |port *Optional*           |
|protocol_web_dav |OCI.protocolWebDAV |protocolWebDAV *Optional* |
|protocol_ftp     |OCI.protocolFTP    |protocolFTP *Optional*    |
</div>


## `SystemFileRepositoryDeviceGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemFileRepositoryDeviceGetRequest20()`.


**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|root_directory   |str                |rootDirectory *Optional*  |
|port             |int                |port *Optional*           |
|protocol_web_dav |OCI.protocolWebDAV |protocolWebDAV *Optional* |
|protocol_ftp     |OCI.protocolFTP    |protocolFTP *Optional*    |
</div>


## `SystemFileRepositoryDeviceGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemFileRepositoryDeviceGetRequest22()`.


**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|root_directory   |str                |rootDirectory *Optional*  |
|port             |int                |port *Optional*           |
|protocol_web_dav |OCI.protocolWebDAV |protocolWebDAV *Optional* |
|protocol_ftp     |OCI.protocolFTP    |protocolFTP *Optional*    |
|protocol_sftp    |OCI.protocolSFTP   |protocolSFTP *Optional*   |
|protocol_ftps    |OCI.protocolFTPS   |protocolFTPS *Optional*   |
</div>


## `SystemGetAvailableLeafDeviceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGetAvailableLeafDeviceListRequest()`.


**Attributes:**

|Name            |Type                    |Description              |
|----------------|------------------------|-------------------------|
|leaf_device_key |List[OCI.leafDeviceKey] |leafDeviceKey *Optional* |
</div>


## `SystemHolidayScheduleGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemHolidayScheduleGetRequest()`.

The response contains the system holiday schedule information.

**Attributes:**

|Name      |Type          |Description          |
|----------|--------------|---------------------|
|holiday01 |OCI.holiday01 |holiday01 *Optional* |
|holiday02 |OCI.holiday02 |holiday02 *Optional* |
|holiday03 |OCI.holiday03 |holiday03 *Optional* |
|holiday04 |OCI.holiday04 |holiday04 *Optional* |
|holiday05 |OCI.holiday05 |holiday05 *Optional* |
|holiday06 |OCI.holiday06 |holiday06 *Optional* |
|holiday07 |OCI.holiday07 |holiday07 *Optional* |
|holiday08 |OCI.holiday08 |holiday08 *Optional* |
|holiday09 |OCI.holiday09 |holiday09 *Optional* |
|holiday10 |OCI.holiday10 |holiday10 *Optional* |
|holiday11 |OCI.holiday11 |holiday11 *Optional* |
|holiday12 |OCI.holiday12 |holiday12 *Optional* |
|holiday13 |OCI.holiday13 |holiday13 *Optional* |
|holiday14 |OCI.holiday14 |holiday14 *Optional* |
|holiday15 |OCI.holiday15 |holiday15 *Optional* |
|holiday16 |OCI.holiday16 |holiday16 *Optional* |
|holiday17 |OCI.holiday17 |holiday17 *Optional* |
|holiday18 |OCI.holiday18 |holiday18 *Optional* |
|holiday19 |OCI.holiday19 |holiday19 *Optional* |
|holiday20 |OCI.holiday20 |holiday20 *Optional* |
</div>


## `SystemInterceptUserGetDnListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemInterceptUserGetDnListRequest()`.

The Intercept User DN List.

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|intercept_user_list |List[OCI.interceptUserList] |interceptUserList *Optional* |
</div>


## `SystemMGCPDeviceTypeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMGCPDeviceTypeGetRequest()`.


**Attributes:**

|Name            |Type              |Description    |
|----------------|------------------|---------------|
|is_obsolete     |bool              |isObsolete     |
|profile         |str               |profile        |
|number_of_ports |OCI.numberOfPorts |numberOfPorts  |
|protocol_choice |List[str]         |protocolChoice |
</div>


## `SystemMeetMeConferencingGetResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMeetMeConferencingGetRequest18()`.


**Attributes:**

|Name                                         |Type                             |Description                             |
|---------------------------------------------|---------------------------------|----------------------------------------|
|conference_id_length                         |int                              |conferenceIdLength                      |
|moderator_pin_length                         |int                              |moderatorPinLength                      |
|enable_conference_end_date_restriction       |bool                             |enableConferenceEndDateRestriction      |
|conference_end_date_restriction_months       |int                              |conferenceEndDateRestrictionMonths      |
|delete_expired_conferences_after_hold_period |bool                             |deleteExpiredConferencesAfterHoldPeriod |
|expired_conference_hold_period_days          |int                              |expiredConferenceHoldPeriodDays         |
|recording_web_app_url                        |str                              |recordingWebAppURL *Optional*           |
|recording_file_format                        |str                              |recordingFileFormat                     |
|terminate_after_grace_period                 |bool                             |terminateAfterGracePeriod               |
|conference_grace_period_minutes              |OCI.conferenceGracePeriodMinutes |conferenceGracePeriodMinutes            |
|conference_participant_early_entry_minutes   |int                              |conferenceParticipantEarlyEntryMinutes  |
|enable_conference_expiry_notification        |bool                             |enableConferenceExpiryNotification      |
|enable_active_conference_notification        |bool                             |enableActiveConferenceNotification      |
|conference_from_address                      |str                              |conferenceFromAddress                   |
</div>


## `SystemMeetMeConferencingGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemMeetMeConferencingGetRequest19()`.


**Attributes:**

|Name                                              |Type                             |Description                                  |
|--------------------------------------------------|---------------------------------|---------------------------------------------|
|conference_id_length                              |int                              |conferenceIdLength                           |
|moderator_pin_length                              |int                              |moderatorPinLength                           |
|enable_conference_end_date_restriction            |bool                             |enableConferenceEndDateRestriction           |
|conference_end_date_restriction_months            |int                              |conferenceEndDateRestrictionMonths           |
|delete_expired_conferences_after_hold_period      |bool                             |deleteExpiredConferencesAfterHoldPeriod      |
|expired_conference_hold_period_days               |int                              |expiredConferenceHoldPeriodDays              |
|recording_web_app_url                             |str                              |recordingWebAppURL *Optional*                |
|recording_file_format                             |str                              |recordingFileFormat                          |
|terminate_after_grace_period                      |bool                             |terminateAfterGracePeriod                    |
|conference_grace_period_minutes                   |OCI.conferenceGracePeriodMinutes |conferenceGracePeriodMinutes                 |
|conference_participant_early_entry_minutes        |int                              |conferenceParticipantEarlyEntryMinutes       |
|enable_conference_expiry_notification             |bool                             |enableConferenceExpiryNotification           |
|enable_active_conference_notification             |bool                             |enableActiveConferenceNotification           |
|conference_from_address                           |str                              |conferenceFromAddress                        |
|conference_active_talker_refresh_interval_seconds |int                              |conferenceActiveTalkerRefreshIntervalSeconds |
</div>


## `SystemNetworkClassOfServiceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemNetworkClassOfServiceGetRequest()`.

The response contains the Network Class of Service information.  Replaced by:
`SystemNetworkClassOfServiceGetResponse17()`

**Attributes:**

|Name                           |Type                             |Description                             |
|-------------------------------|---------------------------------|----------------------------------------|
|description                    |str                              |description *Optional*                  |
|communication_barring_profile0 |OCI.communicationBarringProfile0 |communicationBarringProfile0 *Optional* |
|communication_barring_profile1 |OCI.communicationBarringProfile1 |communicationBarringProfile1 *Optional* |
|communication_barring_profile2 |OCI.communicationBarringProfile2 |communicationBarringProfile2 *Optional* |
|communication_barring_profile3 |OCI.communicationBarringProfile3 |communicationBarringProfile3 *Optional* |
|communication_barring_profile4 |OCI.communicationBarringProfile4 |communicationBarringProfile4 *Optional* |
|communication_barring_profile5 |OCI.communicationBarringProfile5 |communicationBarringProfile5 *Optional* |
|communication_barring_profile6 |OCI.communicationBarringProfile6 |communicationBarringProfile6 *Optional* |
|communication_barring_profile7 |OCI.communicationBarringProfile7 |communicationBarringProfile7 *Optional* |
|communication_barring_profile8 |OCI.communicationBarringProfile8 |communicationBarringProfile8 *Optional* |
|communication_barring_profile9 |OCI.communicationBarringProfile9 |communicationBarringProfile9 *Optional* |
</div>


## `SystemNetworkClassOfServiceGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemNetworkClassOfServiceGetRequest17()`.

The response contains the Network Class of Service information.  Replaced by:
`SystemNetworkClassOfServiceGetResponse19sp1()` in AS data mode

**Attributes:**

|Name                           |Type                             |Description                             |
|-------------------------------|---------------------------------|----------------------------------------|
|description                    |str                              |description *Optional*                  |
|communication_barring_profile0 |OCI.communicationBarringProfile0 |communicationBarringProfile0 *Optional* |
|communication_barring_profile1 |OCI.communicationBarringProfile1 |communicationBarringProfile1 *Optional* |
|communication_barring_profile2 |OCI.communicationBarringProfile2 |communicationBarringProfile2 *Optional* |
|communication_barring_profile3 |OCI.communicationBarringProfile3 |communicationBarringProfile3 *Optional* |
|communication_barring_profile4 |OCI.communicationBarringProfile4 |communicationBarringProfile4 *Optional* |
|communication_barring_profile5 |OCI.communicationBarringProfile5 |communicationBarringProfile5 *Optional* |
|communication_barring_profile6 |OCI.communicationBarringProfile6 |communicationBarringProfile6 *Optional* |
|communication_barring_profile7 |OCI.communicationBarringProfile7 |communicationBarringProfile7 *Optional* |
|communication_barring_profile8 |OCI.communicationBarringProfile8 |communicationBarringProfile8 *Optional* |
|communication_barring_profile9 |OCI.communicationBarringProfile9 |communicationBarringProfile9 *Optional* |
|network_translation_index      |str                              |networkTranslationIndex *Optional*      |
</div>


## `SystemNetworkClassOfServiceGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemNetworkClassOfServiceGetRequest19sp1()`.

The response contains the Network Class of Service information.

**Attributes:**

|Name                                |Type                             |Description                                |
|------------------------------------|---------------------------------|-------------------------------------------|
|description                         |str                              |description *Optional*                     |
|communication_barring_profile0      |OCI.communicationBarringProfile0 |communicationBarringProfile0 *Optional*    |
|communication_barring_profile1      |OCI.communicationBarringProfile1 |communicationBarringProfile1 *Optional*    |
|communication_barring_profile2      |OCI.communicationBarringProfile2 |communicationBarringProfile2 *Optional*    |
|communication_barring_profile3      |OCI.communicationBarringProfile3 |communicationBarringProfile3 *Optional*    |
|communication_barring_profile4      |OCI.communicationBarringProfile4 |communicationBarringProfile4 *Optional*    |
|communication_barring_profile5      |OCI.communicationBarringProfile5 |communicationBarringProfile5 *Optional*    |
|communication_barring_profile6      |OCI.communicationBarringProfile6 |communicationBarringProfile6 *Optional*    |
|communication_barring_profile7      |OCI.communicationBarringProfile7 |communicationBarringProfile7 *Optional*    |
|communication_barring_profile8      |OCI.communicationBarringProfile8 |communicationBarringProfile8 *Optional*    |
|communication_barring_profile9      |OCI.communicationBarringProfile9 |communicationBarringProfile9 *Optional*    |
|network_translation_index           |str                              |networkTranslationIndex *Optional*         |
|call_processing_policy_profile_name |str                              |callProcessingPolicyProfileName *Optional* |
</div>


## `SystemSIPDeviceTypeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest()`.


**Attributes:**

|Name                          |Type                 |Description                  |
|------------------------------|---------------------|-----------------------------|
|is_obsolete                   |bool                 |isObsolete                   |
|number_of_ports               |OCI.numberOfPorts    |numberOfPorts                |
|profile                       |str                  |profile                      |
|registration_capable          |bool                 |registrationCapable          |
|is_conference_device          |bool                 |isConferenceDevice           |
|is_music_on_hold_device       |bool                 |isMusicOnHoldDevice          |
|authentication_override       |bool                 |authenticationOverride       |
|rfc3264_hold                  |bool                 |RFC3264Hold                  |
|is_trusted                    |bool                 |isTrusted                    |
|e164_capable                  |bool                 |E164Capable                  |
|route_advance                 |bool                 |routeAdvance                 |
|forwarding_override           |bool                 |forwardingOverride           |
|wireless_integration          |bool                 |wirelessIntegration          |
|web_based_config_url          |str                  |webBasedConfigURL *Optional* |
|is_video_capable              |bool                 |isVideoCapable               |
|pbx_integration               |bool                 |PBXIntegration               |
|use_business_trunking_contact |bool                 |useBusinessTrunkingContact   |
|static_registration_capable   |bool                 |staticRegistrationCapable    |
|cpe_device_options            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*  |
|protocol_choice               |List[str]            |protocolChoice               |
</div>


## `SystemSIPDeviceTypeGetResponse14sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest14sp1()`.


**Attributes:**

|Name                          |Type                 |Description                  |
|------------------------------|---------------------|-----------------------------|
|is_obsolete                   |bool                 |isObsolete                   |
|number_of_ports               |OCI.numberOfPorts    |numberOfPorts                |
|profile                       |str                  |profile                      |
|registration_capable          |bool                 |registrationCapable          |
|is_conference_device          |bool                 |isConferenceDevice           |
|is_music_on_hold_device       |bool                 |isMusicOnHoldDevice          |
|authentication_override       |bool                 |authenticationOverride       |
|rfc3264_hold                  |bool                 |RFC3264Hold                  |
|is_trusted                    |bool                 |isTrusted                    |
|e164_capable                  |bool                 |E164Capable                  |
|route_advance                 |bool                 |routeAdvance                 |
|forwarding_override           |bool                 |forwardingOverride           |
|wireless_integration          |bool                 |wirelessIntegration          |
|web_based_config_url          |str                  |webBasedConfigURL *Optional* |
|is_video_capable              |bool                 |isVideoCapable               |
|pbx_integration               |bool                 |PBXIntegration               |
|use_business_trunking_contact |bool                 |useBusinessTrunkingContact   |
|static_registration_capable   |bool                 |staticRegistrationCapable    |
|cpe_device_options            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*  |
|protocol_choice               |List[str]            |protocolChoice               |
|early_media_support           |str                  |earlyMediaSupport            |
</div>


## `SystemSIPDeviceTypeGetResponse14sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest14sp2()`.

Replaced By: `SystemSIPDeviceTypeGetResponse14sp3()`

**Attributes:**

|Name                          |Type                 |Description                  |
|------------------------------|---------------------|-----------------------------|
|is_obsolete                   |bool                 |isObsolete                   |
|number_of_ports               |OCI.numberOfPorts    |numberOfPorts                |
|profile                       |str                  |profile                      |
|registration_capable          |bool                 |registrationCapable          |
|is_conference_device          |bool                 |isConferenceDevice           |
|is_music_on_hold_device       |bool                 |isMusicOnHoldDevice          |
|rfc3264_hold                  |bool                 |RFC3264Hold                  |
|is_trusted                    |bool                 |isTrusted                    |
|e164_capable                  |bool                 |E164Capable                  |
|route_advance                 |bool                 |routeAdvance                 |
|forwarding_override           |bool                 |forwardingOverride           |
|wireless_integration          |bool                 |wirelessIntegration          |
|web_based_config_url          |str                  |webBasedConfigURL *Optional* |
|is_video_capable              |bool                 |isVideoCapable               |
|pbx_integration               |bool                 |PBXIntegration               |
|use_business_trunking_contact |bool                 |useBusinessTrunkingContact   |
|static_registration_capable   |bool                 |staticRegistrationCapable    |
|cpe_device_options            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*  |
|protocol_choice               |List[str]            |protocolChoice               |
|early_media_support           |str                  |earlyMediaSupport            |
|authenticate_refer            |bool                 |authenticateRefer            |
|auto_config_soft_client       |bool                 |autoConfigSoftClient         |
|authentication_mode           |str                  |authenticationMode           |
</div>


## `SystemSIPDeviceTypeGetResponse14sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest14sp3()`.

Replaced by: `SystemSIPDeviceTypeGetResponse14sp6()`

**Attributes:**

|Name                                       |Type                 |Description                          |
|-------------------------------------------|---------------------|-------------------------------------|
|is_obsolete                                |bool                 |isObsolete                           |
|number_of_ports                            |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                    |str                  |profile                              |
|registration_capable                       |bool                 |registrationCapable                  |
|is_conference_device                       |bool                 |isConferenceDevice                   |
|is_mobility_manager_device                 |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                    |bool                 |isMusicOnHoldDevice                  |
|rfc3264_hold                               |bool                 |RFC3264Hold                          |
|is_trusted                                 |bool                 |isTrusted                            |
|e164_capable                               |bool                 |E164Capable                          |
|route_advance                              |bool                 |routeAdvance                         |
|forwarding_override                        |bool                 |forwardingOverride                   |
|wireless_integration                       |bool                 |wirelessIntegration                  |
|web_based_config_url                       |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                           |bool                 |isVideoCapable                       |
|pbx_integration                            |bool                 |PBXIntegration                       |
|use_business_trunking_contact              |bool                 |useBusinessTrunkingContact           |
|static_registration_capable                |bool                 |staticRegistrationCapable            |
|cpe_device_options                         |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|protocol_choice                            |List[str]            |protocolChoice                       |
|early_media_support                        |str                  |earlyMediaSupport                    |
|authenticate_refer                         |bool                 |authenticateRefer                    |
|auto_config_soft_client                    |bool                 |autoConfigSoftClient                 |
|authentication_mode                        |str                  |authenticationMode                   |
|tdm_overlay                                |bool                 |tdmOverlay                           |
|supports_broad_works_info_for_call_waiting |bool                 |supportsBroadWorksINFOForCallWaiting |
</div>


## `SystemScheduleGetEventResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemScheduleGetEventRequest()`.

The response contains the event of the system schedulable.

**Attributes:**

|Name          |Type           |Description            |
|--------------|---------------|-----------------------|
|start_date    |str            |startDate              |
|all_day_event |bool           |allDayEvent *Optional* |
|start_time    |OCI.startTime  |startTime *Optional*   |
|end_time      |OCI.endTime    |endTime *Optional*     |
|end_date      |str            |endDate                |
|recurrence    |OCI.recurrence |recurrence *Optional*  |
</div>


## `SystemServiceAttributeDefaultGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemServiceAttributeDefaultGetListRequest()`.

Contains an array Service Attribute entries.

**Attributes:**

|Name                    |Type                            |Description           |
|------------------------|--------------------------------|----------------------|
|service_attribute_entry |List[OCI.serviceAttributeEntry] |serviceAttributeEntry |
</div>


## `SystemTimeScheduleGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `SystemTimeScheduleGetRequest()`.

The response contains the system time schedule's information.

**Attributes:**

|Name            |Type               |Description               |
|----------------|-------------------|--------------------------|
|time_interval01 |OCI.timeInterval01 |timeInterval01 *Optional* |
|time_interval02 |OCI.timeInterval02 |timeInterval02 *Optional* |
|time_interval03 |OCI.timeInterval03 |timeInterval03 *Optional* |
|time_interval04 |OCI.timeInterval04 |timeInterval04 *Optional* |
|time_interval05 |OCI.timeInterval05 |timeInterval05 *Optional* |
|time_interval06 |OCI.timeInterval06 |timeInterval06 *Optional* |
|time_interval07 |OCI.timeInterval07 |timeInterval07 *Optional* |
|time_interval08 |OCI.timeInterval08 |timeInterval08 *Optional* |
|time_interval09 |OCI.timeInterval09 |timeInterval09 *Optional* |
|time_interval10 |OCI.timeInterval10 |timeInterval10 *Optional* |
|time_interval11 |OCI.timeInterval11 |timeInterval11 *Optional* |
|time_interval12 |OCI.timeInterval12 |timeInterval12 *Optional* |
|time_interval13 |OCI.timeInterval13 |timeInterval13 *Optional* |
|time_interval14 |OCI.timeInterval14 |timeInterval14 *Optional* |
|time_interval15 |OCI.timeInterval15 |timeInterval15 *Optional* |
|time_interval16 |OCI.timeInterval16 |timeInterval16 *Optional* |
|time_interval17 |OCI.timeInterval17 |timeInterval17 *Optional* |
|time_interval18 |OCI.timeInterval18 |timeInterval18 *Optional* |
|time_interval19 |OCI.timeInterval19 |timeInterval19 *Optional* |
|time_interval20 |OCI.timeInterval20 |timeInterval20 *Optional* |
</div>


## `SystemVisualDeviceManagementGetDeviceInfoResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemVisualDeviceManagementGetDeviceInfoRequest()`.


**Attributes:**

|Name                             |Type            |Description                   |
|---------------------------------|----------------|------------------------------|
|device_type                      |str             |deviceType                    |
|support_visual_device_management |bool            |supportVisualDeviceManagement |
|mac_address                      |str             |macAddress *Optional*         |
|primary_user                     |OCI.primaryUser |primaryUser *Optional*        |
</div>


## `SystemZoneCallingRestrictionsNetAddressGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemZoneCallingRestrictionsNetAddressGetListRequest()`.

Replaced by: `SystemZoneNetAddressGetListResponse()`

**Attributes:**

|Name              |Type                      |Description                |
|------------------|--------------------------|---------------------------|
|net_address       |List[str]                 |netAddress *Optional*      |
|net_address_range |List[OCI.netAddressRange] |netAddressRange *Optional* |
</div>


## `SystemZoneNetAddressGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemZoneNetAddressGetListRequest()`.


**Attributes:**

|Name              |Type                      |Description                |
|------------------|--------------------------|---------------------------|
|net_address       |List[str]                 |netAddress *Optional*      |
|net_address_range |List[OCI.netAddressRange] |netAddressRange *Optional* |
</div>


## `UserAlternateNumbersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAlternateNumbersGetRequest()`.


**Attributes:**

|Name              |Type                 |Description                 |
|------------------|---------------------|----------------------------|
|distinctive_ring  |bool                 |distinctiveRing             |
|alternate_entry01 |OCI.alternateEntry01 |alternateEntry01 *Optional* |
|alternate_entry02 |OCI.alternateEntry02 |alternateEntry02 *Optional* |
|alternate_entry03 |OCI.alternateEntry03 |alternateEntry03 *Optional* |
|alternate_entry04 |OCI.alternateEntry04 |alternateEntry04 *Optional* |
|alternate_entry05 |OCI.alternateEntry05 |alternateEntry05 *Optional* |
|alternate_entry06 |OCI.alternateEntry06 |alternateEntry06 *Optional* |
|alternate_entry07 |OCI.alternateEntry07 |alternateEntry07 *Optional* |
|alternate_entry08 |OCI.alternateEntry08 |alternateEntry08 *Optional* |
|alternate_entry09 |OCI.alternateEntry09 |alternateEntry09 *Optional* |
|alternate_entry10 |OCI.alternateEntry10 |alternateEntry10 *Optional* |
</div>


## `UserAlternateNumbersGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAlternateNumbersGetRequest17()`.

Replaced by: `UserAlternateNumbersGetResponse21()` in AS data mode

**Attributes:**

|Name              |Type                 |Description                 |
|------------------|---------------------|----------------------------|
|distinctive_ring  |bool                 |distinctiveRing             |
|alternate_entry01 |OCI.alternateEntry01 |alternateEntry01 *Optional* |
|alternate_entry02 |OCI.alternateEntry02 |alternateEntry02 *Optional* |
|alternate_entry03 |OCI.alternateEntry03 |alternateEntry03 *Optional* |
|alternate_entry04 |OCI.alternateEntry04 |alternateEntry04 *Optional* |
|alternate_entry05 |OCI.alternateEntry05 |alternateEntry05 *Optional* |
|alternate_entry06 |OCI.alternateEntry06 |alternateEntry06 *Optional* |
|alternate_entry07 |OCI.alternateEntry07 |alternateEntry07 *Optional* |
|alternate_entry08 |OCI.alternateEntry08 |alternateEntry08 *Optional* |
|alternate_entry09 |OCI.alternateEntry09 |alternateEntry09 *Optional* |
|alternate_entry10 |OCI.alternateEntry10 |alternateEntry10 *Optional* |
</div>


## `UserAlternateNumbersGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAlternateNumbersGetRequest21()`.


**Attributes:**

|Name              |Type                 |Description                 |
|------------------|---------------------|----------------------------|
|distinctive_ring  |bool                 |distinctiveRing             |
|alternate_entry01 |OCI.alternateEntry01 |alternateEntry01 *Optional* |
|alternate_entry02 |OCI.alternateEntry02 |alternateEntry02 *Optional* |
|alternate_entry03 |OCI.alternateEntry03 |alternateEntry03 *Optional* |
|alternate_entry04 |OCI.alternateEntry04 |alternateEntry04 *Optional* |
|alternate_entry05 |OCI.alternateEntry05 |alternateEntry05 *Optional* |
|alternate_entry06 |OCI.alternateEntry06 |alternateEntry06 *Optional* |
|alternate_entry07 |OCI.alternateEntry07 |alternateEntry07 *Optional* |
|alternate_entry08 |OCI.alternateEntry08 |alternateEntry08 *Optional* |
|alternate_entry09 |OCI.alternateEntry09 |alternateEntry09 *Optional* |
|alternate_entry10 |OCI.alternateEntry10 |alternateEntry10 *Optional* |
</div>


## `UserAnnouncementFileGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAnnouncementFileGetRequest22()`.

The response contains the file size (KB), uploaded timestamp, description and usage
for an announcement file in the user announcement repository.  The usage table has
columns "Service Name", "Criteria Name" The "Service Name"" values correspond to
string values of the UserService data types.  With the exception of the string "Voice
Portal" which is returned when the announcement is being used by Voice Portal
Personalized Name.  For Call Center and Route Point users the "Instance Name" column
contains the instance id and when the announcement is being used by a DNIS, "Intance
Name" column contans the instance id and the DNIS id.  For Auto Attendants with
submenus and the announcement is used by a submenu the "Instance Name" column will
contain the submenu name The following data elements are only used in AS data mode:
announcementFileExternalId

**Attributes:**

|Name                          |Type                    |Description                                           |
|------------------------------|------------------------|------------------------------------------------------|
|description                   |str                     |description                                           |
|filesize                      |int                     |filesize                                              |
|last_uploaded                 |str                     |lastUploaded                                          |
|user_id                       |str                     |userId                                                |
|announcement_file_key         |OCI.announcementFileKey |announcementFileKey                                   |
|announcement_file_external_id |str                     |announcementFileExternalId *Optional*                 |
|usage_table                   |List(usageTable)        |usageTable - *Table* array of usageTable named tuples |
</div>


## `UserAssignedServicesGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserAssignedServicesGetListRequest()`.

A user can have both user services and group services because of music on hold.

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|group_service_entry |List[OCI.groupServiceEntry] |groupServiceEntry *Optional* |
|user_service_entry  |List[OCI.userServiceEntry]  |userServiceEntry *Optional*  |
</div>


## `UserBasicCallLogsGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserBasicCallLogsGetListRequest()`.

Replaced By: `UserBasicCallLogsGetListResponse14sp4()`

**Attributes:**

|Name     |Type               |Description         |
|---------|-------------------|--------------------|
|placed   |List[OCI.placed]   |placed *Optional*   |
|received |List[OCI.received] |received *Optional* |
|missed   |List[OCI.missed]   |missed *Optional*   |
</div>


## `UserBasicCallLogsGetListResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserBasicCallLogsGetListRequest14sp4()`.


**Attributes:**

|Name     |Type               |Description         |
|---------|-------------------|--------------------|
|placed   |List[OCI.placed]   |placed *Optional*   |
|received |List[OCI.received] |received *Optional* |
|missed   |List[OCI.missed]   |missed *Optional*   |
</div>


## `UserBroadWorksAnywhereGetSelectiveCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserBroadWorksAnywhereGetSelectiveCriteriaRequest()`.


**Attributes:**

|Name             |Type               |Description             |
|-----------------|-------------------|------------------------|
|time_schedule    |OCI.timeSchedule   |timeSchedule *Optional* |
|from_dn_criteria |OCI.fromDnCriteria |fromDnCriteria          |
</div>


## `UserBroadWorksAnywhereGetSelectiveCriteriaResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserBroadWorksAnywhereGetSelectiveCriteriaRequest16()`.

Replaced by: `UserBroadWorksAnywhereGetSelectiveCriteriaResponse21()` in AS data mode

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted      |bool                |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
</div>


## `UserBroadWorksAnywhereGetSelectiveCriteriaResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserBroadWorksAnywhereGetSelectiveCriteriaRequest21()`.


**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|blacklisted      |bool                   |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserBroadWorksMobilityGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `UserBroadWorksMobilityGetRequest21()`.


**Attributes:**

|Name                                            |Type                     |Description                                   |
|------------------------------------------------|-------------------------|----------------------------------------------|
|is_active                                       |bool                     |isActive                                      |
|use_mobile_identity_call_anchoring              |bool                     |useMobileIdentityCallAnchoring                |
|prevent_calls_to_own_mobiles                    |bool                     |preventCallsToOwnMobiles                      |
|mobile_identity                                 |List[OCI.mobileIdentity] |mobileIdentity *Optional*                     |
|profile_identity_devices_to_ring                |str                      |profileIdentityDevicesToRing                  |
|profile_identity_include_shared_call_appearance |bool                     |profileIdentityIncludeSharedCallAppearance    |
|profile_identity_include_broadworks_anywhere    |bool                     |profileIdentityIncludeBroadworksAnywhere      |
|profile_identity_include_executive_assistant    |bool                     |profileIdentityIncludeExecutiveAssistant      |
|profile_identity_mobile_number_alerted          |List[str]                |profileIdentityMobileNumberAlerted *Optional* |
</div>


## `UserCallCenterGetAvailableDNISListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallCenterGetAvailableDNISListRequest()`.

Contains a list of available DNIS for agent to select.

**Attributes:**

|Name           |Type                    |Description              |
|---------------|------------------------|-------------------------|
|available_dnis |List[OCI.availableDNIS] |availableDNIS *Optional* |
</div>


## `UserCallCenterGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterGetRequest17()`.

Contains the user's call center settings.  Indicates whether the agent is current
available (logged in) to each call center in the list.  Contains a table with column
headings: "Service User Id", "Phone Number", "Extension", "Available", "Logoff
Allowed", "Type", and "Priority". Replaced by `UserCallCenterGetResponse17sp4()`.

**Attributes:**

|Name                                                        |Type                  |Description                                                     |
|------------------------------------------------------------|----------------------|----------------------------------------------------------------|
|agent_acd_state                                             |str                   |agentACDState *Optional*                                        |
|agent_unavailable_code                                      |str                   |agentUnavailableCode *Optional*                                 |
|use_default_guard_timer                                     |bool                  |useDefaultGuardTimer                                            |
|enable_guard_timer                                          |bool                  |enableGuardTimer                                                |
|guard_timer_seconds                                         |int                   |guardTimerSeconds                                               |
|use_system_default_unavailable_settings                     |bool                  |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool                  |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_unavailable_on_personal_calls                         |bool                  |forceUnavailableOnPersonalCalls *Optional*                      |
|force_agent_unavailable_on_bounced_call_limit               |bool                  |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int                   |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|make_outgoing_calls_as_call_center                          |bool                  |makeOutgoingCallsAsCallCenter *Optional*                        |
|outgoing_call_dnis                                          |OCI.outgoingCallDNIS  |outgoingCallDNIS *Optional*                                     |
|call_center_table                                           |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `UserCallCenterGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterGetRequest17sp4()`.

Contains the user's call center settings.  Indicates whether the agent is current
available (logged in) to each call center in the list.  Contains a table with column
headings: "Service User Id", "Phone Number", "Extension", "Available", "Logoff
Allowed", "Type", and "Priority". Replaced by `UserCallCenterGetResponse19()`

**Attributes:**

|Name                                                        |Type                  |Description                                                     |
|------------------------------------------------------------|----------------------|----------------------------------------------------------------|
|agent_acd_state                                             |str                   |agentACDState *Optional*                                        |
|agent_unavailable_code                                      |str                   |agentUnavailableCode *Optional*                                 |
|use_default_guard_timer                                     |bool                  |useDefaultGuardTimer                                            |
|enable_guard_timer                                          |bool                  |enableGuardTimer                                                |
|guard_timer_seconds                                         |int                   |guardTimerSeconds                                               |
|use_system_default_unavailable_settings                     |bool                  |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool                  |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool                  |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool                  |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int                   |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|force_agent_unavailable_on_not_reachable                    |bool                  |forceAgentUnavailableOnNotReachable *Optional*                  |
|make_outgoing_calls_as_call_center                          |bool                  |makeOutgoingCallsAsCallCenter *Optional*                        |
|outgoing_call_dnis                                          |OCI.outgoingCallDNIS  |outgoingCallDNIS *Optional*                                     |
|call_center_table                                           |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `UserCallCenterGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterGetRequest19()`.

Contains the user's call center settings.  Indicates whether the agent is current
available (logged in) to each call center in the list.  Contains a table with column
headings: "Service User Id", "Phone Number", "Extension", "Available", "Logoff
Allowed", "Type", "Priority","Routing Policy" and "Skill Level". The valid "Routing
Type" values are "Priority Based" and "Skill Based". This column is only populated for
Premium Call Centers.  The valid "Skill Level" values are of from 1-20. This column is
only populated for Premium Skill Based Call Centers.  The following elements are only
used in AS data mode and not returned in XS data mode: agentACDState
agentThresholdProfileName agentUnavailableCode useSystemDefaultUnavailableSettings
forceAgentUnavailableOnDNDActivation forceAgentUnavailableOnPersonalCalls
forceAgentUnavailableOnBouncedCallLimit
numberConsecutiveBouncedCallsToForceAgentUnavailable
forceAgentUnavailableOnNotReachable makeOutgoingCallsAsCallCenter outgoingCallDNIS The
following columns are only used in AS data mode and not returned in XS data mode:
"Routing Policy" "Skill Level" Replaced by `UserCallCenterGetResponse23()`.

**Attributes:**

|Name                                                        |Type                  |Description                                                     |
|------------------------------------------------------------|----------------------|----------------------------------------------------------------|
|agent_acd_state                                             |str                   |agentACDState *Optional*                                        |
|agent_threshold_profile_name                                |str                   |agentThresholdProfileName *Optional*                            |
|agent_unavailable_code                                      |str                   |agentUnavailableCode *Optional*                                 |
|use_default_guard_timer                                     |bool                  |useDefaultGuardTimer                                            |
|enable_guard_timer                                          |bool                  |enableGuardTimer                                                |
|guard_timer_seconds                                         |int                   |guardTimerSeconds                                               |
|use_system_default_unavailable_settings                     |bool                  |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool                  |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool                  |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool                  |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int                   |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|force_agent_unavailable_on_not_reachable                    |bool                  |forceAgentUnavailableOnNotReachable *Optional*                  |
|make_outgoing_calls_as_call_center                          |bool                  |makeOutgoingCallsAsCallCenter *Optional*                        |
|outgoing_call_dnis                                          |OCI.outgoingCallDNIS  |outgoingCallDNIS *Optional*                                     |
|call_center_table                                           |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `UserCallCenterGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallCenterGetRequest23()`.

Contains the user's call center settings.  Indicates whether the agent is current
available (logged in) to each call center in the list.  Contains a table with column
headings: "Service User Id", "Phone Number", "Extension", "Available", "Logoff
Allowed", "Type", "Priority","Routing Policy" and "Skill Level". The valid "Routing
Type" values are "Priority Based" and "Skill Based". This column is only populated for
Premium Call Centers.  The valid "Skill Level" values are of from 1-20. This column is
only populated for Premium Skill Based Call Centers.  The following elements are only
used in AS data mode and not returned in XS data mode: agentACDState
agentThresholdProfileName agentUnavailableCode useSystemDefaultUnavailableSettings
forceAgentUnavailableOnDNDActivation forceAgentUnavailableOnPersonalCalls
forceAgentUnavailableOnBouncedCallLimit
numberConsecutiveBouncedCallsToForceAgentUnavailable
forceAgentUnavailableOnNotReachable makeOutgoingCallsAsCallCenter outgoingCallDNIS
useSystemDefaultWrapUpDestination wrapUpDestination The following columns are only
used in AS data mode and not returned in XS data mode: "Routing Policy" "Skill Level"

**Attributes:**

|Name                                                        |Type                  |Description                                                     |
|------------------------------------------------------------|----------------------|----------------------------------------------------------------|
|agent_acd_state                                             |str                   |agentACDState *Optional*                                        |
|agent_threshold_profile_name                                |str                   |agentThresholdProfileName *Optional*                            |
|agent_unavailable_code                                      |str                   |agentUnavailableCode *Optional*                                 |
|use_default_guard_timer                                     |bool                  |useDefaultGuardTimer                                            |
|enable_guard_timer                                          |bool                  |enableGuardTimer                                                |
|guard_timer_seconds                                         |int                   |guardTimerSeconds                                               |
|use_system_default_unavailable_settings                     |bool                  |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool                  |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool                  |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool                  |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int                   |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|force_agent_unavailable_on_not_reachable                    |bool                  |forceAgentUnavailableOnNotReachable *Optional*                  |
|make_outgoing_calls_as_call_center                          |bool                  |makeOutgoingCallsAsCallCenter *Optional*                        |
|outgoing_call_dnis                                          |OCI.outgoingCallDNIS  |outgoingCallDNIS *Optional*                                     |
|use_system_default_wrap_up_destination                      |bool                  |useSystemDefaultWrapUpDestination *Optional*                    |
|wrap_up_destination                                         |str                   |wrapUpDestination *Optional*                                    |
|call_center_table                                           |List(callCenterTable) |callCenterTable - *Table* array of callCenterTable named tuples |
</div>


## `UserCallForwardingSelectiveGetCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallForwardingSelectiveGetCriteriaRequest()`.


**Attributes:**

|Name                        |Type               |Description                     |
|----------------------------|-------------------|--------------------------------|
|time_schedule               |OCI.timeSchedule   |timeSchedule *Optional*         |
|forward_to_number_selection |str                |forwardToNumberSelection        |
|forward_to_phone_number     |str                |forwardToPhoneNumber *Optional* |
|from_dn_criteria            |OCI.fromDnCriteria |fromDnCriteria                  |
</div>


## `UserCallForwardingSelectiveGetCriteriaResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallForwardingSelectiveGetCriteriaRequest16()`.

Replaced by: `UserCallForwardingSelectiveGetCriteriaResponse21()` in AS data mode

**Attributes:**

|Name                        |Type                |Description                     |
|----------------------------|--------------------|--------------------------------|
|time_schedule               |OCI.timeSchedule    |timeSchedule *Optional*         |
|holiday_schedule            |OCI.holidaySchedule |holidaySchedule *Optional*      |
|forward_to_number_selection |str                 |forwardToNumberSelection        |
|forward_to_phone_number     |str                 |forwardToPhoneNumber *Optional* |
|from_dn_criteria            |OCI.fromDnCriteria  |fromDnCriteria                  |
</div>


## `UserCallForwardingSelectiveGetCriteriaResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallForwardingSelectiveGetCriteriaRequest21()`.


**Attributes:**

|Name                        |Type                   |Description                     |
|----------------------------|-----------------------|--------------------------------|
|time_schedule               |OCI.timeSchedule       |timeSchedule *Optional*         |
|holiday_schedule            |OCI.holidaySchedule    |holidaySchedule *Optional*      |
|forward_to_number_selection |str                    |forwardToNumberSelection        |
|forward_to_phone_number     |str                    |forwardToPhoneNumber *Optional* |
|from_dn_criteria            |OCI.fromDnCriteria     |fromDnCriteria                  |
|call_to_number              |List[OCI.callToNumber] |callToNumber *Optional*         |
</div>


## `UserCallMeNowGetCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallMeNowGetCriteriaRequest()`.


**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|reject_call      |bool                |rejectCall                 |
|to_dn_criteria   |OCI.toDnCriteria    |toDnCriteria               |
</div>


## `UserCallNotifyGetCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallNotifyGetCriteriaRequest()`.


**Attributes:**

|Name             |Type               |Description             |
|-----------------|-------------------|------------------------|
|time_schedule    |OCI.timeSchedule   |timeSchedule *Optional* |
|from_dn_criteria |OCI.fromDnCriteria |fromDnCriteria          |
</div>


## `UserCallNotifyGetCriteriaResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallNotifyGetCriteriaRequest16()`.

Replaced by: `UserCallNotifyGetCriteriaResponse21()` in AS data mode

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted      |bool                |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
</div>


## `UserCallNotifyGetCriteriaResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallNotifyGetCriteriaRequest21()`.


**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|blacklisted      |bool                   |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserCallToNumberGetAvailableListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCallToNumberGetAvailableListRequest()`.

Contains a list of the user available Call to Numbers".

**Attributes:**

|Name           |Type                   |Description             |
|---------------|-----------------------|------------------------|
|call_to_number |List[OCI.callToNumber] |callToNumber *Optional* |
</div>


## `UserCollaborateBridgeGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The system-level collaborate supportOutdial setting is returned in the response when
the system-level collaborate supportOutdial setting is disabled.

Response to `UserCollaborateBridgeGetRequest()`. Replaced by:
`UserCollaborateBridgeGetResponse20sp1()`

**Attributes:**

|Name                              |Type                           |Description                     |
|----------------------------------|-------------------------------|--------------------------------|
|bridge_id                         |str                            |bridgeId                        |
|bridge_name                       |str                            |bridgeName                      |
|phone_number                      |str                            |phoneNumber *Optional*          |
|extension                         |str                            |extension *Optional*            |
|alternate_number_entry            |List[OCI.alternateNumberEntry] |alternateNumberEntry *Optional* |
|support_out_dial                  |bool                           |supportOutDial                  |
|max_collaborate_room_participants |int                            |maxCollaborateRoomParticipants  |
</div>


## `UserCollaborateBridgeGetResponse20sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
The system-level collaborate supportOutdial setting is returned in the response when
the system-level collaborate supportOutdial setting is disabled.

Response to `UserCollaborateBridgeGetRequest20sp1()`.

**Attributes:**

|Name                              |Type                           |Description                     |
|----------------------------------|-------------------------------|--------------------------------|
|bridge_id                         |str                            |bridgeId                        |
|bridge_name                       |str                            |bridgeName                      |
|phone_number                      |str                            |phoneNumber *Optional*          |
|extension                         |str                            |extension *Optional*            |
|alternate_number_entry            |List[OCI.alternateNumberEntry] |alternateNumberEntry *Optional* |
|support_out_dial                  |bool                           |supportOutDial                  |
|max_collaborate_room_participants |int                            |maxCollaborateRoomParticipants  |
</div>


## `UserCollaborateProjectRoomGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCollaborateProjectRoomGetRequest()`.


**Attributes:**

|Name                                       |Type             |Description                          |
|-------------------------------------------|-----------------|-------------------------------------|
|room_name                                  |str              |roomName                             |
|attendee_notification                      |str              |attendeeNotification                 |
|end_collaborate_room_session_on_owner_exit |bool             |endCollaborateRoomSessionOnOwnerExit |
|owner_required                             |bool             |ownerRequired                        |
|room_schedule                              |OCI.roomSchedule |roomSchedule                         |
</div>


## `UserCollaborateRoomGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCollaborateRoomGetRequest()`.

The roomType and roomName parameters are returned for all rooms.  The following
parameters are returned for My room and Project Room: attendeeNotification,
endCollaborateRoomSessionOnOwnerExit and ownerRequired.  In addition, the roomSchedule
is returned for Project Room and the instantRoomStartTime and instantRoomEndTime are
returned for Instant Room.

**Attributes:**

|Name                                       |Type             |Description                                     |
|-------------------------------------------|-----------------|------------------------------------------------|
|room_type                                  |str              |roomType                                        |
|room_name                                  |str              |roomName                                        |
|attendee_notification                      |str              |attendeeNotification *Optional*                 |
|end_collaborate_room_session_on_owner_exit |bool             |endCollaborateRoomSessionOnOwnerExit *Optional* |
|owner_required                             |bool             |ownerRequired *Optional*                        |
|instant_room_start_time                    |str              |instantRoomStartTime *Optional*                 |
|instant_room_end_time                      |str              |instantRoomEndTime *Optional*                   |
|room_schedule                              |OCI.roomSchedule |roomSchedule *Optional*                         |
</div>


## `UserCommunicationBarringAuthorizationCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCommunicationBarringAuthorizationCodeGetListRequest()`.

Contains a list of Communication Barring Authorization Codes assigned to the user.

**Attributes:**

|Name |Type           |Description     |
|-----|---------------|----------------|
|code |List[OCI.code] |code *Optional* |
</div>


## `UserCustomRingbackUserGetCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCustomRingbackUserGetCriteriaRequest()`.


**Attributes:**

|Name                   |Type               |Description                     |
|-----------------------|-------------------|--------------------------------|
|time_schedule          |OCI.timeSchedule   |timeSchedule *Optional*         |
|from_dn_criteria       |OCI.fromDnCriteria |fromDnCriteria                  |
|audio_selection        |str                |audioSelection                  |
|audio_file_description |str                |audioFileDescription *Optional* |
|audio_file_url         |str                |audioFileUrl *Optional*         |
|video_selection        |str                |videoSelection                  |
|video_file_description |str                |videoFileDescription *Optional* |
|video_file_url         |str                |videoFileUrl *Optional*         |
</div>


## `UserCustomRingbackUserGetCriteriaResponse15sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCustomRingbackUserGetCriteriaRequest15sp2()`.

Replaced By: `UserCustomRingbackUserAddCriteriaResponse16()`

**Attributes:**

|Name                                |Type               |Description                                |
|------------------------------------|-------------------|-------------------------------------------|
|time_schedule                       |OCI.timeSchedule   |timeSchedule *Optional*                    |
|from_dn_criteria                    |OCI.fromDnCriteria |fromDnCriteria                             |
|audio_selection                     |str                |audioSelection                             |
|audio_file_description              |str                |audioFileDescription *Optional*            |
|audio_file_url                      |str                |audioFileUrl *Optional*                    |
|video_selection                     |str                |videoSelection                             |
|video_file_description              |str                |videoFileDescription *Optional*            |
|video_file_url                      |str                |videoFileUrl *Optional*                    |
|call_waiting_audio_selection        |str                |callWaitingAudioSelection *Optional*       |
|call_waiting_audio_file_description |str                |callWaitingAudioFileDescription *Optional* |
|call_waiting_audio_file_url         |str                |callWaitingAudioFileUrl *Optional*         |
|call_waiting_video_selection        |str                |callWaitingVideoSelection *Optional*       |
|call_waiting_video_file_description |str                |callWaitingVideoFileDescription *Optional* |
|call_waiting_video_file_url         |str                |callWaitingVideoFileUrl *Optional*         |
</div>


## `UserCustomRingbackUserGetCriteriaResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCustomRingbackUserGetCriteriaRequest16()`.

Replaced by: `UserCustomRingbackUserGetCriteriaResponse20()` in AS data mode

**Attributes:**

|Name                                |Type                |Description                                |
|------------------------------------|--------------------|-------------------------------------------|
|time_schedule                       |OCI.timeSchedule    |timeSchedule *Optional*                    |
|holiday_schedule                    |OCI.holidaySchedule |holidaySchedule *Optional*                 |
|blacklisted                         |bool                |blacklisted                                |
|from_dn_criteria                    |OCI.fromDnCriteria  |fromDnCriteria                             |
|audio_selection                     |str                 |audioSelection                             |
|audio_file_description              |str                 |audioFileDescription *Optional*            |
|audio_media_type                    |str                 |audioMediaType *Optional*                  |
|audio_file_url                      |str                 |audioFileUrl *Optional*                    |
|video_selection                     |str                 |videoSelection                             |
|video_file_description              |str                 |videoFileDescription *Optional*            |
|video_media_type                    |str                 |videoMediaType *Optional*                  |
|video_file_url                      |str                 |videoFileUrl *Optional*                    |
|call_waiting_audio_selection        |str                 |callWaitingAudioSelection *Optional*       |
|call_waiting_audio_file_description |str                 |callWaitingAudioFileDescription *Optional* |
|call_waiting_audio_media_type       |str                 |callWaitingAudioMediaType *Optional*       |
|call_waiting_audio_file_url         |str                 |callWaitingAudioFileUrl *Optional*         |
|call_waiting_video_selection        |str                 |callWaitingVideoSelection *Optional*       |
|call_waiting_video_file_description |str                 |callWaitingVideoFileDescription *Optional* |
|call_waiting_video_media_type       |str                 |callWaitingVideoMediaType *Optional*       |
|call_waiting_video_file_url         |str                 |callWaitingVideoFileUrl *Optional*         |
</div>


## `UserCustomRingbackUserGetCriteriaResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCustomRingbackUserGetCriteriaRequest20()`.

Replaced by: `UserCustomRingbackUserGetCriteriaResponse21()`

**Attributes:**

|Name                         |Type                     |Description                          |
|-----------------------------|-------------------------|-------------------------------------|
|time_schedule                |OCI.timeSchedule         |timeSchedule *Optional*              |
|holiday_schedule             |OCI.holidaySchedule      |holidaySchedule *Optional*           |
|blacklisted                  |bool                     |blacklisted                          |
|from_dn_criteria             |OCI.fromDnCriteria       |fromDnCriteria                       |
|audio_selection              |str                      |audioSelection                       |
|audio_file                   |OCI.audioFile            |audioFile *Optional*                 |
|audio_file_url               |str                      |audioFileUrl *Optional*              |
|video_selection              |str                      |videoSelection                       |
|video_file                   |OCI.videoFile            |videoFile *Optional*                 |
|video_file_url               |str                      |videoFileUrl *Optional*              |
|call_waiting_audio_selection |str                      |callWaitingAudioSelection *Optional* |
|call_waiting_audio_file      |OCI.callWaitingAudioFile |callWaitingAudioFile *Optional*      |
|call_waiting_audio_file_url  |str                      |callWaitingAudioFileUrl *Optional*   |
|call_waiting_video_selection |str                      |callWaitingVideoSelection *Optional* |
|call_waiting_video_file      |OCI.callWaitingVideoFile |callWaitingVideoFile *Optional*      |
|call_waiting_video_file_url  |str                      |callWaitingVideoFileUrl *Optional*   |
</div>


## `UserCustomRingbackUserGetCriteriaResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCustomRingbackUserGetCriteriaRequest21()`.


**Attributes:**

|Name                         |Type                     |Description                          |
|-----------------------------|-------------------------|-------------------------------------|
|time_schedule                |OCI.timeSchedule         |timeSchedule *Optional*              |
|holiday_schedule             |OCI.holidaySchedule      |holidaySchedule *Optional*           |
|blacklisted                  |bool                     |blacklisted                          |
|from_dn_criteria             |OCI.fromDnCriteria       |fromDnCriteria                       |
|call_to_number               |List[OCI.callToNumber]   |callToNumber *Optional*              |
|audio_selection              |str                      |audioSelection                       |
|audio_file                   |OCI.audioFile            |audioFile *Optional*                 |
|audio_file_url               |str                      |audioFileUrl *Optional*              |
|video_selection              |str                      |videoSelection                       |
|video_file                   |OCI.videoFile            |videoFile *Optional*                 |
|video_file_url               |str                      |videoFileUrl *Optional*              |
|call_waiting_audio_selection |str                      |callWaitingAudioSelection *Optional* |
|call_waiting_audio_file      |OCI.callWaitingAudioFile |callWaitingAudioFile *Optional*      |
|call_waiting_audio_file_url  |str                      |callWaitingAudioFileUrl *Optional*   |
|call_waiting_video_selection |str                      |callWaitingVideoSelection *Optional* |
|call_waiting_video_file      |OCI.callWaitingVideoFile |callWaitingVideoFile *Optional*      |
|call_waiting_video_file_url  |str                      |callWaitingVideoFileUrl *Optional*   |
</div>


## `UserDirectRouteGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserDirectRouteGetRequest()`.

Contains the direct route setting and the list of DTGs/Trunk Identities assigned to a
user.

**Attributes:**

|Name                           |Type                        |Description                        |
|-------------------------------|----------------------------|-----------------------------------|
|outgoing_dtg_policy            |str                         |outgoingDTGPolicy                  |
|outgoing_trunk_identity_policy |str                         |outgoingTrunkIdentityPolicy        |
|direct_route_identity_list     |OCI.directRouteIdentityList |directRouteIdentityList *Optional* |
</div>


## `UserEnhancedCallLogsGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserEnhancedCallLogsGetListRequest()`.

Replaced By: `UserEnhancedCallLogsGetListResponse14sp4()`

**Attributes:**

|Name     |Type               |Description         |
|---------|-------------------|--------------------|
|placed   |List[OCI.placed]   |placed *Optional*   |
|received |List[OCI.received] |received *Optional* |
|missed   |List[OCI.missed]   |missed *Optional*   |
</div>


## `UserEnhancedCallLogsGetListResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserEnhancedCallLogsGetListRequest14sp4()`.

Replaced by: `UserEnhancedCallLogsGetListResponse16()`

**Attributes:**

|Name     |Type               |Description         |
|---------|-------------------|--------------------|
|placed   |List[OCI.placed]   |placed *Optional*   |
|received |List[OCI.received] |received *Optional* |
|missed   |List[OCI.missed]   |missed *Optional*   |
</div>


## `UserEnhancedCallLogsGetListResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserEnhancedCallLogsGetListRequest16()`.

Total numbers of rows is: - the total number of retrievable logs of the call log type
that was specified in the `UserEnhancedCallLogsGetListRequest16()`, if a call log type
was specified in the request.  - the total number of retrievable logs, if no call log
type was specified in the request.  Replaced by
`UserEnhancedCallLogsGetListResponse17sp4()`

**Attributes:**

|Name                 |Type              |Description        |
|---------------------|------------------|-------------------|
|total_number_of_rows |int               |totalNumberOfRows  |
|call_log             |List[OCI.callLog] |callLog *Optional* |
</div>


## `UserExecutiveGetFilteringSelectiveCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserExecutiveGetFilteringSelectiveCriteriaRequest()`.

Replaced by: `UserExecutiveGetFilteringSelectiveCriteriaResponse21()`

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|filter           |bool                |filter                     |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
</div>


## `UserExecutiveGetFilteringSelectiveCriteriaResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserExecutiveGetFilteringSelectiveCriteriaRequest21()`.


**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|filter           |bool                   |filter                     |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserFeatureAccessCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserFeatureAccessCodeGetListRequest()`.

Replaced by: `UserFeatureAccessCodeGetListResponse20()` in AS data mode

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `UserFeatureAccessCodeGetListResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserFeatureAccessCodeGetListRequest20()`.

In release 20 the "Call Recording" FAC name is changed to "Call Recording Start".
Replaced by: `UserFeatureAccessCodeGetListResponse21()`

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `UserFeatureAccessCodeGetListResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserFeatureAccessCodeGetListRequest21()`.

In release 20 the "Call Recording" FAC name is changed to "Call Recording Start".

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `UserGroupNightForwardingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGroupNightForwardingGetRequest()`.

businessHours and holidaySchedule are returned in the response only when
groupNightForwarding is ‘Auto On’.

**Attributes:**

|Name                   |Type                |Description                |
|-----------------------|--------------------|---------------------------|
|night_forwarding       |str                 |nightForwarding            |
|group_night_forwarding |str                 |groupNightForwarding       |
|business_hours         |OCI.businessHours   |businessHours *Optional*   |
|holiday_schedule       |OCI.holidaySchedule |holidaySchedule *Optional* |
</div>


## `UserHolidayScheduleGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserHolidayScheduleGetRequest()`.

The response contains the user?s holiday schedule information.

**Attributes:**

|Name                  |Type          |Description          |
|----------------------|--------------|---------------------|
|holiday_schedule_name |str           |holidayScheduleName  |
|holiday01             |OCI.holiday01 |holiday01 *Optional* |
|holiday02             |OCI.holiday02 |holiday02 *Optional* |
|holiday03             |OCI.holiday03 |holiday03 *Optional* |
|holiday04             |OCI.holiday04 |holiday04 *Optional* |
|holiday05             |OCI.holiday05 |holiday05 *Optional* |
|holiday06             |OCI.holiday06 |holiday06 *Optional* |
|holiday07             |OCI.holiday07 |holiday07 *Optional* |
|holiday08             |OCI.holiday08 |holiday08 *Optional* |
|holiday09             |OCI.holiday09 |holiday09 *Optional* |
|holiday10             |OCI.holiday10 |holiday10 *Optional* |
|holiday11             |OCI.holiday11 |holiday11 *Optional* |
|holiday12             |OCI.holiday12 |holiday12 *Optional* |
|holiday13             |OCI.holiday13 |holiday13 *Optional* |
|holiday14             |OCI.holiday14 |holiday14 *Optional* |
|holiday15             |OCI.holiday15 |holiday15 *Optional* |
|holiday16             |OCI.holiday16 |holiday16 *Optional* |
|holiday17             |OCI.holiday17 |holiday17 *Optional* |
|holiday18             |OCI.holiday18 |holiday18 *Optional* |
|holiday19             |OCI.holiday19 |holiday19 *Optional* |
|holiday20             |OCI.holiday20 |holiday20 *Optional* |
</div>


## `UserMaliciousCallTraceGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMaliciousCallTraceGetRequest()`.


**Attributes:**

|Name                  |Type                |Description                |
|----------------------|--------------------|---------------------------|
|is_active             |bool                |isActive                   |
|trace_type_selection  |str                 |traceTypeSelection         |
|trace_for_time_period |bool                |traceForTimePeriod         |
|trace_time_period     |OCI.traceTimePeriod |traceTimePeriod *Optional* |
</div>


## `UserMeetMeConferencingGetConferenceGreetingResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMeetMeConferencingGetConferenceGreetingRequest20()`.

Contains the information of a conference custom greeting.

**Attributes:**

|Name                   |Type                     |Description                     |
|-----------------------|-------------------------|--------------------------------|
|play_entrance_greeting |bool                     |playEntranceGreeting            |
|entrance_greeting_file |OCI.entranceGreetingFile |entranceGreetingFile *Optional* |
</div>


## `UserMeetMeConferencingGetConferenceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMeetMeConferencingGetConferenceRequest()`.

Contains the information of a conference.

**Attributes:**

|Name                             |Type                   |Description                      |
|---------------------------------|-----------------------|---------------------------------|
|title                            |str                    |title                            |
|estimated_participants           |int                    |estimatedParticipants *Optional* |
|restrict_participants            |bool                   |restrictParticipants *Optional*  |
|max_participants                 |int                    |maxParticipants *Optional*       |
|account_code                     |str                    |accountCode *Optional*           |
|mute_all_attendees_on_entry      |bool                   |muteAllAttendeesOnEntry          |
|end_conference_on_moderator_exit |bool                   |endConferenceOnModeratorExit     |
|moderator_required               |bool                   |moderatorRequired                |
|attendee_notification            |str                    |attendeeNotification             |
|conference_schedule              |OCI.conferenceSchedule |conferenceSchedule               |
|moderator_pin                    |str                    |moderatorPin                     |
</div>


## `UserMeetMeConferencingGetConferenceResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMeetMeConferencingGetConferenceRequest19()`.

Contains the information of a conference.

**Attributes:**

|Name                             |Type                   |Description                      |
|---------------------------------|-----------------------|---------------------------------|
|title                            |str                    |title                            |
|estimated_participants           |int                    |estimatedParticipants *Optional* |
|restrict_participants            |bool                   |restrictParticipants *Optional*  |
|max_participants                 |int                    |maxParticipants *Optional*       |
|account_code                     |str                    |accountCode *Optional*           |
|mute_all_attendees_on_entry      |bool                   |muteAllAttendeesOnEntry          |
|end_conference_on_moderator_exit |bool                   |endConferenceOnModeratorExit     |
|moderator_required               |bool                   |moderatorRequired                |
|require_security_pin             |bool                   |requireSecurityPin               |
|security_pin                     |str                    |securityPin *Optional*           |
|allow_unique_identifier          |bool                   |allowUniqueIdentifier            |
|attendee_notification            |str                    |attendeeNotification             |
|conference_schedule              |OCI.conferenceSchedule |conferenceSchedule               |
|moderator_pin                    |str                    |moderatorPin                     |
</div>


## `UserMeetMeConferencingGetConferenceResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMeetMeConferencingGetConferenceRequest20()`.

Contains the information of a conference.  Replaced by:
`UserMeetMeConferencingGetConferenceResponse23()`

**Attributes:**

|Name                             |Type                   |Description                      |
|---------------------------------|-----------------------|---------------------------------|
|title                            |str                    |title                            |
|estimated_participants           |int                    |estimatedParticipants *Optional* |
|restrict_participants            |bool                   |restrictParticipants *Optional*  |
|max_participants                 |int                    |maxParticipants *Optional*       |
|account_code                     |str                    |accountCode *Optional*           |
|mute_all_attendees_on_entry      |bool                   |muteAllAttendeesOnEntry          |
|end_conference_on_moderator_exit |bool                   |endConferenceOnModeratorExit     |
|moderator_required               |bool                   |moderatorRequired                |
|require_security_pin             |bool                   |requireSecurityPin               |
|security_pin                     |str                    |securityPin *Optional*           |
|allow_unique_identifier          |bool                   |allowUniqueIdentifier            |
|attendee_notification            |str                    |attendeeNotification             |
|conference_schedule              |OCI.conferenceSchedule |conferenceSchedule               |
|moderator_pin                    |str                    |moderatorPin                     |
|host_time_zone                   |str                    |hostTimeZone                     |
</div>


## `UserMeetMeConferencingGetConferenceResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMeetMeConferencingGetConferenceRequest23()`.

Contains the information of a conference.

**Attributes:**

|Name                                          |Type                   |Description                             |
|----------------------------------------------|-----------------------|----------------------------------------|
|title                                         |str                    |title                                   |
|estimated_participants                        |int                    |estimatedParticipants *Optional*        |
|restrict_participants                         |bool                   |restrictParticipants *Optional*         |
|max_participants                              |int                    |maxParticipants *Optional*              |
|account_code                                  |str                    |accountCode *Optional*                  |
|mute_all_attendees_on_entry                   |bool                   |muteAllAttendeesOnEntry                 |
|end_conference_on_moderator_exit              |bool                   |endConferenceOnModeratorExit            |
|moderator_required                            |bool                   |moderatorRequired                       |
|require_security_pin                          |bool                   |requireSecurityPin                      |
|security_pin                                  |str                    |securityPin *Optional*                  |
|allow_unique_identifier                       |bool                   |allowUniqueIdentifier                   |
|attendee_notification                         |str                    |attendeeNotification                    |
|conference_schedule                           |OCI.conferenceSchedule |conferenceSchedule                      |
|moderator_pin                                 |str                    |moderatorPin                            |
|host_time_zone                                |str                    |hostTimeZone                            |
|allow_participant_unmute_in_auto_lecture_mode |bool                   |allowParticipantUnmuteInAutoLectureMode |
</div>


## `UserModifyGroupIdResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserModifyGroupIdRequest()`.

error indicates the failing conditions preventing the user move.  impact indicates any
change to user and group as the result of a user move.

**Attributes:**

|Name   |Type             |Description       |
|-------|-----------------|------------------|
|error  |List[OCI.error]  |error *Optional*  |
|impact |List[OCI.impact] |impact *Optional* |
</div>


## `UserMusicOnHoldUserGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMusicOnHoldUserGetRequest()`.

Replaced By: `UserMusicOnHoldUserGetResponse16()`

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|enable_video                            |bool               |enableVideo                        |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource *Optional*          |
</div>


## `UserMusicOnHoldUserGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMusicOnHoldUserGetRequest16()`.

Replaced by: `UserMusicOnHoldUserGetResponse20()` in AS data mode

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|enable_video                            |bool               |enableVideo                        |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource *Optional*          |
</div>


## `UserMusicOnHoldUserGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserMusicOnHoldUserGetRequest20()`.


**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|enable_video                            |bool               |enableVideo                        |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource *Optional*          |
</div>


## `UserOutgoingCallingPlanAuthorizationCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanAuthorizationCodeGetListRequest()`.


**Attributes:**

|Name       |Type                |Description          |
|-----------|--------------------|---------------------|
|code_entry |List[OCI.codeEntry] |codeEntry *Optional* |
</div>


## `UserOutgoingCallingPlanCallMeNowGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanCallMeNowGetRequest()`.


**Attributes:**

|Name                |Type                |Description       |
|--------------------|--------------------|------------------|
|use_custom_settings |bool                |useCustomSettings |
|user_permissions    |OCI.userPermissions |userPermissions   |
</div>


## `UserOutgoingCallingPlanOriginatingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanOriginatingGetRequest()`.


**Attributes:**

|Name                |Type                |Description       |
|--------------------|--------------------|------------------|
|use_custom_settings |bool                |useCustomSettings |
|user_permissions    |OCI.userPermissions |userPermissions   |
</div>


## `UserOutgoingCallingPlanRedirectedGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanRedirectedGetRequest()`.


**Attributes:**

|Name                |Type                |Description       |
|--------------------|--------------------|------------------|
|use_custom_settings |bool                |useCustomSettings |
|user_permissions    |OCI.userPermissions |userPermissions   |
</div>


## `UserOutgoingCallingPlanRedirectingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanRedirectingGetRequest()`.


**Attributes:**

|Name                |Type                |Description       |
|--------------------|--------------------|------------------|
|use_custom_settings |bool                |useCustomSettings |
|user_permissions    |OCI.userPermissions |userPermissions   |
</div>


## `UserOutgoingCallingPlanTransferNumbersGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanTransferNumbersGetRequest()`.


**Attributes:**

|Name                |Type            |Description       |
|--------------------|----------------|------------------|
|use_custom_settings |bool            |useCustomSettings |
|user_numbers        |OCI.userNumbers |userNumbers       |
</div>


## `UserPersonalAssistantCallToNumberGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPersonalAssistantCallToNumberGetListRequest()`.

Contains a list of assigned Call to Numbers".

**Attributes:**

|Name           |Type                   |Description             |
|---------------|-----------------------|------------------------|
|call_to_number |List[OCI.callToNumber] |callToNumber *Optional* |
</div>


## `UserPersonalPhoneListGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPersonalPhoneListGetListRequest()`.

The response contains a user's personal phone list.

**Attributes:**

|Name  |Type            |Description      |
|------|----------------|-----------------|
|entry |List[OCI.entry] |entry *Optional* |
</div>


## `UserPreAlertingAnnouncementGetCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPreAlertingAnnouncementGetCriteriaRequest()`.

Replaced by: `UserPreAlertingAnnouncementGetCriteriaResponse21()` in AS data mode

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted      |bool                |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
</div>


## `UserPreAlertingAnnouncementGetCriteriaResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPreAlertingAnnouncementGetCriteriaRequest21()`.


**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|blacklisted      |bool                   |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserPreAlertingAnnouncementGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `UserPreAlertingAnnouncementGetRequest20()`.

The criteria table's column headings are: "Is Active", "Criteria Name", "Blacklisted",
"Calls From", "Calls To Type", "Calls To Number" and "Calls To Extension". The
possible values for the "Calls To Type" column are the following or a combination of
them separated by comma: - Primary - Alternate X (where x is a number between 1 and
10) - Mobility The possible values for the "Calls To Number" column are the following
or a combination of them separated by comma: - The value of the phone number for the
corresponding Calls To Type, when the number is available.  i.e.  Alternate 1 may have
extension, but no number.  - When no number is available a blank space is provided
instead.  The possible values for the "Calls To Extension" column are the following or
a combination of them separated by comma: - The value of the extension for the
corresponding Calls To Type, when the extension is available.  i.e.  Primary may have
number, but no extension.  - For Mobility Calls To Type, this is always blank.  - When
no extension is available a blank space is provided instead.

**Attributes:**

|Name            |Type                |Description                                                 |
|----------------|--------------------|------------------------------------------------------------|
|is_active       |bool                |isActive                                                    |
|audio_selection |str                 |audioSelection                                              |
|audio_file      |OCI.audioFile       |audioFile *Optional*                                        |
|audio_file_url  |str                 |audioFileUrl *Optional*                                     |
|video_selection |str                 |videoSelection                                              |
|video_file      |OCI.videoFile       |videoFile *Optional*                                        |
|video_file_url  |str                 |videoFileUrl *Optional*                                     |
|criteria_table  |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserPreferredCarrierUserGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `UserPreferredCarrierUserGetRequest()`.


**Attributes:**

|Name                  |Type                     |Description          |
|----------------------|-------------------------|---------------------|
|intra_lata_carrier    |OCI.intraLataCarrier     |intraLataCarrier     |
|inter_lata_carrier    |OCI.interLataCarrier     |interLataCarrier     |
|international_carrier |OCI.internationalCarrier |internationalCarrier |
</div>


## `UserPriorityAlertGetCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPriorityAlertGetCriteriaRequest()`.


**Attributes:**

|Name             |Type               |Description             |
|-----------------|-------------------|------------------------|
|time_schedule    |OCI.timeSchedule   |timeSchedule *Optional* |
|from_dn_criteria |OCI.fromDnCriteria |fromDnCriteria          |
</div>


## `UserPriorityAlertGetCriteriaResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPriorityAlertGetCriteriaRequest16()`.

Replaced by: `UserPriorityAlertGetCriteriaResponse21()` in AS data mode

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted      |bool                |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
</div>


## `UserPriorityAlertGetCriteriaResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserPriorityAlertGetCriteriaRequest21()`.


**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|blacklisted      |bool                   |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserScheduleGetEventResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserScheduleGetEventRequest()`.

The response contains the event of the user schedule.

**Attributes:**

|Name          |Type           |Description            |
|--------------|---------------|-----------------------|
|start_date    |str            |startDate              |
|all_day_event |bool           |allDayEvent *Optional* |
|start_time    |OCI.startTime  |startTime *Optional*   |
|end_time      |OCI.endTime    |endTime *Optional*     |
|end_date      |str            |endDate                |
|recurrence    |OCI.recurrence |recurrence *Optional*  |
</div>


## `UserSelectiveCallAcceptanceGetCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSelectiveCallAcceptanceGetCriteriaRequest()`.


**Attributes:**

|Name             |Type               |Description             |
|-----------------|-------------------|------------------------|
|time_schedule    |OCI.timeSchedule   |timeSchedule *Optional* |
|from_dn_criteria |OCI.fromDnCriteria |fromDnCriteria          |
</div>


## `UserSelectiveCallAcceptanceGetCriteriaResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSelectiveCallAcceptanceGetCriteriaRequest16()`.

Replaced by: `UserSelectiveCallAcceptanceGetCriteriaResponse21()` in AS data mode

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted      |bool                |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
</div>


## `UserSelectiveCallAcceptanceGetCriteriaResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSelectiveCallAcceptanceGetCriteriaRequest21()`.


**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|blacklisted      |bool                   |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserSelectiveCallRejectionGetCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSelectiveCallRejectionGetCriteriaRequest()`.


**Attributes:**

|Name             |Type               |Description             |
|-----------------|-------------------|------------------------|
|time_schedule    |OCI.timeSchedule   |timeSchedule *Optional* |
|from_dn_criteria |OCI.fromDnCriteria |fromDnCriteria          |
</div>


## `UserSelectiveCallRejectionGetCriteriaResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSelectiveCallRejectionGetCriteriaRequest16()`.

Replaced by: `UserSelectiveCallRejectionGetCriteriaResponse16sp1()`

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
|blacklisted      |bool                |blacklisted                |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
</div>


## `UserSelectiveCallRejectionGetCriteriaResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSelectiveCallRejectionGetCriteriaRequest16sp1()`.

Private Phone Numbers are omitted from the fromDnCriteria.  Replaced by:
`UserSelectiveCallRejectionGetCriteriaResponse21()` in AS data mode

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
|blacklisted      |bool                |blacklisted                |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|private          |bool                |private                    |
</div>


## `UserSelectiveCallRejectionGetCriteriaResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSelectiveCallRejectionGetCriteriaRequest21()`.

Private Phone Numbers are omitted from the fromDnCriteria.

**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|blacklisted      |bool                   |blacklisted                |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|private          |bool                   |private                    |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserSequentialRingGetCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSequentialRingGetCriteriaRequest()`.


**Attributes:**

|Name             |Type               |Description             |
|-----------------|-------------------|------------------------|
|time_schedule    |OCI.timeSchedule   |timeSchedule *Optional* |
|from_dn_criteria |OCI.fromDnCriteria |fromDnCriteria          |
</div>


## `UserSequentialRingGetCriteriaResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSequentialRingGetCriteriaRequest16()`.


**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted      |bool                |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
</div>


## `UserSequentialRingGetResponse13mp16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSequentialRingGetRequest13mp16()`.

The criteria table's column headings are: "Is Active", "Criteria Name", "Time
Schedule" and "Calls From".

Replaced By: `UserSequentialRingGetResponse14sp4()`

**Attributes:**

|Name                              |Type                |Description                                                 |
|----------------------------------|--------------------|------------------------------------------------------------|
|ring_base_location_first          |bool                |ringBaseLocationFirst                                       |
|base_location_number_of_rings     |int                 |baseLocationNumberOfRings                                   |
|continue_if_base_location_is_busy |bool                |continueIfBaseLocationIsBusy                                |
|caller_may_stop_search            |bool                |callerMayStopSearch                                         |
|location01                        |OCI.Location01      |Location01                                                  |
|location02                        |OCI.Location02      |Location02                                                  |
|location03                        |OCI.Location03      |Location03                                                  |
|location04                        |OCI.Location04      |Location04                                                  |
|location05                        |OCI.Location05      |Location05                                                  |
|criteria_table                    |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserSequentialRingGetResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSequentialRingGetRequest14sp4()`.

The criteria table's column headings are: "Is Active", "Criteria Name", "Time
Schedule", "Calls From", "Blacklisted" and "Holiday Schedule".

**Attributes:**

|Name                              |Type                |Description                                                 |
|----------------------------------|--------------------|------------------------------------------------------------|
|ring_base_location_first          |bool                |ringBaseLocationFirst                                       |
|base_location_number_of_rings     |int                 |baseLocationNumberOfRings                                   |
|continue_if_base_location_is_busy |bool                |continueIfBaseLocationIsBusy                                |
|caller_may_stop_search            |bool                |callerMayStopSearch                                         |
|location01                        |OCI.Location01      |Location01                                                  |
|location02                        |OCI.Location02      |Location02                                                  |
|location03                        |OCI.Location03      |Location03                                                  |
|location04                        |OCI.Location04      |Location04                                                  |
|location05                        |OCI.Location05      |Location05                                                  |
|criteria_table                    |List(criteriaTable) |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserSimultaneousRingFamilyGetCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSimultaneousRingFamilyGetCriteriaRequest()`.


**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted      |bool                |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
</div>


## `UserSimultaneousRingFamilyGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSimultaneousRingFamilyGetRequest17()`.

Contains a criteria table wich column heading: "Is Active", "Criteria Name", "Time
Schedule", "Holiday Schedule", "Calls From" and "Blacklisted".

**Attributes:**

|Name                     |Type                             |Description                                                 |
|-------------------------|---------------------------------|------------------------------------------------------------|
|is_active                |bool                             |isActive                                                    |
|do_not_ring_if_on_call   |bool                             |doNotRingIfOnCall                                           |
|simultaneous_ring_number |List[OCI.simultaneousRingNumber] |simultaneousRingNumber *Optional*                           |
|criteria_table           |List(criteriaTable)              |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserSimultaneousRingPersonalGetCriteriaResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSimultaneousRingPersonalGetCriteriaRequest()`.


**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted      |bool                |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
</div>


## `UserSimultaneousRingPersonalGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSimultaneousRingPersonalGetRequest17()`.

Contains a criteria table with column heading: "Is Active", "Criteria Name", "Time
Schedule", "Holiday Schedule", "Calls From" and "Blacklisted".

**Attributes:**

|Name                     |Type                             |Description                                                 |
|-------------------------|---------------------------------|------------------------------------------------------------|
|is_active                |bool                             |isActive                                                    |
|do_not_ring_if_on_call   |bool                             |doNotRingIfOnCall                                           |
|simultaneous_ring_number |List[OCI.simultaneousRingNumber] |simultaneousRingNumber *Optional*                           |
|criteria_table           |List(criteriaTable)              |criteriaTable - *Table* array of criteriaTable named tuples |
</div>


## `UserSpeedDial100GetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSpeedDial100GetListRequest()`.

Replaced by: UserSpeedDial100GetListResponse17Sp1

**Attributes:**

|Name             |Type                     |Description               |
|-----------------|-------------------------|--------------------------|
|prefix           |str                      |prefix                    |
|speed_dial_entry |List[OCI.speedDialEntry] |speedDialEntry *Optional* |
</div>


## `UserSpeedDial100GetListResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSpeedDial100GetListRequest17sp1()`.


**Attributes:**

|Name             |Type                     |Description               |
|-----------------|-------------------------|--------------------------|
|prefix           |str                      |prefix *Optional*         |
|speed_dial_entry |List[OCI.speedDialEntry] |speedDialEntry *Optional* |
</div>


## `UserSpeedDial8GetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserSpeedDial8GetListRequest()`.


**Attributes:**

|Name             |Type                     |Description    |
|-----------------|-------------------------|---------------|
|speed_dial_entry |List[OCI.speedDialEntry] |speedDialEntry |
</div>


## `UserTimeScheduleGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserTimeScheduleGetRequest()`.

The response contains the requested time schedule information.

**Attributes:**

|Name               |Type               |Description               |
|-------------------|-------------------|--------------------------|
|time_schedule_name |str                |timeScheduleName          |
|time_interval01    |OCI.timeInterval01 |timeInterval01 *Optional* |
|time_interval02    |OCI.timeInterval02 |timeInterval02 *Optional* |
|time_interval03    |OCI.timeInterval03 |timeInterval03 *Optional* |
|time_interval04    |OCI.timeInterval04 |timeInterval04 *Optional* |
|time_interval05    |OCI.timeInterval05 |timeInterval05 *Optional* |
|time_interval06    |OCI.timeInterval06 |timeInterval06 *Optional* |
|time_interval07    |OCI.timeInterval07 |timeInterval07 *Optional* |
|time_interval08    |OCI.timeInterval08 |timeInterval08 *Optional* |
|time_interval09    |OCI.timeInterval09 |timeInterval09 *Optional* |
|time_interval10    |OCI.timeInterval10 |timeInterval10 *Optional* |
|time_interval11    |OCI.timeInterval11 |timeInterval11 *Optional* |
|time_interval12    |OCI.timeInterval12 |timeInterval12 *Optional* |
|time_interval13    |OCI.timeInterval13 |timeInterval13 *Optional* |
|time_interval14    |OCI.timeInterval14 |timeInterval14 *Optional* |
|time_interval15    |OCI.timeInterval15 |timeInterval15 *Optional* |
|time_interval16    |OCI.timeInterval16 |timeInterval16 *Optional* |
|time_interval17    |OCI.timeInterval17 |timeInterval17 *Optional* |
|time_interval18    |OCI.timeInterval18 |timeInterval18 *Optional* |
|time_interval19    |OCI.timeInterval19 |timeInterval19 *Optional* |
|time_interval20    |OCI.timeInterval20 |timeInterval20 *Optional* |
</div>


## `UserVoiceMessagingUserGetGreetingResponse13mp16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserVoiceMessagingUserGetGreetingRequest13mp16()`.

Contains the greeting configuration for a user's voice messaging.

Replaced By: `UserVoiceMessagingUserGetGreetingResponse16()`

**Attributes:**

|Name                             |Type                            |Description                            |
|---------------------------------|--------------------------------|---------------------------------------|
|busy_announcement_selection      |str                             |busyAnnouncementSelection              |
|busy_personal_audio_file         |str                             |busyPersonalAudioFile *Optional*       |
|busy_personal_video_file         |str                             |busyPersonalVideoFile *Optional*       |
|no_answer_announcement_selection |str                             |noAnswerAnnouncementSelection          |
|no_answer_personal_audio_file    |str                             |noAnswerPersonalAudioFile *Optional*   |
|no_answer_personal_video_file    |str                             |noAnswerPersonalVideoFile *Optional*   |
|no_answer_alternate_greeting01   |OCI.noAnswerAlternateGreeting01 |noAnswerAlternateGreeting01 *Optional* |
|no_answer_alternate_greeting02   |OCI.noAnswerAlternateGreeting02 |noAnswerAlternateGreeting02 *Optional* |
|no_answer_alternate_greeting03   |OCI.noAnswerAlternateGreeting03 |noAnswerAlternateGreeting03 *Optional* |
|no_answer_number_of_rings        |int                             |noAnswerNumberOfRings                  |
</div>


## `UserVoiceMessagingUserGetGreetingResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserVoiceMessagingUserGetGreetingRequest16()`.

Contains the greeting configuration for a user's voice messaging.  Replaced by:
`UserVoiceMessagingUserGetGreetingResponse18()`

**Attributes:**

|Name                                |Type                            |Description                               |
|------------------------------------|--------------------------------|------------------------------------------|
|busy_announcement_selection         |str                             |busyAnnouncementSelection                 |
|busy_personal_audio_file            |str                             |busyPersonalAudioFile *Optional*          |
|busy_personal_audio_media_type      |str                             |busyPersonalAudioMediaType *Optional*     |
|busy_personal_video_file            |str                             |busyPersonalVideoFile *Optional*          |
|busy_personal_video_media_type      |str                             |busyPersonalVideoMediaType *Optional*     |
|no_answer_announcement_selection    |str                             |noAnswerAnnouncementSelection             |
|no_answer_personal_audio_file       |str                             |noAnswerPersonalAudioFile *Optional*      |
|no_answer_personal_audio_media_type |str                             |noAnswerPersonalAudioMediaType *Optional* |
|no_answer_personal_video_file       |str                             |noAnswerPersonalVideoFile *Optional*      |
|no_answer_personal_video_media_type |str                             |noAnswerPersonalVideoMediaType *Optional* |
|no_answer_alternate_greeting01      |OCI.noAnswerAlternateGreeting01 |noAnswerAlternateGreeting01 *Optional*    |
|no_answer_alternate_greeting02      |OCI.noAnswerAlternateGreeting02 |noAnswerAlternateGreeting02 *Optional*    |
|no_answer_alternate_greeting03      |OCI.noAnswerAlternateGreeting03 |noAnswerAlternateGreeting03 *Optional*    |
|no_answer_number_of_rings           |int                             |noAnswerNumberOfRings                     |
</div>


## `UserVoiceMessagingUserGetGreetingResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserVoiceMessagingUserGetGreetingRequest18()`.

Contains the greeting configuration for a user's voice messaging.  The following
elements are only used in AS data mode: disableMessageDeposit
disableMessageDepositAction The following elements are only used in AS data mode and
not returned in XS data mode: greetingOnlyForwardDestination Replaced by
`UserVoiceMessagingUserGetGreetingResponse18sp1()` in AS data mode

**Attributes:**

|Name                                |Type                            |Description                               |
|------------------------------------|--------------------------------|------------------------------------------|
|busy_announcement_selection         |str                             |busyAnnouncementSelection                 |
|busy_personal_audio_file            |str                             |busyPersonalAudioFile *Optional*          |
|busy_personal_audio_media_type      |str                             |busyPersonalAudioMediaType *Optional*     |
|busy_personal_video_file            |str                             |busyPersonalVideoFile *Optional*          |
|busy_personal_video_media_type      |str                             |busyPersonalVideoMediaType *Optional*     |
|no_answer_announcement_selection    |str                             |noAnswerAnnouncementSelection             |
|no_answer_personal_audio_file       |str                             |noAnswerPersonalAudioFile *Optional*      |
|no_answer_personal_audio_media_type |str                             |noAnswerPersonalAudioMediaType *Optional* |
|no_answer_personal_video_file       |str                             |noAnswerPersonalVideoFile *Optional*      |
|no_answer_personal_video_media_type |str                             |noAnswerPersonalVideoMediaType *Optional* |
|no_answer_alternate_greeting01      |OCI.noAnswerAlternateGreeting01 |noAnswerAlternateGreeting01 *Optional*    |
|no_answer_alternate_greeting02      |OCI.noAnswerAlternateGreeting02 |noAnswerAlternateGreeting02 *Optional*    |
|no_answer_alternate_greeting03      |OCI.noAnswerAlternateGreeting03 |noAnswerAlternateGreeting03 *Optional*    |
|no_answer_number_of_rings           |int                             |noAnswerNumberOfRings                     |
|disable_message_deposit             |bool                            |disableMessageDeposit                     |
|disable_message_deposit_action      |str                             |disableMessageDepositAction               |
|greeting_only_forward_destination   |str                             |greetingOnlyForwardDestination *Optional* |
</div>


## `UserVoiceMessagingUserGetGreetingResponse18sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserVoiceMessagingUserGetGreetingRequest18sp1()`.

Contains the greeting configuration for a user's voice messaging.  The following
elements are only used in AS data mode: disableMessageDeposit, value "false" is
returned in XS data mode disableMessageDepositAction, value "Disconnect" is returned
in XS data mode extendedAwayEnabled, value "false" is returned in XS data mode
extendedAwayDisableMessageDeposit, value "true" is returned in XS data mode The
following elements are only used in AS data mode and not returned in XS data mode:
greetingOnlyForwardDestination extendedAwayAudioFile extendedAwayAudioMediaType
extendedAwayVideoFile extendedAwayVideoMediaType Replaced by:
`UserVoiceMessagingUserGetGreetingResponse20()` in AS data mode

**Attributes:**

|Name                                  |Type                            |Description                               |
|--------------------------------------|--------------------------------|------------------------------------------|
|busy_announcement_selection           |str                             |busyAnnouncementSelection                 |
|busy_personal_audio_file              |str                             |busyPersonalAudioFile *Optional*          |
|busy_personal_audio_media_type        |str                             |busyPersonalAudioMediaType *Optional*     |
|busy_personal_video_file              |str                             |busyPersonalVideoFile *Optional*          |
|busy_personal_video_media_type        |str                             |busyPersonalVideoMediaType *Optional*     |
|no_answer_announcement_selection      |str                             |noAnswerAnnouncementSelection             |
|no_answer_personal_audio_file         |str                             |noAnswerPersonalAudioFile *Optional*      |
|no_answer_personal_audio_media_type   |str                             |noAnswerPersonalAudioMediaType *Optional* |
|no_answer_personal_video_file         |str                             |noAnswerPersonalVideoFile *Optional*      |
|no_answer_personal_video_media_type   |str                             |noAnswerPersonalVideoMediaType *Optional* |
|extended_away_enabled                 |bool                            |extendedAwayEnabled                       |
|extended_away_disable_message_deposit |bool                            |extendedAwayDisableMessageDeposit         |
|extended_away_audio_file              |str                             |extendedAwayAudioFile *Optional*          |
|extended_away_audio_media_type        |str                             |extendedAwayAudioMediaType *Optional*     |
|extended_away_video_file              |str                             |extendedAwayVideoFile *Optional*          |
|extended_away_video_media_type        |str                             |extendedAwayVideoMediaType *Optional*     |
|no_answer_alternate_greeting01        |OCI.noAnswerAlternateGreeting01 |noAnswerAlternateGreeting01 *Optional*    |
|no_answer_alternate_greeting02        |OCI.noAnswerAlternateGreeting02 |noAnswerAlternateGreeting02 *Optional*    |
|no_answer_alternate_greeting03        |OCI.noAnswerAlternateGreeting03 |noAnswerAlternateGreeting03 *Optional*    |
|no_answer_number_of_rings             |int                             |noAnswerNumberOfRings                     |
|disable_message_deposit               |bool                            |disableMessageDeposit                     |
|disable_message_deposit_action        |str                             |disableMessageDepositAction               |
|greeting_only_forward_destination     |str                             |greetingOnlyForwardDestination *Optional* |
</div>


## `UserVoiceMessagingUserGetVoicePortalResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserVoiceMessagingUserGetVoicePortalRequest20()`.


**Attributes:**

|Name                         |Type                          |Description                          |
|-----------------------------|------------------------------|-------------------------------------|
|use_personalized_name        |bool                          |usePersonalizedName                  |
|voice_portal_auto_login      |bool                          |voicePortalAutoLogin                 |
|personalized_name_audio_file |OCI.personalizedNameAudioFile |personalizedNameAudioFile *Optional* |
</div>


## `EnterpriseSessionAdmissionControlGetAvailableDeviceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseSessionAdmissionControlGetAvailableDeviceListRequest()`.

Contains a table of devices can be assigned to session admission control group in the
enterprise.

**Attributes:**

|Name          |Type                   |Description             |
|--------------|-----------------------|------------------------|
|access_device |List[OCI.accessDevice] |accessDevice *Optional* |
</div>


## `EnterpriseSessionAdmissionControlGroupGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseSessionAdmissionControlGroupGetRequest()`.

Returns the profile information for the session admission control group.

**Attributes:**

|Name                               |Type              |Description                                |
|-----------------------------------|------------------|-------------------------------------------|
|max_session                        |int               |maxSession                                 |
|max_user_originating_sessions      |int               |maxUserOriginatingSessions *Optional*      |
|max_user_terminating_sessions      |int               |maxUserTerminatingSessions *Optional*      |
|reserved_session                   |int               |reservedSession                            |
|reserved_user_originating_sessions |int               |reservedUserOriginatingSessions *Optional* |
|reserved_user_terminating_sessions |int               |reservedUserTerminatingSessions *Optional* |
|default_group                      |bool              |defaultGroup                               |
|count_intra_sac_group_sessions     |bool              |countIntraSACGroupSessions                 |
|devices                            |List[OCI.devices] |devices *Optional*                         |
</div>


## `EnterpriseSessionAdmissionControlGroupGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseSessionAdmissionControlGroupGetRequest19sp1()`.

Returns the profile information for the session admission control group.  Replaced by:
`EnterpriseSessionAdmissionControlGroupGetResponse21sp1()`

**Attributes:**

|Name                                               |Type              |Description                                |
|---------------------------------------------------|------------------|-------------------------------------------|
|max_session                                        |int               |maxSession                                 |
|max_user_originating_sessions                      |int               |maxUserOriginatingSessions *Optional*      |
|max_user_terminating_sessions                      |int               |maxUserTerminatingSessions *Optional*      |
|reserved_session                                   |int               |reservedSession                            |
|reserved_user_originating_sessions                 |int               |reservedUserOriginatingSessions *Optional* |
|reserved_user_terminating_sessions                 |int               |reservedUserTerminatingSessions *Optional* |
|default_group                                      |bool              |defaultGroup                               |
|count_intra_sac_group_sessions                     |bool              |countIntraSACGroupSessions                 |
|devices                                            |List[OCI.devices] |devices *Optional*                         |
|block_emergency_and_repair_calls_due_to_sac_limits |bool              |blockEmergencyAndRepairCallsDueToSACLimits |
</div>


## `EnterpriseSessionAdmissionControlGroupGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseSessionAdmissionControlGroupGetRequest21sp1()`.

Returns the profile information for the session admission control group.

**Attributes:**

|Name                                               |Type              |Description                                |
|---------------------------------------------------|------------------|-------------------------------------------|
|max_session                                        |int               |maxSession                                 |
|max_user_originating_sessions                      |int               |maxUserOriginatingSessions *Optional*      |
|max_user_terminating_sessions                      |int               |maxUserTerminatingSessions *Optional*      |
|reserved_session                                   |int               |reservedSession                            |
|reserved_user_originating_sessions                 |int               |reservedUserOriginatingSessions *Optional* |
|reserved_user_terminating_sessions                 |int               |reservedUserTerminatingSessions *Optional* |
|default_group                                      |bool              |defaultGroup                               |
|count_intra_sac_group_sessions                     |bool              |countIntraSACGroupSessions                 |
|devices                                            |List[OCI.devices] |devices *Optional*                         |
|block_emergency_and_repair_calls_due_to_sac_limits |bool              |blockEmergencyAndRepairCallsDueToSACLimits |
|media_group_name                                   |str               |mediaGroupName *Optional*                  |
</div>


## `GroupAccessDeviceGetLinkedTreeDeviceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAccessDeviceGetLinkedTreeDeviceRequest()`.


**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|tree_device_info |OCI.treeDeviceInfo |treeDeviceInfo *Optional* |
</div>


## `GroupAutoAttendantSubmenuGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAutoAttendantSubmenuGetRequest()`.

Contains AutoAttendant submenu information.  Replaced by:
`GroupAutoAttendantSubmenuGetResponse20()` in AS data mode

**Attributes:**

|Name                           |Type                       |Description                     |
|-------------------------------|---------------------------|--------------------------------|
|announcement_selection         |str                        |announcementSelection           |
|audio_file_description         |str                        |audioFileDescription *Optional* |
|audio_media_type               |str                        |audioMediaType *Optional*       |
|video_file_description         |str                        |videoFileDescription *Optional* |
|video_media_type               |str                        |videoMediaType *Optional*       |
|enable_level_extension_dialing |bool                       |enableLevelExtensionDialing     |
|key_configuration              |List[OCI.keyConfiguration] |keyConfiguration *Optional*     |
</div>


## `GroupBroadWorksAnywhereGetInstanceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupBroadWorksAnywhereGetInstanceRequest()`.

Contains the service profile information.

**Attributes:**

|Name                       |Type                       |Description             |
|---------------------------|---------------------------|------------------------|
|service_instance_profile   |OCI.serviceInstanceProfile |serviceInstanceProfile  |
|broad_works_anywhere_scope |str                        |broadWorksAnywhereScope |
|prompt_for_clid            |str                        |promptForCLID           |
|silent_prompt_mode         |bool                       |silentPromptMode        |
|prompt_for_passcode        |bool                       |promptForPasscode       |
</div>


## `GroupBroadWorksAnywhereGetInstanceResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupBroadWorksAnywhereGetInstanceRequest17()`.

Contains the service profile information.  Replaced by:
`GroupBroadWorksAnywhereGetInstanceResponse19sp1()` in AS data mode

**Attributes:**

|Name                       |Type                       |Description             |
|---------------------------|---------------------------|------------------------|
|service_instance_profile   |OCI.serviceInstanceProfile |serviceInstanceProfile  |
|broad_works_anywhere_scope |str                        |broadWorksAnywhereScope |
|prompt_for_clid            |str                        |promptForCLID           |
|silent_prompt_mode         |bool                       |silentPromptMode        |
|prompt_for_passcode        |bool                       |promptForPasscode       |
</div>


## `GroupBroadWorksAnywhereGetInstanceResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupBroadWorksAnywhereGetInstanceRequest19sp1()`.

Contains the service profile information.

**Attributes:**

|Name                       |Type                       |Description                      |
|---------------------------|---------------------------|---------------------------------|
|service_instance_profile   |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|broad_works_anywhere_scope |str                        |broadWorksAnywhereScope          |
|prompt_for_clid            |str                        |promptForCLID                    |
|silent_prompt_mode         |bool                       |silentPromptMode                 |
|prompt_for_passcode        |bool                       |promptForPasscode                |
|network_class_of_service   |str                        |networkClassOfService *Optional* |
</div>


## `GroupCallCenterComfortMessageBypassGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterComfortMessageBypassGetRequest20()`.


**Attributes:**

|Name                                          |Type              |Description                              |
|----------------------------------------------|------------------|-----------------------------------------|
|is_active                                     |bool              |isActive                                 |
|call_waiting_age_threshold_seconds            |int               |callWaitingAgeThresholdSeconds           |
|play_announcement_after_ringing               |bool              |playAnnouncementAfterRinging             |
|ring_time_before_playing_announcement_seconds |int               |ringTimeBeforePlayingAnnouncementSeconds |
|audio_message_selection                       |str               |audioMessageSelection                    |
|audio_url_list                                |OCI.audioUrlList  |audioUrlList *Optional*                  |
|audio_file_list                               |OCI.audioFileList |audioFileList *Optional*                 |
|video_message_selection                       |str               |videoMessageSelection                    |
|video_url_list                                |OCI.videoUrlList  |videoUrlList *Optional*                  |
|video_file_list                               |OCI.videoFileList |videoFileList *Optional*                 |
</div>


## `GroupCallCenterForcedForwardingGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterForcedForwardingGetRequest20()`.


**Attributes:**

|Name                                |Type              |Description                      |
|------------------------------------|------------------|---------------------------------|
|is_active                           |bool              |isActive                         |
|forward_to_phone_number             |str               |forwardToPhoneNumber *Optional*  |
|allow_enable_via_fac                |bool              |allowEnableViaFAC                |
|play_announcement_before_forwarding |bool              |playAnnouncementBeforeForwarding |
|audio_message_selection             |str               |audioMessageSelection            |
|audio_url_list                      |OCI.audioUrlList  |audioUrlList *Optional*          |
|audio_file_list                     |OCI.audioFileList |audioFileList *Optional*         |
|video_message_selection             |str               |videoMessageSelection            |
|video_url_list                      |OCI.videoUrlList  |videoUrlList *Optional*          |
|video_file_list                     |OCI.videoFileList |videoFileList *Optional*         |
</div>


## `GroupCallCenterGetInstanceResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetInstanceRequest14()`.

Contains the service profile information and a table of assigned users.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Weight".

Replaced By: `GroupCallCenterGetInstanceResponse14sp3()`

**Attributes:**

|Name                                  |Type                       |Description                                                   |
|--------------------------------------|---------------------------|--------------------------------------------------------------|
|service_instance_profile              |OCI.serviceInstanceProfile |serviceInstanceProfile                                        |
|policy                                |str                        |policy                                                        |
|hunt_after_no_answer                  |bool                       |huntAfterNoAnswer                                             |
|no_answer_number_of_rings             |int                        |noAnswerNumberOfRings                                         |
|forward_after_timeout                 |bool                       |forwardAfterTimeout                                           |
|forward_timeout_seconds               |int                        |forwardTimeoutSeconds                                         |
|forward_to_phone_number               |str                        |forwardToPhoneNumber *Optional*                               |
|enable_video                          |bool                       |enableVideo                                                   |
|queue_length                          |int                        |queueLength                                                   |
|allow_agent_logoff                    |bool                       |allowAgentLogoff                                              |
|play_music_on_hold                    |bool                       |playMusicOnHold                                               |
|play_comfort_message                  |bool                       |playComfortMessage                                            |
|time_between_comfort_messages_seconds |int                        |timeBetweenComfortMessagesSeconds                             |
|enable_guard_timer                    |bool                       |enableGuardTimer                                              |
|guard_timer_seconds                   |int                        |guardTimerSeconds                                             |
|agent_user_table                      |List(agentUserTable)       |agentUserTable - *Table* array of agentUserTable named tuples |
|allow_call_waiting_for_agents         |bool                       |allowCallWaitingForAgents                                     |
</div>


## `GroupCallCenterGetInstanceResponse14sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetInstanceRequest14sp3()`.

Contains the service profile information and a table of assigned users.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Weight".

Replaced By: `GroupCallCenterGetInstanceResponse14sp9()`

**Attributes:**

|Name                                       |Type                       |Description                                                   |
|-------------------------------------------|---------------------------|--------------------------------------------------------------|
|service_instance_profile                   |OCI.serviceInstanceProfile |serviceInstanceProfile                                        |
|policy                                     |str                        |policy                                                        |
|hunt_after_no_answer                       |bool                       |huntAfterNoAnswer                                             |
|no_answer_number_of_rings                  |int                        |noAnswerNumberOfRings                                         |
|forward_after_timeout                      |bool                       |forwardAfterTimeout                                           |
|forward_timeout_seconds                    |int                        |forwardTimeoutSeconds                                         |
|forward_to_phone_number                    |str                        |forwardToPhoneNumber *Optional*                               |
|enable_video                               |bool                       |enableVideo                                                   |
|queue_length                               |int                        |queueLength                                                   |
|allow_agent_logoff                         |bool                       |allowAgentLogoff                                              |
|play_music_on_hold                         |bool                       |playMusicOnHold                                               |
|play_comfort_message                       |bool                       |playComfortMessage                                            |
|time_between_comfort_messages_seconds      |int                        |timeBetweenComfortMessagesSeconds                             |
|enable_guard_timer                         |bool                       |enableGuardTimer                                              |
|guard_timer_seconds                        |int                        |guardTimerSeconds                                             |
|agent_user_table                           |List(agentUserTable)       |agentUserTable - *Table* array of agentUserTable named tuples |
|allow_call_waiting_for_agents              |bool                       |allowCallWaitingForAgents                                     |
|allow_calls_to_agents_in_wrap_up           |bool                       |allowCallsToAgentsInWrapUp                                    |
|enable_call_queue_when_no_agents_available |bool                       |enableCallQueueWhenNoAgentsAvailable                          |
</div>


## `GroupCallCenterGetInstanceResponse14sp9`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetInstanceRequest14sp9()`.

Contains the service profile information and a table of assigned users.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Weight".

**Attributes:**

|Name                                       |Type                       |Description                                                   |
|-------------------------------------------|---------------------------|--------------------------------------------------------------|
|service_instance_profile                   |OCI.serviceInstanceProfile |serviceInstanceProfile                                        |
|policy                                     |str                        |policy                                                        |
|hunt_after_no_answer                       |bool                       |huntAfterNoAnswer                                             |
|no_answer_number_of_rings                  |int                        |noAnswerNumberOfRings                                         |
|forward_after_timeout                      |bool                       |forwardAfterTimeout                                           |
|forward_timeout_seconds                    |int                        |forwardTimeoutSeconds                                         |
|forward_to_phone_number                    |str                        |forwardToPhoneNumber *Optional*                               |
|enable_video                               |bool                       |enableVideo                                                   |
|queue_length                               |int                        |queueLength                                                   |
|allow_agent_logoff                         |bool                       |allowAgentLogoff                                              |
|play_music_on_hold                         |bool                       |playMusicOnHold                                               |
|play_comfort_message                       |bool                       |playComfortMessage                                            |
|time_between_comfort_messages_seconds      |int                        |timeBetweenComfortMessagesSeconds                             |
|enable_guard_timer                         |bool                       |enableGuardTimer                                              |
|guard_timer_seconds                        |int                        |guardTimerSeconds                                             |
|agent_user_table                           |List(agentUserTable)       |agentUserTable - *Table* array of agentUserTable named tuples |
|allow_call_waiting_for_agents              |bool                       |allowCallWaitingForAgents                                     |
|allow_calls_to_agents_in_wrap_up           |bool                       |allowCallsToAgentsInWrapUp                                    |
|enable_call_queue_when_no_agents_available |bool                       |enableCallQueueWhenNoAgentsAvailable                          |
|statistics_source                          |str                        |statisticsSource                                              |
</div>


## `GroupCallCenterGetInstanceResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetInstanceRequest16()`.


**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile                         |
|type                                      |str                        |type                                           |
|policy                                    |str                        |policy                                         |
|enable_video                              |bool                       |enableVideo                                    |
|queue_length                              |int                        |queueLength                                    |
|reporting_server_name                     |str                        |reportingServerName *Optional*                 |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit                   |
|escape_digit                              |str                        |escapeDigit                                    |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue *Optional* |
|allow_agent_logoff                        |bool                       |allowAgentLogoff                               |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents                      |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec                    |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec                    |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall                    |
</div>


## `GroupCallCenterGetInstanceResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetInstanceRequest17()`.


**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile                         |
|type                                      |str                        |type                                           |
|policy                                    |str                        |policy                                         |
|enable_video                              |bool                       |enableVideo                                    |
|queue_length                              |int                        |queueLength                                    |
|reporting_server_name                     |str                        |reportingServerName *Optional*                 |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit                   |
|escape_digit                              |str                        |escapeDigit                                    |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue *Optional* |
|allow_agent_logoff                        |bool                       |allowAgentLogoff                               |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents                      |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec                    |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec                    |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall                    |
</div>


## `GroupCallCenterGetInstanceResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetInstanceRequest17sp1()`.


**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile                         |
|type                                      |str                        |type                                           |
|policy                                    |str                        |policy                                         |
|enable_video                              |bool                       |enableVideo                                    |
|queue_length                              |int                        |queueLength                                    |
|enable_reporting                          |bool                       |enableReporting *Optional*                     |
|reporting_server_name                     |str                        |reportingServerName *Optional*                 |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit                   |
|escape_digit                              |str                        |escapeDigit                                    |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue *Optional* |
|allow_agent_logoff                        |bool                       |allowAgentLogoff                               |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents                      |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec                    |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec                    |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall                    |
</div>


## `GroupCallCenterGetInstanceResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetInstanceRequest17sp3()`.

Replaced by `GroupCallCenterGetInstanceResponse19()`

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile                         |
|type                                      |str                        |type                                           |
|policy                                    |str                        |policy                                         |
|enable_video                              |bool                       |enableVideo                                    |
|queue_length                              |int                        |queueLength                                    |
|enable_reporting                          |bool                       |enableReporting *Optional*                     |
|reporting_server_name                     |str                        |reportingServerName *Optional*                 |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit                   |
|escape_digit                              |str                        |escapeDigit                                    |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue            |
|allow_agent_logoff                        |bool                       |allowAgentLogoff                               |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents                      |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec                    |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec                    |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall                    |
</div>


## `GroupCallCenterGetInstanceResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetInstanceRequest19()`.

Replaced by: Response to `GroupCallCenterGetInstanceRequest19sp1()`

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile                         |
|type                                      |str                        |type                                           |
|routing_type                              |str                        |routingType *Optional*                         |
|policy                                    |str                        |policy                                         |
|enable_video                              |bool                       |enableVideo                                    |
|queue_length                              |int                        |queueLength                                    |
|enable_reporting                          |bool                       |enableReporting *Optional*                     |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit                   |
|escape_digit                              |str                        |escapeDigit                                    |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue            |
|allow_agent_logoff                        |bool                       |allowAgentLogoff                               |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents                      |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec                    |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec                    |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall                    |
|call_center_queue_thresholds_is_active    |bool                       |callCenterQueueThresholdsIsActive *Optional*   |
</div>


## `GroupCallCenterGetInstanceResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetInstanceRequest19sp1()`.

Replace by `GroupCallCenterGetInstanceResponse22()`.

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile                         |
|type                                      |str                        |type                                           |
|routing_type                              |str                        |routingType *Optional*                         |
|policy                                    |str                        |policy                                         |
|enable_video                              |bool                       |enableVideo                                    |
|queue_length                              |int                        |queueLength                                    |
|enable_reporting                          |bool                       |enableReporting *Optional*                     |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit                   |
|escape_digit                              |str                        |escapeDigit                                    |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue            |
|allow_agent_logoff                        |bool                       |allowAgentLogoff                               |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents                      |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec                    |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec                    |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall                    |
|call_center_queue_thresholds_is_active    |bool                       |callCenterQueueThresholdsIsActive *Optional*   |
|network_class_of_service                  |str                        |networkClassOfService *Optional*               |
</div>


## `GroupCallCenterGetInstanceResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterGetInstanceRequest22()`.

The following elements are only used in AS data mode and not returned in XS data mode:
routingType enableReporting allowCallsToAgentsInWrapUp overrideAgentWrapUpTime
wrapUpSeconds forceDeliveryOfCalls forceDeliveryWaitTimeSeconds
enableAutomaticStateChangeForAgents agentStateAfterCall agentUnavailableCode
callCenterQueueThresholdsIsActive networkClassOfService

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile                         |
|type                                      |str                        |type                                           |
|routing_type                              |str                        |routingType *Optional*                         |
|policy                                    |str                        |policy                                         |
|enable_video                              |bool                       |enableVideo                                    |
|queue_length                              |int                        |queueLength                                    |
|enable_reporting                          |bool                       |enableReporting *Optional*                     |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit                   |
|escape_digit                              |str                        |escapeDigit                                    |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue            |
|allow_agent_logoff                        |bool                       |allowAgentLogoff                               |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents                      |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec                    |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec                    |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall                    |
|call_center_queue_thresholds_is_active    |bool                       |callCenterQueueThresholdsIsActive *Optional*   |
|network_class_of_service                  |str                        |networkClassOfService *Optional*               |
</div>


## `GroupCallCenterGetInstanceStatisticsResponse13mp8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains Call Center statistics.

Replaced By: `GroupCallCenterGetInstanceStatisticsResponse14sp9()`

**Attributes:**

|Name                       |Type                         |Description                       |
|---------------------------|-----------------------------|----------------------------------|
|number_of_calls_queued_now |int                          |numberOfCallsQueuedNow            |
|generate_daily_report      |bool                         |generateDailyReport               |
|collection_period_minutes  |int                          |collectionPeriodMinutes           |
|reporting_email_address1   |str                          |reportingEmailAddress1 *Optional* |
|reporting_email_address2   |str                          |reportingEmailAddress2 *Optional* |
|queue_statistics_yesterday |OCI.queueStatisticsYesterday |queueStatisticsYesterday          |
|queue_statistics_today     |OCI.queueStatisticsToday     |queueStatisticsToday              |
|agent_statistics           |List[OCI.agentStatistics]    |agentStatistics *Optional*        |
</div>


## `GroupCallCenterGetInstanceStatisticsResponse14sp9`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Contains Call Center statistics.


**Attributes:**

|Name             |Type                      |Description                |
|-----------------|--------------------------|---------------------------|
|statistics_range |OCI.statisticsRange       |statisticsRange            |
|queue_statistics |OCI.queueStatistics       |queueStatistics            |
|agent_statistics |List[OCI.agentStatistics] |agentStatistics *Optional* |
</div>


## `GroupCallCenterHolidayServiceGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterHolidayServiceGetRequest20()`.


**Attributes:**

|Name                            |Type                |Description                    |
|--------------------------------|--------------------|-------------------------------|
|action                          |str                 |action                         |
|holiday_schedule                |OCI.holidaySchedule |holidaySchedule *Optional*     |
|transfer_phone_number           |str                 |transferPhoneNumber *Optional* |
|play_announcement_before_action |bool                |playAnnouncementBeforeAction   |
|audio_message_selection         |str                 |audioMessageSelection          |
|audio_url_list                  |OCI.audioUrlList    |audioUrlList *Optional*        |
|audio_file_list                 |OCI.audioFileList   |audioFileList *Optional*       |
|video_message_selection         |str                 |videoMessageSelection          |
|video_url_list                  |OCI.videoUrlList    |videoUrlList *Optional*        |
|video_file_list                 |OCI.videoFileList   |videoFileList *Optional*       |
</div>


## `GroupCallCenterNightServiceGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterNightServiceGetRequest20()`.


**Attributes:**

|Name                            |Type                    |Description                    |
|--------------------------------|------------------------|-------------------------------|
|action                          |str                     |action                         |
|business_hours                  |OCI.businessHours       |businessHours *Optional*       |
|force_night_service             |bool                    |forceNightService              |
|allow_manual_override_via_fac   |bool                    |allowManualOverrideViaFAC      |
|transfer_phone_number           |str                     |transferPhoneNumber *Optional* |
|play_announcement_before_action |bool                    |playAnnouncementBeforeAction   |
|audio_message_selection         |str                     |audioMessageSelection          |
|audio_url_list                  |OCI.audioUrlList        |audioUrlList *Optional*        |
|audio_file_list                 |OCI.audioFileList       |audioFileList *Optional*       |
|video_message_selection         |str                     |videoMessageSelection          |
|video_url_list                  |OCI.videoUrlList        |videoUrlList *Optional*        |
|video_file_list                 |OCI.videoFileList       |videoFileList *Optional*       |
|manual_announcement_mode        |str                     |manualAnnouncementMode         |
|manual_audio_message_selection  |str                     |manualAudioMessageSelection    |
|manual_audio_url_list           |OCI.manualAudioUrlList  |manualAudioUrlList *Optional*  |
|manual_audio_file_list          |OCI.manualAudioFileList |manualAudioFileList *Optional* |
|manual_video_message_selection  |str                     |manualVideoMessageSelection    |
|manual_video_url_list           |OCI.manualVideoUrlList  |manualVideoUrlList *Optional*  |
|manual_video_file_list          |OCI.manualVideoFileList |manualVideoFileList *Optional* |
</div>


## `GroupCallCenterOverflowGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterOverflowGetRequest20()`.


**Attributes:**

|Name                                         |Type              |Description                              |
|---------------------------------------------|------------------|-----------------------------------------|
|action                                       |str               |action                                   |
|transfer_phone_number                        |str               |transferPhoneNumber *Optional*           |
|overflow_after_timeout                       |bool              |overflowAfterTimeout                     |
|timeout_seconds                              |int               |timeoutSeconds                           |
|play_announcement_before_overflow_processing |bool              |playAnnouncementBeforeOverflowProcessing |
|audio_message_selection                      |str               |audioMessageSelection                    |
|audio_url_list                               |OCI.audioUrlList  |audioUrlList *Optional*                  |
|audio_file_list                              |OCI.audioFileList |audioFileList *Optional*                 |
|video_message_selection                      |str               |videoMessageSelection *Optional*         |
|video_url_list                               |OCI.videoUrlList  |videoUrlList *Optional*                  |
|video_file_list                              |OCI.videoFileList |videoFileList *Optional*                 |
</div>


## `GroupCallCenterStrandedCallGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterStrandedCallGetRequest20()`.


**Attributes:**

|Name                    |Type              |Description                      |
|------------------------|------------------|---------------------------------|
|action                  |str               |action                           |
|transfer_phone_number   |str               |transferPhoneNumber *Optional*   |
|audio_message_selection |str               |audioMessageSelection *Optional* |
|audio_url_list          |OCI.audioUrlList  |audioUrlList *Optional*          |
|audio_file_list         |OCI.audioFileList |audioFileList *Optional*         |
|video_message_selection |str               |videoMessageSelection *Optional* |
|video_url_list          |OCI.videoUrlList  |videoUrlList *Optional*          |
|video_file_list         |OCI.videoFileList |videoFileList *Optional*         |
</div>


## `GroupCallCenterStrandedCallUnavailableGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterStrandedCallUnavailableGetRequest20()`.


**Attributes:**

|Name                                                                 |Type              |Description                                                 |
|---------------------------------------------------------------------|------------------|------------------------------------------------------------|
|condition_policy_on_number_of_agents_with_specified_unavailable_code |bool              |conditionPolicyOnNumberOfAgentsWithSpecifiedUnavailableCode |
|number_of_agents_with_specified_unavailable_code                     |int               |numberOfAgentsWithSpecifiedUnavailableCode *Optional*       |
|agents_unavailable_code                                              |str               |agentsUnavailableCode *Optional*                            |
|action                                                               |str               |action                                                      |
|transfer_phone_number                                                |str               |transferPhoneNumber *Optional*                              |
|audio_message_selection                                              |str               |audioMessageSelection *Optional*                            |
|audio_url_list                                                       |OCI.audioUrlList  |audioUrlList *Optional*                                     |
|audio_file_list                                                      |OCI.audioFileList |audioFileList *Optional*                                    |
|video_message_selection                                              |str               |videoMessageSelection *Optional*                            |
|video_url_list                                                       |OCI.videoUrlList  |videoUrlList *Optional*                                     |
|video_file_list                                                      |OCI.videoFileList |videoFileList *Optional*                                    |
</div>


## `GroupCollaborateBridgeGetInstanceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCollaborateBridgeGetInstanceRequest()`.

The system-level collaborate supportOutdial setting is returned in the response when
the system-level collaborate supportOutdial setting is disabled.  Contains the service
profile information and a table of assigned owners.  The table has column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name",
Phone Number", "Extension", "Department", "Email Address". Collaborate bridge maximum
participant's choices unlimited or a quantified number of participants.  Replaced by:
`GroupCollaborateBridgeGetInstanceResponse20sp1()`

**Attributes:**

|Name                              |Type                            |Description                                                                                    |
|----------------------------------|--------------------------------|-----------------------------------------------------------------------------------------------|
|service_instance_profile          |OCI.serviceInstanceProfile      |serviceInstanceProfile                                                                         |
|maximum_bridge_participants       |OCI.maximumBridgeParticipants   |maximumBridgeParticipants                                                                      |
|network_class_of_service          |str                             |networkClassOfService *Optional*                                                               |
|is_default                        |bool                            |isDefault                                                                                      |
|max_collaborate_room_participants |int                             |maxCollaborateRoomParticipants                                                                 |
|support_outdial                   |bool                            |supportOutdial                                                                                 |
|collaborate_owner_user_table      |List(collaborateOwnerUserTable) |collaborateOwnerUserTable - *Table* array of collaborateOwnerUserTable named tuples *Optional* |
</div>


## `GroupCollaborateBridgeGetInstanceResponse20sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCollaborateBridgeGetInstanceRequest20sp1()`.

The system-level collaborate supportOutdial setting is returned in the response when
the system-level collaborate supportOutdial setting is disabled.  Contains the service
profile information and a table of assigned owners.  The table has column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name",
Phone Number", "Extension", "Department", "Email Address", "Is Phone Number
Activated", "Country Code", "National Prefix", "Department Name", "Department Type",
"Parent Department", "Parent Department Type", "Group Id", "Group Name". Collaborate
bridge maximum participant’s choices unlimited or a quantified number of participants.

**Attributes:**

|Name                              |Type                            |Description                                                                                    |
|----------------------------------|--------------------------------|-----------------------------------------------------------------------------------------------|
|service_instance_profile          |OCI.serviceInstanceProfile      |serviceInstanceProfile                                                                         |
|maximum_bridge_participants       |OCI.maximumBridgeParticipants   |maximumBridgeParticipants                                                                      |
|network_class_of_service          |str                             |networkClassOfService *Optional*                                                               |
|is_default                        |bool                            |isDefault                                                                                      |
|max_collaborate_room_participants |int                             |maxCollaborateRoomParticipants                                                                 |
|support_outdial                   |bool                            |supportOutdial                                                                                 |
|collaborate_owner_user_table      |List(collaborateOwnerUserTable) |collaborateOwnerUserTable - *Table* array of collaborateOwnerUserTable named tuples *Optional* |
</div>


## `GroupFindMeFollowMeGetInstanceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupFindMeFollowMeGetInstanceRequest()`.

Contains the service profile information.  Replaced by:
`GroupFindMeFollowMeGetInstanceResponse19sp1()`

**Attributes:**

|Name                     |Type                       |Description                      |
|-------------------------|---------------------------|---------------------------------|
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|network_class_of_service |str                        |networkClassOfService *Optional* |
</div>


## `GroupFindMeFollowMeGetInstanceResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupFindMeFollowMeGetInstanceRequest19sp1()`.

Contains the service profile information.

**Attributes:**

|Name                     |Type                       |Description                      |
|-------------------------|---------------------------|---------------------------------|
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|network_class_of_service |str                        |networkClassOfService *Optional* |
</div>


## `GroupFlexibleSeatingHostGetInstanceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupFlexibleSeatingHostGetInstanceRequest()`.

Contains the service profile and access device information.

**Attributes:**

|Name                     |Type                       |Description                      |
|-------------------------|---------------------------|---------------------------------|
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|default_alias            |str                        |defaultAlias                     |
|access_device_endpoint   |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*  |
|network_class_of_service |str                        |networkClassOfService *Optional* |
</div>


## `GroupFlexibleSeatingHostGetInstanceResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupFlexibleSeatingHostGetInstanceRequest22()`.

Contains the service profile and access device information.

**Attributes:**

|Name                     |Type                       |Description                      |
|-------------------------|---------------------------|---------------------------------|
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|default_alias            |str                        |defaultAlias                     |
|access_device_endpoint   |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*  |
|network_class_of_service |str                        |networkClassOfService *Optional* |
</div>


## `GroupGetAvailableTreeDeviceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupGetAvailableTreeDeviceListRequest()`.


**Attributes:**

|Name             |Type                     |Description               |
|-----------------|-------------------------|--------------------------|
|tree_device_info |List[OCI.treeDeviceInfo] |treeDeviceInfo *Optional* |
</div>


## `GroupGroupPagingGetInstanceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Replaced By `GroupGroupPagingGetInstanceResponse17sp3()` Response to
`GroupGroupPagingGetInstanceRequest()`.

Contains the service profile information.

**Attributes:**

|Name                              |Type                       |Description                     |
|----------------------------------|---------------------------|--------------------------------|
|service_instance_profile          |OCI.serviceInstanceProfile |serviceInstanceProfile          |
|confirmation_tone_timeout_seconds |int                        |confirmationToneTimeoutSeconds  |
|deliver_originator_clid_instead   |bool                       |deliverOriginatorCLIDInstead    |
|originator_clid_prefix            |str                        |originatorCLIDPrefix *Optional* |
</div>


## `GroupGroupPagingGetInstanceResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupGroupPagingGetInstanceRequest17sp3()`.

Contains the service profile information.  Replaced by:
`GroupGroupPagingGetInstanceResponse19sp1()`

**Attributes:**

|Name                              |Type                       |Description                     |
|----------------------------------|---------------------------|--------------------------------|
|service_instance_profile          |OCI.serviceInstanceProfile |serviceInstanceProfile          |
|confirmation_tone_timeout_seconds |int                        |confirmationToneTimeoutSeconds  |
|deliver_originator_clid_instead   |bool                       |deliverOriginatorCLIDInstead    |
|originator_clid_prefix            |str                        |originatorCLIDPrefix *Optional* |
</div>


## `GroupGroupPagingGetInstanceResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupGroupPagingGetInstanceRequest19sp1()`.

Contains the service profile information.  The following element is only used in AS
data mode and not returned in XS data mode : networkClassOfService

**Attributes:**

|Name                              |Type                       |Description                      |
|----------------------------------|---------------------------|---------------------------------|
|service_instance_profile          |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|confirmation_tone_timeout_seconds |int                        |confirmationToneTimeoutSeconds   |
|deliver_originator_clid_instead   |bool                       |deliverOriginatorCLIDInstead     |
|originator_clid_prefix            |str                        |originatorCLIDPrefix *Optional*  |
|network_class_of_service          |str                        |networkClassOfService *Optional* |
</div>


## `GroupHuntGroupGetInstanceResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupHuntGroupGetInstanceRequest14()`.

Contains the service profile information and a table of assigned users.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Weight".

**Attributes:**

|Name                          |Type                       |Description                                                   |
|------------------------------|---------------------------|--------------------------------------------------------------|
|service_instance_profile      |OCI.serviceInstanceProfile |serviceInstanceProfile                                        |
|policy                        |str                        |policy                                                        |
|hunt_after_no_answer          |bool                       |huntAfterNoAnswer                                             |
|no_answer_number_of_rings     |int                        |noAnswerNumberOfRings                                         |
|forward_after_timeout         |bool                       |forwardAfterTimeout                                           |
|forward_timeout_seconds       |int                        |forwardTimeoutSeconds                                         |
|forward_to_phone_number       |str                        |forwardToPhoneNumber *Optional*                               |
|agent_user_table              |List(agentUserTable)       |agentUserTable - *Table* array of agentUserTable named tuples |
|allow_call_waiting_for_agents |bool                       |allowCallWaitingForAgents                                     |
</div>


## `GroupHuntGroupGetInstanceResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupHuntGroupGetInstanceRequest17()`.

Contains the service profile information and a table of assigned users.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Weight".

**Attributes:**

|Name                          |Type                       |Description                                                   |
|------------------------------|---------------------------|--------------------------------------------------------------|
|service_instance_profile      |OCI.serviceInstanceProfile |serviceInstanceProfile                                        |
|policy                        |str                        |policy                                                        |
|hunt_after_no_answer          |bool                       |huntAfterNoAnswer                                             |
|no_answer_number_of_rings     |int                        |noAnswerNumberOfRings                                         |
|forward_after_timeout         |bool                       |forwardAfterTimeout                                           |
|forward_timeout_seconds       |int                        |forwardTimeoutSeconds                                         |
|forward_to_phone_number       |str                        |forwardToPhoneNumber *Optional*                               |
|agent_user_table              |List(agentUserTable)       |agentUserTable - *Table* array of agentUserTable named tuples |
|allow_call_waiting_for_agents |bool                       |allowCallWaitingForAgents                                     |
</div>


## `GroupHuntGroupGetInstanceResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupHuntGroupGetInstanceRequest17sp3()`.

Contains the service profile information and a table of assigned users.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Weight". The following elements are only used in AS data mode:
useSystemHuntGroupCLIDSetting includeHuntGroupNameInCLID

**Attributes:**

|Name                               |Type                       |Description                                                   |
|-----------------------------------|---------------------------|--------------------------------------------------------------|
|service_instance_profile           |OCI.serviceInstanceProfile |serviceInstanceProfile                                        |
|policy                             |str                        |policy                                                        |
|hunt_after_no_answer               |bool                       |huntAfterNoAnswer                                             |
|no_answer_number_of_rings          |int                        |noAnswerNumberOfRings                                         |
|forward_after_timeout              |bool                       |forwardAfterTimeout                                           |
|forward_timeout_seconds            |int                        |forwardTimeoutSeconds                                         |
|forward_to_phone_number            |str                        |forwardToPhoneNumber *Optional*                               |
|agent_user_table                   |List(agentUserTable)       |agentUserTable - *Table* array of agentUserTable named tuples |
|allow_call_waiting_for_agents      |bool                       |allowCallWaitingForAgents                                     |
|use_system_hunt_group_clid_setting |bool                       |useSystemHuntGroupCLIDSetting                                 |
|include_hunt_group_name_in_clid    |bool                       |includeHuntGroupNameInCLID                                    |
</div>


## `GroupHuntGroupGetInstanceResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupHuntGroupGetInstanceRequest17sp4()`.

Contains the service profile information and a table of assigned users.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Weight", "Phone Number", "Extension", "Department", "Email Address". The
following elements are only used in AS data mode: useSystemHuntGroupCLIDSetting
includeHuntGroupNameInCLID

**Attributes:**

|Name                                  |Type                       |Description                                                   |
|--------------------------------------|---------------------------|--------------------------------------------------------------|
|service_instance_profile              |OCI.serviceInstanceProfile |serviceInstanceProfile                                        |
|policy                                |str                        |policy                                                        |
|hunt_after_no_answer                  |bool                       |huntAfterNoAnswer                                             |
|no_answer_number_of_rings             |int                        |noAnswerNumberOfRings                                         |
|forward_after_timeout                 |bool                       |forwardAfterTimeout                                           |
|forward_timeout_seconds               |int                        |forwardTimeoutSeconds                                         |
|forward_to_phone_number               |str                        |forwardToPhoneNumber *Optional*                               |
|agent_user_table                      |List(agentUserTable)       |agentUserTable - *Table* array of agentUserTable named tuples |
|allow_call_waiting_for_agents         |bool                       |allowCallWaitingForAgents                                     |
|use_system_hunt_group_clid_setting    |bool                       |useSystemHuntGroupCLIDSetting                                 |
|include_hunt_group_name_in_clid       |bool                       |includeHuntGroupNameInCLID                                    |
|enable_not_reachable_forwarding       |bool                       |enableNotReachableForwarding                                  |
|not_reachable_forward_to_phone_number |str                        |notReachableForwardToPhoneNumber *Optional*                   |
|make_busy_when_not_reachable          |bool                       |makeBusyWhenNotReachable                                      |
</div>


## `GroupHuntGroupGetInstanceResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupHuntGroupGetInstanceRequest19()`.

Contains the service profile information and a table of assigned users.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Weight", "Phone Number", "Extension", "Department", "Email Address". The
following elements are only used in AS data mode: useSystemHuntGroupCLIDSetting, value
"true" is returned in XS data mode includeHuntGroupNameInCLID, value "true" is
returned in XS data mode The following elements are only used in XS data mode:
allowMembersToControlGroupBusy enableGroupBusy Replaced by:
`GroupHuntGroupGetInstanceResponse19sp1()` in AS data mode

**Attributes:**

|Name                                  |Type                       |Description                                                   |
|--------------------------------------|---------------------------|--------------------------------------------------------------|
|service_instance_profile              |OCI.serviceInstanceProfile |serviceInstanceProfile                                        |
|policy                                |str                        |policy                                                        |
|hunt_after_no_answer                  |bool                       |huntAfterNoAnswer                                             |
|no_answer_number_of_rings             |int                        |noAnswerNumberOfRings                                         |
|forward_after_timeout                 |bool                       |forwardAfterTimeout                                           |
|forward_timeout_seconds               |int                        |forwardTimeoutSeconds                                         |
|forward_to_phone_number               |str                        |forwardToPhoneNumber *Optional*                               |
|agent_user_table                      |List(agentUserTable)       |agentUserTable - *Table* array of agentUserTable named tuples |
|allow_call_waiting_for_agents         |bool                       |allowCallWaitingForAgents                                     |
|use_system_hunt_group_clid_setting    |bool                       |useSystemHuntGroupCLIDSetting                                 |
|include_hunt_group_name_in_clid       |bool                       |includeHuntGroupNameInCLID                                    |
|enable_not_reachable_forwarding       |bool                       |enableNotReachableForwarding                                  |
|not_reachable_forward_to_phone_number |str                        |notReachableForwardToPhoneNumber *Optional*                   |
|make_busy_when_not_reachable          |bool                       |makeBusyWhenNotReachable                                      |
|allow_members_to_control_group_busy   |bool                       |allowMembersToControlGroupBusy                                |
|enable_group_busy                     |bool                       |enableGroupBusy                                               |
</div>


## `GroupHuntGroupGetInstanceResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupHuntGroupGetInstanceRequest19sp1()`.

Contains the service profile information and a table of assigned users.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Weight", "Phone Number", "Extension", "Department", "Email Address". The
following elements are only used in AS data mode: useSystemHuntGroupCLIDSetting
includeHuntGroupNameInCLID The following elements are only used in XS data mode:
allowMembersToControlGroupBusy enableGroupBusy Replaced by:
`GroupHuntGroupGetInstanceResponse20()`

**Attributes:**

|Name                                  |Type                       |Description                                                   |
|--------------------------------------|---------------------------|--------------------------------------------------------------|
|service_instance_profile              |OCI.serviceInstanceProfile |serviceInstanceProfile                                        |
|policy                                |str                        |policy                                                        |
|hunt_after_no_answer                  |bool                       |huntAfterNoAnswer                                             |
|no_answer_number_of_rings             |int                        |noAnswerNumberOfRings                                         |
|forward_after_timeout                 |bool                       |forwardAfterTimeout                                           |
|forward_timeout_seconds               |int                        |forwardTimeoutSeconds                                         |
|forward_to_phone_number               |str                        |forwardToPhoneNumber *Optional*                               |
|agent_user_table                      |List(agentUserTable)       |agentUserTable - *Table* array of agentUserTable named tuples |
|allow_call_waiting_for_agents         |bool                       |allowCallWaitingForAgents                                     |
|use_system_hunt_group_clid_setting    |bool                       |useSystemHuntGroupCLIDSetting                                 |
|include_hunt_group_name_in_clid       |bool                       |includeHuntGroupNameInCLID                                    |
|enable_not_reachable_forwarding       |bool                       |enableNotReachableForwarding                                  |
|not_reachable_forward_to_phone_number |str                        |notReachableForwardToPhoneNumber *Optional*                   |
|make_busy_when_not_reachable          |bool                       |makeBusyWhenNotReachable                                      |
|allow_members_to_control_group_busy   |bool                       |allowMembersToControlGroupBusy                                |
|enable_group_busy                     |bool                       |enableGroupBusy                                               |
|network_class_of_service              |str                        |networkClassOfService *Optional*                              |
</div>


## `GroupHuntGroupGetInstanceResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupHuntGroupGetInstanceRequest20()`.

Contains the service profile information and a table of assigned users.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", "Weight", "Phone Number", "Extension", "Department", "Email Address", "Is
Phone Number Activated", "Country Code","National Prefix", "Department Name"
,"Department Type", "Parent Department", "Parent Department Type","Group Id","Group
Name". The following elements are only used in AS data mode:
useSystemHuntGroupCLIDSetting includeHuntGroupNameInCLID Is Phone Number Activated
Country Code National Prefix Department Name Department Type Parent Department Parent
Department Type Group Id Group Name

**Attributes:**

|Name                                       |Type                       |Description                                                   |
|-------------------------------------------|---------------------------|--------------------------------------------------------------|
|service_instance_profile                   |OCI.serviceInstanceProfile |serviceInstanceProfile                                        |
|policy                                     |str                        |policy                                                        |
|hunt_after_no_answer                       |bool                       |huntAfterNoAnswer                                             |
|no_answer_number_of_rings                  |int                        |noAnswerNumberOfRings                                         |
|forward_after_timeout                      |bool                       |forwardAfterTimeout                                           |
|forward_timeout_seconds                    |int                        |forwardTimeoutSeconds                                         |
|forward_to_phone_number                    |str                        |forwardToPhoneNumber *Optional*                               |
|agent_user_table                           |List(agentUserTable)       |agentUserTable - *Table* array of agentUserTable named tuples |
|allow_call_waiting_for_agents              |bool                       |allowCallWaitingForAgents                                     |
|use_system_hunt_group_clid_setting         |bool                       |useSystemHuntGroupCLIDSetting                                 |
|include_hunt_group_name_in_clid            |bool                       |includeHuntGroupNameInCLID                                    |
|enable_not_reachable_forwarding            |bool                       |enableNotReachableForwarding                                  |
|not_reachable_forward_to_phone_number      |str                        |notReachableForwardToPhoneNumber *Optional*                   |
|make_busy_when_not_reachable               |bool                       |makeBusyWhenNotReachable                                      |
|allow_members_to_control_group_busy        |bool                       |allowMembersToControlGroupBusy                                |
|enable_group_busy                          |bool                       |enableGroupBusy                                               |
|apply_group_busy_when_terminating_to_agent |bool                       |applyGroupBusyWhenTerminatingToAgent                          |
|network_class_of_service                   |str                        |networkClassOfService *Optional*                              |
</div>


## `GroupIncomingCallingPlanGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupIncomingCallingPlanGetListRequest()`.


**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|group_permissions      |OCI.groupPermissions            |groupPermissions                 |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupInstantGroupCallGetInstanceResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupInstantGroupCallGetInstanceRequest14()`.

Contains the service profile information and a list of phone numbers.

**Attributes:**

|Name                      |Type                       |Description                       |
|--------------------------|---------------------------|----------------------------------|
|service_instance_profile  |OCI.serviceInstanceProfile |serviceInstanceProfile            |
|destination_phone_number  |List[str]                  |destinationPhoneNumber *Optional* |
|is_answer_timeout_enabled |bool                       |isAnswerTimeoutEnabled            |
|answer_timeout_minutes    |int                        |answerTimeoutMinutes *Optional*   |
</div>


## `GroupInstantGroupCallGetInstanceResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupInstantGroupCallGetInstanceRequest17()`.

Contains the service profile information and a list of phone numbers.  Replaced by:
`GroupInstantGroupCallGetInstanceResponse19sp1()`

**Attributes:**

|Name                      |Type                       |Description                       |
|--------------------------|---------------------------|----------------------------------|
|service_instance_profile  |OCI.serviceInstanceProfile |serviceInstanceProfile            |
|destination_phone_number  |List[str]                  |destinationPhoneNumber *Optional* |
|is_answer_timeout_enabled |bool                       |isAnswerTimeoutEnabled            |
|answer_timeout_minutes    |int                        |answerTimeoutMinutes *Optional*   |
</div>


## `GroupInstantGroupCallGetInstanceResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupInstantGroupCallGetInstanceRequest19sp1()`.

Contains the service profile information and a list of phone numbers.

**Attributes:**

|Name                      |Type                       |Description                       |
|--------------------------|---------------------------|----------------------------------|
|service_instance_profile  |OCI.serviceInstanceProfile |serviceInstanceProfile            |
|destination_phone_number  |List[str]                  |destinationPhoneNumber *Optional* |
|is_answer_timeout_enabled |bool                       |isAnswerTimeoutEnabled            |
|answer_timeout_minutes    |int                        |answerTimeoutMinutes *Optional*   |
|network_class_of_service  |str                        |networkClassOfService *Optional*  |
</div>


## `GroupMWIDeliveryToMobileEndpointCustomTemplateGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMWIDeliveryToMobileEndpointCustomTemplateGetRequest()`.


**Attributes:**

|Name          |Type             |Description  |
|--------------|-----------------|-------------|
|is_enabled    |bool             |isEnabled    |
|template_body |OCI.templateBody |templateBody |
</div>


## `GroupMeetMeConferencingGetInstanceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupMeetMeConferencingGetInstanceRequest()`.

Contains the service profile information and a table of assigned hosts.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", and
"Hiragana First Name".

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|service_instance_profile   |OCI.serviceInstanceProfile    |serviceInstanceProfile                                                          |
|allocated_ports            |OCI.allocatedPorts            |allocatedPorts                                                                  |
|network_class_of_service   |str                           |networkClassOfService *Optional*                                                |
|allow_individual_out_dial  |bool                          |allowIndividualOutDial                                                          |
|operator_number            |str                           |operatorNumber *Optional*                                                       |
|conference_host_user_table |List(conferenceHostUserTable) |conferenceHostUserTable - *Table* array of conferenceHostUserTable named tuples |
</div>


## `GroupMeetMeConferencingGetInstanceResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupMeetMeConferencingGetInstanceRequest17sp3()`.

Contains the service profile information and a table of assigned hosts.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", and
"Hiragana First Name".

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|service_instance_profile   |OCI.serviceInstanceProfile    |serviceInstanceProfile                                                          |
|allocated_ports            |OCI.allocatedPorts            |allocatedPorts                                                                  |
|network_class_of_service   |str                           |networkClassOfService *Optional*                                                |
|allow_individual_out_dial  |bool                          |allowIndividualOutDial                                                          |
|operator_number            |str                           |operatorNumber *Optional*                                                       |
|conference_host_user_table |List(conferenceHostUserTable) |conferenceHostUserTable - *Table* array of conferenceHostUserTable named tuples |
</div>


## `GroupMeetMeConferencingGetInstanceResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupMeetMeConferencingGetInstanceRequest17sp4()`.

Contains the service profile information and a table of assigned hosts.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", and
"Hiragana First Name".

**Attributes:**

|Name                       |Type                          |Description                                                                     |
|---------------------------|------------------------------|--------------------------------------------------------------------------------|
|service_instance_profile   |OCI.serviceInstanceProfile    |serviceInstanceProfile                                                          |
|allocated_ports            |OCI.allocatedPorts            |allocatedPorts                                                                  |
|network_class_of_service   |str                           |networkClassOfService *Optional*                                                |
|allow_individual_out_dial  |bool                          |allowIndividualOutDial                                                          |
|operator_number            |str                           |operatorNumber *Optional*                                                       |
|conference_host_user_table |List(conferenceHostUserTable) |conferenceHostUserTable - *Table* array of conferenceHostUserTable named tuples |
</div>


## `GroupMeetMeConferencingGetInstanceResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupMeetMeConferencingGetInstanceRequest18()`.

Contains the service profile information and a table of assigned hosts.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", Phone Number", "Extension", "Department", "Email Address".

**Attributes:**

|Name                                  |Type                             |Description                                                                     |
|--------------------------------------|---------------------------------|--------------------------------------------------------------------------------|
|service_instance_profile              |OCI.serviceInstanceProfile       |serviceInstanceProfile                                                          |
|allocated_ports                       |OCI.allocatedPorts               |allocatedPorts                                                                  |
|network_class_of_service              |str                              |networkClassOfService *Optional*                                                |
|allow_individual_out_dial             |bool                             |allowIndividualOutDial                                                          |
|operator_number                       |str                              |operatorNumber *Optional*                                                       |
|conference_host_user_table            |List(conferenceHostUserTable)    |conferenceHostUserTable - *Table* array of conferenceHostUserTable named tuples |
|play_warning_prompt                   |bool                             |playWarningPrompt                                                               |
|conference_end_warning_prompt_minutes |int                              |conferenceEndWarningPromptMinutes                                               |
|enable_max_conference_duration        |bool                             |enableMaxConferenceDuration                                                     |
|max_conference_duration_minutes       |OCI.maxConferenceDurationMinutes |maxConferenceDurationMinutes                                                    |
</div>


## `GroupMeetMeConferencingGetInstanceResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupMeetMeConferencingGetInstanceRequest19()`.

Contains the service profile information and a table of assigned hosts.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", Phone Number", "Extension", "Department", "Email Address". Replaced by:
`GroupMeetMeConferencingGetInstanceResponse19sp1()`

**Attributes:**

|Name                                      |Type                                      |Description                                                                     |
|------------------------------------------|------------------------------------------|--------------------------------------------------------------------------------|
|service_instance_profile                  |OCI.serviceInstanceProfile                |serviceInstanceProfile                                                          |
|allocated_ports                           |OCI.allocatedPorts                        |allocatedPorts                                                                  |
|network_class_of_service                  |str                                       |networkClassOfService *Optional*                                                |
|security_pin_length                       |int                                       |securityPinLength                                                               |
|allow_individual_out_dial                 |bool                                      |allowIndividualOutDial                                                          |
|operator_number                           |str                                       |operatorNumber *Optional*                                                       |
|conference_host_user_table                |List(conferenceHostUserTable)             |conferenceHostUserTable - *Table* array of conferenceHostUserTable named tuples |
|play_warning_prompt                       |bool                                      |playWarningPrompt                                                               |
|conference_end_warning_prompt_minutes     |int                                       |conferenceEndWarningPromptMinutes                                               |
|enable_max_conference_duration            |bool                                      |enableMaxConferenceDuration                                                     |
|max_conference_duration_minutes           |OCI.maxConferenceDurationMinutes          |maxConferenceDurationMinutes                                                    |
|max_scheduled_conference_duration_minutes |OCI.maxScheduledConferenceDurationMinutes |maxScheduledConferenceDurationMinutes                                           |
</div>


## `GroupMeetMeConferencingGetInstanceResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupMeetMeConferencingGetInstanceRequest19sp1()`.

Contains the service profile information and a table of assigned hosts.  The table has
column headings: "User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana
First Name", Phone Number", "Extension", "Department", "Email Address".

**Attributes:**

|Name                                      |Type                                      |Description                                                                     |
|------------------------------------------|------------------------------------------|--------------------------------------------------------------------------------|
|service_instance_profile                  |OCI.serviceInstanceProfile                |serviceInstanceProfile                                                          |
|allocated_ports                           |OCI.allocatedPorts                        |allocatedPorts                                                                  |
|network_class_of_service                  |str                                       |networkClassOfService *Optional*                                                |
|security_pin_length                       |int                                       |securityPinLength                                                               |
|allow_individual_out_dial                 |bool                                      |allowIndividualOutDial                                                          |
|operator_number                           |str                                       |operatorNumber *Optional*                                                       |
|conference_host_user_table                |List(conferenceHostUserTable)             |conferenceHostUserTable - *Table* array of conferenceHostUserTable named tuples |
|play_warning_prompt                       |bool                                      |playWarningPrompt                                                               |
|conference_end_warning_prompt_minutes     |int                                       |conferenceEndWarningPromptMinutes                                               |
|enable_max_conference_duration            |bool                                      |enableMaxConferenceDuration                                                     |
|max_conference_duration_minutes           |OCI.maxConferenceDurationMinutes          |maxConferenceDurationMinutes                                                    |
|max_scheduled_conference_duration_minutes |OCI.maxScheduledConferenceDurationMinutes |maxScheduledConferenceDurationMinutes                                           |
</div>


## `GroupMusicOnHoldGetInstanceResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMusicOnHoldGetInstanceRequest14()`.


**Attributes:**

|Name                       |Type                     |Description                     |
|---------------------------|-------------------------|--------------------------------|
|service_user_id            |str                      |serviceUserId                   |
|is_active_during_call_hold |bool                     |isActiveDuringCallHold          |
|is_active_during_call_park |bool                     |isActiveDuringCallPark          |
|message_selection          |str                      |messageSelection                |
|access_device_endpoint     |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional* |
|enable_video               |bool                     |enableVideo                     |
|audio_file_description     |str                      |audioFileDescription *Optional* |
|video_file_description     |str                      |videoFileDescription *Optional* |
</div>


## `GroupMusicOnHoldGetInstanceResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupMusicOnHoldGetInstanceRequest14sp4()`.


**Attributes:**

|Name                          |Type                     |Description                     |
|------------------------------|-------------------------|--------------------------------|
|service_user_id               |str                      |serviceUserId                   |
|is_active_during_call_hold    |bool                     |isActiveDuringCallHold          |
|is_active_during_call_park    |bool                     |isActiveDuringCallPark          |
|is_active_during_busy_camp_on |bool                     |isActiveDuringBusyCampOn        |
|message_selection             |str                      |messageSelection                |
|access_device_endpoint        |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional* |
|enable_video                  |bool                     |enableVideo                     |
|audio_file_description        |str                      |audioFileDescription *Optional* |
|video_file_description        |str                      |videoFileDescription *Optional* |
</div>


## `GroupOutgoingCallingPlanAuthorizationCodeGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanAuthorizationCodeGetListRequest()`.


**Attributes:**

|Name                 |Type                         |Description                   |
|---------------------|-----------------------------|------------------------------|
|group_code_list      |OCI.groupCodeList            |groupCodeList                 |
|department_code_list |List[OCI.departmentCodeList] |departmentCodeList *Optional* |
</div>


## `GroupOutgoingCallingPlanCallMeNowGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanCallMeNowGetListRequest()`.


**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|group_permissions      |OCI.groupPermissions            |groupPermissions                 |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanOriginatingGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanOriginatingGetListRequest()`.


**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|group_permissions      |OCI.groupPermissions            |groupPermissions                 |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanRedirectedGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanRedirectedGetListRequest()`.


**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|group_permissions      |OCI.groupPermissions            |groupPermissions                 |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanRedirectingGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanRedirectingGetListRequest()`.


**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|group_permissions      |OCI.groupPermissions            |groupPermissions                 |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanTransferNumbersGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanTransferNumbersGetListRequest()`.


**Attributes:**

|Name               |Type                        |Description                  |
|-------------------|----------------------------|-----------------------------|
|group_numbers      |OCI.groupNumbers            |groupNumbers                 |
|department_numbers |List[OCI.departmentNumbers] |departmentNumbers *Optional* |
</div>


## `GroupRoutePointForcedForwardingGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointForcedForwardingGetRequest20()`.


**Attributes:**

|Name                                |Type              |Description                      |
|------------------------------------|------------------|---------------------------------|
|is_active                           |bool              |isActive                         |
|forward_to_phone_number             |str               |forwardToPhoneNumber *Optional*  |
|play_announcement_before_forwarding |bool              |playAnnouncementBeforeForwarding |
|audio_message_selection             |str               |audioMessageSelection            |
|audio_url_list                      |OCI.audioUrlList  |audioUrlList *Optional*          |
|audio_file_list                     |OCI.audioFileList |audioFileList *Optional*         |
|video_message_selection             |str               |videoMessageSelection            |
|video_url_list                      |OCI.videoUrlList  |videoUrlList *Optional*          |
|video_file_list                     |OCI.videoFileList |videoFileList *Optional*         |
</div>


## `GroupRoutePointGetInstanceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupRoutePointGetInstanceRequest()`.

Replaced by: `GroupRoutePointGetInstanceResponse19sp1()`

**Attributes:**

|Name                                     |Type                       |Description                             |
|-----------------------------------------|---------------------------|----------------------------------------|
|service_instance_profile                 |OCI.serviceInstanceProfile |serviceInstanceProfile                  |
|network_class_of_service                 |str                        |networkClassOfService *Optional*        |
|external_preferred_audio_codec           |str                        |externalPreferredAudioCodec             |
|internal_preferred_audio_codec           |str                        |internalPreferredAudioCodec             |
|queue_length                             |int                        |queueLength                             |
|no_answer_timeout_rings                  |int                        |noAnswerTimeoutRings                    |
|enable_video                             |bool                       |enableVideo                             |
|play_ringing_when_offering_call          |bool                       |playRingingWhenOfferingCall             |
|override_agent_wrap_up_time              |bool                       |overrideAgentWrapUpTime                 |
|wrap_up_seconds                          |int                        |wrapUpSeconds *Optional*                |
|enable_automatic_state_change_for_agents |bool                       |enableAutomaticStateChangeForAgents     |
|agent_state_after_call                   |str                        |agentStateAfterCall                     |
|agent_unavailable_code                   |str                        |agentUnavailableCode *Optional*         |
|force_delivery_of_calls                  |bool                       |forceDeliveryOfCalls                    |
|force_delivery_wait_time_seconds         |int                        |forceDeliveryWaitTimeSeconds *Optional* |
</div>


## `GroupRoutePointGetInstanceResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupRoutePointGetInstanceRequest19sp1()`.

Replace by `GroupRoutePointGetInstanceResponse22()`.

**Attributes:**

|Name                                     |Type                       |Description                             |
|-----------------------------------------|---------------------------|----------------------------------------|
|service_instance_profile                 |OCI.serviceInstanceProfile |serviceInstanceProfile                  |
|network_class_of_service                 |str                        |networkClassOfService *Optional*        |
|external_preferred_audio_codec           |str                        |externalPreferredAudioCodec             |
|internal_preferred_audio_codec           |str                        |internalPreferredAudioCodec             |
|queue_length                             |int                        |queueLength                             |
|no_answer_timeout_rings                  |int                        |noAnswerTimeoutRings                    |
|enable_video                             |bool                       |enableVideo                             |
|play_ringing_when_offering_call          |bool                       |playRingingWhenOfferingCall             |
|override_agent_wrap_up_time              |bool                       |overrideAgentWrapUpTime                 |
|wrap_up_seconds                          |int                        |wrapUpSeconds *Optional*                |
|enable_automatic_state_change_for_agents |bool                       |enableAutomaticStateChangeForAgents     |
|agent_state_after_call                   |str                        |agentStateAfterCall                     |
|agent_unavailable_code                   |str                        |agentUnavailableCode *Optional*         |
|force_delivery_of_calls                  |bool                       |forceDeliveryOfCalls                    |
|force_delivery_wait_time_seconds         |int                        |forceDeliveryWaitTimeSeconds *Optional* |
</div>


## `GroupRoutePointGetInstanceResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupRoutePointGetInstanceRequest22()`.


**Attributes:**

|Name                                     |Type                       |Description                             |
|-----------------------------------------|---------------------------|----------------------------------------|
|service_instance_profile                 |OCI.serviceInstanceProfile |serviceInstanceProfile                  |
|network_class_of_service                 |str                        |networkClassOfService *Optional*        |
|external_preferred_audio_codec           |str                        |externalPreferredAudioCodec             |
|internal_preferred_audio_codec           |str                        |internalPreferredAudioCodec             |
|queue_length                             |int                        |queueLength                             |
|no_answer_timeout_rings                  |int                        |noAnswerTimeoutRings                    |
|enable_video                             |bool                       |enableVideo                             |
|play_ringing_when_offering_call          |bool                       |playRingingWhenOfferingCall             |
|override_agent_wrap_up_time              |bool                       |overrideAgentWrapUpTime                 |
|wrap_up_seconds                          |int                        |wrapUpSeconds *Optional*                |
|enable_automatic_state_change_for_agents |bool                       |enableAutomaticStateChangeForAgents     |
|agent_state_after_call                   |str                        |agentStateAfterCall                     |
|agent_unavailable_code                   |str                        |agentUnavailableCode *Optional*         |
|force_delivery_of_calls                  |bool                       |forceDeliveryOfCalls                    |
|force_delivery_wait_time_seconds         |int                        |forceDeliveryWaitTimeSeconds *Optional* |
</div>


## `GroupRoutePointGetInstanceResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupRoutePointGetInstanceRequest23()`.


**Attributes:**

|Name                                     |Type                       |Description                             |
|-----------------------------------------|---------------------------|----------------------------------------|
|service_instance_profile                 |OCI.serviceInstanceProfile |serviceInstanceProfile                  |
|network_class_of_service                 |str                        |networkClassOfService *Optional*        |
|external_preferred_audio_codec           |str                        |externalPreferredAudioCodec             |
|internal_preferred_audio_codec           |str                        |internalPreferredAudioCodec             |
|queue_length                             |int                        |queueLength                             |
|no_answer_timeout_rings                  |int                        |noAnswerTimeoutRings                    |
|enable_video                             |bool                       |enableVideo                             |
|play_ringing_when_offering_call          |bool                       |playRingingWhenOfferingCall             |
|override_agent_wrap_up_time              |bool                       |overrideAgentWrapUpTime                 |
|wrap_up_seconds                          |int                        |wrapUpSeconds *Optional*                |
|enable_automatic_state_change_for_agents |bool                       |enableAutomaticStateChangeForAgents     |
|agent_state_after_call                   |str                        |agentStateAfterCall                     |
|agent_unavailable_code                   |str                        |agentUnavailableCode *Optional*         |
|force_delivery_of_calls                  |bool                       |forceDeliveryOfCalls                    |
|force_delivery_wait_time_seconds         |int                        |forceDeliveryWaitTimeSeconds *Optional* |
|send_call_admission_notification         |bool                       |sendCallAdmissionNotification           |
|call_admission_timer_seconds             |int                        |callAdmissionTimerSeconds               |
|enable_unlimited_queue_length            |bool                       |enableUnlimitedQueueLength *Optional*   |
</div>


## `GroupRoutePointHolidayServiceGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointHolidayServiceGetRequest20()`.


**Attributes:**

|Name                            |Type                |Description                    |
|--------------------------------|--------------------|-------------------------------|
|action                          |str                 |action                         |
|holiday_schedule                |OCI.holidaySchedule |holidaySchedule *Optional*     |
|transfer_phone_number           |str                 |transferPhoneNumber *Optional* |
|play_announcement_before_action |bool                |playAnnouncementBeforeAction   |
|audio_message_selection         |str                 |audioMessageSelection          |
|audio_url_list                  |OCI.audioUrlList    |audioUrlList *Optional*        |
|audio_file_list                 |OCI.audioFileList   |audioFileList *Optional*       |
|video_message_selection         |str                 |videoMessageSelection          |
|video_url_list                  |OCI.videoUrlList    |videoUrlList *Optional*        |
|video_file_list                 |OCI.videoFileList   |videoFileList *Optional*       |
</div>


## `GroupRoutePointNightServiceGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointNightServiceGetRequest20()`.


**Attributes:**

|Name                            |Type                    |Description                    |
|--------------------------------|------------------------|-------------------------------|
|action                          |str                     |action                         |
|business_hours                  |OCI.businessHours       |businessHours *Optional*       |
|force_night_service             |bool                    |forceNightService              |
|transfer_phone_number           |str                     |transferPhoneNumber *Optional* |
|play_announcement_before_action |bool                    |playAnnouncementBeforeAction   |
|audio_message_selection         |str                     |audioMessageSelection          |
|audio_url_list                  |OCI.audioUrlList        |audioUrlList *Optional*        |
|audio_file_list                 |OCI.audioFileList       |audioFileList *Optional*       |
|video_message_selection         |str                     |videoMessageSelection          |
|video_url_list                  |OCI.videoUrlList        |videoUrlList *Optional*        |
|video_file_list                 |OCI.videoFileList       |videoFileList *Optional*       |
|manual_announcement_mode        |str                     |manualAnnouncementMode         |
|manual_audio_message_selection  |str                     |manualAudioMessageSelection    |
|manual_audio_url_list           |OCI.manualAudioUrlList  |manualAudioUrlList *Optional*  |
|manual_audio_file_list          |OCI.manualAudioFileList |manualAudioFileList *Optional* |
|manual_video_message_selection  |str                     |manualVideoMessageSelection    |
|manual_video_url_list           |OCI.manualVideoUrlList  |manualVideoUrlList *Optional*  |
|manual_video_file_list          |OCI.manualVideoFileList |manualVideoFileList *Optional* |
</div>


## `GroupRoutePointOverflowGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointOverflowGetRequest20()`.


**Attributes:**

|Name                                         |Type              |Description                              |
|---------------------------------------------|------------------|-----------------------------------------|
|action                                       |str               |action                                   |
|transfer_phone_number                        |str               |transferPhoneNumber *Optional*           |
|overflow_after_timeout                       |bool              |overflowAfterTimeout                     |
|timeout_seconds                              |int               |timeoutSeconds                           |
|play_announcement_before_overflow_processing |bool              |playAnnouncementBeforeOverflowProcessing |
|audio_message_selection                      |str               |audioMessageSelection                    |
|audio_url_list                               |OCI.audioUrlList  |audioUrlList *Optional*                  |
|audio_file_list                              |OCI.audioFileList |audioFileList *Optional*                 |
|video_message_selection                      |str               |videoMessageSelection *Optional*         |
|video_url_list                               |OCI.videoUrlList  |videoUrlList *Optional*                  |
|video_file_list                              |OCI.videoFileList |videoFileList *Optional*                 |
</div>


## `GroupScheduleGetEventDetailListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupScheduleGetEventDetailListRequest()`.

The response contains a list of ScheduleEvents.  If the scheduleKey doesn't refer to
an existing schedule on the AS, then the response will be empty.

**Attributes:**

|Name                 |Type                         |Description                   |
|---------------------|-----------------------------|------------------------------|
|schedule_events_list |List[OCI.scheduleEventsList] |scheduleEventsList *Optional* |
</div>


## `GroupScheduleGetListResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupScheduleGetListRequest17sp1()`.

The response contains a list of group schedules.  If the group belongs to an
enterprise, it also contains the schedules for the enterprise.

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|schedule_global_key |List[OCI.scheduleGlobalKey] |scheduleGlobalKey *Optional* |
</div>


## `GroupShInterfaceGetUserListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupShInterfaceGetUserListRequest()`.

The response contains the Sh Non Transparent data and associated Public User Identity
information for every Public User Identity in the group.  Replaced by:
`GroupShInterfaceGetUserListResponse21sp1()` in AS data mode.

**Attributes:**

|Name  |Type            |Description      |
|------|----------------|-----------------|
|entry |List[OCI.entry] |entry *Optional* |
</div>


## `GroupShInterfaceGetUserListResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupShInterfaceGetUserListRequest21sp1()`.

The response contains the Sh Non Transparent data and associated Public User Identity
information for every Public User Identity in the group.

**Attributes:**

|Name  |Type            |Description      |
|------|----------------|-----------------|
|entry |List[OCI.entry] |entry *Optional* |
</div>


## `GroupTrunkGroupGetInstanceResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest()`.

The publicUserIdentity in the ServiceInstanceReadProfile is not used for trunk groups.
Returns the profile information for the Trunk Group.

**Attributes:**

|Name                         |Type                       |Description                          |
|-----------------------------|---------------------------|-------------------------------------|
|service_instance_profile     |OCI.serviceInstanceProfile |serviceInstanceProfile               |
|access_device_endpoint       |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*      |
|max_active_calls             |int                        |maxActiveCalls                       |
|max_incoming_calls           |int                        |maxIncomingCalls *Optional*          |
|max_outgoing_calls           |int                        |maxOutgoingCalls *Optional*          |
|require_authentication       |bool                       |requireAuthentication                |
|sip_authentication_user_name |str                        |sipAuthenticationUserName *Optional* |
</div>


## `GroupTrunkGroupGetInstanceResponse14sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupTrunkGroupGetInstanceRequest14sp1()`.

The publicUserIdentity in the ServiceInstanceReadProfile is not used for trunk groups.
Returns the profile information for the Trunk Group.

**Attributes:**

|Name                                           |Type                       |Description                                          |
|-----------------------------------------------|---------------------------|-----------------------------------------------------|
|service_instance_profile                       |OCI.serviceInstanceProfile |serviceInstanceProfile                               |
|access_device_endpoint                         |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*                      |
|max_active_calls                               |int                        |maxActiveCalls                                       |
|max_incoming_calls                             |int                        |maxIncomingCalls *Optional*                          |
|max_outgoing_calls                             |int                        |maxOutgoingCalls *Optional*                          |
|enable_bursting                                |bool                       |enableBursting                                       |
|bursting_max_active_calls                      |int                        |burstingMaxActiveCalls *Optional*                    |
|bursting_max_incoming_calls                    |int                        |burstingMaxIncomingCalls *Optional*                  |
|bursting_max_outgoing_calls                    |int                        |burstingMaxOutgoingCalls *Optional*                  |
|capacity_exceeded_action                       |str                        |capacityExceededAction *Optional*                    |
|capacity_exceeded_forward_address              |str                        |capacityExceededForwardAddress *Optional*            |
|capacity_exceeded_reroute_trunk_group_id       |str                        |capacityExceededRerouteTrunkGroupId *Optional*       |
|capacity_exceeded_trap_initial_calls           |int                        |capacityExceededTrapInitialCalls                     |
|capacity_exceeded_trap_offset_calls            |int                        |capacityExceededTrapOffsetCalls                      |
|unreachable_destination_action                 |str                        |unreachableDestinationAction *Optional*              |
|unreachable_destination_forward_address        |str                        |unreachableDestinationForwardAddress *Optional*      |
|unreachable_destination_reroute_trunk_group_id |str                        |unreachableDestinationRerouteTrunkGroupId *Optional* |
|unreachable_destination_trap_initial_calls     |int                        |unreachableDestinationTrapInitialCalls               |
|unreachable_destination_trap_offset_calls      |int                        |unreachableDestinationTrapOffsetCalls                |
|invitation_timeout                             |int                        |invitationTimeout                                    |
|require_authentication                         |bool                       |requireAuthentication                                |
|sip_authentication_user_name                   |str                        |sipAuthenticationUserName *Optional*                 |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupVoiceMessagingGroupGetVoicePortalRequest14()`.

Replaced by `GroupVoiceMessagingGroupGetVoicePortalResponse15()`

**Attributes:**

|Name                                                                |Type                       |Description                                               |
|--------------------------------------------------------------------|---------------------------|----------------------------------------------------------|
|service_user_id                                                     |str                        |serviceUserId                                             |
|service_instance_profile                                            |OCI.serviceInstanceProfile |serviceInstanceProfile                                    |
|is_active                                                           |bool                       |isActive                                                  |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool                       |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin |
|use_voice_portal_wizard                                             |bool                       |useVoicePortalWizard                                      |
|voice_portal_external_routing_scope                                 |str                        |voicePortalExternalRoutingScope                           |
|use_external_routing                                                |bool                       |useExternalRouting                                        |
|external_routing_address                                            |str                        |externalRoutingAddress *Optional*                         |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalResponse15`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupVoiceMessagingGroupGetVoicePortalRequest15()`.


**Attributes:**

|Name                                                                |Type                       |Description                                               |
|--------------------------------------------------------------------|---------------------------|----------------------------------------------------------|
|service_user_id                                                     |str                        |serviceUserId                                             |
|service_instance_profile                                            |OCI.serviceInstanceProfile |serviceInstanceProfile                                    |
|is_active                                                           |bool                       |isActive                                                  |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool                       |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin |
|use_voice_portal_wizard                                             |bool                       |useVoicePortalWizard                                      |
|voice_portal_external_routing_scope                                 |str                        |voicePortalExternalRoutingScope                           |
|use_external_routing                                                |bool                       |useExternalRouting                                        |
|external_routing_address                                            |str                        |externalRoutingAddress *Optional*                         |
|home_zone_name                                                      |str                        |homeZoneName *Optional*                                   |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupVoiceMessagingGroupGetVoicePortalRequest17()`.


**Attributes:**

|Name                                                                |Type                       |Description                                               |
|--------------------------------------------------------------------|---------------------------|----------------------------------------------------------|
|service_user_id                                                     |str                        |serviceUserId                                             |
|service_instance_profile                                            |OCI.serviceInstanceProfile |serviceInstanceProfile                                    |
|is_active                                                           |bool                       |isActive                                                  |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool                       |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin |
|use_voice_portal_wizard                                             |bool                       |useVoicePortalWizard                                      |
|voice_portal_external_routing_scope                                 |str                        |voicePortalExternalRoutingScope                           |
|use_external_routing                                                |bool                       |useExternalRouting                                        |
|external_routing_address                                            |str                        |externalRoutingAddress *Optional*                         |
|home_zone_name                                                      |str                        |homeZoneName *Optional*                                   |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupVoiceMessagingGroupGetVoicePortalRequest17sp4()`.

The following elements are only used in XS data mode: enableExtendedScope Replaced by:
`GroupVoiceMessagingGroupGetVoicePortalResponse19sp1()` in AS data mode

**Attributes:**

|Name                                                                |Type                       |Description                                               |
|--------------------------------------------------------------------|---------------------------|----------------------------------------------------------|
|service_user_id                                                     |str                        |serviceUserId                                             |
|service_instance_profile                                            |OCI.serviceInstanceProfile |serviceInstanceProfile                                    |
|is_active                                                           |bool                       |isActive                                                  |
|enable_extended_scope                                               |bool                       |enableExtendedScope                                       |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool                       |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin |
|use_voice_portal_wizard                                             |bool                       |useVoicePortalWizard                                      |
|voice_portal_external_routing_scope                                 |str                        |voicePortalExternalRoutingScope                           |
|use_external_routing                                                |bool                       |useExternalRouting                                        |
|external_routing_address                                            |str                        |externalRoutingAddress *Optional*                         |
|home_zone_name                                                      |str                        |homeZoneName *Optional*                                   |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupVoiceMessagingGroupGetVoicePortalRequest19sp1()`.

The following elements are only used in XS data mode: enableExtendedScope Replaced by:
`GroupVoiceMessagingGroupGetVoicePortalResponse21sp1()` in AS data mode.

**Attributes:**

|Name                                                                |Type                       |Description                                               |
|--------------------------------------------------------------------|---------------------------|----------------------------------------------------------|
|service_user_id                                                     |str                        |serviceUserId                                             |
|service_instance_profile                                            |OCI.serviceInstanceProfile |serviceInstanceProfile                                    |
|is_active                                                           |bool                       |isActive                                                  |
|enable_extended_scope                                               |bool                       |enableExtendedScope                                       |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool                       |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin |
|use_voice_portal_wizard                                             |bool                       |useVoicePortalWizard                                      |
|voice_portal_external_routing_scope                                 |str                        |voicePortalExternalRoutingScope                           |
|use_external_routing                                                |bool                       |useExternalRouting                                        |
|external_routing_address                                            |str                        |externalRoutingAddress *Optional*                         |
|home_zone_name                                                      |str                        |homeZoneName *Optional*                                   |
|network_class_of_service                                            |str                        |networkClassOfService *Optional*                          |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupVoiceMessagingGroupGetVoicePortalRequest21sp1()`.

The following elements are only used in XS data mode: enableExtendedScope The
following elements are only used in AS data mode: expressMode, value "false" is
returned in XS data mode.

**Attributes:**

|Name                                                                |Type                       |Description                                               |
|--------------------------------------------------------------------|---------------------------|----------------------------------------------------------|
|service_user_id                                                     |str                        |serviceUserId                                             |
|service_instance_profile                                            |OCI.serviceInstanceProfile |serviceInstanceProfile                                    |
|is_active                                                           |bool                       |isActive                                                  |
|enable_extended_scope                                               |bool                       |enableExtendedScope                                       |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool                       |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin |
|use_voice_portal_wizard                                             |bool                       |useVoicePortalWizard                                      |
|voice_portal_external_routing_scope                                 |str                        |voicePortalExternalRoutingScope                           |
|use_external_routing                                                |bool                       |useExternalRouting                                        |
|external_routing_address                                            |str                        |externalRoutingAddress *Optional*                         |
|home_zone_name                                                      |str                        |homeZoneName *Optional*                                   |
|network_class_of_service                                            |str                        |networkClassOfService *Optional*                          |
|express_mode                                                        |bool                       |expressMode                                               |
</div>


## `GroupVoiceXmlGetInstanceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupVoiceXmlGetInstanceRequest()`.

Contains the service profile information and possibly access device information.
Replaced by: `GroupVoiceXmlGetInstanceResponse19sp1()` in AS data mode

**Attributes:**

|Name                     |Type                       |Description                      |
|-------------------------|---------------------------|---------------------------------|
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|network_class_of_service |str                        |networkClassOfService *Optional* |
|access_device_endpoint   |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*  |
</div>


## `GroupVoiceXmlGetInstanceResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupVoiceXmlGetInstanceRequest19sp1()`.

Contains the service profile information and possibly access device information.

**Attributes:**

|Name                     |Type                       |Description                      |
|-------------------------|---------------------------|---------------------------------|
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|network_class_of_service |str                        |networkClassOfService *Optional* |
|access_device_endpoint   |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*  |
</div>


## `GroupVoiceXmlGetInstanceResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupVoiceXmlGetInstanceRequest22()`.

Contains the service profile information and possibly access device information.

**Attributes:**

|Name                     |Type                       |Description                      |
|-------------------------|---------------------------|---------------------------------|
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|network_class_of_service |str                        |networkClassOfService *Optional* |
|access_device_endpoint   |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*  |
</div>


## `ServiceProviderAccessDeviceGetLinkedTreeDeviceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderAccessDeviceGetLinkedTreeDeviceRequest()`.


**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|tree_device_info |OCI.treeDeviceInfo |treeDeviceInfo *Optional* |
</div>


## `ServiceProviderGetAvailableTreeDeviceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderGetAvailableTreeDeviceListRequest()`.


**Attributes:**

|Name             |Type                     |Description               |
|-----------------|-------------------------|--------------------------|
|tree_device_info |List[OCI.treeDeviceInfo] |treeDeviceInfo *Optional* |
</div>


## `ServiceProviderMWIDeliveryToMobileEndpointCustomTemplateGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the
`ServiceProviderMWIDeliveryToMobileEndpointCustomTemplateGetRequest()`.


**Attributes:**

|Name          |Type             |Description  |
|--------------|-----------------|-------------|
|is_enabled    |bool             |isEnabled    |
|template_body |OCI.templateBody |templateBody |
</div>


## `ServiceProviderScheduleGetEventDetailListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `ServiceProviderScheduleGetEventDetailListRequest()`.

The response contains a list of ScheduleEvents.  If the scheduleKey doesn't refer to
an existing schedule on the AS, then the response will be empty.

**Attributes:**

|Name                 |Type                         |Description                   |
|---------------------|-----------------------------|------------------------------|
|schedule_events_list |List[OCI.scheduleEventsList] |scheduleEventsList *Optional* |
</div>


## `SystemAccessDeviceGetLinkedTreeDeviceResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemAccessDeviceGetLinkedTreeDeviceRequest()`.


**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|tree_device_info |OCI.treeDeviceInfo |treeDeviceInfo *Optional* |
</div>


## `SystemDeviceTypeGetResponse14sp6`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetRequest14sp6()`.

Replaced by: `SystemDeviceTypeGetResponse16()`

**Attributes:**

|Name                        |Type                 |Description                  |
|----------------------------|---------------------|-----------------------------|
|is_obsolete                 |bool                 |isObsolete                   |
|profile                     |str                  |profile                      |
|web_based_config_url        |str                  |webBasedConfigURL *Optional* |
|static_registration_capable |bool                 |staticRegistrationCapable    |
|cpe_device_options          |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*  |
|protocol_choice             |List[str]            |protocolChoice               |
|is_ip_address_optional      |bool                 |isIpAddressOptional          |
|use_domain                  |bool                 |useDomain                    |
|is_mobility_manager_device  |bool                 |isMobilityManagerDevice      |
</div>


## `SystemDeviceTypeGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetRequest16()`.

Replaced by: `SystemDeviceTypeGetResponse16sp1()`

**Attributes:**

|Name                        |Type                 |Description                  |
|----------------------------|---------------------|-----------------------------|
|is_obsolete                 |bool                 |isObsolete                   |
|profile                     |str                  |profile                      |
|web_based_config_url        |str                  |webBasedConfigURL *Optional* |
|static_registration_capable |bool                 |staticRegistrationCapable    |
|cpe_device_options          |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*  |
|protocol_choice             |List[str]            |protocolChoice               |
|is_ip_address_optional      |bool                 |isIpAddressOptional          |
|use_domain                  |bool                 |useDomain                    |
|is_mobility_manager_device  |bool                 |isMobilityManagerDevice      |
</div>


## `SystemDeviceTypeGetResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Replaced By SystemSIPDeviceTypeGetReponse18.

Response to `SystemDeviceTypeGetRequest16sp1()`.

**Attributes:**

|Name                        |Type                 |Description                  |
|----------------------------|---------------------|-----------------------------|
|is_obsolete                 |bool                 |isObsolete                   |
|profile                     |str                  |profile                      |
|web_based_config_url        |str                  |webBasedConfigURL *Optional* |
|static_registration_capable |bool                 |staticRegistrationCapable    |
|cpe_device_options          |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*  |
|protocol_choice             |List[str]            |protocolChoice               |
|is_ip_address_optional      |bool                 |isIpAddressOptional          |
|use_domain                  |bool                 |useDomain                    |
|is_mobility_manager_device  |bool                 |isMobilityManagerDevice      |
</div>


## `SystemDeviceTypeGetResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetRequest18()`.


**Attributes:**

|Name                             |Type                 |Description                              |
|---------------------------------|---------------------|-----------------------------------------|
|is_obsolete                      |bool                 |isObsolete                               |
|profile                          |str                  |profile                                  |
|web_based_config_url             |str                  |webBasedConfigURL *Optional*             |
|static_registration_capable      |bool                 |staticRegistrationCapable                |
|cpe_device_options               |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                  |List[str]            |protocolChoice                           |
|is_ip_address_optional           |bool                 |isIpAddressOptional                      |
|use_domain                       |bool                 |useDomain                                |
|is_mobility_manager_device       |bool                 |isMobilityManagerDevice                  |
|device_type_configuration_option |str                  |deviceTypeConfigurationOption *Optional* |
</div>


## `SystemDeviceTypeGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetRequest19()`.


**Attributes:**

|Name                             |Type                 |Description                              |
|---------------------------------|---------------------|-----------------------------------------|
|is_obsolete                      |bool                 |isObsolete                               |
|profile                          |str                  |profile                                  |
|web_based_config_url             |str                  |webBasedConfigURL *Optional*             |
|static_registration_capable      |bool                 |staticRegistrationCapable                |
|cpe_device_options               |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                  |List[str]            |protocolChoice                           |
|is_ip_address_optional           |bool                 |isIpAddressOptional                      |
|use_domain                       |bool                 |useDomain                                |
|is_mobility_manager_device       |bool                 |isMobilityManagerDevice                  |
|device_type_configuration_option |str                  |deviceTypeConfigurationOption *Optional* |
|static_line_ordering             |bool                 |staticLineOrdering *Optional*            |
</div>


## `SystemDeviceTypeGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetRequest21sp1()`.


**Attributes:**

|Name                             |Type                 |Description                              |
|---------------------------------|---------------------|-----------------------------------------|
|is_obsolete                      |bool                 |isObsolete                               |
|profile                          |str                  |profile                                  |
|web_based_config_url             |str                  |webBasedConfigURL *Optional*             |
|static_registration_capable      |bool                 |staticRegistrationCapable                |
|cpe_device_options               |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                  |List[str]            |protocolChoice                           |
|is_ip_address_optional           |bool                 |isIpAddressOptional                      |
|use_domain                       |bool                 |useDomain                                |
|is_mobility_manager_device       |bool                 |isMobilityManagerDevice                  |
|device_type_configuration_option |str                  |deviceTypeConfigurationOption *Optional* |
|static_line_ordering             |bool                 |staticLineOrdering *Optional*            |
</div>


## `SystemDeviceTypeGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetRequest22()`.

The following elements are only used in AS data mode: resellerId

**Attributes:**

|Name                             |Type                 |Description                              |
|---------------------------------|---------------------|-----------------------------------------|
|is_obsolete                      |bool                 |isObsolete                               |
|profile                          |str                  |profile                                  |
|web_based_config_url             |str                  |webBasedConfigURL *Optional*             |
|static_registration_capable      |bool                 |staticRegistrationCapable                |
|cpe_device_options               |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                  |List[str]            |protocolChoice                           |
|is_ip_address_optional           |bool                 |isIpAddressOptional                      |
|use_domain                       |bool                 |useDomain                                |
|is_mobility_manager_device       |bool                 |isMobilityManagerDevice                  |
|device_type_configuration_option |str                  |deviceTypeConfigurationOption *Optional* |
|static_line_ordering             |bool                 |staticLineOrdering *Optional*            |
|reseller_id                      |str                  |resellerId *Optional*                    |
</div>


## `SystemDeviceTypeGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetRequest22V2()`.

The following elements are only used in AS data mode: resellerId

**Attributes:**

|Name                             |Type                 |Description                              |
|---------------------------------|---------------------|-----------------------------------------|
|is_obsolete                      |bool                 |isObsolete                               |
|profile                          |str                  |profile                                  |
|web_based_config_url             |str                  |webBasedConfigURL *Optional*             |
|static_registration_capable      |bool                 |staticRegistrationCapable                |
|cpe_device_options               |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                  |List[str]            |protocolChoice                           |
|is_ip_address_optional           |bool                 |isIpAddressOptional                      |
|use_domain                       |bool                 |useDomain                                |
|is_mobility_manager_device       |bool                 |isMobilityManagerDevice                  |
|device_type_configuration_option |str                  |deviceTypeConfigurationOption *Optional* |
|static_line_ordering             |bool                 |staticLineOrdering *Optional*            |
|reseller_id                      |str                  |resellerId *Optional*                    |
</div>


## `SystemDeviceTypeGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetRequest22V3()`.

The following elements are only used in AS data mode: resellerId Replaced by:
`SystemDeviceTypeGetResponse22V4()`

**Attributes:**

|Name                             |Type                 |Description                              |
|---------------------------------|---------------------|-----------------------------------------|
|is_obsolete                      |bool                 |isObsolete                               |
|profile                          |str                  |profile                                  |
|web_based_config_url             |str                  |webBasedConfigURL *Optional*             |
|static_registration_capable      |bool                 |staticRegistrationCapable                |
|cpe_device_options               |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                  |List[str]            |protocolChoice                           |
|is_ip_address_optional           |bool                 |isIpAddressOptional                      |
|use_domain                       |bool                 |useDomain                                |
|is_mobility_manager_device       |bool                 |isMobilityManagerDevice                  |
|device_type_configuration_option |str                  |deviceTypeConfigurationOption *Optional* |
|static_line_ordering             |bool                 |staticLineOrdering *Optional*            |
|reseller_id                      |str                  |resellerId *Optional*                    |
</div>


## `SystemDeviceTypeGetResponse22V4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetRequest22V4()`.

The following elements are only used in AS data mode: resellerId Replaced by:
`SystemDeviceTypeGetResponse22V5()`.

**Attributes:**

|Name                             |Type                 |Description                              |
|---------------------------------|---------------------|-----------------------------------------|
|is_obsolete                      |bool                 |isObsolete                               |
|profile                          |str                  |profile                                  |
|web_based_config_url             |str                  |webBasedConfigURL *Optional*             |
|static_registration_capable      |bool                 |staticRegistrationCapable                |
|cpe_device_options               |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                  |List[str]            |protocolChoice                           |
|is_ip_address_optional           |bool                 |isIpAddressOptional                      |
|use_domain                       |bool                 |useDomain                                |
|is_mobility_manager_device       |bool                 |isMobilityManagerDevice                  |
|device_type_configuration_option |str                  |deviceTypeConfigurationOption *Optional* |
|static_line_ordering             |bool                 |staticLineOrdering *Optional*            |
|reseller_id                      |str                  |resellerId *Optional*                    |
</div>


## `SystemDeviceTypeGetResponse22V5`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemDeviceTypeGetRequest22V5()`.

The following elements are only used in AS data mode: resellerId

**Attributes:**

|Name                             |Type                 |Description                              |
|---------------------------------|---------------------|-----------------------------------------|
|is_obsolete                      |bool                 |isObsolete                               |
|profile                          |str                  |profile                                  |
|web_based_config_url             |str                  |webBasedConfigURL *Optional*             |
|static_registration_capable      |bool                 |staticRegistrationCapable                |
|cpe_device_options               |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                  |List[str]            |protocolChoice                           |
|is_ip_address_optional           |bool                 |isIpAddressOptional                      |
|use_domain                       |bool                 |useDomain                                |
|is_mobility_manager_device       |bool                 |isMobilityManagerDevice                  |
|device_type_configuration_option |str                  |deviceTypeConfigurationOption *Optional* |
|static_line_ordering             |bool                 |staticLineOrdering *Optional*            |
|reseller_id                      |str                  |resellerId *Optional*                    |
</div>


## `SystemGetAvailableTreeDeviceListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemGetAvailableTreeDeviceListRequest()`.


**Attributes:**

|Name             |Type                     |Description               |
|-----------------|-------------------------|--------------------------|
|tree_device_info |List[OCI.treeDeviceInfo] |treeDeviceInfo *Optional* |
</div>


## `SystemSIPDeviceTypeGetResponse14sp6`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest14sp6()`.

Replaced by: `SystemSIPDeviceTypeGetResponse14sp6()`

**Attributes:**

|Name                                       |Type                 |Description                          |
|-------------------------------------------|---------------------|-------------------------------------|
|is_obsolete                                |bool                 |isObsolete                           |
|number_of_ports                            |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                    |str                  |profile                              |
|registration_capable                       |bool                 |registrationCapable                  |
|is_conference_device                       |bool                 |isConferenceDevice                   |
|is_mobility_manager_device                 |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                    |bool                 |isMusicOnHoldDevice                  |
|rfc3264_hold                               |bool                 |RFC3264Hold                          |
|is_trusted                                 |bool                 |isTrusted                            |
|e164_capable                               |bool                 |E164Capable                          |
|route_advance                              |bool                 |routeAdvance                         |
|forwarding_override                        |bool                 |forwardingOverride                   |
|wireless_integration                       |bool                 |wirelessIntegration                  |
|web_based_config_url                       |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                           |bool                 |isVideoCapable                       |
|pbx_integration                            |bool                 |PBXIntegration                       |
|use_business_trunking_contact              |bool                 |useBusinessTrunkingContact           |
|static_registration_capable                |bool                 |staticRegistrationCapable            |
|cpe_device_options                         |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|protocol_choice                            |List[str]            |protocolChoice                       |
|early_media_support                        |str                  |earlyMediaSupport                    |
|authenticate_refer                         |bool                 |authenticateRefer                    |
|auto_config_soft_client                    |bool                 |autoConfigSoftClient                 |
|authentication_mode                        |str                  |authenticationMode                   |
|tdm_overlay                                |bool                 |tdmOverlay                           |
|supports_broad_works_info_for_call_waiting |bool                 |supportsBroadWorksINFOForCallWaiting |
</div>


## `SystemSIPDeviceTypeGetResponse15`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest15()`.

Replaced By : `SystemSIPDeviceTypeAddResponse16()`

**Attributes:**

|Name                                   |Type                 |Description                       |
|---------------------------------------|---------------------|----------------------------------|
|is_obsolete                            |bool                 |isObsolete                        |
|number_of_ports                        |OCI.numberOfPorts    |numberOfPorts                     |
|profile                                |str                  |profile                           |
|registration_capable                   |bool                 |registrationCapable               |
|is_conference_device                   |bool                 |isConferenceDevice                |
|is_mobility_manager_device             |bool                 |isMobilityManagerDevice           |
|is_music_on_hold_device                |bool                 |isMusicOnHoldDevice               |
|rfc3264_hold                           |bool                 |RFC3264Hold                       |
|is_trusted                             |bool                 |isTrusted                         |
|e164_capable                           |bool                 |E164Capable                       |
|route_advance                          |bool                 |routeAdvance                      |
|forwarding_override                    |bool                 |forwardingOverride                |
|wireless_integration                   |bool                 |wirelessIntegration               |
|web_based_config_url                   |str                  |webBasedConfigURL *Optional*      |
|is_video_capable                       |bool                 |isVideoCapable                    |
|pbx_integration                        |bool                 |PBXIntegration                    |
|use_business_trunking_contact          |bool                 |useBusinessTrunkingContact        |
|static_registration_capable            |bool                 |staticRegistrationCapable         |
|cpe_device_options                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*       |
|protocol_choice                        |List[str]            |protocolChoice                    |
|early_media_support                    |str                  |earlyMediaSupport                 |
|authenticate_refer                     |bool                 |authenticateRefer                 |
|auto_config_soft_client                |bool                 |autoConfigSoftClient              |
|authentication_mode                    |str                  |authenticationMode                |
|tdm_overlay                            |bool                 |tdmOverlay                        |
|requires_broad_works_call_waiting_tone |bool                 |requiresBroadWorksCallWaitingTone |
|requires_mwi_subscription              |bool                 |requiresMWISubscription           |
|use_history_info_header_on_access_side |bool                 |useHistoryInfoHeaderOnAccessSide  |
</div>


## `SystemSIPDeviceTypeGetResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest16()`.

Replaced by: `SystemSIPDeviceTypeGetResponse16sp1()`

**Attributes:**

|Name                                   |Type                 |Description                       |
|---------------------------------------|---------------------|----------------------------------|
|is_obsolete                            |bool                 |isObsolete                        |
|number_of_ports                        |OCI.numberOfPorts    |numberOfPorts                     |
|profile                                |str                  |profile                           |
|registration_capable                   |bool                 |registrationCapable               |
|is_conference_device                   |bool                 |isConferenceDevice                |
|is_mobility_manager_device             |bool                 |isMobilityManagerDevice           |
|is_music_on_hold_device                |bool                 |isMusicOnHoldDevice               |
|rfc3264_hold                           |bool                 |RFC3264Hold                       |
|is_trusted                             |bool                 |isTrusted                         |
|e164_capable                           |bool                 |E164Capable                       |
|route_advance                          |bool                 |routeAdvance                      |
|forwarding_override                    |bool                 |forwardingOverride                |
|wireless_integration                   |bool                 |wirelessIntegration               |
|web_based_config_url                   |str                  |webBasedConfigURL *Optional*      |
|is_video_capable                       |bool                 |isVideoCapable                    |
|pbx_integration                        |bool                 |PBXIntegration                    |
|use_business_trunking_contact          |bool                 |useBusinessTrunkingContact        |
|static_registration_capable            |bool                 |staticRegistrationCapable         |
|cpe_device_options                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*       |
|protocol_choice                        |List[str]            |protocolChoice                    |
|early_media_support                    |str                  |earlyMediaSupport                 |
|authenticate_refer                     |bool                 |authenticateRefer                 |
|auto_config_soft_client                |bool                 |autoConfigSoftClient              |
|authentication_mode                    |str                  |authenticationMode                |
|requires_broad_works_digit_collection  |bool                 |requiresBroadWorksDigitCollection |
|requires_broad_works_call_waiting_tone |bool                 |requiresBroadWorksCallWaitingTone |
|requires_mwi_subscription              |bool                 |requiresMWISubscription           |
|use_history_info_header_on_access_side |bool                 |useHistoryInfoHeaderOnAccessSide  |
|advice_of_charge_capable               |bool                 |adviceOfChargeCapable             |
</div>


## `SystemSIPDeviceTypeGetResponse16sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest16sp1()`.


**Attributes:**

|Name                                   |Type                 |Description                       |
|---------------------------------------|---------------------|----------------------------------|
|is_obsolete                            |bool                 |isObsolete                        |
|number_of_ports                        |OCI.numberOfPorts    |numberOfPorts                     |
|profile                                |str                  |profile                           |
|registration_capable                   |bool                 |registrationCapable               |
|is_conference_device                   |bool                 |isConferenceDevice                |
|is_mobility_manager_device             |bool                 |isMobilityManagerDevice           |
|is_music_on_hold_device                |bool                 |isMusicOnHoldDevice               |
|rfc3264_hold                           |bool                 |RFC3264Hold                       |
|is_trusted                             |bool                 |isTrusted                         |
|e164_capable                           |bool                 |E164Capable                       |
|route_advance                          |bool                 |routeAdvance                      |
|forwarding_override                    |bool                 |forwardingOverride                |
|wireless_integration                   |bool                 |wirelessIntegration               |
|web_based_config_url                   |str                  |webBasedConfigURL *Optional*      |
|is_video_capable                       |bool                 |isVideoCapable                    |
|pbx_integration                        |bool                 |PBXIntegration                    |
|use_business_trunking_contact          |bool                 |useBusinessTrunkingContact        |
|static_registration_capable            |bool                 |staticRegistrationCapable         |
|cpe_device_options                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*       |
|protocol_choice                        |List[str]            |protocolChoice                    |
|early_media_support                    |str                  |earlyMediaSupport                 |
|authenticate_refer                     |bool                 |authenticateRefer                 |
|auto_config_soft_client                |bool                 |autoConfigSoftClient              |
|authentication_mode                    |str                  |authenticationMode                |
|requires_broad_works_digit_collection  |bool                 |requiresBroadWorksDigitCollection |
|requires_broad_works_call_waiting_tone |bool                 |requiresBroadWorksCallWaitingTone |
|requires_mwi_subscription              |bool                 |requiresMWISubscription           |
|use_history_info_header_on_access_side |bool                 |useHistoryInfoHeaderOnAccessSide  |
|advice_of_charge_capable               |bool                 |adviceOfChargeCapable             |
|reset_event                            |str                  |resetEvent *Optional*             |
</div>


## `SystemSIPDeviceTypeGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest17()`.


**Attributes:**

|Name                                   |Type                 |Description                       |
|---------------------------------------|---------------------|----------------------------------|
|is_obsolete                            |bool                 |isObsolete                        |
|number_of_ports                        |OCI.numberOfPorts    |numberOfPorts                     |
|profile                                |str                  |profile                           |
|registration_capable                   |bool                 |registrationCapable               |
|is_conference_device                   |bool                 |isConferenceDevice                |
|is_mobility_manager_device             |bool                 |isMobilityManagerDevice           |
|is_music_on_hold_device                |bool                 |isMusicOnHoldDevice               |
|rfc3264_hold                           |bool                 |RFC3264Hold                       |
|is_trusted                             |bool                 |isTrusted                         |
|e164_capable                           |bool                 |E164Capable                       |
|route_advance                          |bool                 |routeAdvance                      |
|forwarding_override                    |bool                 |forwardingOverride                |
|wireless_integration                   |bool                 |wirelessIntegration               |
|web_based_config_url                   |str                  |webBasedConfigURL *Optional*      |
|is_video_capable                       |bool                 |isVideoCapable                    |
|pbx_integration                        |bool                 |PBXIntegration                    |
|static_registration_capable            |bool                 |staticRegistrationCapable         |
|cpe_device_options                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*       |
|protocol_choice                        |List[str]            |protocolChoice                    |
|early_media_support                    |str                  |earlyMediaSupport                 |
|authenticate_refer                     |bool                 |authenticateRefer                 |
|auto_config_soft_client                |bool                 |autoConfigSoftClient              |
|authentication_mode                    |str                  |authenticationMode                |
|requires_broad_works_digit_collection  |bool                 |requiresBroadWorksDigitCollection |
|requires_broad_works_call_waiting_tone |bool                 |requiresBroadWorksCallWaitingTone |
|requires_mwi_subscription              |bool                 |requiresMWISubscription           |
|use_history_info_header_on_access_side |bool                 |useHistoryInfoHeaderOnAccessSide  |
|advice_of_charge_capable               |bool                 |adviceOfChargeCapable             |
|reset_event                            |str                  |resetEvent *Optional*             |
|support_call_center_mime_type          |bool                 |supportCallCenterMIMEType         |
|trunk_mode                             |str                  |trunkMode                         |
|add_p_called_party_id                  |bool                 |addPCalledPartyId                 |
</div>


## `SystemSIPDeviceTypeGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Replaced By `SystemSIPDeviceTypeGetResponse18()`.

Response to `SystemSIPDeviceTypeGetRequest17sp4()`.

**Attributes:**

|Name                                     |Type                 |Description                          |
|-----------------------------------------|---------------------|-------------------------------------|
|is_obsolete                              |bool                 |isObsolete                           |
|number_of_ports                          |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                  |str                  |profile                              |
|registration_capable                     |bool                 |registrationCapable                  |
|is_conference_device                     |bool                 |isConferenceDevice                   |
|is_mobility_manager_device               |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                  |bool                 |isMusicOnHoldDevice                  |
|rfc3264_hold                             |bool                 |RFC3264Hold                          |
|is_trusted                               |bool                 |isTrusted                            |
|e164_capable                             |bool                 |E164Capable                          |
|route_advance                            |bool                 |routeAdvance                         |
|forwarding_override                      |bool                 |forwardingOverride                   |
|wireless_integration                     |bool                 |wirelessIntegration                  |
|web_based_config_url                     |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                         |bool                 |isVideoCapable                       |
|pbx_integration                          |bool                 |PBXIntegration                       |
|static_registration_capable              |bool                 |staticRegistrationCapable            |
|cpe_device_options                       |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|protocol_choice                          |List[str]            |protocolChoice                       |
|early_media_support                      |str                  |earlyMediaSupport                    |
|authenticate_refer                       |bool                 |authenticateRefer                    |
|auto_config_soft_client                  |bool                 |autoConfigSoftClient                 |
|authentication_mode                      |str                  |authenticationMode                   |
|requires_broad_works_digit_collection    |bool                 |requiresBroadWorksDigitCollection    |
|requires_broad_works_call_waiting_tone   |bool                 |requiresBroadWorksCallWaitingTone    |
|requires_mwi_subscription                |bool                 |requiresMWISubscription              |
|use_history_info_header_on_access_side   |bool                 |useHistoryInfoHeaderOnAccessSide     |
|advice_of_charge_capable                 |bool                 |adviceOfChargeCapable                |
|reset_event                              |str                  |resetEvent *Optional*                |
|support_call_center_mime_type            |bool                 |supportCallCenterMIMEType            |
|trunk_mode                               |str                  |trunkMode                            |
|add_p_called_party_id                    |bool                 |addPCalledPartyId                    |
|support_identity_in_update_and_re_invite |bool                 |supportIdentityInUpdateAndReInvite   |
|unscreened_presentation_identity_policy  |str                  |unscreenedPresentationIdentityPolicy |
</div>


## `SystemSIPDeviceTypeGetResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest18()`.

The following elements are only used in XS data mode: enable3G4GContinuity Replaced
by: `SystemSIPDeviceTypeGetResponse19()`

**Attributes:**

|Name                                     |Type                 |Description                          |
|-----------------------------------------|---------------------|-------------------------------------|
|is_obsolete                              |bool                 |isObsolete                           |
|number_of_ports                          |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                  |str                  |profile                              |
|registration_capable                     |bool                 |registrationCapable                  |
|is_conference_device                     |bool                 |isConferenceDevice                   |
|is_mobility_manager_device               |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                  |bool                 |isMusicOnHoldDevice                  |
|rfc3264_hold                             |bool                 |RFC3264Hold                          |
|is_trusted                               |bool                 |isTrusted                            |
|e164_capable                             |bool                 |E164Capable                          |
|route_advance                            |bool                 |routeAdvance                         |
|forwarding_override                      |bool                 |forwardingOverride                   |
|wireless_integration                     |bool                 |wirelessIntegration                  |
|web_based_config_url                     |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                         |bool                 |isVideoCapable                       |
|pbx_integration                          |bool                 |PBXIntegration                       |
|static_registration_capable              |bool                 |staticRegistrationCapable            |
|cpe_device_options                       |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|protocol_choice                          |List[str]            |protocolChoice                       |
|early_media_support                      |str                  |earlyMediaSupport                    |
|authenticate_refer                       |bool                 |authenticateRefer                    |
|auto_config_soft_client                  |bool                 |autoConfigSoftClient                 |
|authentication_mode                      |str                  |authenticationMode                   |
|requires_broad_works_digit_collection    |bool                 |requiresBroadWorksDigitCollection    |
|requires_broad_works_call_waiting_tone   |bool                 |requiresBroadWorksCallWaitingTone    |
|requires_mwi_subscription                |bool                 |requiresMWISubscription              |
|use_history_info_header_on_access_side   |bool                 |useHistoryInfoHeaderOnAccessSide     |
|advice_of_charge_capable                 |bool                 |adviceOfChargeCapable                |
|reset_event                              |str                  |resetEvent *Optional*                |
|support_call_center_mime_type            |bool                 |supportCallCenterMIMEType            |
|trunk_mode                               |str                  |trunkMode                            |
|add_p_called_party_id                    |bool                 |addPCalledPartyId                    |
|support_identity_in_update_and_re_invite |bool                 |supportIdentityInUpdateAndReInvite   |
|unscreened_presentation_identity_policy  |str                  |unscreenedPresentationIdentityPolicy |
|enable3_g4_g_continuity                  |bool                 |enable3G4GContinuity                 |
|support_emergency_disconnect_control     |bool                 |supportEmergencyDisconnectControl    |
|device_type_configuration_option         |str                  |deviceTypeConfigurationOption        |
</div>


## `SystemSIPDeviceTypeGetResponse18sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest18sp1()`.

The following elements are only used in AS data mode: holdAnnouncementMethod The
following elements are only used in XS data mode: enable3G4GContinuity The following
element values are only applicable in AS data mode: holdNormalization=useRfc3264Hold

**Attributes:**

|Name                                     |Type                 |Description                          |
|-----------------------------------------|---------------------|-------------------------------------|
|is_obsolete                              |bool                 |isObsolete                           |
|number_of_ports                          |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                  |str                  |profile                              |
|registration_capable                     |bool                 |registrationCapable                  |
|is_conference_device                     |bool                 |isConferenceDevice                   |
|is_mobility_manager_device               |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                  |bool                 |isMusicOnHoldDevice                  |
|hold_normalization                       |str                  |holdNormalization                    |
|hold_announcement_method                 |str                  |holdAnnouncementMethod               |
|is_trusted                               |bool                 |isTrusted                            |
|e164_capable                             |bool                 |E164Capable                          |
|route_advance                            |bool                 |routeAdvance                         |
|forwarding_override                      |bool                 |forwardingOverride                   |
|wireless_integration                     |bool                 |wirelessIntegration                  |
|web_based_config_url                     |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                         |bool                 |isVideoCapable                       |
|pbx_integration                          |bool                 |PBXIntegration                       |
|static_registration_capable              |bool                 |staticRegistrationCapable            |
|cpe_device_options                       |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|protocol_choice                          |List[str]            |protocolChoice                       |
|early_media_support                      |str                  |earlyMediaSupport                    |
|authenticate_refer                       |bool                 |authenticateRefer                    |
|auto_config_soft_client                  |bool                 |autoConfigSoftClient                 |
|authentication_mode                      |str                  |authenticationMode                   |
|requires_broad_works_digit_collection    |bool                 |requiresBroadWorksDigitCollection    |
|requires_broad_works_call_waiting_tone   |bool                 |requiresBroadWorksCallWaitingTone    |
|requires_mwi_subscription                |bool                 |requiresMWISubscription              |
|use_history_info_header_on_access_side   |bool                 |useHistoryInfoHeaderOnAccessSide     |
|advice_of_charge_capable                 |bool                 |adviceOfChargeCapable                |
|reset_event                              |str                  |resetEvent *Optional*                |
|support_call_center_mime_type            |bool                 |supportCallCenterMIMEType            |
|trunk_mode                               |str                  |trunkMode                            |
|add_p_called_party_id                    |bool                 |addPCalledPartyId                    |
|support_identity_in_update_and_re_invite |bool                 |supportIdentityInUpdateAndReInvite   |
|unscreened_presentation_identity_policy  |str                  |unscreenedPresentationIdentityPolicy |
|enable3_g4_g_continuity                  |bool                 |enable3G4GContinuity                 |
|support_emergency_disconnect_control     |bool                 |supportEmergencyDisconnectControl    |
|device_type_configuration_option         |str                  |deviceTypeConfigurationOption        |
</div>


## `SystemSIPDeviceTypeGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest19()`.

The following elements are only used in AS data mode: holdAnnouncementMethod, value
"useInactive" is returned in XS data mode supportRFC3398, value "false" is returned in
XS data mode The following elements are only used in XS data mode:
enable3G4GContinuity, value "false" is returned in AS data mode The following element
values are only applicable in AS data mode: holdNormalization=useRfc3264Hold Replaced
by: SystemSIPDeviceTypeGetResponse19sSp1

**Attributes:**

|Name                                     |Type                 |Description                          |
|-----------------------------------------|---------------------|-------------------------------------|
|is_obsolete                              |bool                 |isObsolete                           |
|number_of_ports                          |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                  |str                  |profile                              |
|registration_capable                     |bool                 |registrationCapable                  |
|is_conference_device                     |bool                 |isConferenceDevice                   |
|is_mobility_manager_device               |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                  |bool                 |isMusicOnHoldDevice                  |
|hold_normalization                       |str                  |holdNormalization                    |
|hold_announcement_method                 |str                  |holdAnnouncementMethod               |
|is_trusted                               |bool                 |isTrusted                            |
|e164_capable                             |bool                 |E164Capable                          |
|route_advance                            |bool                 |routeAdvance                         |
|forwarding_override                      |bool                 |forwardingOverride                   |
|wireless_integration                     |bool                 |wirelessIntegration                  |
|web_based_config_url                     |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                         |bool                 |isVideoCapable                       |
|pbx_integration                          |bool                 |PBXIntegration                       |
|static_registration_capable              |bool                 |staticRegistrationCapable            |
|cpe_device_options                       |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|protocol_choice                          |List[str]            |protocolChoice                       |
|early_media_support                      |str                  |earlyMediaSupport                    |
|authenticate_refer                       |bool                 |authenticateRefer                    |
|auto_config_soft_client                  |bool                 |autoConfigSoftClient                 |
|authentication_mode                      |str                  |authenticationMode                   |
|requires_broad_works_digit_collection    |bool                 |requiresBroadWorksDigitCollection    |
|requires_broad_works_call_waiting_tone   |bool                 |requiresBroadWorksCallWaitingTone    |
|requires_mwi_subscription                |bool                 |requiresMWISubscription              |
|use_history_info_header_on_access_side   |bool                 |useHistoryInfoHeaderOnAccessSide     |
|advice_of_charge_capable                 |bool                 |adviceOfChargeCapable                |
|reset_event                              |str                  |resetEvent *Optional*                |
|support_call_center_mime_type            |bool                 |supportCallCenterMIMEType            |
|trunk_mode                               |str                  |trunkMode                            |
|add_p_called_party_id                    |bool                 |addPCalledPartyId                    |
|support_identity_in_update_and_re_invite |bool                 |supportIdentityInUpdateAndReInvite   |
|unscreened_presentation_identity_policy  |str                  |unscreenedPresentationIdentityPolicy |
|enable3_g4_g_continuity                  |bool                 |enable3G4GContinuity                 |
|support_emergency_disconnect_control     |bool                 |supportEmergencyDisconnectControl    |
|device_type_configuration_option         |str                  |deviceTypeConfigurationOption        |
|support_rfc3398                          |bool                 |supportRFC3398                       |
|static_line_ordering                     |bool                 |staticLineOrdering                   |
</div>


## `SystemSIPDeviceTypeGetResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest19sp1()`.

The following elements are only used in AS data mode: holdAnnouncementMethod, value
"useInactive" is returned in XS data mode supportRFC3398, value "false" is returned in
XS data mode bypassMediaTreatment The following elements are only used in XS data
mode: enable3G4GContinuity, value "false" is returned in AS data mode The following
element values are only applicable in AS data mode: holdNormalization=useRfc3264Hold
Replaced by: `SystemSIPDeviceTypeGetResponse20()`

**Attributes:**

|Name                                     |Type                 |Description                          |
|-----------------------------------------|---------------------|-------------------------------------|
|is_obsolete                              |bool                 |isObsolete                           |
|number_of_ports                          |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                  |str                  |profile                              |
|registration_capable                     |bool                 |registrationCapable                  |
|is_conference_device                     |bool                 |isConferenceDevice                   |
|is_mobility_manager_device               |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                  |bool                 |isMusicOnHoldDevice                  |
|hold_normalization                       |str                  |holdNormalization                    |
|hold_announcement_method                 |str                  |holdAnnouncementMethod               |
|is_trusted                               |bool                 |isTrusted                            |
|e164_capable                             |bool                 |E164Capable                          |
|route_advance                            |bool                 |routeAdvance                         |
|forwarding_override                      |bool                 |forwardingOverride                   |
|wireless_integration                     |bool                 |wirelessIntegration                  |
|web_based_config_url                     |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                         |bool                 |isVideoCapable                       |
|pbx_integration                          |bool                 |PBXIntegration                       |
|static_registration_capable              |bool                 |staticRegistrationCapable            |
|cpe_device_options                       |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|protocol_choice                          |List[str]            |protocolChoice                       |
|early_media_support                      |str                  |earlyMediaSupport                    |
|authenticate_refer                       |bool                 |authenticateRefer                    |
|auto_config_soft_client                  |bool                 |autoConfigSoftClient                 |
|authentication_mode                      |str                  |authenticationMode                   |
|requires_broad_works_digit_collection    |bool                 |requiresBroadWorksDigitCollection    |
|requires_broad_works_call_waiting_tone   |bool                 |requiresBroadWorksCallWaitingTone    |
|requires_mwi_subscription                |bool                 |requiresMWISubscription              |
|use_history_info_header_on_access_side   |bool                 |useHistoryInfoHeaderOnAccessSide     |
|advice_of_charge_capable                 |bool                 |adviceOfChargeCapable                |
|reset_event                              |str                  |resetEvent *Optional*                |
|support_call_center_mime_type            |bool                 |supportCallCenterMIMEType            |
|trunk_mode                               |str                  |trunkMode                            |
|add_p_called_party_id                    |bool                 |addPCalledPartyId                    |
|support_identity_in_update_and_re_invite |bool                 |supportIdentityInUpdateAndReInvite   |
|unscreened_presentation_identity_policy  |str                  |unscreenedPresentationIdentityPolicy |
|enable3_g4_g_continuity                  |bool                 |enable3G4GContinuity                 |
|support_emergency_disconnect_control     |bool                 |supportEmergencyDisconnectControl    |
|device_type_configuration_option         |str                  |deviceTypeConfigurationOption        |
|support_rfc3398                          |bool                 |supportRFC3398                       |
|static_line_ordering                     |bool                 |staticLineOrdering                   |
|bypass_media_treatment                   |bool                 |bypassMediaTreatment                 |
</div>


## `SystemSIPDeviceTypeGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest20()`.

The following elements are only used in AS data mode: holdAnnouncementMethod
supportRFC3398 supportClientSessionInfo supportCallInfoConferenceSubscriptionURI
supportRemotePartyInfo The following elements are only used in XS data mode:
enable3G4GContinuity The following element values are only applicable in AS data mode:
holdNormalization=useRfc3264Hold

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|is_obsolete                                   |bool                 |isObsolete                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                               |List[str]            |protocolChoice                           |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enable3_g4_g_continuity                       |bool                 |enable3G4GContinuity                     |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
</div>


## `SystemSIPDeviceTypeGetResponse20sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest20sp1()`.

The following elements are only used in AS data mode: holdAnnouncementMethod
supportRFC3398 supportClientSessionInfo supportCallInfoConferenceSubscriptionURI
supportRemotePartyInfo The following elements are only used in HSS data mode:
enable3G4GContinuity The following element values are only applicable in AS data mode:
holdNormalization=useRfc3264Hold Replaced by: SystemSIPDeviceTypeGetResponse21sp1V2.

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|is_obsolete                                   |bool                 |isObsolete                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                               |List[str]            |protocolChoice                           |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enable3_g4_g_continuity                       |bool                 |enable3G4GContinuity                     |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
</div>


## `SystemSIPDeviceTypeGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest21()`.

The following elements are only used in AS data mode: holdAnnouncementMethod
supportRFC3398 supportClientSessionInfo supportCallInfoConferenceSubscriptionURI
supportRemotePartyInfo The following elements are only used in XS data mode:
enhancedForICS - value false is returned in AS data mode enable3G4GContinuity - value
false is returned in AS data mode publishesOwnPresence - value false is returned in AS
data mode The following element values are only applicable in AS data mode:
holdNormalization=useRfc3264Hold The following elements are only used in AS data mode:
supportCauseParameter - value false is returned in XS data mode Replaced by:
SystemSIPDeviceTypeGetResponse21Sp1

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|is_obsolete                                   |bool                 |isObsolete                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                               |List[str]            |protocolChoice                           |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
</div>


## `SystemSIPDeviceTypeGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest21sp1()`.

The following elements are only used in AS data mode: holdAnnouncementMethod
supportRFC3398 supportClientSessionInfo supportRemotePartyInfo The following elements
are only used in XS data mode: enhancedForICS - value false is returned in AS data
mode enable3G4GContinuity - value false is returned in AS data mode
publishesOwnPresence - value false is returned in AS data mode locationNetwork, value
Fixed is returned in AS data mode The following element values are only applicable in
AS data mode: holdNormalization=useRfc3264Hold The following elements are only used in
AS data mode: supportCauseParameter - value false is returned in XS data mode Replaced
by: SystemSIPDeviceTypeGetResponse21sp1V2

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|is_obsolete                                   |bool                 |isObsolete                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                               |List[str]            |protocolChoice                           |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
</div>


## `SystemSIPDeviceTypeGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest22()`.

The following elements are only used in AS data mode: holdAnnouncementMethod
supportRFC3398 supportClientSessionInfo supportCallInfoConferenceSubscriptionURI
supportRemotePartyInfo The following elements are only used in XS data mode:
enhancedForICS - value false is returned in AS data mode enable3G4GContinuity - value
false is returned in AS data mode publishesOwnPresence - value false is returned in AS
data mode locationNetwork, value Fixed is returned in AS data mode The following
element values are only applicable in AS data mode: holdNormalization=useRfc3264Hold
The following elements are only used in AS data mode: supportCauseParameter - value
false is returned in XS data mode Deprecated by:
`SystemSIPDeviceTypeGetResponse22V2()`

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|is_obsolete                                   |bool                 |isObsolete                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                               |List[str]            |protocolChoice                           |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
</div>


## `SystemSIPDeviceTypeGetResponse22V10`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest22V10()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagementRedirectLink, value "false" is returned
in XS data mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
noCallingPartyCategoryInFromHeader, value "false" is returned in XS data mode
resellerId supportVisualDeviceManagementAPI, value "false" is returned in XS data mode
The following elements are only used in AS data mode and not returned in XS data mode:
deviceCategory deviceFamily The following elements are only used in XS data mode:
enhancedForICS, value "false" is returned in AS data mode supports3G4GContinuity,
value "false" is returned in AS data mode publishesOwnPresence, value "false" is
returned in AS data mode locationNetwork, value "Fixed" is returned in AS data mode
allowTerminationBasedOnICSI, value "false" is returned in AS data mode roamingMode,
value "None" is returned in AS data mode

Replaced By: `SystemSIPDeviceTypeGetResponse23V6()`

**Attributes:**

|Name                                           |Type                 |Description                                 |
|-----------------------------------------------|---------------------|--------------------------------------------|
|is_obsolete                                    |bool                 |isObsolete                                  |
|number_of_ports                                |OCI.numberOfPorts    |numberOfPorts                               |
|profile                                        |str                  |profile                                     |
|registration_capable                           |bool                 |registrationCapable                         |
|is_conference_device                           |bool                 |isConferenceDevice                          |
|is_mobility_manager_device                     |bool                 |isMobilityManagerDevice                     |
|is_music_on_hold_device                        |bool                 |isMusicOnHoldDevice                         |
|hold_normalization                             |str                  |holdNormalization                           |
|hold_announcement_method                       |str                  |holdAnnouncementMethod                      |
|is_trusted                                     |bool                 |isTrusted                                   |
|e164_capable                                   |bool                 |E164Capable                                 |
|route_advance                                  |bool                 |routeAdvance                                |
|forwarding_override                            |bool                 |forwardingOverride                          |
|wireless_integration                           |bool                 |wirelessIntegration                         |
|web_based_config_url                           |str                  |webBasedConfigURL *Optional*                |
|is_video_capable                               |bool                 |isVideoCapable                              |
|pbx_integration                                |bool                 |PBXIntegration                              |
|static_registration_capable                    |bool                 |staticRegistrationCapable                   |
|cpe_device_options                             |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                 |
|protocol_choice                                |List[str]            |protocolChoice                              |
|early_media_support                            |str                  |earlyMediaSupport                           |
|authenticate_refer                             |bool                 |authenticateRefer                           |
|auto_config_soft_client                        |bool                 |autoConfigSoftClient                        |
|authentication_mode                            |str                  |authenticationMode                          |
|requires_broad_works_digit_collection          |bool                 |requiresBroadWorksDigitCollection           |
|requires_broad_works_call_waiting_tone         |bool                 |requiresBroadWorksCallWaitingTone           |
|requires_mwi_subscription                      |bool                 |requiresMWISubscription                     |
|use_history_info_header_on_access_side         |bool                 |useHistoryInfoHeaderOnAccessSide            |
|advice_of_charge_capable                       |bool                 |adviceOfChargeCapable                       |
|reset_event                                    |str                  |resetEvent *Optional*                       |
|support_call_center_mime_type                  |bool                 |supportCallCenterMIMEType                   |
|trunk_mode                                     |str                  |trunkMode                                   |
|add_p_called_party_id                          |bool                 |addPCalledPartyId                           |
|support_identity_in_update_and_re_invite       |bool                 |supportIdentityInUpdateAndReInvite          |
|unscreened_presentation_identity_policy        |str                  |unscreenedPresentationIdentityPolicy        |
|enhanced_for_ics                               |bool                 |enhancedForICS                              |
|support_emergency_disconnect_control           |bool                 |supportEmergencyDisconnectControl           |
|device_type_configuration_option               |str                  |deviceTypeConfigurationOption               |
|support_rfc3398                                |bool                 |supportRFC3398                              |
|static_line_ordering                           |bool                 |staticLineOrdering                          |
|support_client_session_info                    |bool                 |supportClientSessionInfo                    |
|support_call_info_conference_subscription_uri  |bool                 |supportCallInfoConferenceSubscriptionURI    |
|support_remote_party_info                      |bool                 |supportRemotePartyInfo                      |
|support_visual_device_management_redirect_link |bool                 |supportVisualDeviceManagementRedirectLink   |
|bypass_media_treatment                         |bool                 |bypassMediaTreatment                        |
|supports3_g4_g_continuity                      |bool                 |supports3G4GContinuity                      |
|publishes_own_presence                         |bool                 |publishesOwnPresence                        |
|support_cause_parameter                        |bool                 |supportCauseParameter                       |
|location_network                               |str                  |locationNetwork                             |
|reseller_id                                    |str                  |resellerId *Optional*                       |
|allow_termination_based_on_icsi                |bool                 |allowTerminationBasedOnICSI                 |
|roaming_mode                                   |str                  |roamingMode                                 |
|support_visual_device_management_api           |bool                 |supportVisualDeviceManagementAPI *Optional* |
|device_category                                |str                  |deviceCategory *Optional*                   |
|device_family                                  |str                  |deviceFamily *Optional*                     |
</div>


## `SystemSIPDeviceTypeGetResponse22V11`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest22V11()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagementRedirectLink, value "false" is returned
in XS data mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
noCallingPartyCategoryInFromHeader, value "false" is returned in XS data mode
resellerId supportVisualDeviceManagementAPI, value "false" is returned in XS data mode
verstatInPAIHeader, value "false" is returned in XS data mode verstatInFromHeader,
value "false" is returned in XS data mode The following elements are only used in AS
data mode and not returned in XS data mode: deviceCategory deviceFamily The following
elements are only used in XS data mode: enhancedForICS, value "false" is returned in
AS data mode supports3G4GContinuity, value "false" is returned in AS data mode
publishesOwnPresence, value "false" is returned in AS data mode locationNetwork, value
"Fixed" is returned in AS data mode allowTerminationBasedOnICSI, value "false" is
returned in AS data mode roamingMode, value "None" is returned in AS data mode
Replaced by `SystemSIPDeviceTypeGetResponse23V7()`

**Attributes:**

|Name                                           |Type                 |Description                                 |
|-----------------------------------------------|---------------------|--------------------------------------------|
|is_obsolete                                    |bool                 |isObsolete                                  |
|number_of_ports                                |OCI.numberOfPorts    |numberOfPorts                               |
|profile                                        |str                  |profile                                     |
|registration_capable                           |bool                 |registrationCapable                         |
|is_conference_device                           |bool                 |isConferenceDevice                          |
|is_mobility_manager_device                     |bool                 |isMobilityManagerDevice                     |
|is_music_on_hold_device                        |bool                 |isMusicOnHoldDevice                         |
|hold_normalization                             |str                  |holdNormalization                           |
|hold_announcement_method                       |str                  |holdAnnouncementMethod                      |
|is_trusted                                     |bool                 |isTrusted                                   |
|e164_capable                                   |bool                 |E164Capable                                 |
|route_advance                                  |bool                 |routeAdvance                                |
|forwarding_override                            |bool                 |forwardingOverride                          |
|wireless_integration                           |bool                 |wirelessIntegration                         |
|web_based_config_url                           |str                  |webBasedConfigURL *Optional*                |
|is_video_capable                               |bool                 |isVideoCapable                              |
|pbx_integration                                |bool                 |PBXIntegration                              |
|static_registration_capable                    |bool                 |staticRegistrationCapable                   |
|cpe_device_options                             |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                 |
|protocol_choice                                |List[str]            |protocolChoice                              |
|early_media_support                            |str                  |earlyMediaSupport                           |
|authenticate_refer                             |bool                 |authenticateRefer                           |
|auto_config_soft_client                        |bool                 |autoConfigSoftClient                        |
|authentication_mode                            |str                  |authenticationMode                          |
|requires_broad_works_digit_collection          |bool                 |requiresBroadWorksDigitCollection           |
|requires_broad_works_call_waiting_tone         |bool                 |requiresBroadWorksCallWaitingTone           |
|requires_mwi_subscription                      |bool                 |requiresMWISubscription                     |
|use_history_info_header_on_access_side         |bool                 |useHistoryInfoHeaderOnAccessSide            |
|advice_of_charge_capable                       |bool                 |adviceOfChargeCapable                       |
|reset_event                                    |str                  |resetEvent *Optional*                       |
|support_call_center_mime_type                  |bool                 |supportCallCenterMIMEType                   |
|trunk_mode                                     |str                  |trunkMode                                   |
|add_p_called_party_id                          |bool                 |addPCalledPartyId                           |
|support_identity_in_update_and_re_invite       |bool                 |supportIdentityInUpdateAndReInvite          |
|unscreened_presentation_identity_policy        |str                  |unscreenedPresentationIdentityPolicy        |
|enhanced_for_ics                               |bool                 |enhancedForICS                              |
|support_emergency_disconnect_control           |bool                 |supportEmergencyDisconnectControl           |
|device_type_configuration_option               |str                  |deviceTypeConfigurationOption               |
|support_rfc3398                                |bool                 |supportRFC3398                              |
|static_line_ordering                           |bool                 |staticLineOrdering                          |
|support_client_session_info                    |bool                 |supportClientSessionInfo                    |
|support_call_info_conference_subscription_uri  |bool                 |supportCallInfoConferenceSubscriptionURI    |
|support_remote_party_info                      |bool                 |supportRemotePartyInfo                      |
|support_visual_device_management_redirect_link |bool                 |supportVisualDeviceManagementRedirectLink   |
|bypass_media_treatment                         |bool                 |bypassMediaTreatment                        |
|supports3_g4_g_continuity                      |bool                 |supports3G4GContinuity                      |
|publishes_own_presence                         |bool                 |publishesOwnPresence                        |
|support_cause_parameter                        |bool                 |supportCauseParameter                       |
|location_network                               |str                  |locationNetwork                             |
|reseller_id                                    |str                  |resellerId *Optional*                       |
|allow_termination_based_on_icsi                |bool                 |allowTerminationBasedOnICSI                 |
|roaming_mode                                   |str                  |roamingMode                                 |
|support_visual_device_management_api           |bool                 |supportVisualDeviceManagementAPI *Optional* |
|device_category                                |str                  |deviceCategory *Optional*                   |
|device_family                                  |str                  |deviceFamily *Optional*                     |
|verstat_in_pai_header                          |bool                 |verstatInPAIHeader *Optional*               |
|verstat_in_from_header                         |bool                 |verstatInFromHeader *Optional*              |
</div>


## `SystemSIPDeviceTypeGetResponse22V12`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest22V12()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagementRedirectLink, value "false" is returned
in XS data mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
noCallingPartyCategoryInFromHeader, value "false" is returned in XS data mode
resellerId supportVisualDeviceManagementAPI, value "false" is returned in XS data mode
verstatInPAIHeader, value "false" is returned in XS data mode verstatInFromHeader,
value "false" is returned in XS data mode The following elements are only used in AS
data mode and not returned in XS data mode: deviceCategory deviceFamily The following
elements are only used in XS data mode: enhancedForICS, value "false" is returned in
AS data mode supports3G4GContinuity, value "false" is returned in AS data mode
publishesOwnPresence, value "false" is returned in AS data mode locationNetwork, value
"Fixed" is returned in AS data mode allowTerminationBasedOnICSI, value "false" is
returned in AS data mode roamingMode, value "None" is returned in AS data mode
Replaced by `SystemSIPDeviceTypeGetResponse23V8()`

**Attributes:**

|Name                                           |Type                 |Description                                 |
|-----------------------------------------------|---------------------|--------------------------------------------|
|is_obsolete                                    |bool                 |isObsolete                                  |
|number_of_ports                                |OCI.numberOfPorts    |numberOfPorts                               |
|profile                                        |str                  |profile                                     |
|registration_capable                           |bool                 |registrationCapable                         |
|is_conference_device                           |bool                 |isConferenceDevice                          |
|is_mobility_manager_device                     |bool                 |isMobilityManagerDevice                     |
|is_music_on_hold_device                        |bool                 |isMusicOnHoldDevice                         |
|hold_normalization                             |str                  |holdNormalization                           |
|hold_announcement_method                       |str                  |holdAnnouncementMethod                      |
|is_trusted                                     |bool                 |isTrusted                                   |
|e164_capable                                   |bool                 |E164Capable                                 |
|route_advance                                  |bool                 |routeAdvance                                |
|forwarding_override                            |bool                 |forwardingOverride                          |
|wireless_integration                           |bool                 |wirelessIntegration                         |
|web_based_config_url                           |str                  |webBasedConfigURL *Optional*                |
|is_video_capable                               |bool                 |isVideoCapable                              |
|pbx_integration                                |bool                 |PBXIntegration                              |
|static_registration_capable                    |bool                 |staticRegistrationCapable                   |
|cpe_device_options                             |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                 |
|protocol_choice                                |List[str]            |protocolChoice                              |
|early_media_support                            |str                  |earlyMediaSupport                           |
|authenticate_refer                             |bool                 |authenticateRefer                           |
|auto_config_soft_client                        |bool                 |autoConfigSoftClient                        |
|authentication_mode                            |str                  |authenticationMode                          |
|requires_broad_works_digit_collection          |bool                 |requiresBroadWorksDigitCollection           |
|requires_broad_works_call_waiting_tone         |bool                 |requiresBroadWorksCallWaitingTone           |
|requires_mwi_subscription                      |bool                 |requiresMWISubscription                     |
|use_history_info_header_on_access_side         |bool                 |useHistoryInfoHeaderOnAccessSide            |
|advice_of_charge_capable                       |bool                 |adviceOfChargeCapable                       |
|reset_event                                    |str                  |resetEvent *Optional*                       |
|support_call_center_mime_type                  |bool                 |supportCallCenterMIMEType                   |
|trunk_mode                                     |str                  |trunkMode                                   |
|add_p_called_party_id                          |bool                 |addPCalledPartyId                           |
|support_identity_in_update_and_re_invite       |bool                 |supportIdentityInUpdateAndReInvite          |
|unscreened_presentation_identity_policy        |str                  |unscreenedPresentationIdentityPolicy        |
|enhanced_for_ics                               |bool                 |enhancedForICS                              |
|support_emergency_disconnect_control           |bool                 |supportEmergencyDisconnectControl           |
|device_type_configuration_option               |str                  |deviceTypeConfigurationOption               |
|support_rfc3398                                |bool                 |supportRFC3398                              |
|static_line_ordering                           |bool                 |staticLineOrdering                          |
|support_client_session_info                    |bool                 |supportClientSessionInfo                    |
|support_call_info_conference_subscription_uri  |bool                 |supportCallInfoConferenceSubscriptionURI    |
|support_remote_party_info                      |bool                 |supportRemotePartyInfo                      |
|support_visual_device_management_redirect_link |bool                 |supportVisualDeviceManagementRedirectLink   |
|bypass_media_treatment                         |bool                 |bypassMediaTreatment                        |
|supports3_g4_g_continuity                      |bool                 |supports3G4GContinuity                      |
|publishes_own_presence                         |bool                 |publishesOwnPresence                        |
|support_cause_parameter                        |bool                 |supportCauseParameter                       |
|location_network                               |str                  |locationNetwork                             |
|reseller_id                                    |str                  |resellerId *Optional*                       |
|allow_termination_based_on_icsi                |bool                 |allowTerminationBasedOnICSI                 |
|roaming_mode                                   |str                  |roamingMode                                 |
|support_visual_device_management_api           |bool                 |supportVisualDeviceManagementAPI *Optional* |
|device_category                                |str                  |deviceCategory *Optional*                   |
|device_family                                  |str                  |deviceFamily *Optional*                     |
|verstat_in_pai_header                          |bool                 |verstatInPAIHeader *Optional*               |
|verstat_in_from_header                         |bool                 |verstatInFromHeader *Optional*              |
</div>


## `SystemSIPDeviceTypeGetResponse22V13`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest22V13()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagementRedirectLink, value "false" is returned
in XS data mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
noCallingPartyCategoryInFromHeader, value "false" is returned in XS data mode
resellerId supportVisualDeviceManagementAPI, value "false" is returned in XS data mode
verstatInPAIHeader, value "false" is returned in XS data mode verstatInFromHeader,
value "false" is returned in XS data mode The following elements are only used in AS
data mode and not returned in XS data mode: deviceCategory deviceFamily The following
elements are only used in XS data mode: enhancedForICS, value "false" is returned in
AS data mode supports3G4GContinuity, value "false" is returned in AS data mode
publishesOwnPresence, value "false" is returned in AS data mode locationNetwork, value
"Fixed" is returned in AS data mode allowTerminationBasedOnICSI, value "false" is
returned in AS data mode roamingMode, value "None" is returned in AS data mode
Replaced by: `SystemSIPDeviceTypeGetResponse23V9()`

**Attributes:**

|Name                                           |Type                 |Description                                 |
|-----------------------------------------------|---------------------|--------------------------------------------|
|is_obsolete                                    |bool                 |isObsolete                                  |
|number_of_ports                                |OCI.numberOfPorts    |numberOfPorts                               |
|profile                                        |str                  |profile                                     |
|registration_capable                           |bool                 |registrationCapable                         |
|is_conference_device                           |bool                 |isConferenceDevice                          |
|is_mobility_manager_device                     |bool                 |isMobilityManagerDevice                     |
|is_music_on_hold_device                        |bool                 |isMusicOnHoldDevice                         |
|hold_normalization                             |str                  |holdNormalization                           |
|hold_announcement_method                       |str                  |holdAnnouncementMethod                      |
|is_trusted                                     |bool                 |isTrusted                                   |
|e164_capable                                   |bool                 |E164Capable                                 |
|route_advance                                  |bool                 |routeAdvance                                |
|forwarding_override                            |bool                 |forwardingOverride                          |
|wireless_integration                           |bool                 |wirelessIntegration                         |
|web_based_config_url                           |str                  |webBasedConfigURL *Optional*                |
|is_video_capable                               |bool                 |isVideoCapable                              |
|pbx_integration                                |bool                 |PBXIntegration                              |
|static_registration_capable                    |bool                 |staticRegistrationCapable                   |
|cpe_device_options                             |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                 |
|protocol_choice                                |List[str]            |protocolChoice                              |
|early_media_support                            |str                  |earlyMediaSupport                           |
|authenticate_refer                             |bool                 |authenticateRefer                           |
|auto_config_soft_client                        |bool                 |autoConfigSoftClient                        |
|authentication_mode                            |str                  |authenticationMode                          |
|requires_broad_works_digit_collection          |bool                 |requiresBroadWorksDigitCollection           |
|requires_broad_works_call_waiting_tone         |bool                 |requiresBroadWorksCallWaitingTone           |
|requires_mwi_subscription                      |bool                 |requiresMWISubscription                     |
|use_history_info_header_on_access_side         |bool                 |useHistoryInfoHeaderOnAccessSide            |
|advice_of_charge_capable                       |bool                 |adviceOfChargeCapable                       |
|reset_event                                    |str                  |resetEvent *Optional*                       |
|reset_string                                   |str                  |resetString *Optional*                      |
|support_call_center_mime_type                  |bool                 |supportCallCenterMIMEType                   |
|trunk_mode                                     |str                  |trunkMode                                   |
|add_p_called_party_id                          |bool                 |addPCalledPartyId                           |
|support_identity_in_update_and_re_invite       |bool                 |supportIdentityInUpdateAndReInvite          |
|unscreened_presentation_identity_policy        |str                  |unscreenedPresentationIdentityPolicy        |
|enhanced_for_ics                               |bool                 |enhancedForICS                              |
|support_emergency_disconnect_control           |bool                 |supportEmergencyDisconnectControl           |
|device_type_configuration_option               |str                  |deviceTypeConfigurationOption               |
|support_rfc3398                                |bool                 |supportRFC3398                              |
|static_line_ordering                           |bool                 |staticLineOrdering                          |
|support_client_session_info                    |bool                 |supportClientSessionInfo                    |
|support_call_info_conference_subscription_uri  |bool                 |supportCallInfoConferenceSubscriptionURI    |
|support_remote_party_info                      |bool                 |supportRemotePartyInfo                      |
|support_visual_device_management_redirect_link |bool                 |supportVisualDeviceManagementRedirectLink   |
|bypass_media_treatment                         |bool                 |bypassMediaTreatment                        |
|supports3_g4_g_continuity                      |bool                 |supports3G4GContinuity                      |
|publishes_own_presence                         |bool                 |publishesOwnPresence                        |
|support_cause_parameter                        |bool                 |supportCauseParameter                       |
|location_network                               |str                  |locationNetwork                             |
|reseller_id                                    |str                  |resellerId *Optional*                       |
|allow_termination_based_on_icsi                |bool                 |allowTerminationBasedOnICSI                 |
|roaming_mode                                   |str                  |roamingMode                                 |
|support_visual_device_management_api           |bool                 |supportVisualDeviceManagementAPI *Optional* |
|device_category                                |str                  |deviceCategory *Optional*                   |
|device_family                                  |str                  |deviceFamily *Optional*                     |
|verstat_in_pai_header                          |bool                 |verstatInPAIHeader *Optional*               |
|verstat_in_from_header                         |bool                 |verstatInFromHeader *Optional*              |
</div>


## `SystemSIPDeviceTypeGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest22V2()`.

The following elements are only used in AS data mode: holdAnnouncementMethod
supportRFC3398 supportClientSessionInfo supportCallInfoConferenceSubscriptionURI
supportRemotePartyInfo resellerId The following elements are only used in XS data
mode: enhancedForICS - value false is returned in AS data mode enable3G4GContinuity -
value false is returned in AS data mode publishesOwnPresence - value false is returned
in AS data mode locationNetwork, value Fixed is returned in AS data mode The following
element values are only applicable in AS data mode: holdNormalization=useRfc3264Hold
The following elements are only used in AS data mode: supportCauseParameter - value
false is returned in XS data mode Deprecated by `SystemSIPDeviceTypeGetResponse22V3()`

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|is_obsolete                                   |bool                 |isObsolete                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                               |List[str]            |protocolChoice                           |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
|reseller_id                                   |str                  |resellerId *Optional*                    |
</div>


## `SystemSIPDeviceTypeGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest22V3()`.

Deprecated by `SystemSIPDeviceTypeGetResponse22V4()`. The following elements are only
used in AS data mode: supportClientSessionInfo, value "false" is returned in XS data
mode supportCallInfoConferenceSubscriptionURI, value "false" is returned in XS data
mode supportRemotePartyInfo, value "false" is returned in XS data mode
supportVisualDeviceManagement, value "false" is returned in XS data mode
bypassMediaTreatment, value "false" is returned in XS data mode supportCauseParameter,
value "false" is returned in XS data mode resellerId The following elements are only
used in XS data mode: enhancedForICS, value "false" is returned in AS data mode
supports3G4GContinuity, value "false" is returned in AS data mode
publishesOwnPresence, value "false" is returned in AS data mode locationNetwork, value
"Fixed" is returned in AS data mode allowTerminationBasedOnICSI, value "false" is
returned in AS data mode roamingMode, value "None" is returned in AS data mode

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|is_obsolete                                   |bool                 |isObsolete                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                               |List[str]            |protocolChoice                           |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
|allow_termination_based_on_icsi               |bool                 |allowTerminationBasedOnICSI              |
|roaming_mode                                  |str                  |roamingMode                              |
|reseller_id                                   |str                  |resellerId *Optional*                    |
</div>


## `SystemSIPDeviceTypeGetResponse22V4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest22V4()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagement, value "false" is returned in XS data
mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode resellerId The
following elements are only used in XS data mode: enhancedForICS, value "false" is
returned in AS data mode supports3G4GContinuity, value "false" is returned in AS data
mode publishesOwnPresence, value "false" is returned in AS data mode locationNetwork,
value "Fixed" is returned in AS data mode allowTerminationBasedOnICSI, value "false"
is returned in AS data mode roamingMode, value "None" is returned in AS data mode

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|is_obsolete                                   |bool                 |isObsolete                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                               |List[str]            |protocolChoice                           |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
|reseller_id                                   |str                  |resellerId *Optional*                    |
|allow_termination_based_on_icsi               |bool                 |allowTerminationBasedOnICSI              |
|roaming_mode                                  |str                  |roamingMode                              |
</div>


## `SystemSIPDeviceTypeGetResponse22V5`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest22V5()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagement, value "false" is returned in XS data
mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode resellerId The
following elements are only used in XS data mode: enhancedForICS, value "false" is
returned in AS data mode supports3G4GContinuity, value "false" is returned in AS data
mode publishesOwnPresence, value "false" is returned in AS data mode locationNetwork,
value "Fixed" is returned in AS data mode allowTerminationBasedOnICSI, value "false"
is returned in AS data mode roamingMode, value "None" is returned in AS data mode
Replaced by: `SystemDeviceTypeGetResponse22V13()` in XS data mode.  Replaced by:
`SystemDeviceTypeGetResponse22V6()` in AS data mode.

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|is_obsolete                                   |bool                 |isObsolete                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                               |List[str]            |protocolChoice                           |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
|reseller_id                                   |str                  |resellerId *Optional*                    |
|allow_termination_based_on_icsi               |bool                 |allowTerminationBasedOnICSI              |
|roaming_mode                                  |str                  |roamingMode                              |
</div>


## `SystemSIPDeviceTypeGetResponse22V6`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest22V6()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagement, value "false" is returned in XS data
mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
noCallingPartyCategoryInFromHeader, value "false" is returned in XS data mode
resellerId The following elements are only used in XS data mode: enhancedForICS, value
"false" is returned in AS data mode supports3G4GContinuity, value "false" is returned
in AS data mode publishesOwnPresence, value "false" is returned in AS data mode
locationNetwork, value "Fixed" is returned in AS data mode
allowTerminationBasedOnICSI, value "false" is returned in AS data mode roamingMode,
value "None" is returned in AS data mode

Replaced By: `SystemSIPDeviceTypeGetResponse23V2()`

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|is_obsolete                                   |bool                 |isObsolete                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                               |List[str]            |protocolChoice                           |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
|reseller_id                                   |str                  |resellerId *Optional*                    |
|allow_termination_based_on_icsi               |bool                 |allowTerminationBasedOnICSI              |
|roaming_mode                                  |str                  |roamingMode                              |
</div>


## `SystemSIPDeviceTypeGetResponse22V7`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest22V7()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagement, value "false" is returned in XS data
mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
noCallingPartyCategoryInFromHeader, value "false" is returned in XS data mode
resellerId The following elements are only used in XS data mode: enhancedForICS, value
"false" is returned in AS data mode supports3G4GContinuity, value "false" is returned
in AS data mode publishesOwnPresence, value "false" is returned in AS data mode
locationNetwork, value "Fixed" is returned in AS data mode
allowTerminationBasedOnICSI, value "false" is returned in AS data mode roamingMode,
value "None" is returned in AS data mode

Replaced By: `SystemSIPDeviceTypeGetResponse23V2()`

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|is_obsolete                                   |bool                 |isObsolete                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|protocol_choice                               |List[str]            |protocolChoice                           |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
|reseller_id                                   |str                  |resellerId *Optional*                    |
|allow_termination_based_on_icsi               |bool                 |allowTerminationBasedOnICSI              |
|roaming_mode                                  |str                  |roamingMode                              |
</div>


## `SystemSIPDeviceTypeGetResponse22V8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest22V8()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagementRedirectLink, value "false" is returned
in XS data mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
noCallingPartyCategoryInFromHeader, value "false" is returned in XS data mode
resellerId supportVisualDeviceManagementAPI, value "false" is returned in XS data mode
The following elements are only used in XS data mode: enhancedForICS, value "false" is
returned in AS data mode supports3G4GContinuity, value "false" is returned in AS data
mode publishesOwnPresence, value "false" is returned in AS data mode locationNetwork,
value "Fixed" is returned in AS data mode allowTerminationBasedOnICSI, value "false"
is returned in AS data mode roamingMode, value "None" is returned in AS data mode

Replaced By: `SystemSIPDeviceTypeGetResponse23V4()`

**Attributes:**

|Name                                           |Type                 |Description                                 |
|-----------------------------------------------|---------------------|--------------------------------------------|
|is_obsolete                                    |bool                 |isObsolete                                  |
|number_of_ports                                |OCI.numberOfPorts    |numberOfPorts                               |
|profile                                        |str                  |profile                                     |
|registration_capable                           |bool                 |registrationCapable                         |
|is_conference_device                           |bool                 |isConferenceDevice                          |
|is_mobility_manager_device                     |bool                 |isMobilityManagerDevice                     |
|is_music_on_hold_device                        |bool                 |isMusicOnHoldDevice                         |
|hold_normalization                             |str                  |holdNormalization                           |
|hold_announcement_method                       |str                  |holdAnnouncementMethod                      |
|is_trusted                                     |bool                 |isTrusted                                   |
|e164_capable                                   |bool                 |E164Capable                                 |
|route_advance                                  |bool                 |routeAdvance                                |
|forwarding_override                            |bool                 |forwardingOverride                          |
|wireless_integration                           |bool                 |wirelessIntegration                         |
|web_based_config_url                           |str                  |webBasedConfigURL *Optional*                |
|is_video_capable                               |bool                 |isVideoCapable                              |
|pbx_integration                                |bool                 |PBXIntegration                              |
|static_registration_capable                    |bool                 |staticRegistrationCapable                   |
|cpe_device_options                             |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                 |
|protocol_choice                                |List[str]            |protocolChoice                              |
|early_media_support                            |str                  |earlyMediaSupport                           |
|authenticate_refer                             |bool                 |authenticateRefer                           |
|auto_config_soft_client                        |bool                 |autoConfigSoftClient                        |
|authentication_mode                            |str                  |authenticationMode                          |
|requires_broad_works_digit_collection          |bool                 |requiresBroadWorksDigitCollection           |
|requires_broad_works_call_waiting_tone         |bool                 |requiresBroadWorksCallWaitingTone           |
|requires_mwi_subscription                      |bool                 |requiresMWISubscription                     |
|use_history_info_header_on_access_side         |bool                 |useHistoryInfoHeaderOnAccessSide            |
|advice_of_charge_capable                       |bool                 |adviceOfChargeCapable                       |
|reset_event                                    |str                  |resetEvent *Optional*                       |
|support_call_center_mime_type                  |bool                 |supportCallCenterMIMEType                   |
|trunk_mode                                     |str                  |trunkMode                                   |
|add_p_called_party_id                          |bool                 |addPCalledPartyId                           |
|support_identity_in_update_and_re_invite       |bool                 |supportIdentityInUpdateAndReInvite          |
|unscreened_presentation_identity_policy        |str                  |unscreenedPresentationIdentityPolicy        |
|enhanced_for_ics                               |bool                 |enhancedForICS                              |
|support_emergency_disconnect_control           |bool                 |supportEmergencyDisconnectControl           |
|device_type_configuration_option               |str                  |deviceTypeConfigurationOption               |
|support_rfc3398                                |bool                 |supportRFC3398                              |
|static_line_ordering                           |bool                 |staticLineOrdering                          |
|support_client_session_info                    |bool                 |supportClientSessionInfo                    |
|support_call_info_conference_subscription_uri  |bool                 |supportCallInfoConferenceSubscriptionURI    |
|support_remote_party_info                      |bool                 |supportRemotePartyInfo                      |
|support_visual_device_management_redirect_link |bool                 |supportVisualDeviceManagementRedirectLink   |
|bypass_media_treatment                         |bool                 |bypassMediaTreatment                        |
|supports3_g4_g_continuity                      |bool                 |supports3G4GContinuity                      |
|publishes_own_presence                         |bool                 |publishesOwnPresence                        |
|support_cause_parameter                        |bool                 |supportCauseParameter                       |
|location_network                               |str                  |locationNetwork                             |
|reseller_id                                    |str                  |resellerId *Optional*                       |
|allow_termination_based_on_icsi                |bool                 |allowTerminationBasedOnICSI                 |
|roaming_mode                                   |str                  |roamingMode                                 |
|support_visual_device_management_api           |bool                 |supportVisualDeviceManagementAPI *Optional* |
</div>


## `SystemSIPDeviceTypeGetResponse22V9`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest22V8()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagementRedirectLink, value "false" is returned
in XS data mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
noCallingPartyCategoryInFromHeader, value "false" is returned in XS data mode
resellerId supportVisualDeviceManagementAPI, value "false" is returned in XS data mode
Replaced by: `GroupMusicOnHoldGetInstanceResponse22V2()` The following elements are
only used in AS data mode and not returned in XS data mode: deviceCategory
deviceFamily The following elements are only used in XS data mode: enhancedForICS,
value "false" is returned in AS data mode supports3G4GContinuity, value "false" is
returned in AS data mode publishesOwnPresence, value "false" is returned in AS data
mode locationNetwork, value "Fixed" is returned in AS data mode
allowTerminationBasedOnICSI, value "false" is returned in AS data mode roamingMode,
value "None" is returned in AS data mode

Replaced By: `SystemSIPDeviceTypeGetResponse23V6()`

**Attributes:**

|Name                                           |Type                 |Description                                 |
|-----------------------------------------------|---------------------|--------------------------------------------|
|is_obsolete                                    |bool                 |isObsolete                                  |
|number_of_ports                                |OCI.numberOfPorts    |numberOfPorts                               |
|profile                                        |str                  |profile                                     |
|registration_capable                           |bool                 |registrationCapable                         |
|is_conference_device                           |bool                 |isConferenceDevice                          |
|is_mobility_manager_device                     |bool                 |isMobilityManagerDevice                     |
|is_music_on_hold_device                        |bool                 |isMusicOnHoldDevice                         |
|hold_normalization                             |str                  |holdNormalization                           |
|hold_announcement_method                       |str                  |holdAnnouncementMethod                      |
|is_trusted                                     |bool                 |isTrusted                                   |
|e164_capable                                   |bool                 |E164Capable                                 |
|route_advance                                  |bool                 |routeAdvance                                |
|forwarding_override                            |bool                 |forwardingOverride                          |
|wireless_integration                           |bool                 |wirelessIntegration                         |
|web_based_config_url                           |str                  |webBasedConfigURL *Optional*                |
|is_video_capable                               |bool                 |isVideoCapable                              |
|pbx_integration                                |bool                 |PBXIntegration                              |
|static_registration_capable                    |bool                 |staticRegistrationCapable                   |
|cpe_device_options                             |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                 |
|protocol_choice                                |List[str]            |protocolChoice                              |
|early_media_support                            |str                  |earlyMediaSupport                           |
|authenticate_refer                             |bool                 |authenticateRefer                           |
|auto_config_soft_client                        |bool                 |autoConfigSoftClient                        |
|authentication_mode                            |str                  |authenticationMode                          |
|requires_broad_works_digit_collection          |bool                 |requiresBroadWorksDigitCollection           |
|requires_broad_works_call_waiting_tone         |bool                 |requiresBroadWorksCallWaitingTone           |
|requires_mwi_subscription                      |bool                 |requiresMWISubscription                     |
|use_history_info_header_on_access_side         |bool                 |useHistoryInfoHeaderOnAccessSide            |
|advice_of_charge_capable                       |bool                 |adviceOfChargeCapable                       |
|reset_event                                    |str                  |resetEvent *Optional*                       |
|support_call_center_mime_type                  |bool                 |supportCallCenterMIMEType                   |
|trunk_mode                                     |str                  |trunkMode                                   |
|add_p_called_party_id                          |bool                 |addPCalledPartyId                           |
|support_identity_in_update_and_re_invite       |bool                 |supportIdentityInUpdateAndReInvite          |
|unscreened_presentation_identity_policy        |str                  |unscreenedPresentationIdentityPolicy        |
|enhanced_for_ics                               |bool                 |enhancedForICS                              |
|support_emergency_disconnect_control           |bool                 |supportEmergencyDisconnectControl           |
|device_type_configuration_option               |str                  |deviceTypeConfigurationOption               |
|support_rfc3398                                |bool                 |supportRFC3398                              |
|static_line_ordering                           |bool                 |staticLineOrdering                          |
|support_client_session_info                    |bool                 |supportClientSessionInfo                    |
|support_call_info_conference_subscription_uri  |bool                 |supportCallInfoConferenceSubscriptionURI    |
|support_remote_party_info                      |bool                 |supportRemotePartyInfo                      |
|support_visual_device_management_redirect_link |bool                 |supportVisualDeviceManagementRedirectLink   |
|bypass_media_treatment                         |bool                 |bypassMediaTreatment                        |
|supports3_g4_g_continuity                      |bool                 |supports3G4GContinuity                      |
|publishes_own_presence                         |bool                 |publishesOwnPresence                        |
|support_cause_parameter                        |bool                 |supportCauseParameter                       |
|location_network                               |str                  |locationNetwork                             |
|reseller_id                                    |str                  |resellerId *Optional*                       |
|allow_termination_based_on_icsi                |bool                 |allowTerminationBasedOnICSI                 |
|roaming_mode                                   |str                  |roamingMode                                 |
|support_visual_device_management_api           |bool                 |supportVisualDeviceManagementAPI *Optional* |
|device_category                                |str                  |deviceCategory *Optional*                   |
|device_family                                  |str                  |deviceFamily *Optional*                     |
</div>


## `SystemSIPDeviceTypeGetResponse23`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest23()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagement, value "false" is returned in XS data
mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
supportCallingPartyCategoryInOutboundFromHeader, value "true" is returned in XS data
mode resellerId The following elements are only used in XS data mode: enhancedForICS,
value "false" is returned in AS data mode supports3G4GContinuity, value "false" is
returned in AS data mode publishesOwnPresence, value "false" is returned in AS data
mode locationNetwork, value "Fixed" is returned in AS data mode
allowTerminationBasedOnICSI, value "false" is returned in AS data mode roamingMode,
value "None" is returned in AS data mode

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|is_obsolete                                            |bool                 |isObsolete                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|protocol_choice                                        |List[str]            |protocolChoice                                  |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management                       |bool                 |supportVisualDeviceManagement                   |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
</div>


## `SystemSIPDeviceTypeGetResponse23V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest23V2()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagement, value "false" is returned in XS data
mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
supportCallingPartyCategoryInOutboundFromHeader, value "true" is returned in XS data
mode resellerId The following elements are only used in XS data mode: enhancedForICS,
value "false" is returned in AS data mode supports3G4GContinuity, value "false" is
returned in AS data mode publishesOwnPresence, value "false" is returned in AS data
mode locationNetwork, value "Fixed" is returned in AS data mode
allowTerminationBasedOnICSI, value "false" is returned in AS data mode roamingMode,
value "None" is returned in AS data mode

Replaced By: `SystemSIPDeviceTypeGetResponse23V3()`.

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|is_obsolete                                            |bool                 |isObsolete                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|protocol_choice                                        |List[str]            |protocolChoice                                  |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management                       |bool                 |supportVisualDeviceManagement                   |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
</div>


## `SystemSIPDeviceTypeGetResponse23V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest23V3()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagement, value "false" is returned in XS data
mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
supportCallingPartyCategoryInOutboundFromHeader, value "true" is returned in XS data
mode resellerId The following elements are only used in XS data mode: enhancedForICS,
value "false" is returned in AS data mode supports3G4GContinuity, value "false" is
returned in AS data mode publishesOwnPresence, value "false" is returned in AS data
mode locationNetwork, value "Fixed" is returned in AS data mode
allowTerminationBasedOnICSI, value "false" is returned in AS data mode roamingMode,
value "None" is returned in AS data mode

Replaced By: `SystemSIPDeviceTypeGetResponse23V4()`.

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|is_obsolete                                            |bool                 |isObsolete                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|protocol_choice                                        |List[str]            |protocolChoice                                  |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management                       |bool                 |supportVisualDeviceManagement                   |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
</div>


## `SystemSIPDeviceTypeGetResponse23V4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest23V4()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagementRedirectLink, value "false" is returned
in XS data mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
supportCallingPartyCategoryInOutboundFromHeader, value "true" is returned in XS data
mode resellerId supportVisualDeviceManagementAPI, value "false" is returned in XS data
mode The following elements are only used in XS data mode: enhancedForICS, value
"false" is returned in AS data mode supports3G4GContinuity, value "false" is returned
in AS data mode publishesOwnPresence, value "false" is returned in AS data mode
locationNetwork, value "Fixed" is returned in AS data mode
allowTerminationBasedOnICSI, value "false" is returned in AS data mode roamingMode,
value "None" is returned in AS data mode

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|is_obsolete                                            |bool                 |isObsolete                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|protocol_choice                                        |List[str]            |protocolChoice                                  |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*     |
</div>


## `SystemSIPDeviceTypeGetResponse23V5`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest23V5()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagementRedirectLink, value "false" is returned
in XS data mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
supportCallingPartyCategoryInOutboundFromHeader, value "true" is returned in XS data
mode resellerId supportVisualDeviceManagementAPI, value "false" is returned in XS data
mode The following elements are only used in AS data mode and not returned in XS data
mode: deviceCategory deviceFamily The following elements are only used in XS data
mode: enhancedForICS, value "false" is returned in AS data mode
supports3G4GContinuity, value "false" is returned in AS data mode
publishesOwnPresence, value "false" is returned in AS data mode locationNetwork, value
"Fixed" is returned in AS data mode allowTerminationBasedOnICSI, value "false" is
returned in AS data mode roamingMode, value "None" is returned in AS data mode
Replaced by `SystemSIPDeviceTypeGetResponse23V6()`

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|is_obsolete                                            |bool                 |isObsolete                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|protocol_choice                                        |List[str]            |protocolChoice                                  |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*     |
|device_category                                        |str                  |deviceCategory *Optional*                       |
|device_family                                          |str                  |deviceFamily *Optional*                         |
</div>


## `SystemSIPDeviceTypeGetResponse23V6`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest23V6()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagementRedirectLink, value "false" is returned
in XS data mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
supportCallingPartyCategoryInOutboundFromHeader, value "true" is returned in XS data
mode resellerId supportVisualDeviceManagementAPI, value "false" is returned in XS data
mode The following elements are only used in AS data mode and not returned in XS data
mode: deviceCategory deviceFamily The following elements are only used in XS data
mode: enhancedForICS, value "false" is returned in AS data mode
supports3G4GContinuity, value "false" is returned in AS data mode
publishesOwnPresence, value "false" is returned in AS data mode locationNetwork, value
"Fixed" is returned in AS data mode allowTerminationBasedOnICSI, value "false" is
returned in AS data mode roamingMode, value "None" is returned in AS data mode
Replaced by `SystemSIPDeviceTypeGetResponse23V7()`

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|is_obsolete                                            |bool                 |isObsolete                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|protocol_choice                                        |List[str]            |protocolChoice                                  |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*     |
|device_category                                        |str                  |deviceCategory *Optional*                       |
|device_family                                          |str                  |deviceFamily *Optional*                         |
</div>


## `SystemSIPDeviceTypeGetResponse23V7`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest23V7()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagementRedirectLink, value "false" is returned
in XS data mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
supportCallingPartyCategoryInOutboundFromHeader, value "true" is returned in XS data
mode resellerId supportVisualDeviceManagementAPI, value "false" is returned in XS data
mode verstatInPAIHeader, value "false" is returned in XS data mode
verstatInFromHeader, value "false" is returned in XS data mode The following elements
are only used in AS data mode and not returned in XS data mode: deviceCategory
deviceFamily The following elements are only used in XS data mode: enhancedForICS,
value "false" is returned in AS data mode supports3G4GContinuity, value "false" is
returned in AS data mode publishesOwnPresence, value "false" is returned in AS data
mode locationNetwork, value "Fixed" is returned in AS data mode
allowTerminationBasedOnICSI, value "false" is returned in AS data mode roamingMode,
value "None" is returned in AS data mode Replaced by
`SystemSIPDeviceTypeGetResponse23V8()`

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|is_obsolete                                            |bool                 |isObsolete                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|protocol_choice                                        |List[str]            |protocolChoice                                  |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*     |
|device_category                                        |str                  |deviceCategory *Optional*                       |
|device_family                                          |str                  |deviceFamily *Optional*                         |
|verstat_in_pai_header                                  |bool                 |verstatInPAIHeader *Optional*                   |
|verstat_in_from_header                                 |bool                 |verstatInFromHeader *Optional*                  |
</div>


## `SystemSIPDeviceTypeGetResponse23V8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest23V8()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagementRedirectLink, value "false" is returned
in XS data mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
supportCallingPartyCategoryInOutboundFromHeader, value "true" is returned in XS data
mode resellerId supportVisualDeviceManagementAPI, value "false" is returned in XS data
mode verstatInPAIHeader, value "false" is returned in XS data mode
verstatInFromHeader, value "false" is returned in XS data mode The following elements
are only used in AS data mode and not returned in XS data mode: deviceCategory
deviceFamily The following elements are only used in XS data mode: enhancedForICS,
value "false" is returned in AS data mode supports3G4GContinuity, value "false" is
returned in AS data mode publishesOwnPresence, value "false" is returned in AS data
mode locationNetwork, value "Fixed" is returned in AS data mode
allowTerminationBasedOnICSI, value "false" is returned in AS data mode roamingMode,
value "None" is returned in AS data mode Replaced by:
`SystemSIPDeviceTypeGetResponse23V9()` in AS mode.

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|is_obsolete                                            |bool                 |isObsolete                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|protocol_choice                                        |List[str]            |protocolChoice                                  |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*     |
|device_category                                        |str                  |deviceCategory *Optional*                       |
|device_family                                          |str                  |deviceFamily *Optional*                         |
|verstat_in_pai_header                                  |bool                 |verstatInPAIHeader *Optional*                   |
|verstat_in_from_header                                 |bool                 |verstatInFromHeader *Optional*                  |
</div>


## `SystemSIPDeviceTypeGetResponse23V9`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `SystemSIPDeviceTypeGetRequest23V9()`.

The following elements are only used in AS data mode: supportClientSessionInfo, value
"false" is returned in XS data mode supportCallInfoConferenceSubscriptionURI, value
"false" is returned in XS data mode supportRemotePartyInfo, value "false" is returned
in XS data mode supportVisualDeviceManagementRedirectLink, value "false" is returned
in XS data mode bypassMediaTreatment, value "false" is returned in XS data mode
supportCauseParameter, value "false" is returned in XS data mode
supportCallingPartyCategoryInOutboundFromHeader, value "true" is returned in XS data
mode resellerId supportVisualDeviceManagementAPI, value "false" is returned in XS data
mode The following elements are only used in AS data mode and not returned in XS data
mode: deviceCategory deviceFamily The following elements are only used in XS data
mode: enhancedForICS, value "false" is returned in AS data mode
supports3G4GContinuity, value "false" is returned in AS data mode
publishesOwnPresence, value "false" is returned in AS data mode locationNetwork, value
"Fixed" is returned in AS data mode allowTerminationBasedOnICSI, value "false" is
returned in AS data mode roamingMode, value "None" is returned in AS data mode

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|is_obsolete                                            |bool                 |isObsolete                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|protocol_choice                                        |List[str]            |protocolChoice                                  |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|reset_string                                           |str                  |resetString *Optional*                          |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*     |
|device_category                                        |str                  |deviceCategory *Optional*                       |
|device_family                                          |str                  |deviceFamily *Optional*                         |
|verstat_in_pai_header                                  |bool                 |verstatInPAIHeader *Optional*                   |
|verstat_in_from_header                                 |bool                 |verstatInFromHeader *Optional*                  |
</div>


## `UserBroadWorksMobilityMobileIdentityGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `UserBroadWorksMobilityMobileIdentityGetRequest()`.

Replaced by: `UserBroadWorksMobilityMobileIdentityGetResponse21sp1()`.

**Attributes:**

|Name                           |Type                |Description                    |
|-------------------------------|--------------------|-------------------------------|
|description                    |str                 |description *Optional*         |
|is_primary                     |bool                |isPrimary                      |
|enable_alerting                |bool                |enableAlerting                 |
|alert_agent_calls              |bool                |alertAgentCalls                |
|alert_click_to_dial_calls      |bool                |alertClickToDialCalls          |
|alert_group_paging_calls       |bool                |alertGroupPagingCalls          |
|use_mobility_calling_line_id   |bool                |useMobilityCallingLineID       |
|enable_diversion_inhibitor     |bool                |enableDiversionInhibitor       |
|require_answer_confirmation    |bool                |requireAnswerConfirmation      |
|broadworks_call_control        |bool                |broadworksCallControl          |
|use_setting_level              |str                 |useSettingLevel                |
|deny_call_originations         |bool                |denyCallOriginations           |
|deny_call_terminations         |bool                |denyCallTerminations           |
|devices_to_ring                |str                 |devicesToRing                  |
|include_shared_call_appearance |bool                |includeSharedCallAppearance    |
|include_broadworks_anywhere    |bool                |includeBroadworksAnywhere      |
|include_executive_assistant    |bool                |includeExecutiveAssistant      |
|mobile_number_alerted          |List[str]           |mobileNumberAlerted *Optional* |
|enable_call_anchoring          |bool                |enableCallAnchoring            |
|time_schedule                  |OCI.timeSchedule    |timeSchedule *Optional*        |
|holiday_schedule               |OCI.holidaySchedule |holidaySchedule *Optional*     |
</div>


## `UserBroadWorksMobilityMobileIdentityGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `UserBroadWorksMobilityMobileIdentityGetRequest21sp1()`.

Replaced by: UserBroadWorksMobilityMobileIdentityGetResponse21sp1V2.

**Attributes:**

|Name                               |Type                     |Description                        |
|-----------------------------------|-------------------------|-----------------------------------|
|description                        |str                      |description *Optional*             |
|is_primary                         |bool                     |isPrimary                          |
|enable_alerting                    |bool                     |enableAlerting                     |
|alert_agent_calls                  |bool                     |alertAgentCalls                    |
|alert_click_to_dial_calls          |bool                     |alertClickToDialCalls              |
|alert_group_paging_calls           |bool                     |alertGroupPagingCalls              |
|use_mobility_calling_line_id       |bool                     |useMobilityCallingLineID           |
|enable_diversion_inhibitor         |bool                     |enableDiversionInhibitor           |
|require_answer_confirmation        |bool                     |requireAnswerConfirmation          |
|broadworks_call_control            |bool                     |broadworksCallControl              |
|use_setting_level                  |str                      |useSettingLevel                    |
|deny_call_originations             |bool                     |denyCallOriginations               |
|deny_call_terminations             |bool                     |denyCallTerminations               |
|devices_to_ring                    |str                      |devicesToRing                      |
|include_shared_call_appearance     |bool                     |includeSharedCallAppearance        |
|include_broadworks_anywhere        |bool                     |includeBroadworksAnywhere          |
|include_executive_assistant        |bool                     |includeExecutiveAssistant          |
|mobile_number_alerted              |List[str]                |mobileNumberAlerted *Optional*     |
|enable_call_anchoring              |bool                     |enableCallAnchoring                |
|time_schedule                      |OCI.timeSchedule         |timeSchedule *Optional*            |
|holiday_schedule                   |OCI.holidaySchedule      |holidaySchedule *Optional*         |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*    |
|outbound_alternate_number          |str                      |outboundAlternateNumber *Optional* |
|enable_direct_routing              |bool                     |enableDirectRouting                |
|mark_cdr_as_enterprise_group_calls |bool                     |markCDRAsEnterpriseGroupCalls      |
</div>


## `UserBroadWorksMobilityMobileIdentityGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `UserBroadWorksMobilityMobileIdentityGetRequest22()`.

Columns for the mobileNumberAlertedTable are as follows: "Mobile Number", "Country
Code", "National Prefix" Replaced by
`UserBroadWorksMobilityMobileIdentityGetResponse22V2()`.

**Attributes:**

|Name                                      |Type                           |Description                                                                       |
|------------------------------------------|-------------------------------|----------------------------------------------------------------------------------|
|description                               |str                            |description *Optional*                                                            |
|is_primary                                |bool                           |isPrimary                                                                         |
|enable_alerting                           |bool                           |enableAlerting                                                                    |
|alert_agent_calls                         |bool                           |alertAgentCalls                                                                   |
|alert_click_to_dial_calls                 |bool                           |alertClickToDialCalls                                                             |
|alert_group_paging_calls                  |bool                           |alertGroupPagingCalls                                                             |
|use_mobility_calling_line_id              |bool                           |useMobilityCallingLineID                                                          |
|enable_diversion_inhibitor                |bool                           |enableDiversionInhibitor                                                          |
|require_answer_confirmation               |bool                           |requireAnswerConfirmation                                                         |
|broadworks_call_control                   |bool                           |broadworksCallControl                                                             |
|use_setting_level                         |str                            |useSettingLevel                                                                   |
|deny_call_originations                    |bool                           |denyCallOriginations                                                              |
|deny_call_terminations                    |bool                           |denyCallTerminations                                                              |
|effective_enable_location_services        |bool                           |effectiveEnableLocationServices                                                   |
|effective_enable_msrn_lookup              |bool                           |effectiveEnableMSRNLookup                                                         |
|effective_enable_mobile_state_checking    |bool                           |effectiveEnableMobileStateChecking                                                |
|effective_enable_announcement_suppression |bool                           |effectiveEnableAnnouncementSuppression                                            |
|effective_deny_call_originations          |bool                           |effectiveDenyCallOriginations                                                     |
|effective_deny_call_terminations          |bool                           |effectiveDenyCallTerminations                                                     |
|devices_to_ring                           |str                            |devicesToRing                                                                     |
|include_shared_call_appearance            |bool                           |includeSharedCallAppearance                                                       |
|include_broadworks_anywhere               |bool                           |includeBroadworksAnywhere                                                         |
|include_executive_assistant               |bool                           |includeExecutiveAssistant                                                         |
|enable_call_anchoring                     |bool                           |enableCallAnchoring                                                               |
|time_schedule                             |OCI.timeSchedule               |timeSchedule *Optional*                                                           |
|holiday_schedule                          |OCI.holidaySchedule            |holidaySchedule *Optional*                                                        |
|access_device_endpoint                    |OCI.accessDeviceEndpoint       |accessDeviceEndpoint *Optional*                                                   |
|outbound_alternate_number                 |str                            |outboundAlternateNumber *Optional*                                                |
|enable_direct_routing                     |bool                           |enableDirectRouting                                                               |
|mark_cdr_as_enterprise_group_calls        |bool                           |markCDRAsEnterpriseGroupCalls                                                     |
|mobile_number_alerted_table               |List(mobileNumberAlertedTable) |mobileNumberAlertedTable - *Table* array of mobileNumberAlertedTable named tuples |
</div>


## `UserBroadWorksMobilityMobileIdentityGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `UserBroadWorksMobilityMobileIdentityGetRequest22V2()`.

Columns for the mobileNumberAlertedTable are as follows: "Mobile Number", "Country
Code", "National Prefix"

Replaced By: `UserBroadWorksMobilityMobileIdentityGetResponse22V3()`

**Attributes:**

|Name                                      |Type                           |Description                                                                       |
|------------------------------------------|-------------------------------|----------------------------------------------------------------------------------|
|description                               |str                            |description *Optional*                                                            |
|is_primary                                |bool                           |isPrimary                                                                         |
|enable_alerting                           |bool                           |enableAlerting                                                                    |
|alert_agent_calls                         |bool                           |alertAgentCalls                                                                   |
|alert_click_to_dial_calls                 |bool                           |alertClickToDialCalls                                                             |
|alert_group_paging_calls                  |bool                           |alertGroupPagingCalls                                                             |
|use_mobility_calling_line_id              |bool                           |useMobilityCallingLineID                                                          |
|enable_diversion_inhibitor                |bool                           |enableDiversionInhibitor                                                          |
|require_answer_confirmation               |bool                           |requireAnswerConfirmation                                                         |
|broadworks_call_control                   |bool                           |broadworksCallControl                                                             |
|use_setting_level                         |str                            |useSettingLevel                                                                   |
|deny_call_originations                    |bool                           |denyCallOriginations                                                              |
|deny_call_terminations                    |bool                           |denyCallTerminations                                                              |
|effective_enable_location_services        |bool                           |effectiveEnableLocationServices                                                   |
|effective_enable_msrn_lookup              |bool                           |effectiveEnableMSRNLookup                                                         |
|effective_enable_mobile_state_checking    |bool                           |effectiveEnableMobileStateChecking                                                |
|effective_enable_announcement_suppression |bool                           |effectiveEnableAnnouncementSuppression                                            |
|effective_deny_call_originations          |bool                           |effectiveDenyCallOriginations                                                     |
|effective_deny_call_terminations          |bool                           |effectiveDenyCallTerminations                                                     |
|devices_to_ring                           |str                            |devicesToRing                                                                     |
|include_shared_call_appearance            |bool                           |includeSharedCallAppearance                                                       |
|include_broadworks_anywhere               |bool                           |includeBroadworksAnywhere                                                         |
|include_executive_assistant               |bool                           |includeExecutiveAssistant                                                         |
|enable_call_anchoring                     |bool                           |enableCallAnchoring                                                               |
|time_schedule                             |OCI.timeSchedule               |timeSchedule *Optional*                                                           |
|holiday_schedule                          |OCI.holidaySchedule            |holidaySchedule *Optional*                                                        |
|access_device_endpoint                    |OCI.accessDeviceEndpoint       |accessDeviceEndpoint *Optional*                                                   |
|outbound_alternate_number                 |str                            |outboundAlternateNumber *Optional*                                                |
|enable_direct_routing                     |bool                           |enableDirectRouting                                                               |
|mark_cdr_as_enterprise_group_calls        |bool                           |markCDRAsEnterpriseGroupCalls                                                     |
|use_mobility_connected_identity           |bool                           |useMobilityConnectedIdentity                                                      |
|network_translation_index                 |str                            |networkTranslationIndex *Optional*                                                |
|mobile_number_alerted_table               |List(mobileNumberAlertedTable) |mobileNumberAlertedTable - *Table* array of mobileNumberAlertedTable named tuples |
</div>


## `UserBroadWorksMobilityMobileIdentityGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to a `UserBroadWorksMobilityMobileIdentityGetRequest22V3()`.

Columns for the mobileNumberAlertedTable are as follows: "Mobile Number", "Country
Code", "National Prefix"

**Attributes:**

|Name                                      |Type                           |Description                                                                       |
|------------------------------------------|-------------------------------|----------------------------------------------------------------------------------|
|description                               |str                            |description *Optional*                                                            |
|is_primary                                |bool                           |isPrimary                                                                         |
|enable_alerting                           |bool                           |enableAlerting                                                                    |
|alert_agent_calls                         |bool                           |alertAgentCalls                                                                   |
|alert_click_to_dial_calls                 |bool                           |alertClickToDialCalls                                                             |
|alert_group_paging_calls                  |bool                           |alertGroupPagingCalls                                                             |
|use_mobility_calling_line_id              |bool                           |useMobilityCallingLineID                                                          |
|enable_diversion_inhibitor                |bool                           |enableDiversionInhibitor                                                          |
|require_answer_confirmation               |bool                           |requireAnswerConfirmation                                                         |
|broadworks_call_control                   |bool                           |broadworksCallControl                                                             |
|use_setting_level                         |str                            |useSettingLevel                                                                   |
|deny_call_originations                    |bool                           |denyCallOriginations                                                              |
|deny_call_terminations                    |bool                           |denyCallTerminations                                                              |
|effective_enable_location_services        |bool                           |effectiveEnableLocationServices                                                   |
|effective_enable_msrn_lookup              |bool                           |effectiveEnableMSRNLookup                                                         |
|effective_enable_mobile_state_checking    |bool                           |effectiveEnableMobileStateChecking                                                |
|effective_enable_announcement_suppression |bool                           |effectiveEnableAnnouncementSuppression                                            |
|effective_deny_call_originations          |bool                           |effectiveDenyCallOriginations                                                     |
|effective_deny_call_terminations          |bool                           |effectiveDenyCallTerminations                                                     |
|devices_to_ring                           |str                            |devicesToRing                                                                     |
|include_shared_call_appearance            |bool                           |includeSharedCallAppearance                                                       |
|include_broadworks_anywhere               |bool                           |includeBroadworksAnywhere                                                         |
|include_executive_assistant               |bool                           |includeExecutiveAssistant                                                         |
|enable_call_anchoring                     |bool                           |enableCallAnchoring                                                               |
|time_schedule                             |OCI.timeSchedule               |timeSchedule *Optional*                                                           |
|holiday_schedule                          |OCI.holidaySchedule            |holidaySchedule *Optional*                                                        |
|access_device_endpoint                    |OCI.accessDeviceEndpoint       |accessDeviceEndpoint *Optional*                                                   |
|outbound_alternate_number                 |str                            |outboundAlternateNumber *Optional*                                                |
|enable_direct_routing                     |bool                           |enableDirectRouting                                                               |
|mark_cdr_as_enterprise_group_calls        |bool                           |markCDRAsEnterpriseGroupCalls                                                     |
|use_mobility_connected_identity           |bool                           |useMobilityConnectedIdentity                                                      |
|network_translation_index                 |str                            |networkTranslationIndex *Optional*                                                |
|mobile_number_alerted_table               |List(mobileNumberAlertedTable) |mobileNumberAlertedTable - *Table* array of mobileNumberAlertedTable named tuples |
</div>


## `UserCommPilotExpressGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserCommPilotExpressGetRequest()`.


**Attributes:**

|Name                    |Type                     |Description          |
|------------------------|-------------------------|---------------------|
|profile                 |str                      |profile *Optional*   |
|available_in_office     |OCI.availableInOffice    |availableInOffice    |
|available_out_of_office |OCI.availableOutOfOffice |availableOutOfOffice |
|busy                    |OCI.busy                 |busy                 |
|unavailable             |OCI.unavailable          |unavailable          |
</div>


## `UserFlexibleSeatingGuestGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserFlexibleSeatingGuestGetRequest()`.


**Attributes:**

|Name                            |Type                     |Description                             |
|--------------------------------|-------------------------|----------------------------------------|
|is_active                       |bool                     |isActive                                |
|enable_association_limit        |bool                     |enableAssociationLimit                  |
|association_limit_hours         |int                      |associationLimitHours                   |
|unlock_phone_pin_code           |str                      |unlockPhonePINCode *Optional*           |
|access_device_endpoint          |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*         |
|host_user_id                    |str                      |hostUserId *Optional*                   |
|host_last_name                  |str                      |hostLastName *Optional*                 |
|host_first_name                 |str                      |hostFirstName *Optional*                |
|host_association_date_time      |str                      |hostAssociationDateTime *Optional*      |
|host_enforces_association_limit |bool                     |hostEnforcesAssociationLimit *Optional* |
|host_association_limit_hours    |int                      |hostAssociationLimitHours *Optional*    |
</div>


## `UserFlexibleSeatingGuestGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserFlexibleSeatingGuestGetRequest22()`.


**Attributes:**

|Name                            |Type                     |Description                             |
|--------------------------------|-------------------------|----------------------------------------|
|is_active                       |bool                     |isActive                                |
|enable_association_limit        |bool                     |enableAssociationLimit                  |
|association_limit_hours         |int                      |associationLimitHours                   |
|unlock_phone_pin_code           |str                      |unlockPhonePINCode *Optional*           |
|access_device_endpoint          |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*         |
|host_user_id                    |str                      |hostUserId *Optional*                   |
|host_last_name                  |str                      |hostLastName *Optional*                 |
|host_first_name                 |str                      |hostFirstName *Optional*                |
|host_association_date_time      |str                      |hostAssociationDateTime *Optional*      |
|host_enforces_association_limit |bool                     |hostEnforcesAssociationLimit *Optional* |
|host_association_limit_hours    |int                      |hostAssociationLimitHours *Optional*    |
</div>


## `UserGetResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest14()`.

The callingLineIdPhoneNumber is no longer being formatted for display purpose.  The
value is returned exactly the same as being stored.

**Attributes:**

|Name                         |Type                         |Description                         |
|-----------------------------|-----------------------------|------------------------------------|
|service_provider_id          |str                          |serviceProviderId                   |
|group_id                     |str                          |groupId                             |
|last_name                    |str                          |lastName                            |
|first_name                   |str                          |firstName                           |
|calling_line_id_last_name    |str                          |callingLineIdLastName               |
|calling_line_id_first_name   |str                          |callingLineIdFirstName              |
|hiragana_last_name           |str                          |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                          |hiraganaFirstName *Optional*        |
|phone_number                 |str                          |phoneNumber *Optional*              |
|extension                    |str                          |extension *Optional*                |
|calling_line_id_phone_number |str                          |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department               |department *Optional*               |
|department_full_path         |str                          |departmentFullPath *Optional*       |
|language                     |str                          |language                            |
|time_zone                    |str                          |timeZone                            |
|time_zone_display_name       |str                          |timeZoneDisplayName                 |
|default_alias                |str                          |defaultAlias                        |
|alias                        |List[str]                    |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint     |accessDeviceEndpoint *Optional*     |
|trunk_group_device_endpoint  |OCI.trunkGroupDeviceEndpoint |trunkGroupDeviceEndpoint *Optional* |
|title                        |str                          |title *Optional*                    |
|pager_phone_number           |str                          |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                          |mobilePhoneNumber *Optional*        |
|email_address                |str                          |emailAddress *Optional*             |
|yahoo_id                     |str                          |yahooId *Optional*                  |
|address_location             |str                          |addressLocation *Optional*          |
|address                      |OCI.address                  |address *Optional*                  |
</div>


## `UserGetResponse14sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest14sp4()`.

The callingLineIdPhoneNumber is no longer being formatted for display purpose.  The
value is returned exactly the same as being stored.

**Attributes:**

|Name                         |Type                         |Description                         |
|-----------------------------|-----------------------------|------------------------------------|
|service_provider_id          |str                          |serviceProviderId                   |
|group_id                     |str                          |groupId                             |
|last_name                    |str                          |lastName                            |
|first_name                   |str                          |firstName                           |
|calling_line_id_last_name    |str                          |callingLineIdLastName               |
|calling_line_id_first_name   |str                          |callingLineIdFirstName              |
|hiragana_last_name           |str                          |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                          |hiraganaFirstName *Optional*        |
|phone_number                 |str                          |phoneNumber *Optional*              |
|extension                    |str                          |extension *Optional*                |
|calling_line_id_phone_number |str                          |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department               |department *Optional*               |
|department_full_path         |str                          |departmentFullPath *Optional*       |
|language                     |str                          |language                            |
|time_zone                    |str                          |timeZone                            |
|time_zone_display_name       |str                          |timeZoneDisplayName                 |
|default_alias                |str                          |defaultAlias                        |
|alias                        |List[str]                    |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint     |accessDeviceEndpoint *Optional*     |
|trunk_group_device_endpoint  |OCI.trunkGroupDeviceEndpoint |trunkGroupDeviceEndpoint *Optional* |
|title                        |str                          |title *Optional*                    |
|pager_phone_number           |str                          |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                          |mobilePhoneNumber *Optional*        |
|email_address                |str                          |emailAddress *Optional*             |
|yahoo_id                     |str                          |yahooId *Optional*                  |
|address_location             |str                          |addressLocation *Optional*          |
|address                      |OCI.address                  |address *Optional*                  |
|country_code                 |str                          |countryCode *Optional*              |
|national_prefix              |str                          |nationalPrefix *Optional*           |
</div>


## `UserGetResponse14sp9`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest14sp9()`.

The callingLineIdPhoneNumber is no longer being formatted for display purpose.  The
value is returned exactly the same as being stored.

**Attributes:**

|Name                         |Type                     |Description                         |
|-----------------------------|-------------------------|------------------------------------|
|service_provider_id          |str                      |serviceProviderId                   |
|group_id                     |str                      |groupId                             |
|last_name                    |str                      |lastName                            |
|first_name                   |str                      |firstName                           |
|calling_line_id_last_name    |str                      |callingLineIdLastName               |
|calling_line_id_first_name   |str                      |callingLineIdFirstName              |
|hiragana_last_name           |str                      |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                      |hiraganaFirstName *Optional*        |
|phone_number                 |str                      |phoneNumber *Optional*              |
|extension                    |str                      |extension *Optional*                |
|calling_line_id_phone_number |str                      |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department           |department *Optional*               |
|department_full_path         |str                      |departmentFullPath *Optional*       |
|language                     |str                      |language                            |
|time_zone                    |str                      |timeZone                            |
|time_zone_display_name       |str                      |timeZoneDisplayName                 |
|default_alias                |str                      |defaultAlias                        |
|alias                        |List[str]                |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing      |trunkAddressing *Optional*          |
|title                        |str                      |title *Optional*                    |
|pager_phone_number           |str                      |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                      |mobilePhoneNumber *Optional*        |
|email_address                |str                      |emailAddress *Optional*             |
|yahoo_id                     |str                      |yahooId *Optional*                  |
|address_location             |str                      |addressLocation *Optional*          |
|address                      |OCI.address              |address *Optional*                  |
|country_code                 |str                      |countryCode *Optional*              |
|national_prefix              |str                      |nationalPrefix *Optional*           |
</div>


## `UserGetResponse15sp2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest15sp2()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The callingLineIdPhoneNumber is no longer
being formatted for display purpose.  The value is returned exactly the same as being
stored.

**Attributes:**

|Name                         |Type                     |Description                         |
|-----------------------------|-------------------------|------------------------------------|
|service_provider_id          |str                      |serviceProviderId                   |
|group_id                     |str                      |groupId                             |
|last_name                    |str                      |lastName                            |
|first_name                   |str                      |firstName                           |
|calling_line_id_last_name    |str                      |callingLineIdLastName               |
|calling_line_id_first_name   |str                      |callingLineIdFirstName              |
|hiragana_last_name           |str                      |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                      |hiraganaFirstName *Optional*        |
|phone_number                 |str                      |phoneNumber *Optional*              |
|extension                    |str                      |extension *Optional*                |
|calling_line_id_phone_number |str                      |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department           |department *Optional*               |
|department_full_path         |str                      |departmentFullPath *Optional*       |
|language                     |str                      |language                            |
|time_zone                    |str                      |timeZone                            |
|time_zone_display_name       |str                      |timeZoneDisplayName                 |
|default_alias                |str                      |defaultAlias                        |
|alias                        |List[str]                |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing      |trunkAddressing *Optional*          |
|title                        |str                      |title *Optional*                    |
|pager_phone_number           |str                      |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                      |mobilePhoneNumber *Optional*        |
|email_address                |str                      |emailAddress *Optional*             |
|yahoo_id                     |str                      |yahooId *Optional*                  |
|address_location             |str                      |addressLocation *Optional*          |
|address                      |OCI.address              |address *Optional*                  |
|country_code                 |str                      |countryCode *Optional*              |
|national_prefix              |str                      |nationalPrefix *Optional*           |
|network_class_of_service     |str                      |networkClassOfService *Optional*    |
</div>


## `UserGetResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Replaced By `UserGetResponse17sp4()` Response to `UserGetRequest17()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The callingLineIdPhoneNumber is no longer
being formatted for display purpose.  The value is returned exactly the same as being
stored.

**Attributes:**

|Name                         |Type                     |Description                         |
|-----------------------------|-------------------------|------------------------------------|
|service_provider_id          |str                      |serviceProviderId                   |
|group_id                     |str                      |groupId                             |
|last_name                    |str                      |lastName                            |
|first_name                   |str                      |firstName                           |
|calling_line_id_last_name    |str                      |callingLineIdLastName               |
|calling_line_id_first_name   |str                      |callingLineIdFirstName              |
|hiragana_last_name           |str                      |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                      |hiraganaFirstName *Optional*        |
|phone_number                 |str                      |phoneNumber *Optional*              |
|extension                    |str                      |extension *Optional*                |
|calling_line_id_phone_number |str                      |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department           |department *Optional*               |
|department_full_path         |str                      |departmentFullPath *Optional*       |
|language                     |str                      |language                            |
|time_zone                    |str                      |timeZone                            |
|time_zone_display_name       |str                      |timeZoneDisplayName                 |
|default_alias                |str                      |defaultAlias                        |
|alias                        |List[str]                |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing      |trunkAddressing *Optional*          |
|title                        |str                      |title *Optional*                    |
|pager_phone_number           |str                      |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                      |mobilePhoneNumber *Optional*        |
|email_address                |str                      |emailAddress *Optional*             |
|yahoo_id                     |str                      |yahooId *Optional*                  |
|address_location             |str                      |addressLocation *Optional*          |
|address                      |OCI.address              |address *Optional*                  |
|country_code                 |str                      |countryCode *Optional*              |
|national_prefix              |str                      |nationalPrefix *Optional*           |
|network_class_of_service     |str                      |networkClassOfService *Optional*    |
|office_zone_name             |str                      |officeZoneName *Optional*           |
|primary_zone_name            |str                      |primaryZoneName *Optional*          |
</div>


## `UserGetResponse17sp3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Replaced By `UserGetRequest18()` Response to `UserGetRequest17sp3()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The callingLineIdPhoneNumber is no longer
being formatted for display purpose.  The value is returned exactly the same as being
stored.

**Attributes:**

|Name                         |Type                     |Description                         |
|-----------------------------|-------------------------|------------------------------------|
|service_provider_id          |str                      |serviceProviderId                   |
|group_id                     |str                      |groupId                             |
|last_name                    |str                      |lastName                            |
|first_name                   |str                      |firstName                           |
|calling_line_id_last_name    |str                      |callingLineIdLastName               |
|calling_line_id_first_name   |str                      |callingLineIdFirstName              |
|hiragana_last_name           |str                      |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                      |hiraganaFirstName *Optional*        |
|phone_number                 |str                      |phoneNumber *Optional*              |
|extension                    |str                      |extension *Optional*                |
|calling_line_id_phone_number |str                      |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department           |department *Optional*               |
|department_full_path         |str                      |departmentFullPath *Optional*       |
|language                     |str                      |language                            |
|time_zone                    |str                      |timeZone                            |
|time_zone_display_name       |str                      |timeZoneDisplayName                 |
|default_alias                |str                      |defaultAlias                        |
|alias                        |List[str]                |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing      |trunkAddressing *Optional*          |
|title                        |str                      |title *Optional*                    |
|pager_phone_number           |str                      |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                      |mobilePhoneNumber *Optional*        |
|email_address                |str                      |emailAddress *Optional*             |
|yahoo_id                     |str                      |yahooId *Optional*                  |
|address_location             |str                      |addressLocation *Optional*          |
|address                      |OCI.address              |address *Optional*                  |
|country_code                 |str                      |countryCode *Optional*              |
|national_prefix              |str                      |nationalPrefix *Optional*           |
|network_class_of_service     |str                      |networkClassOfService *Optional*    |
|office_zone_name             |str                      |officeZoneName *Optional*           |
|primary_zone_name            |str                      |primaryZoneName *Optional*          |
|imp_id                       |str                      |impId *Optional*                    |
</div>


## `UserGetResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Replaced By `UserGetResponse18()` Response to `UserGetRequest17sp4()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following elements are only used in
AS data mode and not returned in XS data mode: contact[2]-contact[5] The country code
(countryCode) included is the user's phone number country code when the user has a
phone number assigned, or the user's Group associated country code when the user does
not have a phone number assigned, or the system default country code when the user's
Group does not have an associated country code.  The nationalPrefix in this response
is the one associated to the included countryCode.  The callingLineIdPhoneNumber is no
longer being formatted for display purpose.  The value is returned exactly the same as
being stored.

**Attributes:**

|Name                         |Type                     |Description                         |
|-----------------------------|-------------------------|------------------------------------|
|service_provider_id          |str                      |serviceProviderId                   |
|group_id                     |str                      |groupId                             |
|last_name                    |str                      |lastName                            |
|first_name                   |str                      |firstName                           |
|calling_line_id_last_name    |str                      |callingLineIdLastName               |
|calling_line_id_first_name   |str                      |callingLineIdFirstName              |
|hiragana_last_name           |str                      |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                      |hiraganaFirstName *Optional*        |
|phone_number                 |str                      |phoneNumber *Optional*              |
|extension                    |str                      |extension *Optional*                |
|calling_line_id_phone_number |str                      |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department           |department *Optional*               |
|department_full_path         |str                      |departmentFullPath *Optional*       |
|language                     |str                      |language                            |
|time_zone                    |str                      |timeZone                            |
|time_zone_display_name       |str                      |timeZoneDisplayName                 |
|default_alias                |str                      |defaultAlias                        |
|alias                        |List[str]                |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing      |trunkAddressing *Optional*          |
|title                        |str                      |title *Optional*                    |
|pager_phone_number           |str                      |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                      |mobilePhoneNumber *Optional*        |
|email_address                |str                      |emailAddress *Optional*             |
|yahoo_id                     |str                      |yahooId *Optional*                  |
|address_location             |str                      |addressLocation *Optional*          |
|address                      |OCI.address              |address *Optional*                  |
|country_code                 |str                      |countryCode                         |
|national_prefix              |str                      |nationalPrefix *Optional*           |
|network_class_of_service     |str                      |networkClassOfService *Optional*    |
|office_zone_name             |str                      |officeZoneName *Optional*           |
|primary_zone_name            |str                      |primaryZoneName *Optional*          |
</div>


## `UserGetResponse18`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest18()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following elements are only used in
AS data mode and not returned in XS data mode: contact[2]-contact[5] The country code
(countryCode) included is the user's phone number country code when the user has a
phone number assigned, or the user's Group associated country code when the user does
not have a phone number assigned, or the system default country code when the user's
Group does not have an associated country code.  The nationalPrefix in this response
is the one associated to the included countryCode.  The callingLineIdPhoneNumber is no
longer being formatted for display purpose.  The value is returned exactly the same as
being stored.

**Attributes:**

|Name                         |Type                     |Description                         |
|-----------------------------|-------------------------|------------------------------------|
|service_provider_id          |str                      |serviceProviderId                   |
|group_id                     |str                      |groupId                             |
|last_name                    |str                      |lastName                            |
|first_name                   |str                      |firstName                           |
|calling_line_id_last_name    |str                      |callingLineIdLastName               |
|calling_line_id_first_name   |str                      |callingLineIdFirstName              |
|hiragana_last_name           |str                      |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                      |hiraganaFirstName *Optional*        |
|phone_number                 |str                      |phoneNumber *Optional*              |
|extension                    |str                      |extension *Optional*                |
|calling_line_id_phone_number |str                      |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department           |department *Optional*               |
|department_full_path         |str                      |departmentFullPath *Optional*       |
|language                     |str                      |language                            |
|time_zone                    |str                      |timeZone                            |
|time_zone_display_name       |str                      |timeZoneDisplayName                 |
|default_alias                |str                      |defaultAlias                        |
|alias                        |List[str]                |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing      |trunkAddressing *Optional*          |
|title                        |str                      |title *Optional*                    |
|pager_phone_number           |str                      |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                      |mobilePhoneNumber *Optional*        |
|email_address                |str                      |emailAddress *Optional*             |
|yahoo_id                     |str                      |yahooId *Optional*                  |
|address_location             |str                      |addressLocation *Optional*          |
|address                      |OCI.address              |address *Optional*                  |
|country_code                 |str                      |countryCode                         |
|national_prefix              |str                      |nationalPrefix *Optional*           |
|network_class_of_service     |str                      |networkClassOfService *Optional*    |
|office_zone_name             |str                      |officeZoneName *Optional*           |
|primary_zone_name            |str                      |primaryZoneName *Optional*          |
|imp_id                       |str                      |impId *Optional*                    |
</div>


## `UserGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest19()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following elements are only used in
AS data mode and not returned in XS data mode: contact[2]-contact[5] The country code
(countryCode) included is the user's phone number country code when the user has a
phone number assigned, or the user's Group associated country code when the user does
not have a phone number assigned, or the system default country code when the user's
Group does not have an associated country code.  The nationalPrefix in this response
is the one associated to the included countryCode.  The callingLineIdPhoneNumber is no
longer being formatted for display purpose.  The value is returned exactly the same as
being stored.

**Attributes:**

|Name                         |Type                     |Description                         |
|-----------------------------|-------------------------|------------------------------------|
|service_provider_id          |str                      |serviceProviderId                   |
|group_id                     |str                      |groupId                             |
|last_name                    |str                      |lastName                            |
|first_name                   |str                      |firstName                           |
|calling_line_id_last_name    |str                      |callingLineIdLastName               |
|calling_line_id_first_name   |str                      |callingLineIdFirstName              |
|hiragana_last_name           |str                      |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                      |hiraganaFirstName *Optional*        |
|phone_number                 |str                      |phoneNumber *Optional*              |
|extension                    |str                      |extension *Optional*                |
|calling_line_id_phone_number |str                      |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department           |department *Optional*               |
|department_full_path         |str                      |departmentFullPath *Optional*       |
|language                     |str                      |language                            |
|time_zone                    |str                      |timeZone                            |
|time_zone_display_name       |str                      |timeZoneDisplayName                 |
|default_alias                |str                      |defaultAlias                        |
|alias                        |List[str]                |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing      |trunkAddressing *Optional*          |
|title                        |str                      |title *Optional*                    |
|pager_phone_number           |str                      |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                      |mobilePhoneNumber *Optional*        |
|email_address                |str                      |emailAddress *Optional*             |
|yahoo_id                     |str                      |yahooId *Optional*                  |
|address_location             |str                      |addressLocation *Optional*          |
|address                      |OCI.address              |address *Optional*                  |
|country_code                 |str                      |countryCode                         |
|national_prefix              |str                      |nationalPrefix *Optional*           |
|network_class_of_service     |str                      |networkClassOfService *Optional*    |
|office_zone_name             |str                      |officeZoneName *Optional*           |
|primary_zone_name            |str                      |primaryZoneName *Optional*          |
|imp_id                       |str                      |impId *Optional*                    |
</div>


## `UserGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest20()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following elements are only used in
AS data mode and not returned in XS data mode: contact[2]-contact[5] The country code
(countryCode) included is the user's phone number country code when the user has a
phone number assigned, or the user's Group associated country code when the user does
not have a phone number assigned, or the system default country code when the user's
Group does not have an associated country code.  The nationalPrefix in this response
is the one associated to the included countryCode.

**Attributes:**

|Name                         |Type                     |Description                         |
|-----------------------------|-------------------------|------------------------------------|
|service_provider_id          |str                      |serviceProviderId                   |
|group_id                     |str                      |groupId                             |
|last_name                    |str                      |lastName                            |
|first_name                   |str                      |firstName                           |
|calling_line_id_last_name    |str                      |callingLineIdLastName               |
|calling_line_id_first_name   |str                      |callingLineIdFirstName              |
|name_dialing_name            |OCI.nameDialingName      |nameDialingName *Optional*          |
|hiragana_last_name           |str                      |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                      |hiraganaFirstName *Optional*        |
|phone_number                 |str                      |phoneNumber *Optional*              |
|extension                    |str                      |extension *Optional*                |
|calling_line_id_phone_number |str                      |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department           |department *Optional*               |
|department_full_path         |str                      |departmentFullPath *Optional*       |
|language                     |str                      |language                            |
|time_zone                    |str                      |timeZone                            |
|time_zone_display_name       |str                      |timeZoneDisplayName                 |
|default_alias                |str                      |defaultAlias                        |
|alias                        |List[str]                |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing      |trunkAddressing *Optional*          |
|title                        |str                      |title *Optional*                    |
|pager_phone_number           |str                      |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                      |mobilePhoneNumber *Optional*        |
|email_address                |str                      |emailAddress *Optional*             |
|yahoo_id                     |str                      |yahooId *Optional*                  |
|address_location             |str                      |addressLocation *Optional*          |
|address                      |OCI.address              |address *Optional*                  |
|country_code                 |str                      |countryCode                         |
|national_prefix              |str                      |nationalPrefix *Optional*           |
|network_class_of_service     |str                      |networkClassOfService *Optional*    |
|office_zone_name             |str                      |officeZoneName *Optional*           |
|primary_zone_name            |str                      |primaryZoneName *Optional*          |
|imp_id                       |str                      |impId *Optional*                    |
</div>


## `UserGetResponse21`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest21()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following data elements are only used
in AS data mode: contact[2]-contact[5] nameDialingName The following data elements are
only used in XS data mode: alternateTrunkIdentityDomain The country code (countryCode)
included is the user's phone number country code when the user has a phone number
assigned, or the user's Group associated country code when the user does not have a
phone number assigned, or the system default country code when the user's Group does
not have an associated country code.  The nationalPrefix in this response is the one
associated to the included countryCode.  The callingLineIdPhoneNumber is no longer
being formatted for display purpose.  The value is returned exactly the same as being
stored.  Replaced by `UserGetResponse21sp1()`

**Attributes:**

|Name                         |Type                     |Description                         |
|-----------------------------|-------------------------|------------------------------------|
|service_provider_id          |str                      |serviceProviderId                   |
|group_id                     |str                      |groupId                             |
|last_name                    |str                      |lastName                            |
|first_name                   |str                      |firstName                           |
|calling_line_id_last_name    |str                      |callingLineIdLastName               |
|calling_line_id_first_name   |str                      |callingLineIdFirstName              |
|name_dialing_name            |OCI.nameDialingName      |nameDialingName *Optional*          |
|hiragana_last_name           |str                      |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                      |hiraganaFirstName *Optional*        |
|phone_number                 |str                      |phoneNumber *Optional*              |
|extension                    |str                      |extension *Optional*                |
|calling_line_id_phone_number |str                      |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department           |department *Optional*               |
|department_full_path         |str                      |departmentFullPath *Optional*       |
|language                     |str                      |language                            |
|time_zone                    |str                      |timeZone                            |
|time_zone_display_name       |str                      |timeZoneDisplayName                 |
|default_alias                |str                      |defaultAlias                        |
|alias                        |List[str]                |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing      |trunkAddressing *Optional*          |
|title                        |str                      |title *Optional*                    |
|pager_phone_number           |str                      |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                      |mobilePhoneNumber *Optional*        |
|email_address                |str                      |emailAddress *Optional*             |
|yahoo_id                     |str                      |yahooId *Optional*                  |
|address_location             |str                      |addressLocation *Optional*          |
|address                      |OCI.address              |address *Optional*                  |
|country_code                 |str                      |countryCode                         |
|national_prefix              |str                      |nationalPrefix *Optional*           |
|network_class_of_service     |str                      |networkClassOfService *Optional*    |
|office_zone_name             |str                      |officeZoneName *Optional*           |
|primary_zone_name            |str                      |primaryZoneName *Optional*          |
|imp_id                       |str                      |impId *Optional*                    |
</div>


## `UserGetResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest21sp1()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following data elements are only used
in AS data mode and not returned in XS data mode: contact[2]-contact[5]
nameDialingName alternateUserId The following data elements are only used in XS data
mode: alternateTrunkIdentityDomain The country code (countryCode) included is the
user's phone number country code when the user has a phone number assigned, or the
user's Group associated country code when the user does not have a phone number
assigned, or the system default country code when the user's Group does not have an
associated country code.  The nationalPrefix in this response is the one associated to
the included countryCode.  The callingLineIdPhoneNumber is no longer being formatted
for display purpose.  The value is returned exactly the same as being stored.
Replaced by `UserGetResponse22()`

**Attributes:**

|Name                         |Type                      |Description                         |
|-----------------------------|--------------------------|------------------------------------|
|service_provider_id          |str                       |serviceProviderId                   |
|group_id                     |str                       |groupId                             |
|last_name                    |str                       |lastName                            |
|first_name                   |str                       |firstName                           |
|calling_line_id_last_name    |str                       |callingLineIdLastName               |
|calling_line_id_first_name   |str                       |callingLineIdFirstName              |
|name_dialing_name            |OCI.nameDialingName       |nameDialingName *Optional*          |
|hiragana_last_name           |str                       |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                       |hiraganaFirstName *Optional*        |
|phone_number                 |str                       |phoneNumber *Optional*              |
|extension                    |str                       |extension *Optional*                |
|calling_line_id_phone_number |str                       |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department            |department *Optional*               |
|department_full_path         |str                       |departmentFullPath *Optional*       |
|language                     |str                       |language                            |
|time_zone                    |str                       |timeZone                            |
|time_zone_display_name       |str                       |timeZoneDisplayName                 |
|default_alias                |str                       |defaultAlias                        |
|alias                        |List[str]                 |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint  |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing       |trunkAddressing *Optional*          |
|title                        |str                       |title *Optional*                    |
|pager_phone_number           |str                       |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                       |mobilePhoneNumber *Optional*        |
|email_address                |str                       |emailAddress *Optional*             |
|yahoo_id                     |str                       |yahooId *Optional*                  |
|address_location             |str                       |addressLocation *Optional*          |
|address                      |OCI.address               |address *Optional*                  |
|country_code                 |str                       |countryCode                         |
|national_prefix              |str                       |nationalPrefix *Optional*           |
|network_class_of_service     |str                       |networkClassOfService *Optional*    |
|office_zone_name             |str                       |officeZoneName *Optional*           |
|primary_zone_name            |str                       |primaryZoneName *Optional*          |
|imp_id                       |str                       |impId *Optional*                    |
|alternate_user_id            |List[OCI.alternateUserId] |alternateUserId *Optional*          |
</div>


## `UserGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest22()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following data elements are only used
in AS data mode and not returned in XS data mode: contact[2]-contact[5]
nameDialingName alternateUserId The following elements are only used in AS data mode:
userId The following data elements are only used in XS data mode:
alternateTrunkIdentityDomain The userId returned in this response is the user's
primary userId and may not be the userId passed in the request.  The country code
(countryCode) included is the user's phone number country code when the user has a
phone number assigned, or the user's Group associated country code when the user does
not have a phone number assigned, or the system default country code when the user's
Group does not have an associated country code.  The nationalPrefix in this response
is the one associated to the included countryCode.  The callingLineIdPhoneNumber is no
longer being formatted for display purpose.  The value is returned exactly the same as
being stored.  Replaced by `UserGetResponse22V2()`

**Attributes:**

|Name                         |Type                      |Description                         |
|-----------------------------|--------------------------|------------------------------------|
|service_provider_id          |str                       |serviceProviderId                   |
|group_id                     |str                       |groupId                             |
|user_id                      |str                       |userId                              |
|last_name                    |str                       |lastName                            |
|first_name                   |str                       |firstName                           |
|calling_line_id_last_name    |str                       |callingLineIdLastName               |
|calling_line_id_first_name   |str                       |callingLineIdFirstName              |
|name_dialing_name            |OCI.nameDialingName       |nameDialingName *Optional*          |
|hiragana_last_name           |str                       |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                       |hiraganaFirstName *Optional*        |
|phone_number                 |str                       |phoneNumber *Optional*              |
|extension                    |str                       |extension *Optional*                |
|calling_line_id_phone_number |str                       |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department            |department *Optional*               |
|department_full_path         |str                       |departmentFullPath *Optional*       |
|language                     |str                       |language                            |
|time_zone                    |str                       |timeZone                            |
|time_zone_display_name       |str                       |timeZoneDisplayName                 |
|default_alias                |str                       |defaultAlias                        |
|alias                        |List[str]                 |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint  |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing       |trunkAddressing *Optional*          |
|title                        |str                       |title *Optional*                    |
|pager_phone_number           |str                       |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                       |mobilePhoneNumber *Optional*        |
|email_address                |str                       |emailAddress *Optional*             |
|yahoo_id                     |str                       |yahooId *Optional*                  |
|address_location             |str                       |addressLocation *Optional*          |
|address                      |OCI.address               |address *Optional*                  |
|country_code                 |str                       |countryCode                         |
|national_prefix              |str                       |nationalPrefix *Optional*           |
|network_class_of_service     |str                       |networkClassOfService *Optional*    |
|office_zone_name             |str                       |officeZoneName *Optional*           |
|primary_zone_name            |str                       |primaryZoneName *Optional*          |
|imp_id                       |str                       |impId *Optional*                    |
|alternate_user_id            |List[OCI.alternateUserId] |alternateUserId *Optional*          |
</div>


## `UserGetResponse22V2`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest22V2()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following data elements are only used
in AS data mode and not returned in XS data mode: contact[2]-contact[5]
nameDialingName alternateUserId resellerId The following data elements are only used
in XS data mode: alternateTrunkIdentityDomain The following data elements are only
used in AS data mode: userId The userId returned in this response is the user's
primary userId and may not be the userId passed in the request.  The country code
(countryCode) included is the user's phone number country code when the user has a
phone number assigned, or the user's Group associated country code when the user does
not have a phone number assigned, or the system default country code when the user's
Group does not have an associated country code.  The nationalPrefix in this response
is the one associated to the included countryCode.  The callingLineIdPhoneNumber is no
longer being formatted for display purpose.  The value is returned exactly the same as
being stored.  Replaced by: `UserGetResponse22V3()` in AS data mode.

**Attributes:**

|Name                         |Type                      |Description                         |
|-----------------------------|--------------------------|------------------------------------|
|service_provider_id          |str                       |serviceProviderId                   |
|group_id                     |str                       |groupId                             |
|user_id                      |str                       |userId                              |
|last_name                    |str                       |lastName                            |
|first_name                   |str                       |firstName                           |
|calling_line_id_last_name    |str                       |callingLineIdLastName               |
|calling_line_id_first_name   |str                       |callingLineIdFirstName              |
|name_dialing_name            |OCI.nameDialingName       |nameDialingName *Optional*          |
|hiragana_last_name           |str                       |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                       |hiraganaFirstName *Optional*        |
|phone_number                 |str                       |phoneNumber *Optional*              |
|extension                    |str                       |extension *Optional*                |
|calling_line_id_phone_number |str                       |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department            |department *Optional*               |
|department_full_path         |str                       |departmentFullPath *Optional*       |
|language                     |str                       |language                            |
|time_zone                    |str                       |timeZone                            |
|time_zone_display_name       |str                       |timeZoneDisplayName                 |
|default_alias                |str                       |defaultAlias                        |
|alias                        |List[str]                 |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint  |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing       |trunkAddressing *Optional*          |
|title                        |str                       |title *Optional*                    |
|pager_phone_number           |str                       |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                       |mobilePhoneNumber *Optional*        |
|email_address                |str                       |emailAddress *Optional*             |
|yahoo_id                     |str                       |yahooId *Optional*                  |
|address_location             |str                       |addressLocation *Optional*          |
|address                      |OCI.address               |address *Optional*                  |
|country_code                 |str                       |countryCode                         |
|national_prefix              |str                       |nationalPrefix *Optional*           |
|network_class_of_service     |str                       |networkClassOfService *Optional*    |
|office_zone_name             |str                       |officeZoneName *Optional*           |
|primary_zone_name            |str                       |primaryZoneName *Optional*          |
|imp_id                       |str                       |impId *Optional*                    |
|alternate_user_id            |List[OCI.alternateUserId] |alternateUserId *Optional*          |
|reseller_id                  |str                       |resellerId *Optional*               |
</div>


## `UserGetResponse22V3`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest22V3()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following data elements are only used
in AS data mode and not returned in XS data mode: contact[2]-contact[5] userId
nameDialingName alternateUserId resellerId The following data elements are only used
in XS data mode: alternateTrunkIdentityDomain The following data elements are only
used in AS data mode: userId resellerId The userId returned in this response is the
user's primary userId and may not be the userId passed in the request.  The country
code (countryCode) included is the user's phone number country code when the user has
a phone number assigned, or the user's Group associated country code when the user
does not have a phone number assigned, or the system default country code when the
user's Group does not have an associated country code.  The nationalPrefix in this
response is the one associated to the included countryCode.  The
callingLineIdPhoneNumber is no longer being formatted for display purpose.  The value
is returned exactly the same as being stored.  Replaced by: `UserGetResponse22V4()`

**Attributes:**

|Name                         |Type                      |Description                         |
|-----------------------------|--------------------------|------------------------------------|
|service_provider_id          |str                       |serviceProviderId                   |
|group_id                     |str                       |groupId                             |
|user_id                      |str                       |userId                              |
|last_name                    |str                       |lastName                            |
|first_name                   |str                       |firstName                           |
|calling_line_id_last_name    |str                       |callingLineIdLastName               |
|calling_line_id_first_name   |str                       |callingLineIdFirstName              |
|name_dialing_name            |OCI.nameDialingName       |nameDialingName *Optional*          |
|hiragana_last_name           |str                       |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                       |hiraganaFirstName *Optional*        |
|phone_number                 |str                       |phoneNumber *Optional*              |
|extension                    |str                       |extension *Optional*                |
|calling_line_id_phone_number |str                       |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department            |department *Optional*               |
|department_full_path         |str                       |departmentFullPath *Optional*       |
|language                     |str                       |language                            |
|time_zone                    |str                       |timeZone                            |
|time_zone_display_name       |str                       |timeZoneDisplayName                 |
|default_alias                |str                       |defaultAlias                        |
|alias                        |List[str]                 |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint  |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing       |trunkAddressing *Optional*          |
|title                        |str                       |title *Optional*                    |
|pager_phone_number           |str                       |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                       |mobilePhoneNumber *Optional*        |
|email_address                |str                       |emailAddress *Optional*             |
|yahoo_id                     |str                       |yahooId *Optional*                  |
|address_location             |str                       |addressLocation *Optional*          |
|address                      |OCI.address               |address *Optional*                  |
|country_code                 |str                       |countryCode                         |
|national_prefix              |str                       |nationalPrefix *Optional*           |
|network_class_of_service     |str                       |networkClassOfService *Optional*    |
|office_zone_name             |str                       |officeZoneName *Optional*           |
|primary_zone_name            |str                       |primaryZoneName *Optional*          |
|imp_id                       |str                       |impId *Optional*                    |
|alternate_user_id            |List[OCI.alternateUserId] |alternateUserId *Optional*          |
|reseller_id                  |str                       |resellerId *Optional*               |
</div>


## `UserGetResponse22V4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest22V4()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following data elements are only used
in AS data mode and not returned in XS data mode: contact[2]-contact[5] userId
nameDialingName alternateUserId resellerId The following data elements are only used
in XS data mode: alternateTrunkIdentityDomain The following data elements are only
used in AS data mode: userId resellerId The following data elements are only used in
XS data mode: alternateTrunkIdentityDomain allowVideo, value "true" is returned in AS
data mode.  The userId returned in this response is the user's primary userId and may
not be the userId passed in the request.  The country code (countryCode) included is
the user's phone number country code when the user has a phone number assigned, or the
user's Group associated country code when the user does not have a phone number
assigned, or the system default country code when the user's Group does not have an
associated country code.  The nationalPrefix in this response is the one associated to
the included countryCode.  The callingLineIdPhoneNumber is no longer being formatted
for display purpose.  The value is returned exactly the same as being stored.
Replaced by: `UserGetResponse22V5()` in AS data mode

**Attributes:**

|Name                         |Type                      |Description                         |
|-----------------------------|--------------------------|------------------------------------|
|service_provider_id          |str                       |serviceProviderId                   |
|group_id                     |str                       |groupId                             |
|user_id                      |str                       |userId                              |
|last_name                    |str                       |lastName                            |
|first_name                   |str                       |firstName                           |
|calling_line_id_last_name    |str                       |callingLineIdLastName               |
|calling_line_id_first_name   |str                       |callingLineIdFirstName              |
|name_dialing_name            |OCI.nameDialingName       |nameDialingName *Optional*          |
|hiragana_last_name           |str                       |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                       |hiraganaFirstName *Optional*        |
|phone_number                 |str                       |phoneNumber *Optional*              |
|extension                    |str                       |extension *Optional*                |
|calling_line_id_phone_number |str                       |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department            |department *Optional*               |
|department_full_path         |str                       |departmentFullPath *Optional*       |
|language                     |str                       |language                            |
|time_zone                    |str                       |timeZone                            |
|time_zone_display_name       |str                       |timeZoneDisplayName                 |
|default_alias                |str                       |defaultAlias                        |
|alias                        |List[str]                 |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint  |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing       |trunkAddressing *Optional*          |
|title                        |str                       |title *Optional*                    |
|pager_phone_number           |str                       |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                       |mobilePhoneNumber *Optional*        |
|email_address                |str                       |emailAddress *Optional*             |
|yahoo_id                     |str                       |yahooId *Optional*                  |
|address_location             |str                       |addressLocation *Optional*          |
|address                      |OCI.address               |address *Optional*                  |
|country_code                 |str                       |countryCode                         |
|national_prefix              |str                       |nationalPrefix *Optional*           |
|network_class_of_service     |str                       |networkClassOfService *Optional*    |
|office_zone_name             |str                       |officeZoneName *Optional*           |
|primary_zone_name            |str                       |primaryZoneName *Optional*          |
|imp_id                       |str                       |impId *Optional*                    |
|alternate_user_id            |List[OCI.alternateUserId] |alternateUserId *Optional*          |
|allow_video                  |bool                      |allowVideo                          |
|reseller_id                  |str                       |resellerId *Optional*               |
</div>


## `UserIncomingCallingPlanGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserIncomingCallingPlanGetRequest()`.


**Attributes:**

|Name                |Type                |Description       |
|--------------------|--------------------|------------------|
|use_custom_settings |bool                |useCustomSettings |
|user_permissions    |OCI.userPermissions |userPermissions   |
</div>


## `UserOutgoingCallingPlanDigitPlanCallMeNowGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanDigitPlanCallMeNowGetRequest()`.


**Attributes:**

|Name                |Type                |Description                |
|--------------------|--------------------|---------------------------|
|use_custom_settings |bool                |useCustomSettings          |
|user_permissions    |OCI.userPermissions |userPermissions *Optional* |
</div>


## `UserOutgoingCallingPlanDigitPlanOriginatingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanDigitPlanOriginatingGetRequest()`.


**Attributes:**

|Name                |Type                |Description                |
|--------------------|--------------------|---------------------------|
|use_custom_settings |bool                |useCustomSettings          |
|user_permissions    |OCI.userPermissions |userPermissions *Optional* |
</div>


## `UserOutgoingCallingPlanDigitPlanRedirectingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanDigitPlanRedirectingGetRequest()`.


**Attributes:**

|Name                |Type                |Description                |
|--------------------|--------------------|---------------------------|
|use_custom_settings |bool                |useCustomSettings          |
|user_permissions    |OCI.userPermissions |userPermissions *Optional* |
</div>


## `UserOutgoingCallingPlanPinholeDigitPlanCallMeNowGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanPinholeDigitPlanCallMeNowGetRequest()`.


**Attributes:**

|Name                |Type                |Description                |
|--------------------|--------------------|---------------------------|
|use_custom_settings |bool                |useCustomSettings          |
|user_permissions    |OCI.userPermissions |userPermissions *Optional* |
</div>


## `UserOutgoingCallingPlanPinholeDigitPlanOriginatingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanPinholeDigitPlanOriginatingGetRequest()`.


**Attributes:**

|Name                |Type                |Description                |
|--------------------|--------------------|---------------------------|
|use_custom_settings |bool                |useCustomSettings          |
|user_permissions    |OCI.userPermissions |userPermissions *Optional* |
</div>


## `UserOutgoingCallingPlanPinholeDigitPlanRedirectingGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserOutgoingCallingPlanPinholeDigitPlanRedirectingGetRequest()`.


**Attributes:**

|Name                |Type                |Description                |
|--------------------|--------------------|---------------------------|
|use_custom_settings |bool                |useCustomSettings          |
|user_permissions    |OCI.userPermissions |userPermissions *Optional* |
</div>


## `UserScheduleGetEventDetailListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserScheduleGetEventRequest()`.

The response contains collection of event details of a requested schedule.

**Attributes:**

|Name            |Type                     |Description               |
|----------------|-------------------------|--------------------------|
|schedule_events |List[OCI.scheduleEvents] |scheduleEvents *Optional* |
</div>


## `UserScheduleGetListResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserScheduleGetListRequest17sp1()`.

The response contains a list of schedules viewable by the user.  It contains the
schedules defined for the user and the group the user belongs to.  If the user belongs
to an enterprise, the list also contains the schedules defined for the enterprise.

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|schedule_global_key |List[OCI.scheduleGlobalKey] |scheduleGlobalKey *Optional* |
</div>


## `UserShInterfaceGetUserIdDataResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserShInterfaceGetUserIdDataRequest()`.

The response contains the Sh non-transparent data for the specified userId.  The data
also includes a userType, publicUserIdentity and endpointType.  Replaced by:
`UserShInterfaceGetUserIdDataResponse21sp1()` in AS data mode.

**Attributes:**

|Name  |Type            |Description      |
|------|----------------|-----------------|
|entry |List[OCI.entry] |entry *Optional* |
</div>


## `UserShInterfaceGetUserIdDataResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserShInterfaceGetUserIdDataRequest21sp1()`.

The response contains the Sh non-transparent data for the specified userId.  The data
also includes a userType, publicUserIdentity and endpointType.  The value Mobility in
Endpoint Type is only applicable in AS data mode.

**Attributes:**

|Name  |Type            |Description      |
|------|----------------|-----------------|
|entry |List[OCI.entry] |entry *Optional* |
</div>


## `UserVideoAddOnGetResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserVideoAddOnGetRequest14()`.


**Attributes:**

|Name                               |Type                     |Description                     |
|-----------------------------------|-------------------------|--------------------------------|
|is_active                          |bool                     |isActive                        |
|max_originating_call_delay_seconds |int                      |maxOriginatingCallDelaySeconds  |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional* |
</div>


## `UserVideoAddOnGetResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserVideoAddOnGetRequest19()`.


**Attributes:**

|Name                               |Type                     |Description                     |
|-----------------------------------|-------------------------|--------------------------------|
|is_active                          |bool                     |isActive                        |
|max_originating_call_delay_seconds |int                      |maxOriginatingCallDelaySeconds  |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional* |
</div>


## `UserVideoAddOnGetResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `UserVideoAddOnGetRequest22()`.


**Attributes:**

|Name                               |Type                     |Description                     |
|-----------------------------------|-------------------------|--------------------------------|
|is_active                          |bool                     |isActive                        |
|max_originating_call_delay_seconds |int                      |maxOriginatingCallDelaySeconds  |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional* |
</div>


## `UserVoiceMessagingUserGetGreetingResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserVoiceMessagingUserGetGreetingRequest20()`.

Contains the greeting configuration for a user's voice messaging.  The following
elements are only used in AS data mode: disableMessageDeposit
disableMessageDepositAction greetingOnlyForwardDestination extendedAwayEnabled
extendedAwayDisableMessageDeposit extendedAwayAudioFile extendedAwayAudioMediaType
extendedAwayVideoFile extendedAwayVideoMediaTyp

**Attributes:**

|Name                                  |Type                            |Description                               |
|--------------------------------------|--------------------------------|------------------------------------------|
|busy_announcement_selection           |str                             |busyAnnouncementSelection                 |
|busy_personal_audio_file              |OCI.busyPersonalAudioFile       |busyPersonalAudioFile *Optional*          |
|busy_personal_video_file              |OCI.busyPersonalVideoFile       |busyPersonalVideoFile *Optional*          |
|no_answer_announcement_selection      |str                             |noAnswerAnnouncementSelection             |
|no_answer_personal_audio_file         |OCI.noAnswerPersonalAudioFile   |noAnswerPersonalAudioFile *Optional*      |
|no_answer_personal_video_file         |OCI.noAnswerPersonalVideoFile   |noAnswerPersonalVideoFile *Optional*      |
|no_answer_alternate_greeting01        |OCI.noAnswerAlternateGreeting01 |noAnswerAlternateGreeting01 *Optional*    |
|no_answer_alternate_greeting02        |OCI.noAnswerAlternateGreeting02 |noAnswerAlternateGreeting02 *Optional*    |
|no_answer_alternate_greeting03        |OCI.noAnswerAlternateGreeting03 |noAnswerAlternateGreeting03 *Optional*    |
|extended_away_enabled                 |bool                            |extendedAwayEnabled                       |
|extended_away_disable_message_deposit |bool                            |extendedAwayDisableMessageDeposit         |
|extended_away_audio_file              |OCI.extendedAwayAudioFile       |extendedAwayAudioFile *Optional*          |
|extended_away_video_file              |OCI.extendedAwayVideoFile       |extendedAwayVideoFile *Optional*          |
|no_answer_number_of_rings             |int                             |noAnswerNumberOfRings                     |
|disable_message_deposit               |bool                            |disableMessageDeposit                     |
|disable_message_deposit_action        |str                             |disableMessageDepositAction               |
|greeting_only_forward_destination     |str                             |greetingOnlyForwardDestination *Optional* |
</div>


## `EnterpriseCallCenterEnhancedReportingScheduledReportGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `EnterpriseCallCenterEnhancedReportingScheduledReportGetRequest()`.


**Attributes:**

|Name                               |Type                       |Description                                |
|-----------------------------------|---------------------------|-------------------------------------------|
|description                        |str                        |description *Optional*                     |
|report_template                    |OCI.reportTemplate         |reportTemplate                             |
|schedule                           |OCI.schedule               |schedule                                   |
|sampling_period                    |str                        |samplingPeriod *Optional*                  |
|start_day_of_week                  |str                        |startDayOfWeek *Optional*                  |
|report_time_zone                   |str                        |reportTimeZone                             |
|report_date_format                 |str                        |reportDateFormat                           |
|report_time_format                 |str                        |reportTimeFormat                           |
|report_interval                    |OCI.reportInterval         |reportInterval                             |
|report_format                      |str                        |reportFormat                               |
|agent                              |OCI.agent                  |agent *Optional*                           |
|call_center                        |OCI.callCenter             |callCenter *Optional*                      |
|dnis                               |OCI.dnis                   |dnis *Optional*                            |
|call_completion_threshold_seconds  |int                        |callCompletionThresholdSeconds *Optional*  |
|short_duration_threshold_seconds   |int                        |shortDurationThresholdSeconds *Optional*   |
|service_level_threshold_seconds    |List[int]                  |serviceLevelThresholdSeconds *Optional*    |
|service_level_inclusions           |OCI.serviceLevelInclusions |serviceLevelInclusions *Optional*          |
|service_level_objective_percentage |int                        |serviceLevelObjectivePercentage *Optional* |
|abandoned_call_threshold_seconds   |List[int]                  |abandonedCallThresholdSeconds *Optional*   |
|email_address                      |List[str]                  |emailAddress                               |
</div>


## `GroupAutoAttendantGetInstanceResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAutoAttendantGetInstanceRequest19()`.

Contains the service profile information.  The following elements are only used in AS
data mode: type, value "Basic" is returned in XS data mode The following elements are
only used in AS data mode and not returned in XS data mode: holidayMenu The following
elements are only valid for Standard Auto Attendants: holidayMenu Replaced by:
`GroupAutoAttendantGetInstanceResponse19sp1()` in AS data mode

**Attributes:**

|Name                     |Type                       |Description                |
|-------------------------|---------------------------|---------------------------|
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile     |
|type                     |str                        |type                       |
|enable_video             |bool                       |enableVideo                |
|business_hours           |OCI.businessHours          |businessHours *Optional*   |
|holiday_schedule         |OCI.holidaySchedule        |holidaySchedule *Optional* |
|extension_dialing_scope  |str                        |extensionDialingScope      |
|name_dialing_scope       |str                        |nameDialingScope           |
|name_dialing_entries     |str                        |nameDialingEntries         |
|business_hours_menu      |OCI.businessHoursMenu      |businessHoursMenu          |
|after_hours_menu         |OCI.afterHoursMenu         |afterHoursMenu             |
|holiday_menu             |OCI.holidayMenu            |holidayMenu *Optional*     |
</div>


## `GroupAutoAttendantGetInstanceResponse19sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAutoAttendantGetInstanceRequest19sp1()`.

Contains the service profile information.  The following elements are only used in AS
data mode: type, value "Basic" is returned in XS data mode The following elements are
only used in AS data mode and not returned in XS data mode: holidayMenu The following
elementsare only valid for Standard Auto Attendants: holidayMenu Replaced by:
`GroupAutoAttendantGetInstanceResponse20()` in AS data mode

**Attributes:**

|Name                     |Type                       |Description                      |
|-------------------------|---------------------------|---------------------------------|
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|type                     |str                        |type                             |
|enable_video             |bool                       |enableVideo                      |
|business_hours           |OCI.businessHours          |businessHours *Optional*         |
|holiday_schedule         |OCI.holidaySchedule        |holidaySchedule *Optional*       |
|extension_dialing_scope  |str                        |extensionDialingScope            |
|name_dialing_scope       |str                        |nameDialingScope                 |
|name_dialing_entries     |str                        |nameDialingEntries               |
|business_hours_menu      |OCI.businessHoursMenu      |businessHoursMenu                |
|after_hours_menu         |OCI.afterHoursMenu         |afterHoursMenu                   |
|holiday_menu             |OCI.holidayMenu            |holidayMenu *Optional*           |
|network_class_of_service |str                        |networkClassOfService *Optional* |
</div>


## `GroupAutoAttendantSubmenuGetResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAutoAttendantSubmenuGetRequest20()`.

Contains AutoAttendant submenu information.

**Attributes:**

|Name                           |Type                       |Description                 |
|-------------------------------|---------------------------|----------------------------|
|announcement_selection         |str                        |announcementSelection       |
|audio_file                     |OCI.audioFile              |audioFile *Optional*        |
|video_file                     |OCI.videoFile              |videoFile *Optional*        |
|enable_level_extension_dialing |bool                       |enableLevelExtensionDialing |
|key_configuration              |List[OCI.keyConfiguration] |keyConfiguration *Optional* |
</div>


## `GroupCallCenterEnhancedReportingScheduledReportGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupCallCenterEnhancedReportingScheduledReportGetRequest()`.


**Attributes:**

|Name                               |Type                       |Description                                |
|-----------------------------------|---------------------------|-------------------------------------------|
|description                        |str                        |description *Optional*                     |
|report_template                    |OCI.reportTemplate         |reportTemplate                             |
|schedule                           |OCI.schedule               |schedule                                   |
|sampling_period                    |str                        |samplingPeriod *Optional*                  |
|start_day_of_week                  |str                        |startDayOfWeek *Optional*                  |
|report_time_zone                   |str                        |reportTimeZone                             |
|report_date_format                 |str                        |reportDateFormat                           |
|report_time_format                 |str                        |reportTimeFormat                           |
|report_interval                    |OCI.reportInterval         |reportInterval                             |
|report_format                      |str                        |reportFormat                               |
|agent                              |OCI.agent                  |agent *Optional*                           |
|call_center                        |OCI.callCenter             |callCenter *Optional*                      |
|dnis                               |OCI.dnis                   |dnis *Optional*                            |
|call_completion_threshold_seconds  |int                        |callCompletionThresholdSeconds *Optional*  |
|short_duration_threshold_seconds   |int                        |shortDurationThresholdSeconds *Optional*   |
|service_level_threshold_seconds    |List[int]                  |serviceLevelThresholdSeconds *Optional*    |
|service_level_inclusions           |OCI.serviceLevelInclusions |serviceLevelInclusions *Optional*          |
|service_level_objective_percentage |int                        |serviceLevelObjectivePercentage *Optional* |
|abandoned_call_threshold_seconds   |List[int]                  |abandonedCallThresholdSeconds *Optional*   |
|email_address                      |List[str]                  |emailAddress                               |
</div>


## `GroupCallCenterGetAnnouncementResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAnnouncementRequest16()`.


**Attributes:**

|Name                                                  |Type                          |Description                                              |
|------------------------------------------------------|------------------------------|---------------------------------------------------------|
|play_entrance_message                                 |bool                          |playEntranceMessage                                      |
|mandatory_entrance_message                            |bool                          |mandatoryEntranceMessage                                 |
|entrance_audio_message_selection                      |str                           |entranceAudioMessageSelection                            |
|entrance_audio_file_url                               |str                           |entranceAudioFileUrl *Optional*                          |
|entrance_message_audio_file_description               |str                           |entranceMessageAudioFileDescription *Optional*           |
|entrance_audio_file_media_type                        |str                           |entranceAudioFileMediaType *Optional*                    |
|entrance_video_message_selection                      |str                           |entranceVideoMessageSelection *Optional*                 |
|entrance_video_file_url                               |str                           |entranceVideoFileUrl *Optional*                          |
|entrance_message_video_file_description               |str                           |entranceMessageVideoFileDescription *Optional*           |
|entrance_video_file_media_type                        |str                           |entranceVideoFileMediaType *Optional*                    |
|play_periodic_comfort_message                         |bool                          |playPeriodicComfortMessage                               |
|time_between_comfort_messages_seconds                 |int                           |timeBetweenComfortMessagesSeconds                        |
|periodic_comfort_audio_message_selection              |str                           |periodicComfortAudioMessageSelection                     |
|periodic_comfort_audio_file_url                       |str                           |periodicComfortAudioFileUrl *Optional*                   |
|periodic_comfort_message_audio_file_description       |str                           |periodicComfortMessageAudioFileDescription *Optional*    |
|periodic_comfort_audio_file_media_type                |str                           |periodicComfortAudioFileMediaType *Optional*             |
|periodic_comfort_video_message_selection              |str                           |periodicComfortVideoMessageSelection *Optional*          |
|periodic_comfort_video_file_url                       |str                           |periodicComfortVideoFileUrl *Optional*                   |
|periodic_comfort_message_video_file_description       |str                           |periodicComfortMessageVideoFileDescription *Optional*    |
|periodic_comfort_video_file_media_type                |str                           |periodicComfortVideoFileMediaType *Optional*             |
|enable_media_on_hold_for_queued_calls                 |bool                          |enableMediaOnHoldForQueuedCalls                          |
|media_on_hold_source                                  |OCI.mediaOnHoldSource         |mediaOnHoldSource                                        |
|media_on_hold_use_alternate_source_for_internal_calls |bool                          |mediaOnHoldUseAlternateSourceForInternalCalls *Optional* |
|media_on_hold_internal_source                         |OCI.mediaOnHoldInternalSource |mediaOnHoldInternalSource *Optional*                     |
</div>


## `GroupCallCenterGetAnnouncementResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAnnouncementRequest17()`.

Replaced by `GroupCallCenterGetAnnouncementResponse17sp4()`

**Attributes:**

|Name                                                  |Type                                         |Description                                              |
|------------------------------------------------------|---------------------------------------------|---------------------------------------------------------|
|play_entrance_message                                 |bool                                         |playEntranceMessage                                      |
|mandatory_entrance_message                            |bool                                         |mandatoryEntranceMessage                                 |
|entrance_audio_message_selection                      |str                                          |entranceAudioMessageSelection                            |
|entrance_message_audio_url_list                       |OCI.entranceMessageAudioUrlList              |entranceMessageAudioUrlList *Optional*                   |
|entrance_message_audio_file_list                      |OCI.entranceMessageAudioFileList             |entranceMessageAudioFileList *Optional*                  |
|entrance_message_audio_media_type_list                |OCI.entranceMessageAudioMediaTypeList        |entranceMessageAudioMediaTypeList *Optional*             |
|entrance_video_message_selection                      |str                                          |entranceVideoMessageSelection *Optional*                 |
|entrance_message_video_url_list                       |OCI.entranceMessageVideoUrlList              |entranceMessageVideoUrlList *Optional*                   |
|entrance_message_video_file_list                      |OCI.entranceMessageVideoFileList             |entranceMessageVideoFileList *Optional*                  |
|entrance_message_video_media_type_list                |OCI.entranceMessageVideoMediaTypeList        |entranceMessageVideoMediaTypeList *Optional*             |
|play_periodic_comfort_message                         |bool                                         |playPeriodicComfortMessage                               |
|time_between_comfort_messages_seconds                 |int                                          |timeBetweenComfortMessagesSeconds                        |
|periodic_comfort_audio_message_selection              |str                                          |periodicComfortAudioMessageSelection                     |
|periodic_comfort_message_audio_url_list               |OCI.periodicComfortMessageAudioUrlList       |periodicComfortMessageAudioUrlList *Optional*            |
|periodic_comfort_message_audio_file_list              |OCI.periodicComfortMessageAudioFileList      |periodicComfortMessageAudioFileList *Optional*           |
|periodic_comfort_message_audio_media_type_list        |OCI.periodicComfortMessageAudioMediaTypeList |periodicComfortMessageAudioMediaTypeList *Optional*      |
|periodic_comfort_video_message_selection              |str                                          |periodicComfortVideoMessageSelection *Optional*          |
|periodic_comfort_message_video_url_list               |OCI.periodicComfortMessageVideoUrlList       |periodicComfortMessageVideoUrlList *Optional*            |
|periodic_comfort_message_video_file_list              |OCI.periodicComfortMessageVideoFileList      |periodicComfortMessageVideoFileList *Optional*           |
|periodic_comfort_message_video_media_type_list        |OCI.periodicComfortMessageVideoMediaTypeList |periodicComfortMessageVideoMediaTypeList *Optional*      |
|enable_media_on_hold_for_queued_calls                 |bool                                         |enableMediaOnHoldForQueuedCalls                          |
|media_on_hold_source                                  |OCI.mediaOnHoldSource                        |mediaOnHoldSource                                        |
|media_on_hold_use_alternate_source_for_internal_calls |bool                                         |mediaOnHoldUseAlternateSourceForInternalCalls *Optional* |
|media_on_hold_internal_source                         |OCI.mediaOnHoldInternalSource                |mediaOnHoldInternalSource *Optional*                     |
|play_whisper_message                                  |bool                                         |playWhisperMessage *Optional*                            |
|whisper_audio_message_selection                       |str                                          |whisperAudioMessageSelection *Optional*                  |
|whisper_message_audio_url_list                        |OCI.whisperMessageAudioUrlList               |whisperMessageAudioUrlList *Optional*                    |
|whisper_message_audio_file_list                       |OCI.whisperMessageAudioFileList              |whisperMessageAudioFileList *Optional*                   |
|whisper_message_audio_media_type_list                 |OCI.whisperMessageAudioMediaTypeList         |whisperMessageAudioMediaTypeList *Optional*              |
|whisper_video_message_selection                       |str                                          |whisperVideoMessageSelection *Optional*                  |
|whisper_message_video_url_list                        |OCI.whisperMessageVideoUrlList               |whisperMessageVideoUrlList *Optional*                    |
|whisper_message_video_file_list                       |OCI.whisperMessageVideoFileList              |whisperMessageVideoFileList *Optional*                   |
|whisper_message_video_media_type_list                 |OCI.whisperMessageVideoMediaTypeList         |whisperMessageVideoMediaTypeList *Optional*              |
|estimated_wait_message_options_read                   |OCI.estimatedWaitMessageOptionsRead          |estimatedWaitMessageOptionsRead                          |
</div>


## `GroupCallCenterGetAnnouncementResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAnnouncementRequest17sp4()`.


**Attributes:**

|Name                                                  |Type                                         |Description                                              |
|------------------------------------------------------|---------------------------------------------|---------------------------------------------------------|
|play_entrance_message                                 |bool                                         |playEntranceMessage                                      |
|mandatory_entrance_message                            |bool                                         |mandatoryEntranceMessage                                 |
|entrance_audio_message_selection                      |str                                          |entranceAudioMessageSelection                            |
|entrance_message_audio_url_list                       |OCI.entranceMessageAudioUrlList              |entranceMessageAudioUrlList *Optional*                   |
|entrance_message_audio_file_list                      |OCI.entranceMessageAudioFileList             |entranceMessageAudioFileList *Optional*                  |
|entrance_message_audio_media_type_list                |OCI.entranceMessageAudioMediaTypeList        |entranceMessageAudioMediaTypeList *Optional*             |
|entrance_video_message_selection                      |str                                          |entranceVideoMessageSelection *Optional*                 |
|entrance_message_video_url_list                       |OCI.entranceMessageVideoUrlList              |entranceMessageVideoUrlList *Optional*                   |
|entrance_message_video_file_list                      |OCI.entranceMessageVideoFileList             |entranceMessageVideoFileList *Optional*                  |
|entrance_message_video_media_type_list                |OCI.entranceMessageVideoMediaTypeList        |entranceMessageVideoMediaTypeList *Optional*             |
|play_periodic_comfort_message                         |bool                                         |playPeriodicComfortMessage                               |
|time_between_comfort_messages_seconds                 |int                                          |timeBetweenComfortMessagesSeconds                        |
|periodic_comfort_audio_message_selection              |str                                          |periodicComfortAudioMessageSelection                     |
|periodic_comfort_message_audio_url_list               |OCI.periodicComfortMessageAudioUrlList       |periodicComfortMessageAudioUrlList *Optional*            |
|periodic_comfort_message_audio_file_list              |OCI.periodicComfortMessageAudioFileList      |periodicComfortMessageAudioFileList *Optional*           |
|periodic_comfort_message_audio_media_type_list        |OCI.periodicComfortMessageAudioMediaTypeList |periodicComfortMessageAudioMediaTypeList *Optional*      |
|periodic_comfort_video_message_selection              |str                                          |periodicComfortVideoMessageSelection *Optional*          |
|periodic_comfort_message_video_url_list               |OCI.periodicComfortMessageVideoUrlList       |periodicComfortMessageVideoUrlList *Optional*            |
|periodic_comfort_message_video_file_list              |OCI.periodicComfortMessageVideoFileList      |periodicComfortMessageVideoFileList *Optional*           |
|periodic_comfort_message_video_media_type_list        |OCI.periodicComfortMessageVideoMediaTypeList |periodicComfortMessageVideoMediaTypeList *Optional*      |
|enable_media_on_hold_for_queued_calls                 |bool                                         |enableMediaOnHoldForQueuedCalls                          |
|media_on_hold_source                                  |OCI.mediaOnHoldSource                        |mediaOnHoldSource                                        |
|media_on_hold_use_alternate_source_for_internal_calls |bool                                         |mediaOnHoldUseAlternateSourceForInternalCalls *Optional* |
|media_on_hold_internal_source                         |OCI.mediaOnHoldInternalSource                |mediaOnHoldInternalSource *Optional*                     |
|play_whisper_message                                  |bool                                         |playWhisperMessage *Optional*                            |
|whisper_audio_message_selection                       |str                                          |whisperAudioMessageSelection *Optional*                  |
|whisper_message_audio_url_list                        |OCI.whisperMessageAudioUrlList               |whisperMessageAudioUrlList *Optional*                    |
|whisper_message_audio_file_list                       |OCI.whisperMessageAudioFileList              |whisperMessageAudioFileList *Optional*                   |
|whisper_message_audio_media_type_list                 |OCI.whisperMessageAudioMediaTypeList         |whisperMessageAudioMediaTypeList *Optional*              |
|whisper_video_message_selection                       |str                                          |whisperVideoMessageSelection *Optional*                  |
|whisper_message_video_url_list                        |OCI.whisperMessageVideoUrlList               |whisperMessageVideoUrlList *Optional*                    |
|whisper_message_video_file_list                       |OCI.whisperMessageVideoFileList              |whisperMessageVideoFileList *Optional*                   |
|whisper_message_video_media_type_list                 |OCI.whisperMessageVideoMediaTypeList         |whisperMessageVideoMediaTypeList *Optional*              |
|estimated_wait_message_options_read                   |OCI.estimatedWaitMessageOptionsRead          |estimatedWaitMessageOptionsRead                          |
</div>


## `GroupCallCenterGetAnnouncementResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAnnouncementRequest19()`.


**Attributes:**

|Name                                                  |Type                                         |Description                                              |
|------------------------------------------------------|---------------------------------------------|---------------------------------------------------------|
|play_entrance_message                                 |bool                                         |playEntranceMessage                                      |
|mandatory_entrance_message                            |bool                                         |mandatoryEntranceMessage                                 |
|entrance_audio_message_selection                      |str                                          |entranceAudioMessageSelection                            |
|entrance_message_audio_url_list                       |OCI.entranceMessageAudioUrlList              |entranceMessageAudioUrlList *Optional*                   |
|entrance_message_audio_file_list                      |OCI.entranceMessageAudioFileList             |entranceMessageAudioFileList *Optional*                  |
|entrance_message_audio_media_type_list                |OCI.entranceMessageAudioMediaTypeList        |entranceMessageAudioMediaTypeList *Optional*             |
|entrance_video_message_selection                      |str                                          |entranceVideoMessageSelection *Optional*                 |
|entrance_message_video_url_list                       |OCI.entranceMessageVideoUrlList              |entranceMessageVideoUrlList *Optional*                   |
|entrance_message_video_file_list                      |OCI.entranceMessageVideoFileList             |entranceMessageVideoFileList *Optional*                  |
|entrance_message_video_media_type_list                |OCI.entranceMessageVideoMediaTypeList        |entranceMessageVideoMediaTypeList *Optional*             |
|play_periodic_comfort_message                         |bool                                         |playPeriodicComfortMessage                               |
|time_between_comfort_messages_seconds                 |int                                          |timeBetweenComfortMessagesSeconds                        |
|periodic_comfort_audio_message_selection              |str                                          |periodicComfortAudioMessageSelection                     |
|periodic_comfort_message_audio_url_list               |OCI.periodicComfortMessageAudioUrlList       |periodicComfortMessageAudioUrlList *Optional*            |
|periodic_comfort_message_audio_file_list              |OCI.periodicComfortMessageAudioFileList      |periodicComfortMessageAudioFileList *Optional*           |
|periodic_comfort_message_audio_media_type_list        |OCI.periodicComfortMessageAudioMediaTypeList |periodicComfortMessageAudioMediaTypeList *Optional*      |
|periodic_comfort_video_message_selection              |str                                          |periodicComfortVideoMessageSelection *Optional*          |
|periodic_comfort_message_video_url_list               |OCI.periodicComfortMessageVideoUrlList       |periodicComfortMessageVideoUrlList *Optional*            |
|periodic_comfort_message_video_file_list              |OCI.periodicComfortMessageVideoFileList      |periodicComfortMessageVideoFileList *Optional*           |
|periodic_comfort_message_video_media_type_list        |OCI.periodicComfortMessageVideoMediaTypeList |periodicComfortMessageVideoMediaTypeList *Optional*      |
|enable_media_on_hold_for_queued_calls                 |bool                                         |enableMediaOnHoldForQueuedCalls                          |
|media_on_hold_source                                  |OCI.mediaOnHoldSource                        |mediaOnHoldSource                                        |
|media_on_hold_use_alternate_source_for_internal_calls |bool                                         |mediaOnHoldUseAlternateSourceForInternalCalls *Optional* |
|media_on_hold_internal_source                         |OCI.mediaOnHoldInternalSource                |mediaOnHoldInternalSource *Optional*                     |
|play_whisper_message                                  |bool                                         |playWhisperMessage *Optional*                            |
|whisper_audio_message_selection                       |str                                          |whisperAudioMessageSelection *Optional*                  |
|whisper_message_audio_url_list                        |OCI.whisperMessageAudioUrlList               |whisperMessageAudioUrlList *Optional*                    |
|whisper_message_audio_file_list                       |OCI.whisperMessageAudioFileList              |whisperMessageAudioFileList *Optional*                   |
|whisper_message_audio_media_type_list                 |OCI.whisperMessageAudioMediaTypeList         |whisperMessageAudioMediaTypeList *Optional*              |
|whisper_video_message_selection                       |str                                          |whisperVideoMessageSelection *Optional*                  |
|whisper_message_video_url_list                        |OCI.whisperMessageVideoUrlList               |whisperMessageVideoUrlList *Optional*                    |
|whisper_message_video_file_list                       |OCI.whisperMessageVideoFileList              |whisperMessageVideoFileList *Optional*                   |
|whisper_message_video_media_type_list                 |OCI.whisperMessageVideoMediaTypeList         |whisperMessageVideoMediaTypeList *Optional*              |
|estimated_wait_message_options_read                   |OCI.estimatedWaitMessageOptionsRead          |estimatedWaitMessageOptionsRead                          |
</div>


## `GroupCallCenterGetAnnouncementResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAnnouncementRequest20()`.


**Attributes:**

|Name                                                  |Type                                    |Description                                              |
|------------------------------------------------------|----------------------------------------|---------------------------------------------------------|
|play_entrance_message                                 |bool                                    |playEntranceMessage                                      |
|mandatory_entrance_message                            |bool                                    |mandatoryEntranceMessage                                 |
|entrance_audio_message_selection                      |str                                     |entranceAudioMessageSelection                            |
|entrance_message_audio_url_list                       |OCI.entranceMessageAudioUrlList         |entranceMessageAudioUrlList *Optional*                   |
|entrance_message_audio_file_list                      |OCI.entranceMessageAudioFileList        |entranceMessageAudioFileList *Optional*                  |
|entrance_video_message_selection                      |str                                     |entranceVideoMessageSelection *Optional*                 |
|entrance_message_video_url_list                       |OCI.entranceMessageVideoUrlList         |entranceMessageVideoUrlList *Optional*                   |
|entrance_message_video_file_list                      |OCI.entranceMessageVideoFileList        |entranceMessageVideoFileList *Optional*                  |
|play_periodic_comfort_message                         |bool                                    |playPeriodicComfortMessage                               |
|time_between_comfort_messages_seconds                 |int                                     |timeBetweenComfortMessagesSeconds                        |
|periodic_comfort_audio_message_selection              |str                                     |periodicComfortAudioMessageSelection                     |
|periodic_comfort_message_audio_url_list               |OCI.periodicComfortMessageAudioUrlList  |periodicComfortMessageAudioUrlList *Optional*            |
|periodic_comfort_message_audio_file_list              |OCI.periodicComfortMessageAudioFileList |periodicComfortMessageAudioFileList *Optional*           |
|periodic_comfort_video_message_selection              |str                                     |periodicComfortVideoMessageSelection *Optional*          |
|periodic_comfort_message_video_url_list               |OCI.periodicComfortMessageVideoUrlList  |periodicComfortMessageVideoUrlList *Optional*            |
|periodic_comfort_message_video_file_list              |OCI.periodicComfortMessageVideoFileList |periodicComfortMessageVideoFileList *Optional*           |
|enable_media_on_hold_for_queued_calls                 |bool                                    |enableMediaOnHoldForQueuedCalls                          |
|media_on_hold_source                                  |OCI.mediaOnHoldSource                   |mediaOnHoldSource                                        |
|media_on_hold_use_alternate_source_for_internal_calls |bool                                    |mediaOnHoldUseAlternateSourceForInternalCalls *Optional* |
|media_on_hold_internal_source                         |OCI.mediaOnHoldInternalSource           |mediaOnHoldInternalSource *Optional*                     |
|play_whisper_message                                  |bool                                    |playWhisperMessage *Optional*                            |
|whisper_audio_message_selection                       |str                                     |whisperAudioMessageSelection *Optional*                  |
|whisper_message_audio_url_list                        |OCI.whisperMessageAudioUrlList          |whisperMessageAudioUrlList *Optional*                    |
|whisper_message_audio_file_list                       |OCI.whisperMessageAudioFileList         |whisperMessageAudioFileList *Optional*                   |
|whisper_video_message_selection                       |str                                     |whisperVideoMessageSelection *Optional*                  |
|whisper_message_video_url_list                        |OCI.whisperMessageVideoUrlList          |whisperMessageVideoUrlList *Optional*                    |
|whisper_message_video_file_list                       |OCI.whisperMessageVideoFileList         |whisperMessageVideoFileList *Optional*                   |
|estimated_wait_message_options_read                   |OCI.estimatedWaitMessageOptionsRead     |estimatedWaitMessageOptionsRead                          |
</div>


## `GroupCallCenterGetAnnouncementResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetAnnouncementRequest22()`.


**Attributes:**

|Name                                                  |Type                                    |Description                                              |
|------------------------------------------------------|----------------------------------------|---------------------------------------------------------|
|play_entrance_message                                 |bool                                    |playEntranceMessage                                      |
|mandatory_entrance_message                            |bool                                    |mandatoryEntranceMessage                                 |
|entrance_audio_message_selection                      |str                                     |entranceAudioMessageSelection                            |
|entrance_message_audio_url_list                       |OCI.entranceMessageAudioUrlList         |entranceMessageAudioUrlList *Optional*                   |
|entrance_message_audio_file_list                      |OCI.entranceMessageAudioFileList        |entranceMessageAudioFileList *Optional*                  |
|entrance_video_message_selection                      |str                                     |entranceVideoMessageSelection *Optional*                 |
|entrance_message_video_url_list                       |OCI.entranceMessageVideoUrlList         |entranceMessageVideoUrlList *Optional*                   |
|entrance_message_video_file_list                      |OCI.entranceMessageVideoFileList        |entranceMessageVideoFileList *Optional*                  |
|play_periodic_comfort_message                         |bool                                    |playPeriodicComfortMessage                               |
|time_between_comfort_messages_seconds                 |int                                     |timeBetweenComfortMessagesSeconds                        |
|periodic_comfort_audio_message_selection              |str                                     |periodicComfortAudioMessageSelection                     |
|periodic_comfort_message_audio_url_list               |OCI.periodicComfortMessageAudioUrlList  |periodicComfortMessageAudioUrlList *Optional*            |
|periodic_comfort_message_audio_file_list              |OCI.periodicComfortMessageAudioFileList |periodicComfortMessageAudioFileList *Optional*           |
|periodic_comfort_video_message_selection              |str                                     |periodicComfortVideoMessageSelection *Optional*          |
|periodic_comfort_message_video_url_list               |OCI.periodicComfortMessageVideoUrlList  |periodicComfortMessageVideoUrlList *Optional*            |
|periodic_comfort_message_video_file_list              |OCI.periodicComfortMessageVideoFileList |periodicComfortMessageVideoFileList *Optional*           |
|enable_media_on_hold_for_queued_calls                 |bool                                    |enableMediaOnHoldForQueuedCalls                          |
|media_on_hold_source                                  |OCI.mediaOnHoldSource                   |mediaOnHoldSource                                        |
|media_on_hold_use_alternate_source_for_internal_calls |bool                                    |mediaOnHoldUseAlternateSourceForInternalCalls *Optional* |
|media_on_hold_internal_source                         |OCI.mediaOnHoldInternalSource           |mediaOnHoldInternalSource *Optional*                     |
|play_whisper_message                                  |bool                                    |playWhisperMessage *Optional*                            |
|whisper_audio_message_selection                       |str                                     |whisperAudioMessageSelection *Optional*                  |
|whisper_message_audio_url_list                        |OCI.whisperMessageAudioUrlList          |whisperMessageAudioUrlList *Optional*                    |
|whisper_message_audio_file_list                       |OCI.whisperMessageAudioFileList         |whisperMessageAudioFileList *Optional*                   |
|whisper_video_message_selection                       |str                                     |whisperVideoMessageSelection *Optional*                  |
|whisper_message_video_url_list                        |OCI.whisperMessageVideoUrlList          |whisperMessageVideoUrlList *Optional*                    |
|whisper_message_video_file_list                       |OCI.whisperMessageVideoFileList         |whisperMessageVideoFileList *Optional*                   |
|estimated_wait_message_options_read                   |OCI.estimatedWaitMessageOptionsRead     |estimatedWaitMessageOptionsRead                          |
</div>


## `GroupCallCenterGetDNISAnnouncementResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetDNISAnnouncementResponse()`.

Replaced by `GroupCallCenterGetDNISAnnouncementResponse17sp4()`

**Attributes:**

|Name                                           |Type                                         |Description                                         |
|-----------------------------------------------|---------------------------------------------|----------------------------------------------------|
|play_entrance_message                          |bool                                         |playEntranceMessage                                 |
|mandatory_entrance_message                     |bool                                         |mandatoryEntranceMessage                            |
|entrance_audio_message_selection               |str                                          |entranceAudioMessageSelection                       |
|entrance_message_audio_url_list                |OCI.entranceMessageAudioUrlList              |entranceMessageAudioUrlList *Optional*              |
|entrance_message_audio_file_list               |OCI.entranceMessageAudioFileList             |entranceMessageAudioFileList *Optional*             |
|entrance_message_audio_media_type_list         |OCI.entranceMessageAudioMediaTypeList        |entranceMessageAudioMediaTypeList *Optional*        |
|entrance_video_message_selection               |str                                          |entranceVideoMessageSelection *Optional*            |
|entrance_message_video_url_list                |OCI.entranceMessageVideoUrlList              |entranceMessageVideoUrlList *Optional*              |
|entrance_message_video_file_list               |OCI.entranceMessageVideoFileList             |entranceMessageVideoFileList *Optional*             |
|entrance_message_video_media_type_list         |OCI.entranceMessageVideoMediaTypeList        |entranceMessageVideoMediaTypeList *Optional*        |
|play_periodic_comfort_message                  |bool                                         |playPeriodicComfortMessage                          |
|time_between_comfort_messages_seconds          |int                                          |timeBetweenComfortMessagesSeconds                   |
|periodic_comfort_audio_message_selection       |str                                          |periodicComfortAudioMessageSelection                |
|periodic_comfort_message_audio_url_list        |OCI.periodicComfortMessageAudioUrlList       |periodicComfortMessageAudioUrlList *Optional*       |
|periodic_comfort_message_audio_file_list       |OCI.periodicComfortMessageAudioFileList      |periodicComfortMessageAudioFileList *Optional*      |
|periodic_comfort_message_audio_media_type_list |OCI.periodicComfortMessageAudioMediaTypeList |periodicComfortMessageAudioMediaTypeList *Optional* |
|periodic_comfort_video_message_selection       |str                                          |periodicComfortVideoMessageSelection *Optional*     |
|periodic_comfort_message_video_url_list        |OCI.periodicComfortMessageVideoUrlList       |periodicComfortMessageVideoUrlList *Optional*       |
|periodic_comfort_message_video_file_list       |OCI.periodicComfortMessageVideoFileList      |periodicComfortMessageVideoFileList *Optional*      |
|periodic_comfort_message_video_media_type_list |OCI.periodicComfortMessageVideoMediaTypeList |periodicComfortMessageVideoMediaTypeList *Optional* |
|enable_media_on_hold_for_queued_calls          |bool                                         |enableMediaOnHoldForQueuedCalls                     |
|media_on_hold_source                           |OCI.mediaOnHoldSource                        |mediaOnHoldSource                                   |
|play_whisper_message                           |bool                                         |playWhisperMessage                                  |
|whisper_audio_message_selection                |str                                          |whisperAudioMessageSelection                        |
|whisper_message_audio_url_list                 |OCI.whisperMessageAudioUrlList               |whisperMessageAudioUrlList *Optional*               |
|whisper_message_audio_file_list                |OCI.whisperMessageAudioFileList              |whisperMessageAudioFileList *Optional*              |
|whisper_message_audio_media_type_list          |OCI.whisperMessageAudioMediaTypeList         |whisperMessageAudioMediaTypeList *Optional*         |
|whisper_video_message_selection                |str                                          |whisperVideoMessageSelection *Optional*             |
|whisper_message_video_url_list                 |OCI.whisperMessageVideoUrlList               |whisperMessageVideoUrlList *Optional*               |
|whisper_message_video_file_list                |OCI.whisperMessageVideoFileList              |whisperMessageVideoFileList *Optional*              |
|whisper_message_video_media_type_list          |OCI.whisperMessageVideoMediaTypeList         |whisperMessageVideoMediaTypeList *Optional*         |
|estimated_wait_message_options_read            |OCI.estimatedWaitMessageOptionsRead          |estimatedWaitMessageOptionsRead                     |
</div>


## `GroupCallCenterGetDNISAnnouncementResponse17sp4`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetDNISAnnouncementResponse17sp4()`.


**Attributes:**

|Name                                           |Type                                         |Description                                         |
|-----------------------------------------------|---------------------------------------------|----------------------------------------------------|
|play_entrance_message                          |bool                                         |playEntranceMessage                                 |
|mandatory_entrance_message                     |bool                                         |mandatoryEntranceMessage                            |
|entrance_audio_message_selection               |str                                          |entranceAudioMessageSelection                       |
|entrance_message_audio_url_list                |OCI.entranceMessageAudioUrlList              |entranceMessageAudioUrlList *Optional*              |
|entrance_message_audio_file_list               |OCI.entranceMessageAudioFileList             |entranceMessageAudioFileList *Optional*             |
|entrance_message_audio_media_type_list         |OCI.entranceMessageAudioMediaTypeList        |entranceMessageAudioMediaTypeList *Optional*        |
|entrance_video_message_selection               |str                                          |entranceVideoMessageSelection *Optional*            |
|entrance_message_video_url_list                |OCI.entranceMessageVideoUrlList              |entranceMessageVideoUrlList *Optional*              |
|entrance_message_video_file_list               |OCI.entranceMessageVideoFileList             |entranceMessageVideoFileList *Optional*             |
|entrance_message_video_media_type_list         |OCI.entranceMessageVideoMediaTypeList        |entranceMessageVideoMediaTypeList *Optional*        |
|play_periodic_comfort_message                  |bool                                         |playPeriodicComfortMessage                          |
|time_between_comfort_messages_seconds          |int                                          |timeBetweenComfortMessagesSeconds                   |
|periodic_comfort_audio_message_selection       |str                                          |periodicComfortAudioMessageSelection                |
|periodic_comfort_message_audio_url_list        |OCI.periodicComfortMessageAudioUrlList       |periodicComfortMessageAudioUrlList *Optional*       |
|periodic_comfort_message_audio_file_list       |OCI.periodicComfortMessageAudioFileList      |periodicComfortMessageAudioFileList *Optional*      |
|periodic_comfort_message_audio_media_type_list |OCI.periodicComfortMessageAudioMediaTypeList |periodicComfortMessageAudioMediaTypeList *Optional* |
|periodic_comfort_video_message_selection       |str                                          |periodicComfortVideoMessageSelection *Optional*     |
|periodic_comfort_message_video_url_list        |OCI.periodicComfortMessageVideoUrlList       |periodicComfortMessageVideoUrlList *Optional*       |
|periodic_comfort_message_video_file_list       |OCI.periodicComfortMessageVideoFileList      |periodicComfortMessageVideoFileList *Optional*      |
|periodic_comfort_message_video_media_type_list |OCI.periodicComfortMessageVideoMediaTypeList |periodicComfortMessageVideoMediaTypeList *Optional* |
|enable_media_on_hold_for_queued_calls          |bool                                         |enableMediaOnHoldForQueuedCalls                     |
|media_on_hold_source                           |OCI.mediaOnHoldSource                        |mediaOnHoldSource                                   |
|play_whisper_message                           |bool                                         |playWhisperMessage                                  |
|whisper_audio_message_selection                |str                                          |whisperAudioMessageSelection                        |
|whisper_message_audio_url_list                 |OCI.whisperMessageAudioUrlList               |whisperMessageAudioUrlList *Optional*               |
|whisper_message_audio_file_list                |OCI.whisperMessageAudioFileList              |whisperMessageAudioFileList *Optional*              |
|whisper_message_audio_media_type_list          |OCI.whisperMessageAudioMediaTypeList         |whisperMessageAudioMediaTypeList *Optional*         |
|whisper_video_message_selection                |str                                          |whisperVideoMessageSelection *Optional*             |
|whisper_message_video_url_list                 |OCI.whisperMessageVideoUrlList               |whisperMessageVideoUrlList *Optional*               |
|whisper_message_video_file_list                |OCI.whisperMessageVideoFileList              |whisperMessageVideoFileList *Optional*              |
|whisper_message_video_media_type_list          |OCI.whisperMessageVideoMediaTypeList         |whisperMessageVideoMediaTypeList *Optional*         |
|estimated_wait_message_options_read            |OCI.estimatedWaitMessageOptionsRead          |estimatedWaitMessageOptionsRead                     |
</div>


## `GroupCallCenterGetDNISAnnouncementResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetDNISAnnouncementRequest19()`.


**Attributes:**

|Name                                           |Type                                         |Description                                         |
|-----------------------------------------------|---------------------------------------------|----------------------------------------------------|
|play_entrance_message                          |bool                                         |playEntranceMessage                                 |
|mandatory_entrance_message                     |bool                                         |mandatoryEntranceMessage                            |
|entrance_audio_message_selection               |str                                          |entranceAudioMessageSelection                       |
|entrance_message_audio_url_list                |OCI.entranceMessageAudioUrlList              |entranceMessageAudioUrlList *Optional*              |
|entrance_message_audio_file_list               |OCI.entranceMessageAudioFileList             |entranceMessageAudioFileList *Optional*             |
|entrance_message_audio_media_type_list         |OCI.entranceMessageAudioMediaTypeList        |entranceMessageAudioMediaTypeList *Optional*        |
|entrance_video_message_selection               |str                                          |entranceVideoMessageSelection *Optional*            |
|entrance_message_video_url_list                |OCI.entranceMessageVideoUrlList              |entranceMessageVideoUrlList *Optional*              |
|entrance_message_video_file_list               |OCI.entranceMessageVideoFileList             |entranceMessageVideoFileList *Optional*             |
|entrance_message_video_media_type_list         |OCI.entranceMessageVideoMediaTypeList        |entranceMessageVideoMediaTypeList *Optional*        |
|play_periodic_comfort_message                  |bool                                         |playPeriodicComfortMessage                          |
|time_between_comfort_messages_seconds          |int                                          |timeBetweenComfortMessagesSeconds                   |
|periodic_comfort_audio_message_selection       |str                                          |periodicComfortAudioMessageSelection                |
|periodic_comfort_message_audio_url_list        |OCI.periodicComfortMessageAudioUrlList       |periodicComfortMessageAudioUrlList *Optional*       |
|periodic_comfort_message_audio_file_list       |OCI.periodicComfortMessageAudioFileList      |periodicComfortMessageAudioFileList *Optional*      |
|periodic_comfort_message_audio_media_type_list |OCI.periodicComfortMessageAudioMediaTypeList |periodicComfortMessageAudioMediaTypeList *Optional* |
|periodic_comfort_video_message_selection       |str                                          |periodicComfortVideoMessageSelection *Optional*     |
|periodic_comfort_message_video_url_list        |OCI.periodicComfortMessageVideoUrlList       |periodicComfortMessageVideoUrlList *Optional*       |
|periodic_comfort_message_video_file_list       |OCI.periodicComfortMessageVideoFileList      |periodicComfortMessageVideoFileList *Optional*      |
|periodic_comfort_message_video_media_type_list |OCI.periodicComfortMessageVideoMediaTypeList |periodicComfortMessageVideoMediaTypeList *Optional* |
|enable_media_on_hold_for_queued_calls          |bool                                         |enableMediaOnHoldForQueuedCalls                     |
|media_on_hold_source                           |OCI.mediaOnHoldSource                        |mediaOnHoldSource                                   |
|play_whisper_message                           |bool                                         |playWhisperMessage                                  |
|whisper_audio_message_selection                |str                                          |whisperAudioMessageSelection                        |
|whisper_message_audio_url_list                 |OCI.whisperMessageAudioUrlList               |whisperMessageAudioUrlList *Optional*               |
|whisper_message_audio_file_list                |OCI.whisperMessageAudioFileList              |whisperMessageAudioFileList *Optional*              |
|whisper_message_audio_media_type_list          |OCI.whisperMessageAudioMediaTypeList         |whisperMessageAudioMediaTypeList *Optional*         |
|whisper_video_message_selection                |str                                          |whisperVideoMessageSelection *Optional*             |
|whisper_message_video_url_list                 |OCI.whisperMessageVideoUrlList               |whisperMessageVideoUrlList *Optional*               |
|whisper_message_video_file_list                |OCI.whisperMessageVideoFileList              |whisperMessageVideoFileList *Optional*              |
|whisper_message_video_media_type_list          |OCI.whisperMessageVideoMediaTypeList         |whisperMessageVideoMediaTypeList *Optional*         |
|estimated_wait_message_options_read            |OCI.estimatedWaitMessageOptionsRead          |estimatedWaitMessageOptionsRead                     |
</div>


## `GroupCallCenterGetDNISAnnouncementResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetDNISAnnouncementRequest20()`.


**Attributes:**

|Name                                     |Type                                    |Description                                     |
|-----------------------------------------|----------------------------------------|------------------------------------------------|
|play_entrance_message                    |bool                                    |playEntranceMessage                             |
|mandatory_entrance_message               |bool                                    |mandatoryEntranceMessage                        |
|entrance_audio_message_selection         |str                                     |entranceAudioMessageSelection                   |
|entrance_message_audio_url_list          |OCI.entranceMessageAudioUrlList         |entranceMessageAudioUrlList *Optional*          |
|entrance_message_audio_file_list         |OCI.entranceMessageAudioFileList        |entranceMessageAudioFileList *Optional*         |
|entrance_video_message_selection         |str                                     |entranceVideoMessageSelection *Optional*        |
|entrance_message_video_url_list          |OCI.entranceMessageVideoUrlList         |entranceMessageVideoUrlList *Optional*          |
|entrance_message_video_file_list         |OCI.entranceMessageVideoFileList        |entranceMessageVideoFileList *Optional*         |
|play_periodic_comfort_message            |bool                                    |playPeriodicComfortMessage                      |
|time_between_comfort_messages_seconds    |int                                     |timeBetweenComfortMessagesSeconds               |
|periodic_comfort_audio_message_selection |str                                     |periodicComfortAudioMessageSelection            |
|periodic_comfort_message_audio_url_list  |OCI.periodicComfortMessageAudioUrlList  |periodicComfortMessageAudioUrlList *Optional*   |
|periodic_comfort_message_audio_file_list |OCI.periodicComfortMessageAudioFileList |periodicComfortMessageAudioFileList *Optional*  |
|periodic_comfort_video_message_selection |str                                     |periodicComfortVideoMessageSelection *Optional* |
|periodic_comfort_message_video_url_list  |OCI.periodicComfortMessageVideoUrlList  |periodicComfortMessageVideoUrlList *Optional*   |
|periodic_comfort_message_video_file_list |OCI.periodicComfortMessageVideoFileList |periodicComfortMessageVideoFileList *Optional*  |
|enable_media_on_hold_for_queued_calls    |bool                                    |enableMediaOnHoldForQueuedCalls                 |
|media_on_hold_source                     |OCI.mediaOnHoldSource                   |mediaOnHoldSource                               |
|play_whisper_message                     |bool                                    |playWhisperMessage                              |
|whisper_audio_message_selection          |str                                     |whisperAudioMessageSelection                    |
|whisper_message_audio_url_list           |OCI.whisperMessageAudioUrlList          |whisperMessageAudioUrlList *Optional*           |
|whisper_message_audio_file_list          |OCI.whisperMessageAudioFileList         |whisperMessageAudioFileList *Optional*          |
|whisper_video_message_selection          |str                                     |whisperVideoMessageSelection *Optional*         |
|whisper_message_video_url_list           |OCI.whisperMessageVideoUrlList          |whisperMessageVideoUrlList *Optional*           |
|whisper_message_video_file_list          |OCI.whisperMessageVideoFileList         |whisperMessageVideoFileList *Optional*          |
|estimated_wait_message_options_read      |OCI.estimatedWaitMessageOptionsRead     |estimatedWaitMessageOptionsRead                 |
</div>


## `GroupCallCenterGetDNISAnnouncementResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupCallCenterGetDNISAnnouncementRequest22()`.


**Attributes:**

|Name                                     |Type                                    |Description                                     |
|-----------------------------------------|----------------------------------------|------------------------------------------------|
|play_entrance_message                    |bool                                    |playEntranceMessage                             |
|mandatory_entrance_message               |bool                                    |mandatoryEntranceMessage                        |
|entrance_audio_message_selection         |str                                     |entranceAudioMessageSelection                   |
|entrance_message_audio_url_list          |OCI.entranceMessageAudioUrlList         |entranceMessageAudioUrlList *Optional*          |
|entrance_message_audio_file_list         |OCI.entranceMessageAudioFileList        |entranceMessageAudioFileList *Optional*         |
|entrance_video_message_selection         |str                                     |entranceVideoMessageSelection *Optional*        |
|entrance_message_video_url_list          |OCI.entranceMessageVideoUrlList         |entranceMessageVideoUrlList *Optional*          |
|entrance_message_video_file_list         |OCI.entranceMessageVideoFileList        |entranceMessageVideoFileList *Optional*         |
|play_periodic_comfort_message            |bool                                    |playPeriodicComfortMessage                      |
|time_between_comfort_messages_seconds    |int                                     |timeBetweenComfortMessagesSeconds               |
|periodic_comfort_audio_message_selection |str                                     |periodicComfortAudioMessageSelection            |
|periodic_comfort_message_audio_url_list  |OCI.periodicComfortMessageAudioUrlList  |periodicComfortMessageAudioUrlList *Optional*   |
|periodic_comfort_message_audio_file_list |OCI.periodicComfortMessageAudioFileList |periodicComfortMessageAudioFileList *Optional*  |
|periodic_comfort_video_message_selection |str                                     |periodicComfortVideoMessageSelection *Optional* |
|periodic_comfort_message_video_url_list  |OCI.periodicComfortMessageVideoUrlList  |periodicComfortMessageVideoUrlList *Optional*   |
|periodic_comfort_message_video_file_list |OCI.periodicComfortMessageVideoFileList |periodicComfortMessageVideoFileList *Optional*  |
|enable_media_on_hold_for_queued_calls    |bool                                    |enableMediaOnHoldForQueuedCalls                 |
|media_on_hold_source                     |OCI.mediaOnHoldSource                   |mediaOnHoldSource                               |
|play_whisper_message                     |bool                                    |playWhisperMessage                              |
|whisper_audio_message_selection          |str                                     |whisperAudioMessageSelection                    |
|whisper_message_audio_url_list           |OCI.whisperMessageAudioUrlList          |whisperMessageAudioUrlList *Optional*           |
|whisper_message_audio_file_list          |OCI.whisperMessageAudioFileList         |whisperMessageAudioFileList *Optional*          |
|whisper_video_message_selection          |str                                     |whisperVideoMessageSelection *Optional*         |
|whisper_message_video_url_list           |OCI.whisperMessageVideoUrlList          |whisperMessageVideoUrlList *Optional*           |
|whisper_message_video_file_list          |OCI.whisperMessageVideoFileList         |whisperMessageVideoFileList *Optional*          |
|estimated_wait_message_options_read      |OCI.estimatedWaitMessageOptionsRead     |estimatedWaitMessageOptionsRead                 |
</div>


## `GroupOutgoingCallingPlanDigitPlanCallMeNowGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanDigitPlanCallMeNowGetListRequest()`.


**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanDigitPlanOriginatingGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanDigitPlanOriginatingGetListRequest()`.


**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanDigitPlanRedirectingGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanDigitPlanRedirectingGetListRequest()`.


**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPlanCallMeNowGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanPinholeDigitPlanCallMeNowGetListRequest()`.


**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPlanOriginatingGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanPinholeDigitPlanOriginatingGetListRequest()`.


**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPlanRedirectingGetListResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupOutgoingCallingPlanPinholeDigitPlanRedirectingGetListRequest()`.


**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupRoutePointGetAnnouncementResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointGetAnnouncementRequest()`.


**Attributes:**

|Name                 |Type                  |Description       |
|---------------------|----------------------|------------------|
|media_on_hold_source |OCI.mediaOnHoldSource |mediaOnHoldSource |
</div>


## `GroupRoutePointGetAnnouncementResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointGetAnnouncementRequest19()`.


**Attributes:**

|Name                 |Type                  |Description       |
|---------------------|----------------------|------------------|
|media_on_hold_source |OCI.mediaOnHoldSource |mediaOnHoldSource |
</div>


## `GroupRoutePointGetAnnouncementResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointGetAnnouncementRequest20()`.


**Attributes:**

|Name                 |Type                  |Description       |
|---------------------|----------------------|------------------|
|media_on_hold_source |OCI.mediaOnHoldSource |mediaOnHoldSource |
</div>


## `GroupRoutePointGetAnnouncementResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointGetAnnouncementRequest22()`.


**Attributes:**

|Name                 |Type                  |Description       |
|---------------------|----------------------|------------------|
|media_on_hold_source |OCI.mediaOnHoldSource |mediaOnHoldSource |
</div>


## `GroupRoutePointGetDNISAnnouncementResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointGetDNISAnnouncementRequest()`.


**Attributes:**

|Name                 |Type                  |Description       |
|---------------------|----------------------|------------------|
|media_on_hold_source |OCI.mediaOnHoldSource |mediaOnHoldSource |
</div>


## `GroupRoutePointGetDNISAnnouncementResponse19`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointGetDNISAnnouncementRequest19()`.


**Attributes:**

|Name                 |Type                  |Description       |
|---------------------|----------------------|------------------|
|media_on_hold_source |OCI.mediaOnHoldSource |mediaOnHoldSource |
</div>


## `GroupRoutePointGetDNISAnnouncementResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointGetDNISAnnouncementRequest20()`.


**Attributes:**

|Name                 |Type                  |Description       |
|---------------------|----------------------|------------------|
|media_on_hold_source |OCI.mediaOnHoldSource |mediaOnHoldSource |
</div>


## `GroupRoutePointGetDNISAnnouncementResponse22`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to the `GroupRoutePointGetDNISAnnouncementRequest22()`.


**Attributes:**

|Name                 |Type                  |Description       |
|---------------------|----------------------|------------------|
|media_on_hold_source |OCI.mediaOnHoldSource |mediaOnHoldSource |
</div>


## `UserCallCenterEnhancedReportingScheduledReportGetResponse`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserCallCenterEnhancedReportingScheduledReportGetRequest()`.


**Attributes:**

|Name                               |Type                       |Description                                |
|-----------------------------------|---------------------------|-------------------------------------------|
|description                        |str                        |description *Optional*                     |
|report_template                    |OCI.reportTemplate         |reportTemplate                             |
|schedule                           |OCI.schedule               |schedule                                   |
|sampling_period                    |str                        |samplingPeriod *Optional*                  |
|start_day_of_week                  |str                        |startDayOfWeek *Optional*                  |
|report_time_zone                   |str                        |reportTimeZone                             |
|report_date_format                 |str                        |reportDateFormat                           |
|report_time_format                 |str                        |reportTimeFormat                           |
|report_interval                    |OCI.reportInterval         |reportInterval                             |
|report_format                      |str                        |reportFormat                               |
|agent                              |OCI.agent                  |agent *Optional*                           |
|call_center                        |OCI.callCenter             |callCenter *Optional*                      |
|dnis                               |OCI.dnis                   |dnis *Optional*                            |
|call_completion_threshold_seconds  |int                        |callCompletionThresholdSeconds *Optional*  |
|short_duration_threshold_seconds   |int                        |shortDurationThresholdSeconds *Optional*   |
|service_level_threshold_seconds    |List[int]                  |serviceLevelThresholdSeconds *Optional*    |
|service_level_inclusions           |OCI.serviceLevelInclusions |serviceLevelInclusions *Optional*          |
|service_level_objective_percentage |int                        |serviceLevelObjectivePercentage *Optional* |
|abandoned_call_threshold_seconds   |List[int]                  |abandonedCallThresholdSeconds *Optional*   |
|email_address                      |List[str]                  |emailAddress                               |
</div>


## `UserGetResponse22V5`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest22V5()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following data elements are only used
in AS data mode and not returned in XS data mode: contact[2]-contact[5] userId
nameDialingName alternateUserId resellerId The following data elements are only used
in XS data mode: alternateTrunkIdentityDomain The following data elements are only
used in AS data mode: userId resellerId The following data elements are only used in
XS data mode: alternateTrunkIdentityDomain allowVideo, value "true" is returned in AS
data mode.  The userId returned in this response is the user's primary userId and may
not be the userId passed in the request.  The country code (countryCode) included is
the user's phone number country code when the user has a phone number assigned, or the
user's Group associated country code when the user does not have a phone number
assigned, or the system default country code when the user's Group does not have an
associated country code.  The nationalPrefix in this response is the one associated to
the included countryCode.  The callingLineIdPhoneNumber is no longer being formatted
for display purpose.  The value is returned exactly the same as being stored.
Replaced by: `UserGetResponse22V6()`

**Attributes:**

|Name                         |Type                      |Description                         |
|-----------------------------|--------------------------|------------------------------------|
|service_provider_id          |str                       |serviceProviderId                   |
|group_id                     |str                       |groupId                             |
|user_id                      |str                       |userId                              |
|last_name                    |str                       |lastName                            |
|first_name                   |str                       |firstName                           |
|calling_line_id_last_name    |str                       |callingLineIdLastName               |
|calling_line_id_first_name   |str                       |callingLineIdFirstName              |
|name_dialing_name            |OCI.nameDialingName       |nameDialingName *Optional*          |
|hiragana_last_name           |str                       |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                       |hiraganaFirstName *Optional*        |
|phone_number                 |str                       |phoneNumber *Optional*              |
|extension                    |str                       |extension *Optional*                |
|calling_line_id_phone_number |str                       |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department            |department *Optional*               |
|department_full_path         |str                       |departmentFullPath *Optional*       |
|language                     |str                       |language                            |
|time_zone                    |str                       |timeZone                            |
|time_zone_display_name       |str                       |timeZoneDisplayName                 |
|default_alias                |str                       |defaultAlias                        |
|alias                        |List[str]                 |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint  |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing       |trunkAddressing *Optional*          |
|title                        |str                       |title *Optional*                    |
|pager_phone_number           |str                       |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                       |mobilePhoneNumber *Optional*        |
|email_address                |str                       |emailAddress *Optional*             |
|yahoo_id                     |str                       |yahooId *Optional*                  |
|address_location             |str                       |addressLocation *Optional*          |
|address                      |OCI.address               |address *Optional*                  |
|country_code                 |str                       |countryCode                         |
|national_prefix              |str                       |nationalPrefix *Optional*           |
|network_class_of_service     |str                       |networkClassOfService *Optional*    |
|office_zone_name             |str                       |officeZoneName *Optional*           |
|primary_zone_name            |str                       |primaryZoneName *Optional*          |
|imp_id                       |str                       |impId *Optional*                    |
|alternate_user_id            |List[OCI.alternateUserId] |alternateUserId *Optional*          |
|allow_video                  |bool                      |allowVideo                          |
|reseller_id                  |str                       |resellerId *Optional*               |
</div>


## `UserGetResponse22V6`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest22V6()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following data elements are only used
in AS data mode and not returned in XS data mode: contact[2]-contact[5] userId
nameDialingName alternateUserId resellerId The following data elements are only used
in XS data mode: alternateTrunkIdentityDomain The following data elements are only
used in AS data mode: userId resellerId The following data elements are only used in
XS data mode: alternateTrunkIdentityDomain allowVideo, value "true" is returned in AS
data mode.  The userId returned in this response is the user's primary userId and may
not be the userId passed in the request.  The country code (countryCode) included is
the user's phone number country code when the user has a phone number assigned, or the
user's Group associated country code when the user does not have a phone number
assigned, or the system default country code when the user's Group does not have an
associated country code.  The nationalPrefix in this response is the one associated to
the included countryCode.  The callingLineIdPhoneNumber is no longer being formatted
for display purpose.  The value is returned exactly the same as being stored.
Replaced by: `UserGetResponse22V7()`

**Attributes:**

|Name                         |Type                      |Description                         |
|-----------------------------|--------------------------|------------------------------------|
|service_provider_id          |str                       |serviceProviderId                   |
|group_id                     |str                       |groupId                             |
|user_id                      |str                       |userId                              |
|last_name                    |str                       |lastName                            |
|first_name                   |str                       |firstName                           |
|calling_line_id_last_name    |str                       |callingLineIdLastName               |
|calling_line_id_first_name   |str                       |callingLineIdFirstName              |
|name_dialing_name            |OCI.nameDialingName       |nameDialingName *Optional*          |
|hiragana_last_name           |str                       |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                       |hiraganaFirstName *Optional*        |
|phone_number                 |str                       |phoneNumber *Optional*              |
|extension                    |str                       |extension *Optional*                |
|calling_line_id_phone_number |str                       |callingLineIdPhoneNumber *Optional* |
|department                   |OCI.department            |department *Optional*               |
|department_full_path         |str                       |departmentFullPath *Optional*       |
|language                     |str                       |language                            |
|time_zone                    |str                       |timeZone                            |
|time_zone_display_name       |str                       |timeZoneDisplayName                 |
|default_alias                |str                       |defaultAlias                        |
|alias                        |List[str]                 |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint  |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing       |trunkAddressing *Optional*          |
|title                        |str                       |title *Optional*                    |
|pager_phone_number           |str                       |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                       |mobilePhoneNumber *Optional*        |
|email_address                |str                       |emailAddress *Optional*             |
|yahoo_id                     |str                       |yahooId *Optional*                  |
|address_location             |str                       |addressLocation *Optional*          |
|address                      |OCI.address               |address *Optional*                  |
|country_code                 |str                       |countryCode                         |
|national_prefix              |str                       |nationalPrefix *Optional*           |
|network_class_of_service     |str                       |networkClassOfService *Optional*    |
|office_zone_name             |str                       |officeZoneName *Optional*           |
|primary_zone_name            |str                       |primaryZoneName *Optional*          |
|imp_id                       |str                       |impId *Optional*                    |
|alternate_user_id            |List[OCI.alternateUserId] |alternateUserId *Optional*          |
|allow_video                  |bool                      |allowVideo                          |
|reseller_id                  |str                       |resellerId *Optional*               |
</div>


## `UserGetResponse22V7`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest22V7()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following data elements are only used
in AS data mode and not returned in XS data mode: contact[2]-contact[5] userId
nameDialingName alternateUserId resellerId serviceProviderExternalId groupExternalId
userExternalId The following data elements are only used in XS data mode:
alternateTrunkIdentityDomain The following data elements are only used in AS data
mode: userId resellerId The following data elements are only used in XS data mode:
alternateTrunkIdentityDomain allowVideo, value "true" is returned in AS data mode.
The userId returned in this response is the user's primary userId and may not be the
userId passed in the request.  The country code (countryCode) included is the user's
phone number country code when the user has a phone number assigned, or the user's
Group associated country code when the user does not have a phone number assigned, or
the system default country code when the user's Group does not have an associated
country code.  The nationalPrefix in this response is the one associated to the
included countryCode.  The callingLineIdPhoneNumber is no longer being formatted for
display purpose.  The value is returned exactly the same as being stored.

**Attributes:**

|Name                         |Type                      |Description                          |
|-----------------------------|--------------------------|-------------------------------------|
|service_provider_id          |str                       |serviceProviderId                    |
|group_id                     |str                       |groupId                              |
|user_id                      |str                       |userId                               |
|last_name                    |str                       |lastName                             |
|first_name                   |str                       |firstName                            |
|calling_line_id_last_name    |str                       |callingLineIdLastName                |
|calling_line_id_first_name   |str                       |callingLineIdFirstName               |
|name_dialing_name            |OCI.nameDialingName       |nameDialingName *Optional*           |
|hiragana_last_name           |str                       |hiraganaLastName *Optional*          |
|hiragana_first_name          |str                       |hiraganaFirstName *Optional*         |
|phone_number                 |str                       |phoneNumber *Optional*               |
|extension                    |str                       |extension *Optional*                 |
|calling_line_id_phone_number |str                       |callingLineIdPhoneNumber *Optional*  |
|department                   |OCI.department            |department *Optional*                |
|department_full_path         |str                       |departmentFullPath *Optional*        |
|language                     |str                       |language                             |
|time_zone                    |str                       |timeZone                             |
|time_zone_display_name       |str                       |timeZoneDisplayName                  |
|default_alias                |str                       |defaultAlias                         |
|alias                        |List[str]                 |alias *Optional*                     |
|access_device_endpoint       |OCI.accessDeviceEndpoint  |accessDeviceEndpoint *Optional*      |
|trunk_addressing             |OCI.trunkAddressing       |trunkAddressing *Optional*           |
|title                        |str                       |title *Optional*                     |
|pager_phone_number           |str                       |pagerPhoneNumber *Optional*          |
|mobile_phone_number          |str                       |mobilePhoneNumber *Optional*         |
|email_address                |str                       |emailAddress *Optional*              |
|yahoo_id                     |str                       |yahooId *Optional*                   |
|address_location             |str                       |addressLocation *Optional*           |
|address                      |OCI.address               |address *Optional*                   |
|country_code                 |str                       |countryCode                          |
|national_prefix              |str                       |nationalPrefix *Optional*            |
|network_class_of_service     |str                       |networkClassOfService *Optional*     |
|office_zone_name             |str                       |officeZoneName *Optional*            |
|primary_zone_name            |str                       |primaryZoneName *Optional*           |
|imp_id                       |str                       |impId *Optional*                     |
|alternate_user_id            |List[OCI.alternateUserId] |alternateUserId *Optional*           |
|allow_video                  |bool                      |allowVideo                           |
|reseller_id                  |str                       |resellerId *Optional*                |
|service_provider_external_id |str                       |serviceProviderExternalId *Optional* |
|group_external_id            |str                       |groupExternalId *Optional*           |
|user_external_id             |str                       |userExternalId *Optional*            |
</div>


## `UserGetResponse22V8`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserGetRequest22V8()`.

It is possible that the TrunkAddressingRead element is present with nothing populated
in it which means the user is a trunk user.  The following data elements are only used
in AS data mode and not returned in XS data mode: contact[2]-contact[5] userId
nameDialingName alternateUserId resellerId serviceProviderExternalId groupExternalId
userExternalId The following data elements are only used in XS data mode:
alternateTrunkIdentityDomain The following data elements are only used in AS data
mode: userId resellerId The following data elements are only used in XS data mode:
alternateTrunkIdentityDomain allowVideo, value "true" is returned in AS data mode.
The userId returned in this response is the user's primary userId and may not be the
userId passed in the request.  The country code (countryCode) included is the user's
phone number country code when the user has a phone number assigned, or the user's
Group associated country code when the user does not have a phone number assigned, or
the system default country code when the user's Group does not have an associated
country code.  The nationalPrefix in this response is the one associated to the
included countryCode.  The callingLineIdPhoneNumber is no longer being formatted for
display purpose.  The value is returned exactly the same as being stored.

**Attributes:**

|Name                         |Type                      |Description                          |
|-----------------------------|--------------------------|-------------------------------------|
|service_provider_id          |str                       |serviceProviderId                    |
|group_id                     |str                       |groupId                              |
|user_id                      |str                       |userId                               |
|last_name                    |str                       |lastName                             |
|first_name                   |str                       |firstName                            |
|calling_line_id_last_name    |str                       |callingLineIdLastName                |
|calling_line_id_first_name   |str                       |callingLineIdFirstName               |
|name_dialing_name            |OCI.nameDialingName       |nameDialingName *Optional*           |
|hiragana_last_name           |str                       |hiraganaLastName *Optional*          |
|hiragana_first_name          |str                       |hiraganaFirstName *Optional*         |
|phone_number                 |str                       |phoneNumber *Optional*               |
|extension                    |str                       |extension *Optional*                 |
|calling_line_id_phone_number |str                       |callingLineIdPhoneNumber *Optional*  |
|department                   |OCI.department            |department *Optional*                |
|department_full_path         |str                       |departmentFullPath *Optional*        |
|language                     |str                       |language                             |
|time_zone                    |str                       |timeZone                             |
|time_zone_display_name       |str                       |timeZoneDisplayName                  |
|default_alias                |str                       |defaultAlias                         |
|alias                        |List[str]                 |alias *Optional*                     |
|access_device_endpoint       |OCI.accessDeviceEndpoint  |accessDeviceEndpoint *Optional*      |
|trunk_addressing             |OCI.trunkAddressing       |trunkAddressing *Optional*           |
|title                        |str                       |title *Optional*                     |
|pager_phone_number           |str                       |pagerPhoneNumber *Optional*          |
|mobile_phone_number          |str                       |mobilePhoneNumber *Optional*         |
|email_address                |str                       |emailAddress *Optional*              |
|yahoo_id                     |str                       |yahooId *Optional*                   |
|address_location             |str                       |addressLocation *Optional*           |
|address                      |OCI.address               |address *Optional*                   |
|country_code                 |str                       |countryCode                          |
|national_prefix              |str                       |nationalPrefix *Optional*            |
|network_class_of_service     |str                       |networkClassOfService *Optional*     |
|office_zone_name             |str                       |officeZoneName *Optional*            |
|primary_zone_name            |str                       |primaryZoneName *Optional*           |
|imp_id                       |str                       |impId *Optional*                     |
|alternate_user_id            |List[OCI.alternateUserId] |alternateUserId *Optional*           |
|allow_video                  |bool                      |allowVideo                           |
|reseller_id                  |str                       |resellerId *Optional*                |
|service_provider_external_id |str                       |serviceProviderExternalId *Optional* |
|group_external_id            |str                       |groupExternalId *Optional*           |
|user_external_id             |str                       |userExternalId *Optional*            |
</div>


## `UserPushNotificationRegistrationGetListResponse21sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `UserPushNotificationRegistrationGetListRequest21sp1()`.

A registration has more than one row in the response when the registration includes
more than one token and/or one or more event.  There can be one more tokens per
registration ID and there can be one or more events per token.  Registration Date uses
the format "yyyy-MM-dd'T'HH:mm:ss.SSSZ" in the time zone of the requested user.
Example: 2010-10-01T09:30:00:000-0400.

**Attributes:**

|Name                                |Type                                       |Description                                 |
|------------------------------------|-------------------------------------------|--------------------------------------------|
|user_id                             |str                                        |userId                                      |
|push_notification_registration_data |List[OCI.pushNotificationRegistrationData] |pushNotificationRegistrationData *Optional* |
</div>


## `GroupAutoAttendantGetInstanceResponse14`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAutoAttendantGetInstanceRequest14()`.

Contains the service profile information.

Replaced By: `GroupAutoAttendantGetInstanceResponse16()`

**Attributes:**

|Name                     |Type                       |Description                    |
|-------------------------|---------------------------|-------------------------------|
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile         |
|enable_video             |bool                       |enableVideo                    |
|business_hours           |str                        |businessHours *Optional*       |
|holiday_schedule_name    |str                        |holidayScheduleName *Optional* |
|extension_dialing_scope  |str                        |extensionDialingScope          |
|name_dialing_scope       |str                        |nameDialingScope               |
|name_dialing_entries     |str                        |nameDialingEntries             |
|business_hours_menu      |OCI.businessHoursMenu      |businessHoursMenu              |
|after_hours_menu         |OCI.afterHoursMenu         |afterHoursMenu                 |
</div>


## `GroupAutoAttendantGetInstanceResponse16`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAutoAttendantGetInstanceRequest16()`.

Contains the service profile information.

**Attributes:**

|Name                     |Type                       |Description                    |
|-------------------------|---------------------------|-------------------------------|
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile         |
|enable_video             |bool                       |enableVideo                    |
|business_hours           |str                        |businessHours *Optional*       |
|holiday_schedule_name    |str                        |holidayScheduleName *Optional* |
|extension_dialing_scope  |str                        |extensionDialingScope          |
|name_dialing_scope       |str                        |nameDialingScope               |
|name_dialing_entries     |str                        |nameDialingEntries             |
|business_hours_menu      |OCI.businessHoursMenu      |businessHoursMenu              |
|after_hours_menu         |OCI.afterHoursMenu         |afterHoursMenu                 |
</div>


## `GroupAutoAttendantGetInstanceResponse17`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAutoAttendantGetInstanceRequest17()`.

Contains the service profile information.

**Attributes:**

|Name                     |Type                       |Description                    |
|-------------------------|---------------------------|-------------------------------|
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile         |
|enable_video             |bool                       |enableVideo                    |
|business_hours           |str                        |businessHours *Optional*       |
|holiday_schedule_name    |str                        |holidayScheduleName *Optional* |
|extension_dialing_scope  |str                        |extensionDialingScope          |
|name_dialing_scope       |str                        |nameDialingScope               |
|name_dialing_entries     |str                        |nameDialingEntries             |
|business_hours_menu      |OCI.businessHoursMenu      |businessHoursMenu              |
|after_hours_menu         |OCI.afterHoursMenu         |afterHoursMenu                 |
</div>


## `GroupAutoAttendantGetInstanceResponse17sp1`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAutoAttendantGetInstanceRequest17sp1()`.

Contains the service profile information.

**Attributes:**

|Name                     |Type                       |Description                |
|-------------------------|---------------------------|---------------------------|
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile     |
|enable_video             |bool                       |enableVideo                |
|business_hours           |OCI.businessHours          |businessHours *Optional*   |
|holiday_schedule         |OCI.holidaySchedule        |holidaySchedule *Optional* |
|extension_dialing_scope  |str                        |extensionDialingScope      |
|name_dialing_scope       |str                        |nameDialingScope           |
|name_dialing_entries     |str                        |nameDialingEntries         |
|business_hours_menu      |OCI.businessHoursMenu      |businessHoursMenu          |
|after_hours_menu         |OCI.afterHoursMenu         |afterHoursMenu             |
</div>


## `GroupAutoAttendantGetInstanceResponse20`([`OCIResponse`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIResponse))

<div class="doc-contents" markdown="1">
Response to `GroupAutoAttendantGetInstanceRequest20()`.

Contains the service profile information.  The following elements are only used in AS
data mode: type, use AutoAttendantType.BASIC in XS mode.  holidayMenu.  The following
elements are only valid for Standard Auto Attendants: holidayMenu

**Attributes:**

|Name                        |Type                       |Description                      |
|----------------------------|---------------------------|---------------------------------|
|service_instance_profile    |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|type                        |str                        |type                             |
|first_digit_timeout_seconds |int                        |firstDigitTimeoutSeconds         |
|enable_video                |bool                       |enableVideo                      |
|business_hours              |OCI.businessHours          |businessHours *Optional*         |
|holiday_schedule            |OCI.holidaySchedule        |holidaySchedule *Optional*       |
|extension_dialing_scope     |str                        |extensionDialingScope            |
|name_dialing_scope          |str                        |nameDialingScope                 |
|name_dialing_entries        |str                        |nameDialingEntries               |
|business_hours_menu         |OCI.businessHoursMenu      |businessHoursMenu                |
|after_hours_menu            |OCI.afterHoursMenu         |afterHoursMenu                   |
|holiday_menu                |OCI.holidayMenu            |holidayMenu *Optional*           |
|network_class_of_service    |str                        |networkClassOfService *Optional* |
</div>
